/* -------------------------------------------------------------------------- *
 *                 Simbody(tm) Example: Amy's IK Problem                      *
 * -------------------------------------------------------------------------- *
 * This is part of the SimTK biosimulation toolkit originating from           *
 * Simbios, the NIH National Center for Physics-Based Simulation of           *
 * Biological Structures at Stanford, funded under the NIH Roadmap for        *
 * Medical Research, grant U54 GM072970. See https://simtk.org/home/simbody.  *
 *                                                                            *
 * Portions copyright (c) 2010-12 Stanford University and the Authors.        *
 * Authors: Michael Sherman                                                   *
 * Contributors:                                                              *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may    *
 * not use this file except in compliance with the License. You may obtain a  *
 * copy of the License at http://www.apache.org/licenses/LICENSE-2.0.         *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 * -------------------------------------------------------------------------- */

/* This is a test of repeated Assembly analysis, also known as 
InverseKinematics (IK). The problem is from a 56 dof OpenSim model built by Amy 
Silder in Scott Delp's lab. The model was read from various OpenSim data
files and machine-translated into a standalone C++ Simbody model during the 
development of the Assembler study. There are "markers" (distinguished points)
on many of the bodies, and many frames of laboratory data giving sequentially-
observed positions of these markers. The idea is to solve for the set of q's
in each frame that pose the bodies so that their attached marker positions
are a best fit for the observed data. Sequential frames are expected to be
spatially close. 

There is some commented-out code below for playing with various ways
of handling constraints.
*/


#include "Simbody.h"

#include <cstdio>
#include <exception>

using std::cout; using std::cin; using std::endl;

using namespace SimTK;

static int getNumFrames();
static int getNumObservations();
static Real getFrameTime(int i);
static const char* const* getObservationOrder();
static ArrayViewConst_<Vec3> getFrame(int i);

int main() {
  try
  { // Create the system.
    
    MultibodySystem         system;
    SimbodyMatterSubsystem  matter(system);
    GeneralForceSubsystem   forces(system);
    Force::UniformGravity   gravity(forces, matter, Vec3(0, -9.8, 0));

// BODY ground
Markers& markers = *new Markers();
DecorativeGeometry markerDecoration = DecorativeSphere(0.1).setColor(Blue);
MobilizedBody& mobod_ground = matter.updGround();
// END BODY ground


// Kludge to get the initial view large enough.
mobod_ground.addBodyDecoration(Vec3(-1,-1,-1), markerDecoration);
mobod_ground.addBodyDecoration(Vec3(1,1,1), markerDecoration);

// BODY loadcell1
Body::Rigid body_loadcell1(MassProperties(0,Vec3(0),Inertia(0,0,0)));
// Joint name is gnd_loadcell1
MobilizedBody::Free mobod_loadcell1(mobod_ground,Vec3(0), body_loadcell1,Vec3(0));
// END BODY loadcell1

// BODY loadcell2
Body::Rigid body_loadcell2(MassProperties(0,Vec3(0),Inertia(0,0,0)));
// Joint name is gnd_loadcell2
MobilizedBody::Free mobod_loadcell2(mobod_ground,Vec3(0), body_loadcell2,Vec3(0));
// END BODY loadcell2

// BODY pelvis
Body::Rigid body_pelvis(MassProperties(8.3775,Vec3(-0.0893,-0.025796,0),Inertia(0.0595677,0.128085,0.139644,-0.0192983,0,0)));
body_pelvis.addDecoration(Vec3(-.1,0,0),DecorativeEllipsoid(Vec3(.1,.06,.15)).setColor(Cyan));
// Joint name is gnd_pelvis
MobilizedBody::Free mobod_pelvis(mobod_ground,Vec3(0), body_pelvis,Vec3(0));
markers.addMarker("S2",mobod_pelvis,Vec3(-0.2,0,0),1);
body_pelvis.addDecoration(Vec3(-0.2,0,0),markerDecoration);
markers.addMarker("R.ASIS",mobod_pelvis,Vec3(0.01,0,0.128),1);
body_pelvis.addDecoration(Vec3(0.01,0,0.128),markerDecoration);
markers.addMarker("R.Iliac",mobod_pelvis,Vec3(-0.08,0.06,0.15),1);
body_pelvis.addDecoration(Vec3(-0.08,0.06,0.15),markerDecoration);
markers.addMarker("R.PSIS",mobod_pelvis,Vec3(-0.2,0,0.055),1);
body_pelvis.addDecoration(Vec3(-0.2,0,0.055),markerDecoration);
markers.addMarker("L.ASIS",mobod_pelvis,Vec3(0.01,0,-0.128),1);
body_pelvis.addDecoration(Vec3(0.01,0,-0.128),markerDecoration);
markers.addMarker("L.Iliac",mobod_pelvis,Vec3(-0.08,0.06,-0.15),1);
body_pelvis.addDecoration(Vec3(-0.08,0.06,-0.15),markerDecoration);
markers.addMarker("L.PSIS",mobod_pelvis,Vec3(-0.2,0,-0.055),1);
body_pelvis.addDecoration(Vec3(-0.2,0,-0.055),markerDecoration);
markers.addMarker("R_HJC",mobod_pelvis,Vec3(-0.08,-0.0824,0.0785),1);
body_pelvis.addDecoration(Vec3(-0.08,-0.0824,0.0785),markerDecoration);
markers.addMarker("L_HJC",mobod_pelvis,Vec3(-0.08,-0.0824,-0.0785),1);
body_pelvis.addDecoration(Vec3(-0.08,-0.0824,-0.0785),markerDecoration);
// END BODY pelvis

// BODY torso
Body::Rigid body_torso(MassProperties(24.2175,Vec3(0.0145,0.256438,0),Inertia(2.03337,0.281964,2.19416,-0.0900492,0,0)));
body_torso.addDecoration(Vec3(0,.25,0), DecorativeBrick(Vec3(.08,.3,.165)).setColor(Green).setOpacity(.2));
// Joint name is pelvis_torso
MobilizedBody::Ball mobod_torso(mobod_pelvis,Vec3(-0.0872,0.0331,0), body_torso,Vec3(0));
markers.addMarker("R.Clavicle",mobod_torso,Vec3(0.035,0.43,0.025),1);
body_torso.addDecoration(Vec3(0.035,0.43,0.025),markerDecoration);
markers.addMarker("L.Clavicle",mobod_torso,Vec3(0.035,0.43,-0.025),1);
body_torso.addDecoration(Vec3(0.035,0.43,-0.025),markerDecoration);
markers.addMarker("L.Scapula",mobod_torso,Vec3(-0.12,-0.1,0.08),1);
body_torso.addDecoration(Vec3(-0.12,-0.1,0.08),markerDecoration);
markers.addMarker("R.Shoulder",mobod_torso,Vec3(-0.0488,0.47065,0.165),1);
body_torso.addDecoration(Vec3(-0.0488,0.47065,0.165),markerDecoration);
markers.addMarker("L.Shoulder",mobod_torso,Vec3(-0.0488,0.47065,-0.165),1);
body_torso.addDecoration(Vec3(-0.0488,0.47065,-0.165),markerDecoration);
// END BODY torso

// BODY neckhead
Body::Rigid body_neckhead(MassProperties(5.205,Vec3(0.0288,0.161501,0),Inertia(0.166231,0.0252372,0.168272,-0.0242096,0,0)));
body_neckhead.addDecoration(Vec3(0.0288,0.161501,0), DecorativeSphere(.12).setColor(Yellow));
// Joint name is torso_neckhead
MobilizedBody::Ball mobod_neckhead(mobod_torso,Vec3(-0.0253,0.44895,0), body_neckhead,Vec3(0));
markers.addMarker("C7",mobod_neckhead,Vec3(0),1);
body_neckhead.addDecoration(Vec3(0),markerDecoration);
// END BODY neckhead

// BODY humerus_r
Body::Rigid body_humerus_r(MassProperties(2.0325,Vec3(0,-0.164502,0),Inertia(0.0669473,0.004121,0.0684103)));
body_humerus_r.addDecoration(Vec3(0,-.15,0), DecorativeEllipsoid(Vec3(.05,.3,.05)).setColor(Yellow));
// Joint name is acromial_r
MobilizedBody::Ball mobod_humerus_r(mobod_torso,Vec3(-0.0281,0.41645,0.199), body_humerus_r,Vec3(0));
markers.addMarker("R.Bicep",mobod_humerus_r,Vec3(0.04,-0.15,0),1);
body_humerus_r.addDecoration(Vec3(0.04,-0.15,0),markerDecoration);
markers.addMarker("R.Elbow",mobod_humerus_r,Vec3(-0.01,-0.281,0.04),1);
body_humerus_r.addDecoration(Vec3(-0.01,-0.281,0.04),markerDecoration);
markers.addMarker("R.MElbow",mobod_humerus_r,Vec3(0,-0.281,-0.04),1);
body_humerus_r.addDecoration(Vec3(0,-0.281,-0.04),markerDecoration);
// END BODY humerus_r

// BODY ulna_r
Body::Rigid body_ulna_r(MassProperties(0.6075,Vec3(0,-0.120525,0),Inertia(0.0117867,0.000618,0.0120377)));
body_ulna_r.addDecoration(Vec3(0,-.15,0), DecorativeEllipsoid(Vec3(.03,.3,.03)).setColor(Yellow));
// Joint name is elbow_r
MobilizedBody::Pin mobod_ulna_r(mobod_humerus_r,Vec3(0.013144,-0.286273,-0.009595), body_ulna_r,Vec3(0));
markers.addMarker("R.Forearm",mobod_ulna_r,Vec3(0,-0.15,0),1);
body_ulna_r.addDecoration(Vec3(0,-0.15,0),markerDecoration);
// END BODY ulna_r

// BODY radius_r
Body::Rigid body_radius_r(MassProperties(0.6075,Vec3(0,-0.120525,0),Inertia(0.0117867,0.000618,0.0120377)));
// Joint name is radioulnar_r
MobilizedBody::Pin mobod_radius_r(mobod_ulna_r,Vec3(-0.006727,-0.013007,0.026083), body_radius_r,Vec3(0));
markers.addMarker("R.Wrist",mobod_radius_r,Vec3(-0.025,-0.245,0.006),1);
body_radius_r.addDecoration(Vec3(-0.025,-0.245,0.006),markerDecoration);
// END BODY radius_r

// BODY hand_r
Body::Rigid body_hand_r(MassProperties(0.4575,Vec3(0,-0.068095,0),Inertia(0.0030134,0.000547,0.0034614)));
// Joint name is radius_hand_r
MobilizedBody::Pin mobod_hand_r(mobod_radius_r,Vec3(-0.008797,-0.235841,0.01361), body_hand_r,Vec3(0));
// END BODY hand_r

// BODY humerus_l
Body::Rigid body_humerus_l(MassProperties(2.0325,Vec3(0,-0.164502,0),Inertia(0.0669473,0.004121,0.0684103)));
body_humerus_l.addDecoration(Vec3(0,-.15,0), DecorativeEllipsoid(Vec3(.05,.3,.05)).setColor(Yellow));
// Joint name is acromial_l
MobilizedBody::Ball mobod_humerus_l(mobod_torso,Vec3(-0.0281,0.41645,-0.199), body_humerus_l,Vec3(0));
markers.addMarker("L.Bicep",mobod_humerus_l,Vec3(0.04,-0.15,0),1);
body_humerus_l.addDecoration(Vec3(0.04,-0.15,0),markerDecoration);
markers.addMarker("L.Elbow",mobod_humerus_l,Vec3(0.01,-0.281,-0.04),1);
body_humerus_l.addDecoration(Vec3(0.01,-0.281,-0.04),markerDecoration);
markers.addMarker("L.MElbow",mobod_humerus_l,Vec3(-0.02,-0.281,0.04),1);
body_humerus_l.addDecoration(Vec3(-0.02,-0.281,0.04),markerDecoration);
// END BODY humerus_l

// BODY ulna_l
Body::Rigid body_ulna_l(MassProperties(0.6075,Vec3(0,-0.120525,0),Inertia(0.0117867,0.000618,0.0120377)));
body_ulna_l.addDecoration(Vec3(0,-.15,0), DecorativeEllipsoid(Vec3(.03,.3,.03)).setColor(Yellow));
// Joint name is elbow_l
MobilizedBody::Pin mobod_ulna_l(mobod_humerus_l,Vec3(0.013144,-0.286273,0.009595), body_ulna_l,Vec3(0));
markers.addMarker("L.Forearm",mobod_ulna_l,Vec3(0,-0.15,0),1);
body_ulna_l.addDecoration(Vec3(0,-0.15,0),markerDecoration);
// END BODY ulna_l

// BODY radius_l
Body::Rigid body_radius_l(MassProperties(0.6075,Vec3(0,-0.120525,0),Inertia(0.0117867,0.000618,0.0120377)));
// Joint name is radioulnar_l
MobilizedBody::Pin mobod_radius_l(mobod_ulna_l,Vec3(-0.006727,-0.013007,-0.026083), body_radius_l,Vec3(0));
markers.addMarker("L.Wrist",mobod_radius_l,Vec3(-0.025,-0.245,-0.006),1);
body_radius_l.addDecoration(Vec3(-0.025,-0.245,-0.006),markerDecoration);
// END BODY radius_l

// BODY hand_l
Body::Rigid body_hand_l(MassProperties(0.4575,Vec3(0,-0.068095,0),Inertia(0.0030134,0.000547,0.0034614)));
// Joint name is radius_hand_l
MobilizedBody::Pin mobod_hand_l(mobod_radius_l,Vec3(-0.008797,-0.235841,-0.01361), body_hand_l,Vec3(0));
// END BODY hand_l

// BODY femur_r
Body::Rigid body_femur_r(MassProperties(10.5225,Vec3(0,-0.162162,0),Inertia(0.455313,0.036634,0.455313)));
body_femur_r.addDecoration(Vec3(0,-.2,0), DecorativeEllipsoid(Vec3(.08,.2,.1)).setColor(Yellow));
// Joint name is hip_r
MobilizedBody::Ball mobod_femur_r(mobod_pelvis,Vec3(-0.08,-0.0824,0.0785), body_femur_r,Vec3(0));
markers.addMarker("R.Knee",mobod_femur_r,Vec3(0,-0.404,0.05),1);
body_femur_r.addDecoration(Vec3(0,-0.404,0.05),markerDecoration);
markers.addMarker("R.MKnee",mobod_femur_r,Vec3(0,-0.404,-0.05),1);
body_femur_r.addDecoration(Vec3(0,-0.404,-0.05),markerDecoration);
markers.addMarker("R.TH1",mobod_femur_r,Vec3(0.0179,-0.224,0.1147),1);
body_femur_r.addDecoration(Vec3(0.0179,-0.224,0.1147),markerDecoration);
markers.addMarker("R.TH2",mobod_femur_r,Vec3(0.0179,-0.264,0.0647),1);
body_femur_r.addDecoration(Vec3(0.0179,-0.264,0.0647),markerDecoration);
markers.addMarker("R.TH3",mobod_femur_r,Vec3(0.0179,-0.264,0.0647),1);
body_femur_r.addDecoration(Vec3(0.0179,-0.264,0.0647),markerDecoration);
markers.addMarker("R.TH4",mobod_femur_r,Vec3(0.08,-0.324,0.0047),1);
body_femur_r.addDecoration(Vec3(0.08,-0.324,0.0047),markerDecoration);
// END BODY femur_r

// BODY tibia_r
Body::Rigid body_tibia_r(MassProperties(3.2475,Vec3(0,-0.171713,0),Inertia(0.125753,0.005157,0.126985)));
body_tibia_r.addDecoration(Vec3(0,-.2,0), DecorativeEllipsoid(Vec3(.05,.2,.07)).setColor(Yellow));
// Joint name is knee_r
MobilizedBody::Pin mobod_tibia_r(mobod_femur_r,Vec3(0,-.4,0), body_tibia_r,Vec3(0));
markers.addMarker("R.Ankle",mobod_tibia_r,Vec3(-0.005,-0.41,0.053),1);
body_tibia_r.addDecoration(Vec3(-0.005,-0.41,0.053),markerDecoration);
markers.addMarker("R.MAnkle",mobod_tibia_r,Vec3(0.006,-0.3888,-0.038),1);
body_tibia_r.addDecoration(Vec3(0.006,-0.3888,-0.038),markerDecoration);
markers.addMarker("R.SH1",mobod_tibia_r,Vec3(0.0104,-0.2322,0.0748),1);
body_tibia_r.addDecoration(Vec3(0.0104,-0.2322,0.0748),markerDecoration);
markers.addMarker("R.SH2",mobod_tibia_r,Vec3(0.0125,-0.3196,0.06),1);
body_tibia_r.addDecoration(Vec3(0.0125,-0.3196,0.06),markerDecoration);
markers.addMarker("R.SH3",mobod_tibia_r,Vec3(0.0125,-0.3196,0.06),1);
body_tibia_r.addDecoration(Vec3(0.0125,-0.3196,0.06),markerDecoration);
markers.addMarker("R.SH4",mobod_tibia_r,Vec3(0.0125,-0.3196,0.06),1);
body_tibia_r.addDecoration(Vec3(0.0125,-0.3196,0.06),markerDecoration);
// END BODY tibia_r

// BODY patella_r
Body::Rigid body_patella_r(MassProperties(0.0975,Vec3(0.0018,0.0264,0),Inertia(7.09536e-005,1.53159e-005,8.32695e-005,-4.6332e-006,0,0)));
// Joint name is tib_pat_r
MobilizedBody::/*FourDOF*/Cartesian mobod_patella_r(mobod_tibia_r,Vec3(0), body_patella_r,Vec3(0));
// END BODY patella_r

// BODY talus_r
Body::Rigid body_talus_r(MassProperties(0.045,Vec3(0.0055,0.0023,0),Inertia(3.23805e-006,2.36125e-006,4.5993e-006,-5.6925e-007,0,0)));
// Joint name is ankle_r
MobilizedBody::Pin mobod_talus_r(mobod_tibia_r,Vec3(0,-0.426,0), body_talus_r,Vec3(0));
// END BODY talus_r

// BODY foot_r
Body::Rigid body_foot_r(MassProperties(0.885,Vec3(0.101865,0.0156,0),Inertia(0.00112437,0.0114972,0.0120816,-0.00140635,0,0)));
// Joint name is subtalar_r
MobilizedBody::Pin mobod_foot_r(mobod_talus_r,Vec3(-0.04877,-0.04195,0.00792), body_foot_r,Vec3(0));
markers.addMarker("R.Toe",mobod_foot_r,Vec3(0.19,0.018,0),1);
body_foot_r.addDecoration(Vec3(0.19,0.018,0),markerDecoration);
markers.addMarker("R.MT1",mobod_foot_r,Vec3(0.2,0.005,-0.045),1);
body_foot_r.addDecoration(Vec3(0.2,0.005,-0.045),markerDecoration);
markers.addMarker("R.MT5",mobod_foot_r,Vec3(0.15,0.005,0.055),1);
body_foot_r.addDecoration(Vec3(0.15,0.005,0.055),markerDecoration);
markers.addMarker("R.Heel",mobod_foot_r,Vec3(-0.03,0.018,-0.01),1);
body_foot_r.addDecoration(Vec3(-0.03,0.018,-0.01),markerDecoration);
// END BODY foot_r

// BODY toes_r
Body::Rigid body_toes_r(MassProperties(0.0975,Vec3(0.0307,-0.0026,0.0105),Inertia(0.000111408,0.000357642,0.000386552,7.78245e-006,-3.14291e-005,2.66175e-006)));
// Joint name is toes_r
MobilizedBody::Pin mobod_toes_r(mobod_foot_r,Vec3(0.1768,-0.002,0.00108), body_toes_r,Vec3(0));
// END BODY toes_r

// BODY femur_l
Body::Rigid body_femur_l(MassProperties(10.5225,Vec3(0,-0.162162,0),Inertia(0.455313,0.036634,0.455313)));
body_femur_l.addDecoration(Vec3(0,-.2,0), DecorativeEllipsoid(Vec3(.08,.2,.1)).setColor(Yellow));
// Joint name is hip_l
MobilizedBody::Ball mobod_femur_l(mobod_pelvis,Vec3(-0.08,-0.0824,-0.0785), body_femur_l,Vec3(0));
markers.addMarker("L.Knee",mobod_femur_l,Vec3(0,-0.404,-0.05),1);
body_femur_l.addDecoration(Vec3(0,-0.404,-0.05),markerDecoration);
markers.addMarker("L.MKnee",mobod_femur_l,Vec3(0,-0.404,0.05),1);
body_femur_l.addDecoration(Vec3(0,-0.404,0.05),markerDecoration);
markers.addMarker("L.TH1",mobod_femur_l,Vec3(0.0179,-0.224,-0.1147),1);
body_femur_l.addDecoration(Vec3(0.0179,-0.224,-0.1147),markerDecoration);
markers.addMarker("L.TH2",mobod_femur_l,Vec3(0.0179,-0.224,-0.1147),1);
body_femur_l.addDecoration(Vec3(0.0179,-0.224,-0.1147),markerDecoration);
markers.addMarker("L.TH3",mobod_femur_l,Vec3(0.0179,-0.264,-0.0647),1);
body_femur_l.addDecoration(Vec3(0.0179,-0.264,-0.0647),markerDecoration);
markers.addMarker("L.TH4",mobod_femur_l,Vec3(0.08,-0.324,-0.0047),1);
body_femur_l.addDecoration(Vec3(0.08,-0.324,-0.0047),markerDecoration);
// END BODY femur_l

// BODY tibia_l
Body::Rigid body_tibia_l(MassProperties(3.2475,Vec3(0,-0.171713,0),Inertia(0.125753,0.005157,0.126985)));
body_tibia_l.addDecoration(Vec3(0,-.2,0), DecorativeEllipsoid(Vec3(.05,.2,.07)).setColor(Yellow));
// Joint name is knee_l
MobilizedBody::Pin mobod_tibia_l(mobod_femur_l,Vec3(0,-.4,0), body_tibia_l,Vec3(0));
markers.addMarker("L.Ankle",mobod_tibia_l,Vec3(-0.005,-0.41,-0.053),1);
body_tibia_l.addDecoration(Vec3(-0.005,-0.41,-0.053),markerDecoration);
markers.addMarker("L.MAnkle",mobod_tibia_l,Vec3(0.006,-0.3888,0.038),1);
body_tibia_l.addDecoration(Vec3(0.006,-0.3888,0.038),markerDecoration);
markers.addMarker("L.SH1",mobod_tibia_l,Vec3(0.0104,-0.2322,-0.0748),1);
body_tibia_l.addDecoration(Vec3(0.0104,-0.2322,-0.0748),markerDecoration);
markers.addMarker("L.SH2",mobod_tibia_l,Vec3(0.0425,-0.3596,0),1);
body_tibia_l.addDecoration(Vec3(0.0425,-0.3596,0),markerDecoration);
markers.addMarker("L.SH3",mobod_tibia_l,Vec3(0.0125,-0.3196,-0.06),1);
body_tibia_l.addDecoration(Vec3(0.0125,-0.3196,-0.06),markerDecoration);
markers.addMarker("L.SH4",mobod_tibia_l,Vec3(0.0125,-0.3196,-0.06),1);
body_tibia_l.addDecoration(Vec3(0.0125,-0.3196,-0.06),markerDecoration);
// END BODY tibia_l

// BODY patella_l
Body::Rigid body_patella_l(MassProperties(0.0975,Vec3(0.0018,0.0264,0),Inertia(7.09536e-005,1.53159e-005,8.32695e-005,-4.6332e-006,0,0)));
// Joint name is tib_pat_l
MobilizedBody::/*FourDOF*/Cartesian mobod_patella_l(mobod_tibia_l,Vec3(0), body_patella_l,Vec3(0));
// END BODY patella_l

// BODY talus_l
Body::Rigid body_talus_l(MassProperties(0.045,Vec3(0.0055,0.0023,0),Inertia(3.23805e-006,2.36125e-006,4.5993e-006,-5.6925e-007,0,0)));
// Joint name is ankle_l
MobilizedBody::Pin mobod_talus_l(mobod_tibia_l,Vec3(0,-0.426,0), body_talus_l,Vec3(0));
// END BODY talus_l

// BODY foot_l
Body::Rigid body_foot_l(MassProperties(0.885,Vec3(0.101865,0.0156,0),Inertia(0.00112437,0.0114972,0.0120816,-0.00140635,0,0)));
// Joint name is subtalar_l
MobilizedBody::Pin mobod_foot_l(mobod_talus_l,Vec3(-0.04877,-0.04195,-0.00792), body_foot_l,Vec3(0));
markers.addMarker("L.Toe",mobod_foot_l,Vec3(0.19,0.018,0),1);
body_foot_l.addDecoration(Vec3(0.19,0.018,0),markerDecoration);
markers.addMarker("L.Heel",mobod_foot_l,Vec3(-0.03,0.018,0.01),1);
body_foot_l.addDecoration(Vec3(-0.03,0.018,0.01),markerDecoration);
markers.addMarker("L.MT1",mobod_foot_l,Vec3(0.2,0.005,0.045),1);
body_foot_l.addDecoration(Vec3(0.2,0.005,0.045),markerDecoration);
markers.addMarker("L.MT5",mobod_foot_l,Vec3(0.15,0.005,-0.055),1);
body_foot_l.addDecoration(Vec3(0.15,0.005,-0.055),markerDecoration);
// END BODY foot_l

// BODY toes_l
Body::Rigid body_toes_l(MassProperties(0.0975,Vec3(0.0307,-0.0026,-0.0105),Inertia(0.000111408,0.000357642,0.000386552,7.78245e-006,3.14291e-005,-2.66175e-006)));
// Joint name is toes_l
MobilizedBody::Pin mobod_toes_l(mobod_foot_l,Vec3(0.1768,-0.002,-0.00108), body_toes_l,Vec3(0));
// END BODY toes_l

// Here are some constraints you can try. If you have these enabled,
// you should experiment with treating these as constraints or as
// weighted errors merged with the IK objective. See call below for
// ik.setSystemConstraintsWeight(wt) where wt==Infinity is the default
// and handles these as constraints; wt==finite value treats constraint
// satisfaction as part of the objective.

//Constraint::Rod(mobod_tibia_l, mobod_tibia_r, 2*.25);
//Constraint::Rod(mobod_tibia_l, mobod_hand_r, .25);

    matter.setShowDefaultGeometry(false);
    Visualizer viz(system);
    system.addEventReporter(new Visualizer::Reporter(viz, 0.1));


    // Initialize the system and state.
    
    system.realizeTopology();
    State state = system.getDefaultState();

    // Show initial configuration
    viz.report(state);
    State tempState = state; 
    matter.setUseEulerAngles(tempState, true);
    system.realizeModel(tempState);
    system.realize(tempState, Stage::Position);
    cout << "INITIAL CONFIGURATION\n"; 
    cout << tempState.getNU() << " dofs, " 
         << tempState.getNQErr() << " constraints.\n";
    
    cout << "Type any character to continue:\n";
    getchar();


    Assembler ik(system);
    ik.adoptAssemblyGoal(&markers);

    //ik.adoptAssemblyGoal(new QValue(mobod_tibia_r, MobilizerQIndex(0),
    //                     Pi/2), 1);


    // See comment above near the Constraints. If you use this
    // weight the constraints will be violated somewhat but the
    // IK will run much faster.
    //ik.setSystemConstraintsWeight(2);

    // This is the default treatment of constraints.
    //ik.setSystemConstraintsWeight(Infinity);

    ik.lockMobilizer(mobod_patella_l);
    ik.lockMobilizer(mobod_patella_r);
    ik.lockMobilizer(mobod_loadcell1);
    ik.lockMobilizer(mobod_loadcell2);
    //ik.restrictQ(mobod_tibia_r, MobilizerQIndex(0),
    //    -10*Pi/180, 10*Pi/180);

    markers.defineObservationOrder(getNumObservations(), getObservationOrder());
    markers.moveAllObservations(getFrame(0)); // initial observed locations
    state.setTime(getFrameTime(0));
    //ik.setForceNumericalGradient(true);
    //ik.setForceNumericalJacobian(true);

    ik.initialize(state);
    printf("UNASSEMBLED CONFIGURATION (err=%g, cost=%g, qerr=%g)\n",
        ik.calcCurrentErrorNorm(), ik.calcCurrentGoal(),
        max(abs(ik.getInternalState().getQErr())));
    cout << "num freeQs: " << ik.getNumFreeQs() << endl;

    const Real Accuracy = 1e-3;
    ik.setAccuracy(Accuracy);
    ik.assemble(); // solve first frame.
    ik.updateFromInternalState(state);
    viz.report(state);
    printf("ASSEMBLED CONFIGURATION (acc=%g tol=%g err=%g, cost=%g, qerr=%g)\n",
        ik.getAccuracyInUse(), ik.getErrorToleranceInUse(), 
        ik.calcCurrentErrorNorm(), ik.calcCurrentGoal(),
        max(abs(ik.getInternalState().getQErr())));
    printf("# initializations=%d\n", ik.getNumInitializations());
    printf("# assembly steps: %d\n", ik.getNumAssemblySteps());
    printf(" evals: goal=%d grad=%d error=%d jac=%d\n",
        ik.getNumGoalEvals(), ik.getNumGoalGradientEvals(),
        ik.getNumErrorEvals(), ik.getNumErrorJacobianEvals());

    cout << "Type any character to continue:\n";
    getchar();

    const int NSteps = getNumFrames();
    const int NToSkip = 4; // show every nth frame
    const double startReal = realTime(), startCPU = cpuTime();
    for (int f=1; f < NSteps; ++f) {
        markers.moveAllObservations(getFrame(f));
        // update internal state to match new observed locations
        ik.track(getFrameTime(f)); 
        if ((f%NToSkip)==0) {
            ik.updateFromInternalState(state);
            viz.report(state);
        }
    }

    cout << "ASSEMBLED " << NSteps-1 << " steps in " <<
        cpuTime()-startCPU << " CPU s, " << realTime()-startReal << " REAL s\n";

    printf("FINAL CONFIGURATION (acc=%g tol=%g err=%g, cost=%g, qerr=%g)\n",
        ik.getAccuracyInUse(), ik.getErrorToleranceInUse(), 
        ik.calcCurrentErrorNorm(), ik.calcCurrentGoal(),
        max(abs(ik.getInternalState().getQErr())));

    const double oons = Real(1)/ik.getNumAssemblySteps();
    printf("# initializations=%d\n", ik.getNumInitializations());
    printf("# assembly steps: %d\n", ik.getNumAssemblySteps());
    printf("  avg evals: goal=%g grad=%g error=%g jac=%g\n",
        ik.getNumGoalEvals()*oons, ik.getNumGoalGradientEvals()*oons,
        ik.getNumErrorEvals()*oons, ik.getNumErrorJacobianEvals()*oons);


    cout << "DONE ASSEMBLING\n";
    viz.report(state);

    cout << "Type any character to continue:\n";
    getchar();
   
  } catch (const std::exception& e) {
    std::printf("EXCEPTION THROWN: %s\n", e.what());
    exit(1);

  } catch (...) {
    std::printf("UNKNOWN EXCEPTION THROWN\n");
    exit(1);
  }

    return 0;
}

/* Below here is the marker observation data at 200Hz. */

static const int NObservations = 44;
static const int NFrames       = 2105;
static Real frameTimes[NFrames] = {
/*0*/0,0.005,0.01,0.015,0.02,0.025,0.03,0.035,0.04,0.045,0.05,0.055,0.06,0.065,0.07,0.075,0.08,0.085,0.09,0.095,
/*20*/0.1,0.105,0.11,0.115,0.12,0.125,0.13,0.135,0.14,0.145,0.15,0.155,0.16,0.165,0.17,0.175,0.18,0.185,0.19,0.195,
/*40*/0.2,0.205,0.21,0.215,0.22,0.225,0.23,0.235,0.24,0.245,0.25,0.255,0.26,0.265,0.27,0.275,0.28,0.285,0.29,0.295,
/*60*/0.3,0.305,0.31,0.315,0.32,0.325,0.33,0.335,0.34,0.345,0.35,0.355,0.36,0.365,0.37,0.375,0.38,0.385,0.39,0.395,
/*80*/0.4,0.405,0.41,0.415,0.42,0.425,0.43,0.435,0.44,0.445,0.45,0.455,0.46,0.465,0.47,0.475,0.48,0.485,0.49,0.495,
/*100*/0.5,0.505,0.51,0.515,0.52,0.525,0.53,0.535,0.54,0.545,0.55,0.555,0.56,0.565,0.57,0.575,0.58,0.585,0.59,0.595,
/*120*/0.6,0.605,0.61,0.615,0.62,0.625,0.63,0.635,0.64,0.645,0.65,0.655,0.66,0.665,0.67,0.675,0.68,0.685,0.69,0.695,
/*140*/0.7,0.705,0.71,0.715,0.72,0.725,0.73,0.735,0.74,0.745,0.75,0.755,0.76,0.765,0.77,0.775,0.78,0.785,0.79,0.795,
/*160*/0.8,0.805,0.81,0.815,0.82,0.825,0.83,0.835,0.84,0.845,0.85,0.855,0.86,0.865,0.87,0.875,0.88,0.885,0.89,0.895,
/*180*/0.9,0.905,0.91,0.915,0.92,0.925,0.93,0.935,0.94,0.945,0.95,0.955,0.96,0.965,0.97,0.975,0.98,0.985,0.99,0.995,
/*200*/1,1.005,1.01,1.015,1.02,1.025,1.03,1.035,1.04,1.045,1.05,1.055,1.06,1.065,1.07,1.075,1.08,1.085,1.09,1.095,
/*220*/1.1,1.105,1.11,1.115,1.12,1.125,1.13,1.135,1.14,1.145,1.15,1.155,1.16,1.165,1.17,1.175,1.18,1.185,1.19,1.195,
/*240*/1.2,1.205,1.21,1.215,1.22,1.225,1.23,1.235,1.24,1.245,1.25,1.255,1.26,1.265,1.27,1.275,1.28,1.285,1.29,1.295,
/*260*/1.3,1.305,1.31,1.315,1.32,1.325,1.33,1.335,1.34,1.345,1.35,1.355,1.36,1.365,1.37,1.375,1.38,1.385,1.39,1.395,
/*280*/1.4,1.405,1.41,1.415,1.42,1.425,1.43,1.435,1.44,1.445,1.45,1.455,1.46,1.465,1.47,1.475,1.48,1.485,1.49,1.495,
/*300*/1.5,1.505,1.51,1.515,1.52,1.525,1.53,1.535,1.54,1.545,1.55,1.555,1.56,1.565,1.57,1.575,1.58,1.585,1.59,1.595,
/*320*/1.6,1.605,1.61,1.615,1.62,1.625,1.63,1.635,1.64,1.645,1.65,1.655,1.66,1.665,1.67,1.675,1.68,1.685,1.69,1.695,
/*340*/1.7,1.705,1.71,1.715,1.72,1.725,1.73,1.735,1.74,1.745,1.75,1.755,1.76,1.765,1.77,1.775,1.78,1.785,1.79,1.795,
/*360*/1.8,1.805,1.81,1.815,1.82,1.825,1.83,1.835,1.84,1.845,1.85,1.855,1.86,1.865,1.87,1.875,1.88,1.885,1.89,1.895,
/*380*/1.9,1.905,1.91,1.915,1.92,1.925,1.93,1.935,1.94,1.945,1.95,1.955,1.96,1.965,1.97,1.975,1.98,1.985,1.99,1.995,
/*400*/2,2.005,2.01,2.015,2.02,2.025,2.03,2.035,2.04,2.045,2.05,2.055,2.06,2.065,2.07,2.075,2.08,2.085,2.09,2.095,
/*420*/2.1,2.105,2.11,2.115,2.12,2.125,2.13,2.135,2.14,2.145,2.15,2.155,2.16,2.165,2.17,2.175,2.18,2.185,2.19,2.195,
/*440*/2.2,2.205,2.21,2.215,2.22,2.225,2.23,2.235,2.24,2.245,2.25,2.255,2.26,2.265,2.27,2.275,2.28,2.285,2.29,2.295,
/*460*/2.3,2.305,2.31,2.315,2.32,2.325,2.33,2.335,2.34,2.345,2.35,2.355,2.36,2.365,2.37,2.375,2.38,2.385,2.39,2.395,
/*480*/2.4,2.405,2.41,2.415,2.42,2.425,2.43,2.435,2.44,2.445,2.45,2.455,2.46,2.465,2.47,2.475,2.48,2.485,2.49,2.495,
/*500*/2.5,2.505,2.51,2.515,2.52,2.525,2.53,2.535,2.54,2.545,2.55,2.555,2.56,2.565,2.57,2.575,2.58,2.585,2.59,2.595,
/*520*/2.6,2.605,2.61,2.615,2.62,2.625,2.63,2.635,2.64,2.645,2.65,2.655,2.66,2.665,2.67,2.675,2.68,2.685,2.69,2.695,
/*540*/2.7,2.705,2.71,2.715,2.72,2.725,2.73,2.735,2.74,2.745,2.75,2.755,2.76,2.765,2.77,2.775,2.78,2.785,2.79,2.795,
/*560*/2.8,2.805,2.81,2.815,2.82,2.825,2.83,2.835,2.84,2.845,2.85,2.855,2.86,2.865,2.87,2.875,2.88,2.885,2.89,2.895,
/*580*/2.9,2.905,2.91,2.915,2.92,2.925,2.93,2.935,2.94,2.945,2.95,2.955,2.96,2.965,2.97,2.975,2.98,2.985,2.99,2.995,
/*600*/3,3.005,3.01,3.015,3.02,3.025,3.03,3.035,3.04,3.045,3.05,3.055,3.06,3.065,3.07,3.075,3.08,3.085,3.09,3.095,
/*620*/3.1,3.105,3.11,3.115,3.12,3.125,3.13,3.135,3.14,3.145,3.15,3.155,3.16,3.165,3.17,3.175,3.18,3.185,3.19,3.195,
/*640*/3.2,3.205,3.21,3.215,3.22,3.225,3.23,3.235,3.24,3.245,3.25,3.255,3.26,3.265,3.27,3.275,3.28,3.285,3.29,3.295,
/*660*/3.3,3.305,3.31,3.315,3.32,3.325,3.33,3.335,3.34,3.345,3.35,3.355,3.36,3.365,3.37,3.375,3.38,3.385,3.39,3.395,
/*680*/3.4,3.405,3.41,3.415,3.42,3.425,3.43,3.435,3.44,3.445,3.45,3.455,3.46,3.465,3.47,3.475,3.48,3.485,3.49,3.495,
/*700*/3.5,3.505,3.51,3.515,3.52,3.525,3.53,3.535,3.54,3.545,3.55,3.555,3.56,3.565,3.57,3.575,3.58,3.585,3.59,3.595,
/*720*/3.6,3.605,3.61,3.615,3.62,3.625,3.63,3.635,3.64,3.645,3.65,3.655,3.66,3.665,3.67,3.675,3.68,3.685,3.69,3.695,
/*740*/3.7,3.705,3.71,3.715,3.72,3.725,3.73,3.735,3.74,3.745,3.75,3.755,3.76,3.765,3.77,3.775,3.78,3.785,3.79,3.795,
/*760*/3.8,3.805,3.81,3.815,3.82,3.825,3.83,3.835,3.84,3.845,3.85,3.855,3.86,3.865,3.87,3.875,3.88,3.885,3.89,3.895,
/*780*/3.9,3.905,3.91,3.915,3.92,3.925,3.93,3.935,3.94,3.945,3.95,3.955,3.96,3.965,3.97,3.975,3.98,3.985,3.99,3.995,
/*800*/4,4.005,4.01,4.015,4.02,4.025,4.03,4.035,4.04,4.045,4.05,4.055,4.06,4.065,4.07,4.075,4.08,4.085,4.09,4.095,
/*820*/4.1,4.105,4.11,4.115,4.12,4.125,4.13,4.135,4.14,4.145,4.15,4.155,4.16,4.165,4.17,4.175,4.18,4.185,4.19,4.195,
/*840*/4.2,4.205,4.21,4.215,4.22,4.225,4.23,4.235,4.24,4.245,4.25,4.255,4.26,4.265,4.27,4.275,4.28,4.285,4.29,4.295,
/*860*/4.3,4.305,4.31,4.315,4.32,4.325,4.33,4.335,4.34,4.345,4.35,4.355,4.36,4.365,4.37,4.375,4.38,4.385,4.39,4.395,
/*880*/4.4,4.405,4.41,4.415,4.42,4.425,4.43,4.435,4.44,4.445,4.45,4.455,4.46,4.465,4.47,4.475,4.48,4.485,4.49,4.495,
/*900*/4.5,4.505,4.51,4.515,4.52,4.525,4.53,4.535,4.54,4.545,4.55,4.555,4.56,4.565,4.57,4.575,4.58,4.585,4.59,4.595,
/*920*/4.6,4.605,4.61,4.615,4.62,4.625,4.63,4.635,4.64,4.645,4.65,4.655,4.66,4.665,4.67,4.675,4.68,4.685,4.69,4.695,
/*940*/4.7,4.705,4.71,4.715,4.72,4.725,4.73,4.735,4.74,4.745,4.75,4.755,4.76,4.765,4.77,4.775,4.78,4.785,4.79,4.795,
/*960*/4.8,4.805,4.81,4.815,4.82,4.825,4.83,4.835,4.84,4.845,4.85,4.855,4.86,4.865,4.87,4.875,4.88,4.885,4.89,4.895,
/*980*/4.9,4.905,4.91,4.915,4.92,4.925,4.93,4.935,4.94,4.945,4.95,4.955,4.96,4.965,4.97,4.975,4.98,4.985,4.99,4.995,
/*1000*/5,5.005,5.01,5.015,5.02,5.025,5.03,5.035,5.04,5.045,5.05,5.055,5.06,5.065,5.07,5.075,5.08,5.085,5.09,5.095,
/*1020*/5.1,5.105,5.11,5.115,5.12,5.125,5.13,5.135,5.14,5.145,5.15,5.155,5.16,5.165,5.17,5.175,5.18,5.185,5.19,5.195,
/*1040*/5.2,5.205,5.21,5.215,5.22,5.225,5.23,5.235,5.24,5.245,5.25,5.255,5.26,5.265,5.27,5.275,5.28,5.285,5.29,5.295,
/*1060*/5.3,5.305,5.31,5.315,5.32,5.325,5.33,5.335,5.34,5.345,5.35,5.355,5.36,5.365,5.37,5.375,5.38,5.385,5.39,5.395,
/*1080*/5.4,5.405,5.41,5.415,5.42,5.425,5.43,5.435,5.44,5.445,5.45,5.455,5.46,5.465,5.47,5.475,5.48,5.485,5.49,5.495,
/*1100*/5.5,5.505,5.51,5.515,5.52,5.525,5.53,5.535,5.54,5.545,5.55,5.555,5.56,5.565,5.57,5.575,5.58,5.585,5.59,5.595,
/*1120*/5.6,5.605,5.61,5.615,5.62,5.625,5.63,5.635,5.64,5.645,5.65,5.655,5.66,5.665,5.67,5.675,5.68,5.685,5.69,5.695,
/*1140*/5.7,5.705,5.71,5.715,5.72,5.725,5.73,5.735,5.74,5.745,5.75,5.755,5.76,5.765,5.77,5.775,5.78,5.785,5.79,5.795,
/*1160*/5.8,5.805,5.81,5.815,5.82,5.825,5.83,5.835,5.84,5.845,5.85,5.855,5.86,5.865,5.87,5.875,5.88,5.885,5.89,5.895,
/*1180*/5.9,5.905,5.91,5.915,5.92,5.925,5.93,5.935,5.94,5.945,5.95,5.955,5.96,5.965,5.97,5.975,5.98,5.985,5.99,5.995,
/*1200*/6,6.005,6.01,6.015,6.02,6.025,6.03,6.035,6.04,6.045,6.05,6.055,6.06,6.065,6.07,6.075,6.08,6.085,6.09,6.095,
/*1220*/6.1,6.105,6.11,6.115,6.12,6.125,6.13,6.135,6.14,6.145,6.15,6.155,6.16,6.165,6.17,6.175,6.18,6.185,6.19,6.195,
/*1240*/6.2,6.205,6.21,6.215,6.22,6.225,6.23,6.235,6.24,6.245,6.25,6.255,6.26,6.265,6.27,6.275,6.28,6.285,6.29,6.295,
/*1260*/6.3,6.305,6.31,6.315,6.32,6.325,6.33,6.335,6.34,6.345,6.35,6.355,6.36,6.365,6.37,6.375,6.38,6.385,6.39,6.395,
/*1280*/6.4,6.405,6.41,6.415,6.42,6.425,6.43,6.435,6.44,6.445,6.45,6.455,6.46,6.465,6.47,6.475,6.48,6.485,6.49,6.495,
/*1300*/6.5,6.505,6.51,6.515,6.52,6.525,6.53,6.535,6.54,6.545,6.55,6.555,6.56,6.565,6.57,6.575,6.58,6.585,6.59,6.595,
/*1320*/6.6,6.605,6.61,6.615,6.62,6.625,6.63,6.635,6.64,6.645,6.65,6.655,6.66,6.665,6.67,6.675,6.68,6.685,6.69,6.695,
/*1340*/6.7,6.705,6.71,6.715,6.72,6.725,6.73,6.735,6.74,6.745,6.75,6.755,6.76,6.765,6.77,6.775,6.78,6.785,6.79,6.795,
/*1360*/6.8,6.805,6.81,6.815,6.82,6.825,6.83,6.835,6.84,6.845,6.85,6.855,6.86,6.865,6.87,6.875,6.88,6.885,6.89,6.895,
/*1380*/6.9,6.905,6.91,6.915,6.92,6.925,6.93,6.935,6.94,6.945,6.95,6.955,6.96,6.965,6.97,6.975,6.98,6.985,6.99,6.995,
/*1400*/7,7.005,7.01,7.015,7.02,7.025,7.03,7.035,7.04,7.045,7.05,7.055,7.06,7.065,7.07,7.075,7.08,7.085,7.09,7.095,
/*1420*/7.1,7.105,7.11,7.115,7.12,7.125,7.13,7.135,7.14,7.145,7.15,7.155,7.16,7.165,7.17,7.175,7.18,7.185,7.19,7.195,
/*1440*/7.2,7.205,7.21,7.215,7.22,7.225,7.23,7.235,7.24,7.245,7.25,7.255,7.26,7.265,7.27,7.275,7.28,7.285,7.29,7.295,
/*1460*/7.3,7.305,7.31,7.315,7.32,7.325,7.33,7.335,7.34,7.345,7.35,7.355,7.36,7.365,7.37,7.375,7.38,7.385,7.39,7.395,
/*1480*/7.4,7.405,7.41,7.415,7.42,7.425,7.43,7.435,7.44,7.445,7.45,7.455,7.46,7.465,7.47,7.475,7.48,7.485,7.49,7.495,
/*1500*/7.5,7.505,7.51,7.515,7.52,7.525,7.53,7.535,7.54,7.545,7.55,7.555,7.56,7.565,7.57,7.575,7.58,7.585,7.59,7.595,
/*1520*/7.6,7.605,7.61,7.615,7.62,7.625,7.63,7.635,7.64,7.645,7.65,7.655,7.66,7.665,7.67,7.675,7.68,7.685,7.69,7.695,
/*1540*/7.7,7.705,7.71,7.715,7.72,7.725,7.73,7.735,7.74,7.745,7.75,7.755,7.76,7.765,7.77,7.775,7.78,7.785,7.79,7.795,
/*1560*/7.8,7.805,7.81,7.815,7.82,7.825,7.83,7.835,7.84,7.845,7.85,7.855,7.86,7.865,7.87,7.875,7.88,7.885,7.89,7.895,
/*1580*/7.9,7.905,7.91,7.915,7.92,7.925,7.93,7.935,7.94,7.945,7.95,7.955,7.96,7.965,7.97,7.975,7.98,7.985,7.99,7.995,
/*1600*/8,8.005,8.01,8.015,8.02,8.025,8.03,8.035,8.04,8.045,8.05,8.055,8.06,8.065,8.07,8.075,8.08,8.085,8.09,8.095,
/*1620*/8.1,8.105,8.11,8.115,8.12,8.125,8.13,8.135,8.14,8.145,8.15,8.155,8.16,8.165,8.17,8.175,8.18,8.185,8.19,8.195,
/*1640*/8.2,8.205,8.21,8.215,8.22,8.225,8.23,8.235,8.24,8.245,8.25,8.255,8.26,8.265,8.27,8.275,8.28,8.285,8.29,8.295,
/*1660*/8.3,8.305,8.31,8.315,8.32,8.325,8.33,8.335,8.34,8.345,8.35,8.355,8.36,8.365,8.37,8.375,8.38,8.385,8.39,8.395,
/*1680*/8.4,8.405,8.41,8.415,8.42,8.425,8.43,8.435,8.44,8.445,8.45,8.455,8.46,8.465,8.47,8.475,8.48,8.485,8.49,8.495,
/*1700*/8.5,8.505,8.51,8.515,8.52,8.525,8.53,8.535,8.54,8.545,8.55,8.555,8.56,8.565,8.57,8.575,8.58,8.585,8.59,8.595,
/*1720*/8.6,8.605,8.61,8.615,8.62,8.625,8.63,8.635,8.64,8.645,8.65,8.655,8.66,8.665,8.67,8.675,8.68,8.685,8.69,8.695,
/*1740*/8.7,8.705,8.71,8.715,8.72,8.725,8.73,8.735,8.74,8.745,8.75,8.755,8.76,8.765,8.77,8.775,8.78,8.785,8.79,8.795,
/*1760*/8.8,8.805,8.81,8.815,8.82,8.825,8.83,8.835,8.84,8.845,8.85,8.855,8.86,8.865,8.87,8.875,8.88,8.885,8.89,8.895,
/*1780*/8.9,8.905,8.91,8.915,8.92,8.925,8.93,8.935,8.94,8.945,8.95,8.955,8.96,8.965,8.97,8.975,8.98,8.985,8.99,8.995,
/*1800*/9,9.005,9.01,9.015,9.02,9.025,9.03,9.035,9.04,9.045,9.05,9.055,9.06,9.065,9.07,9.075,9.08,9.085,9.09,9.095,
/*1820*/9.1,9.105,9.11,9.115,9.12,9.125,9.13,9.135,9.14,9.145,9.15,9.155,9.16,9.165,9.17,9.175,9.18,9.185,9.19,9.195,
/*1840*/9.2,9.205,9.21,9.215,9.22,9.225,9.23,9.235,9.24,9.245,9.25,9.255,9.26,9.265,9.27,9.275,9.28,9.285,9.29,9.295,
/*1860*/9.3,9.305,9.31,9.315,9.32,9.325,9.33,9.335,9.34,9.345,9.35,9.355,9.36,9.365,9.37,9.375,9.38,9.385,9.39,9.395,
/*1880*/9.4,9.405,9.41,9.415,9.42,9.425,9.43,9.435,9.44,9.445,9.45,9.455,9.46,9.465,9.47,9.475,9.48,9.485,9.49,9.495,
/*1900*/9.5,9.505,9.51,9.515,9.52,9.525,9.53,9.535,9.54,9.545,9.55,9.555,9.56,9.565,9.57,9.575,9.58,9.585,9.59,9.595,
/*1920*/9.6,9.605,9.61,9.615,9.62,9.625,9.63,9.635,9.64,9.645,9.65,9.655,9.66,9.665,9.67,9.675,9.68,9.685,9.69,9.695,
/*1940*/9.7,9.705,9.71,9.715,9.72,9.725,9.73,9.735,9.74,9.745,9.75,9.755,9.76,9.765,9.77,9.775,9.78,9.785,9.79,9.795,
/*1960*/9.8,9.805,9.81,9.815,9.82,9.825,9.83,9.835,9.84,9.845,9.85,9.855,9.86,9.865,9.87,9.875,9.88,9.885,9.89,9.895,
/*1980*/9.9,9.905,9.91,9.915,9.92,9.925,9.93,9.935,9.94,9.945,9.95,9.955,9.96,9.965,9.97,9.975,9.98,9.985,9.99,9.995,
/*2000*/10,10.005,10.01,10.015,10.02,10.025,10.03,10.035,10.04,10.045,10.05,10.055,10.06,10.065,10.07,10.075,10.08,10.085,10.09,10.095,
/*2020*/10.1,10.105,10.11,10.115,10.12,10.125,10.13,10.135,10.14,10.145,10.15,10.155,10.16,10.165,10.17,10.175,10.18,10.185,10.19,10.195,
/*2040*/10.2,10.205,10.21,10.215,10.22,10.225,10.23,10.235,10.24,10.245,10.25,10.255,10.26,10.265,10.27,10.275,10.28,10.285,10.29,10.295,
/*2060*/10.3,10.305,10.31,10.315,10.32,10.325,10.33,10.335,10.34,10.345,10.35,10.355,10.36,10.365,10.37,10.375,10.38,10.385,10.39,10.395,
/*2080*/10.4,10.405,10.41,10.415,10.42,10.425,10.43,10.435,10.44,10.445,10.45,10.455,10.46,10.465,10.47,10.475,10.48,10.485,10.49,10.495,
/*2100*/10.5,10.505,10.51,10.515,10.52
};
static const char* observationOrder[NObservations] = {
/*0*/"R.Shoulder","R.Clavicle","R.Bicep","R.Elbow","R.Forearm","R.Wrist","L.Shoulder","L.Clavicle","L.Scapula","L.Bicep",
/*10*/"L.Elbow","L.Forearm","L.Wrist","R.ASIS","R.PSIS","S2","L.PSIS","L.ASIS","R.TH1","R.TH2",
/*20*/"R.TH3","R.Knee","R.SH1","R.SH2","R.SH3","R.SH4","R.Ankle","R.Heel","R.MT1","R.MT5",
/*30*/"L.TH1","L.TH2","L.TH3","L.TH4","L.Knee","L.SH1","L.SH2","L.SH3","L.Ankle","L.Heel",
/*40*/"L.MT1","L.MT5","R_HJC","L_HJC"
};
static double observations[NFrames][3*NObservations] = {
/*0*/{0.090174,1.88432,-1.71703,0.183195,1.8414,-1.85736,-0.03272,1.75705,-1.63169,-0.124639,1.65522,-1.58515,0.018105,1.57584,-1.61167,0.095363,1.52367,-1.612,0.127943,1.92047,-2.10315,0.194393,1.84906,-1.93091,-0.009998,1.87655,-2.0326,-0.014027,1.71457,-2.22251,0.035047,1.62438,-2.26588,0.185972,1.57007,-2.14576,0.244882,1.53837,-2.14,0.108311,1.41565,-1.81786,-0.080276,1.47065,-1.89218,-0.075026,1.49623,-1.95279,-0.067967,1.46745,-2.00846,0.123187,1.40594,-2.07196,0.170297,1.12647,-1.75035,0.048508,1.07145,-1.78442,0.083181,0.995259,-1.80496,0.189256,0.912886,-1.78579,0.237219,0.726513,-1.77991,0.248158,0.652262,-1.79449,0.127715,0.709792,-1.80196,0.140083,0.639374,-1.81181,0.223738,0.423112,-1.8286,0.145578,0.35512,-1.91536,0.389378,0.414344,-1.85826,0.369371,0.347959,-1.79518,0.085408,1.08672,-2.11457,0.08914,1.00371,-2.09678,-0.054983,1.0813,-2.08294,-0.049952,1.00025,-2.06546,-0.021551,0.872819,-2.06933,-0.19154,0.812236,-2.06037,-0.193648,0.925116,-2.07387,-0.264475,0.919419,-2.06751,-0.487294,0.881914,-2.0409,-0.513099,0.983557,-1.98142,-0.618697,0.72077,-1.98067,-0.647563,0.774091,-2.03551,0.031863,1.32665,-1.82976,0.038375,1.31961,-2.04478},
/*1*/{0.091297,1.87806,-1.71564,0.182311,1.83703,-1.85764,-0.028513,1.74764,-1.62789,-0.118465,1.64442,-1.57894,0.025159,1.56849,-1.60827,0.103256,1.51788,-1.61005,0.126087,1.91504,-2.10347,0.193485,1.84336,-1.93154,-0.010839,1.87079,-2.03188,-0.020112,1.71092,-2.22225,0.028199,1.61943,-2.26571,0.17971,1.5599,-2.14963,0.237434,1.52621,-2.14531,0.107126,1.41214,-1.81599,-0.081285,1.46489,-1.8934,-0.07621,1.49056,-1.95294,-0.068882,1.46171,-2.00913,0.121952,1.401,-2.07248,0.168246,1.12131,-1.75028,0.046138,1.06706,-1.78509,0.080908,0.990501,-1.80488,0.184639,0.90639,-1.78596,0.229278,0.72023,-1.78174,0.23953,0.64616,-1.79634,0.118966,0.705653,-1.80378,0.128657,0.634755,-1.81369,0.209121,0.419185,-1.83021,0.123655,0.353672,-1.91521,0.373979,0.404006,-1.86016,0.350952,0.340743,-1.79787,0.090933,1.08275,-2.11412,0.096081,0.999049,-2.09626,-0.049201,1.07404,-2.08249,-0.042046,0.994004,-2.06538,-0.010775,0.867443,-2.06977,-0.180869,0.811455,-2.06146,-0.181582,0.924533,-2.07482,-0.251431,0.919956,-2.06733,-0.478855,0.890919,-2.04362,-0.500405,0.989962,-1.98289,-0.609456,0.727974,-1.98331,-0.642838,0.789095,-2.04123,0.031282,1.32239,-1.82912,0.03836,1.31418,-2.04408},
/*2*/{0.091335,1.87169,-1.71479,0.183083,1.82953,-1.85712,-0.023951,1.7383,-1.62404,-0.11091,1.63499,-1.57333,0.032871,1.5612,-1.60512,0.110852,1.51258,-1.60793,0.124791,1.90938,-2.10431,0.193996,1.83813,-1.93194,-0.012086,1.86576,-2.03137,-0.024299,1.70718,-2.2217,0.020478,1.61543,-2.26539,0.173088,1.54986,-2.15399,0.230455,1.51413,-2.15068,0.104805,1.40744,-1.81493,-0.083976,1.45985,-1.89355,-0.0781,1.48507,-1.9529,-0.069696,1.45639,-2.01053,0.121724,1.39661,-2.07049,0.164122,1.11498,-1.74983,0.042093,1.06248,-1.78534,0.077625,0.98602,-1.80517,0.178142,0.900235,-1.78648,0.221834,0.713953,-1.78405,0.22966,0.640235,-1.79881,0.110812,0.703157,-1.80525,0.119605,0.632032,-1.81396,0.191836,0.419832,-1.83335,0.10278,0.355621,-1.91511,0.356322,0.395949,-1.86564,0.331367,0.340436,-1.79931,0.096225,1.07895,-2.11492,0.103221,0.995321,-2.09644,-0.043438,1.0675,-2.08231,-0.034777,0.987421,-2.06562,0.000839,0.862208,-2.07096,-0.169381,0.810094,-2.062,-0.167271,0.922114,-2.0754,-0.237948,0.920033,-2.06772,-0.466303,0.896161,-2.04443,-0.488694,0.995061,-1.98287,-0.597545,0.733429,-1.98694,-0.629991,0.794214,-2.04519,0.029047,1.31749,-1.82856,0.03832,1.30941,-2.04344},
/*3*/{0.092087,1.86568,-1.71333,0.182831,1.82511,-1.85789,-0.01871,1.72901,-1.62038,-0.103618,1.62466,-1.56734,0.041183,1.55492,-1.60203,0.119592,1.50664,-1.60573,0.124153,1.90441,-2.10496,0.193549,1.83257,-1.9327,-0.01286,1.86058,-2.03072,-0.030531,1.70266,-2.22109,0.012698,1.61085,-2.26538,0.166654,1.53936,-2.15824,0.222259,1.50243,-2.15566,0.102622,1.40302,-1.81331,-0.086237,1.455,-1.89456,-0.07984,1.47883,-1.95377,-0.072053,1.45063,-2.01137,0.121167,1.39182,-2.06906,0.161441,1.11035,-1.74795,0.038014,1.05788,-1.78564,0.073335,0.982563,-1.80681,0.171976,0.894191,-1.78659,0.213772,0.710666,-1.78572,0.220346,0.637231,-1.80096,0.103499,0.703459,-1.80564,0.108837,0.631532,-1.81537,0.173975,0.420755,-1.83629,0.080526,0.355486,-1.91597,0.334785,0.393686,-1.86957,0.308578,0.341522,-1.80107,0.100994,1.0748,-2.11529,0.110248,0.99185,-2.0974,-0.038583,1.0601,-2.08139,-0.027802,0.980256,-2.06559,0.011933,0.856059,-2.07199,-0.158015,0.808797,-2.06279,-0.153527,0.920215,-2.07636,-0.223751,0.919911,-2.06808,-0.452295,0.900178,-2.04574,-0.47589,0.999844,-1.98461,-0.583499,0.737196,-1.99084,-0.616894,0.798704,-2.04833,0.02694,1.31293,-1.82776,0.038016,1.30404,-2.04252},
/*4*/{0.093353,1.85929,-1.71192,0.183228,1.81831,-1.85746,-0.012746,1.7196,-1.61667,-0.095804,1.61451,-1.56114,0.049678,1.54751,-1.59868,0.128215,1.5024,-1.60385,0.123235,1.89968,-2.10598,0.19428,1.82751,-1.93354,-0.01348,1.85534,-2.02912,-0.03415,1.69845,-2.22057,0.004914,1.60661,-2.26578,0.159918,1.53025,-2.16303,0.213638,1.49,-2.16112,0.098635,1.39922,-1.81269,-0.089307,1.45081,-1.89675,-0.082555,1.47378,-1.95558,-0.074797,1.44483,-2.01252,0.122134,1.38754,-2.06714,0.153185,1.10725,-1.74555,0.034798,1.05586,-1.78504,0.06885,0.980545,-1.80828,0.165422,0.887157,-1.78753,0.209076,0.710633,-1.7865,0.212711,0.635973,-1.80211,0.097576,0.706842,-1.80572,0.100599,0.635444,-1.81662,0.152744,0.421808,-1.83836,0.058849,0.356964,-1.91696,0.312235,0.391388,-1.87279,0.286349,0.34185,-1.80251,0.106219,1.07175,-2.11511,0.117692,0.988541,-2.09801,-0.033711,1.05294,-2.08134,-0.019602,0.973584,-2.06483,0.022909,0.85025,-2.07263,-0.145615,0.806616,-2.06285,-0.138032,0.917618,-2.07615,-0.209909,0.919131,-2.06918,-0.438381,0.903351,-2.04703,-0.462152,1.00206,-1.9863,-0.570126,0.739626,-1.99337,-0.601632,0.801662,-2.05235,0.023598,1.30901,-1.82732,0.037989,1.29931,-2.04186},
/*5*/{0.094187,1.85462,-1.71052,0.1833,1.81388,-1.85825,-0.005894,1.71058,-1.61324,-0.085588,1.60545,-1.55552,0.059256,1.54157,-1.59556,0.137858,1.49781,-1.60231,0.122382,1.89488,-2.10714,0.194885,1.8218,-1.93386,-0.01458,1.85216,-2.0276,-0.039699,1.6948,-2.22017,-0.002082,1.60262,-2.2655,0.152843,1.51995,-2.16763,0.204903,1.47882,-2.16672,0.095466,1.39565,-1.81297,-0.093194,1.44607,-1.89718,-0.086238,1.46806,-1.95603,-0.076539,1.43936,-2.01355,0.120146,1.38273,-2.0666,0.150597,1.10498,-1.74172,0.03075,1.05599,-1.78697,0.066093,0.979874,-1.80947,0.160098,0.884492,-1.78824,0.204794,0.709803,-1.78745,0.204792,0.635777,-1.80302,0.093495,0.711775,-1.80495,0.093403,0.640444,-1.81595,0.134256,0.424017,-1.84014,0.035955,0.358335,-1.91768,0.291155,0.391583,-1.87439,0.26462,0.340916,-1.80316,0.110673,1.06845,-2.11586,0.124507,0.98618,-2.09821,-0.028286,1.04648,-2.08203,-0.012102,0.966787,-2.06454,0.033904,0.84432,-2.07211,-0.132945,0.806003,-2.06418,-0.124792,0.916087,-2.07658,-0.195242,0.918672,-2.07047,-0.41867,0.902701,-2.04587,-0.449693,1.00489,-1.98884,-0.554652,0.741414,-1.99687,-0.586195,0.802536,-2.05568,0.02091,1.3049,-1.82694,0.03631,1.29427,-2.04136},
/*6*/{0.095729,1.84966,-1.70919,0.184067,1.80892,-1.85878,0.001161,1.7015,-1.61103,-0.074648,1.5961,-1.55046,0.068514,1.53624,-1.59393,0.148058,1.49411,-1.60094,0.122291,1.8912,-2.10838,0.19469,1.81667,-1.93506,-0.015233,1.84998,-2.02662,-0.042729,1.69173,-2.22001,-0.009105,1.59889,-2.26398,0.144665,1.50931,-2.17191,0.195652,1.46696,-2.17202,0.091803,1.39296,-1.81113,-0.096951,1.44181,-1.89835,-0.089504,1.46355,-1.95797,-0.080636,1.4341,-2.01495,0.118084,1.37838,-2.0653,0.148764,1.1036,-1.7394,0.029243,1.05442,-1.78868,0.063905,0.979099,-1.80961,0.160076,0.88797,-1.78603,0.201104,0.709148,-1.78875,0.194944,0.634878,-1.80384,0.087633,0.715615,-1.80386,0.083845,0.645144,-1.81314,0.11387,0.424562,-1.84051,0.014128,0.35929,-1.91853,0.270946,0.390148,-1.87131,0.242574,0.340396,-1.80197,0.114808,1.06723,-2.11572,0.13163,0.984854,-2.09807,-0.022454,1.04011,-2.08147,-0.004035,0.96123,-2.06457,0.046309,0.840123,-2.07138,-0.118786,0.802535,-2.06368,-0.109887,0.913992,-2.07787,-0.180123,0.916215,-2.07074,-0.40905,0.906165,-2.05085,-0.436363,1.00486,-1.98928,-0.539061,0.740428,-2.00003,-0.569873,0.800947,-2.05886,0.01718,1.30196,-1.82588,0.034505,1.2895,-2.04006},
/*7*/{0.096568,1.84563,-1.70836,0.184708,1.80316,-1.85888,0.009135,1.6945,-1.61045,-0.065657,1.58736,-1.54593,0.07816,1.53185,-1.5927,0.159315,1.49178,-1.59935,0.121274,1.88765,-2.10932,0.195721,1.81172,-1.93587,-0.015837,1.84837,-2.02445,-0.046414,1.69033,-2.2188,-0.015707,1.59644,-2.26315,0.137288,1.50196,-2.17557,0.186289,1.45751,-2.17685,0.088901,1.39019,-1.81098,-0.101482,1.43683,-1.90087,-0.092025,1.4587,-1.95859,-0.08381,1.42908,-2.01586,0.116761,1.37474,-2.06398,0.144709,1.10356,-1.73851,0.02777,1.0539,-1.78807,0.062803,0.978161,-1.81016,0.163906,0.892783,-1.7853,0.19275,0.708128,-1.78902,0.184225,0.633192,-1.80449,0.079781,0.718722,-1.80026,0.074107,0.648974,-1.81065,0.094102,0.425354,-1.84075,-0.007014,0.360167,-1.91856,0.249896,0.389082,-1.87299,0.221352,0.339077,-1.80146,0.120243,1.06739,-2.1153,0.139397,0.98561,-2.09812,-0.017235,1.0346,-2.08133,0.003723,0.956926,-2.06442,0.059331,0.836946,-2.07049,-0.104357,0.800104,-2.06247,-0.095018,0.912091,-2.07841,-0.165251,0.914086,-2.07169,-0.393661,0.906129,-2.05161,-0.423415,1.00467,-1.99254,-0.522383,0.738633,-2.00217,-0.552303,0.798661,-2.06183,0.014425,1.29851,-1.82566,0.03359,1.28531,-2.03964},
/*8*/{0.097382,1.84288,-1.70801,0.184091,1.80043,-1.86026,0.015423,1.69006,-1.6092,-0.054602,1.58161,-1.54312,0.088364,1.52854,-1.59238,0.169979,1.49015,-1.59909,0.121337,1.88439,-2.10937,0.195026,1.80842,-1.93745,-0.015983,1.84802,-2.02398,-0.047971,1.69093,-2.21671,-0.021898,1.59518,-2.26112,0.128561,1.49452,-2.17808,0.175944,1.44767,-2.18203,0.085652,1.38856,-1.80907,-0.104585,1.43312,-1.90214,-0.094421,1.45446,-1.95905,-0.087138,1.42308,-2.01735,0.113806,1.37061,-2.06345,0.14252,1.10342,-1.73903,0.024783,1.05098,-1.78757,0.062472,0.976386,-1.80868,0.168916,0.896616,-1.78442,0.183334,0.706387,-1.78919,0.174518,0.634081,-1.80492,0.072029,0.720934,-1.79875,0.063409,0.650494,-1.8079,0.07575,0.426351,-1.84057,-0.028344,0.361033,-1.91797,0.228097,0.387174,-1.87187,0.199481,0.33897,-1.80052,0.124636,1.06824,-2.11478,0.147351,0.986516,-2.09722,-0.011155,1.03111,-2.08167,0.012436,0.954123,-2.06475,0.074001,0.836215,-2.06862,-0.090121,0.798358,-2.06179,-0.080444,0.909894,-2.07958,-0.149841,0.912341,-2.07244,-0.378784,0.903847,-2.05347,-0.411234,1.00312,-1.99493,-0.504439,0.735094,-2.00381,-0.536547,0.794336,-2.06421,0.011663,1.29636,-1.82417,0.031795,1.28054,-2.03788},
/*9*/{0.097987,1.83984,-1.70815,0.184473,1.7964,-1.86062,0.020833,1.68652,-1.60865,-0.044085,1.57764,-1.54053,0.099375,1.52665,-1.5917,0.180819,1.48987,-1.59872,0.121746,1.88194,-2.10948,0.19461,1.80464,-1.93839,-0.01577,1.84717,-2.02358,-0.052498,1.68994,-2.21369,-0.028512,1.59583,-2.25865,0.119527,1.4878,-2.18008,0.165742,1.4401,-2.18675,0.082546,1.38708,-1.80751,-0.106813,1.43073,-1.90409,-0.096968,1.45228,-1.95945,-0.090871,1.4191,-2.01805,0.111328,1.36727,-2.06348,0.138474,1.10209,-1.7387,0.021505,1.04909,-1.78791,0.059398,0.973442,-1.80819,0.173942,0.897235,-1.78466,0.173597,0.703433,-1.78778,0.160699,0.630316,-1.80373,0.062011,0.721978,-1.79712,0.051099,0.651581,-1.80801,0.055428,0.426501,-1.84,-0.049493,0.361903,-1.91804,0.20714,0.386743,-1.87261,0.177029,0.338831,-1.80038,0.131126,1.06886,-2.11478,0.155054,0.98885,-2.0966,-0.005301,1.02814,-2.08265,0.021412,0.951649,-2.06569,0.089374,0.836308,-2.06755,-0.074404,0.79764,-2.06037,-0.064627,0.90769,-2.08072,-0.134639,0.910776,-2.07429,-0.360617,0.900002,-2.05331,-0.400694,1.00006,-1.99811,-0.485664,0.72979,-2.00585,-0.517743,0.787438,-2.06755,0.008543,1.29484,-1.82334,0.029352,1.27712,-2.03683},
/*10*/{0.099501,1.83777,-1.70854,0.183263,1.79551,-1.86103,0.026735,1.68402,-1.60851,-0.03388,1.57463,-1.53843,0.110259,1.52571,-1.59143,0.19291,1.49062,-1.59942,0.122863,1.87987,-2.10904,0.192505,1.80126,-1.93932,-0.015902,1.84631,-2.02332,-0.057763,1.69149,-2.20986,-0.035401,1.59762,-2.25601,0.110867,1.48296,-2.1823,0.154895,1.43367,-2.19119,0.078954,1.38535,-1.80555,-0.108853,1.42859,-1.90512,-0.097829,1.4527,-1.95972,-0.092736,1.41687,-2.01869,0.108127,1.36533,-2.06377,0.13348,1.09958,-1.73781,0.017358,1.04691,-1.78777,0.055343,0.970583,-1.80708,0.173574,0.894387,-1.78565,0.161705,0.700863,-1.78587,0.147193,0.627427,-1.8019,0.050382,0.721548,-1.79643,0.038416,0.651994,-1.80485,0.035774,0.426238,-1.83879,-0.070713,0.362829,-1.91694,0.185499,0.386096,-1.87198,0.155991,0.33794,-1.80004,0.137909,1.07158,-2.1144,0.164622,0.991515,-2.09681,0.002483,1.02908,-2.08572,0.031297,0.950265,-2.06708,0.105042,0.838392,-2.06729,-0.059321,0.796609,-2.05912,-0.048822,0.905536,-2.08197,-0.119293,0.908594,-2.07479,-0.349659,0.898372,-2.05632,-0.389949,0.995255,-2.00057,-0.465974,0.722773,-2.00768,-0.498272,0.779223,-2.06995,0.004972,1.29324,-1.82319,0.026732,1.27528,-2.03657},
/*11*/{0.101487,1.8358,-1.70907,0.182986,1.7929,-1.86111,0.031669,1.6824,-1.60778,-0.023637,1.57318,-1.53751,0.120925,1.5257,-1.59127,0.204399,1.49264,-1.60057,0.123425,1.87808,-2.10816,0.192394,1.79888,-1.93926,-0.015896,1.84573,-2.0232,-0.062844,1.69391,-2.20634,-0.04217,1.60022,-2.25316,0.101822,1.48029,-2.18444,0.143903,1.42839,-2.19461,0.075152,1.38256,-1.79922,-0.110244,1.42756,-1.90563,-0.099716,1.45247,-1.95973,-0.094397,1.41592,-2.01929,0.106355,1.36368,-2.06448,0.129567,1.09721,-1.73785,0.012184,1.04497,-1.78725,0.048542,0.96872,-1.80542,0.168755,0.889643,-1.78452,0.148319,0.697053,-1.78435,0.132092,0.624062,-1.80074,0.038007,0.720783,-1.79528,0.023283,0.651359,-1.80727,0.014797,0.426486,-1.83804,-0.092231,0.363468,-1.91652,0.163956,0.385215,-1.87073,0.134283,0.336997,-1.79815,0.145614,1.07435,-2.11391,0.174269,0.995642,-2.09541,0.011479,1.02795,-2.08771,0.042655,0.949288,-2.06778,0.121956,0.840869,-2.06613,-0.042545,0.79326,-2.05725,-0.034204,0.903832,-2.0827,-0.103679,0.904811,-2.075,-0.335715,0.894646,-2.05756,-0.380483,0.990471,-2.00359,-0.44557,0.715379,-2.00935,-0.478964,0.769313,-2.07265,0.000525,1.29115,-1.8225,0.024539,1.27394,-2.0357},
/*12*/{0.103362,1.83464,-1.70961,0.182467,1.79045,-1.86165,0.037151,1.6807,-1.60707,-0.014949,1.57092,-1.5353,0.131625,1.52706,-1.59167,0.215737,1.49589,-1.60199,0.123831,1.87653,-2.10792,0.192009,1.79709,-1.93875,-0.016419,1.84547,-2.02338,-0.066142,1.69742,-2.20094,-0.049691,1.60308,-2.25131,0.093253,1.4789,-2.18668,0.133403,1.42539,-2.19744,0.073299,1.38255,-1.80138,-0.112103,1.42768,-1.9061,-0.101243,1.45188,-1.96005,-0.096407,1.41598,-2.01977,0.105074,1.36325,-2.06479,0.124756,1.09389,-1.73702,0.005051,1.04312,-1.78808,0.043154,0.965414,-1.80644,0.159249,0.884342,-1.78375,0.135154,0.692392,-1.78369,0.116676,0.620474,-1.79985,0.025245,0.720562,-1.79481,0.00873,0.650498,-1.80592,-0.006521,0.425876,-1.8366,-0.113708,0.364329,-1.9155,0.143868,0.384903,-1.87002,0.113297,0.337146,-1.79752,0.153402,1.07759,-2.11387,0.185742,1.0004,-2.09496,0.021059,1.02609,-2.08812,0.053341,0.951931,-2.07088,0.137867,0.843681,-2.06548,-0.026552,0.791735,-2.05673,-0.019346,0.902296,-2.08251,-0.089002,0.903176,-2.07565,-0.321451,0.888203,-2.05964,-0.370477,0.98369,-2.00806,-0.424496,0.705794,-2.01027,-0.458898,0.757362,-2.07491,-0.001043,1.29106,-1.8232,0.022701,1.2737,-2.03642},
/*13*/{0.104943,1.83409,-1.71048,0.182701,1.78677,-1.86125,0.041993,1.68032,-1.60688,-0.005174,1.57048,-1.53451,0.141148,1.52916,-1.59185,0.226856,1.50054,-1.60342,0.123712,1.87524,-2.10741,0.191799,1.79547,-1.93847,-0.01659,1.84528,-2.0233,-0.071916,1.70148,-2.19645,-0.05665,1.60695,-2.24916,0.083929,1.47758,-2.1882,0.122506,1.42404,-2.20003,0.070529,1.38132,-1.79998,-0.112486,1.42758,-1.90506,-0.102572,1.45113,-1.96001,-0.097435,1.41649,-2.0189,0.102265,1.36294,-2.06504,0.11833,1.09041,-1.73684,-0.000861,1.04209,-1.78756,0.03493,0.964454,-1.80629,0.147724,0.879793,-1.7828,0.120096,0.688922,-1.78265,0.101497,0.617055,-1.79928,0.011243,0.71921,-1.79427,-0.007605,0.649462,-1.80607,-0.027067,0.42709,-1.83601,-0.134849,0.36502,-1.91473,0.121806,0.384729,-1.86874,0.091909,0.336956,-1.79589,0.161538,1.08292,-2.11333,0.196167,1.00577,-2.09441,0.031199,1.02518,-2.08911,0.066355,0.953402,-2.07122,0.153865,0.847517,-2.06417,-0.010347,0.791629,-2.05524,-0.004361,0.902025,-2.08253,-0.074873,0.901733,-2.07646,-0.306817,0.880973,-2.06078,-0.361325,0.97482,-2.01042,-0.400828,0.695444,-2.00972,-0.438408,0.744792,-2.07717,-0.003359,1.29006,-1.82303,0.020387,1.27341,-2.0363},
/*14*/{0.107849,1.83391,-1.71058,0.182287,1.78744,-1.86306,0.046045,1.68062,-1.60618,0.002846,1.56922,-1.53304,0.150423,1.53283,-1.59281,0.23755,1.5059,-1.60557,0.1232,1.87454,-2.10766,0.191769,1.79496,-1.93837,-0.016768,1.8453,-2.02336,-0.076225,1.70681,-2.19175,-0.064397,1.61111,-2.24767,0.075621,1.47875,-2.19004,0.112063,1.4233,-2.2022,0.069836,1.38069,-1.79928,-0.113928,1.42688,-1.90501,-0.104225,1.45003,-1.95981,-0.0991,1.41704,-2.01811,0.100798,1.36339,-2.06585,0.112596,1.08634,-1.73722,-0.006814,1.04166,-1.78802,0.024897,0.962791,-1.80639,0.134204,0.874453,-1.7818,0.104745,0.684987,-1.78193,0.082262,0.613265,-1.79874,-0.002751,0.717611,-1.79473,-0.023167,0.649784,-1.80646,-0.046528,0.426824,-1.83489,-0.1558,0.365811,-1.91382,0.100195,0.383661,-1.86756,0.070382,0.336255,-1.79509,0.169015,1.08858,-2.11345,0.206312,1.01285,-2.09377,0.040626,1.02574,-2.09027,0.078659,0.955137,-2.07274,0.169469,0.852336,-2.06415,0.005813,0.791,-2.05393,0.009078,0.902482,-2.08359,-0.061159,0.900695,-2.07799,-0.287551,0.871361,-2.05954,-0.354402,0.966172,-2.01294,-0.378429,0.683744,-2.01238,-0.416321,0.73121,-2.07892,-0.004138,1.28928,-1.82343,0.019208,1.27366,-2.03682},
/*15*/{0.109227,1.83504,-1.71077,0.182131,1.78696,-1.86361,0.04963,1.68136,-1.60603,0.010533,1.56969,-1.5326,0.158976,1.53636,-1.59377,0.246765,1.51184,-1.60834,0.121418,1.8745,-2.10768,0.192039,1.7948,-1.93858,-0.017548,1.84555,-2.02326,-0.081668,1.71189,-2.18845,-0.072145,1.61571,-2.24605,0.066569,1.47985,-2.19133,0.101843,1.42411,-2.20445,0.067032,1.37915,-1.79888,-0.114367,1.42695,-1.90534,-0.104346,1.45001,-1.9597,-0.100795,1.41745,-2.01693,0.099771,1.36446,-2.06675,0.108334,1.083,-1.73711,-0.014363,1.04098,-1.78806,0.015632,0.962128,-1.80821,0.120468,0.868831,-1.78128,0.088644,0.681003,-1.78208,0.066413,0.610049,-1.79832,-0.017672,0.715926,-1.7952,-0.039773,0.647311,-1.80889,-0.067675,0.42705,-1.83376,-0.176835,0.366527,-1.91379,0.07977,0.383223,-1.8669,0.049754,0.33612,-1.79452,0.176577,1.09441,-2.11385,0.2167,1.02089,-2.09347,0.050776,1.02823,-2.09126,0.091378,0.958342,-2.07336,0.183729,0.857205,-2.06408,0.021356,0.791473,-2.05383,0.023047,0.903409,-2.08302,-0.047126,0.899871,-2.07865,-0.27803,0.865979,-2.06276,-0.346324,0.955547,-2.01661,-0.354962,0.672556,-2.01128,-0.394009,0.71767,-2.08112,-0.00593,1.28804,-1.82439,0.017844,1.27435,-2.03787},
/*16*/{0.111101,1.83622,-1.71111,0.18191,1.78688,-1.86387,0.053408,1.68284,-1.6059,0.018321,1.56918,-1.53087,0.167365,1.54098,-1.59476,0.255318,1.5191,-1.61108,0.120246,1.87475,-2.10808,0.192333,1.79512,-1.93898,-0.01888,1.84682,-2.02271,-0.085611,1.71713,-2.18482,-0.08025,1.62045,-2.2449,0.057505,1.48218,-2.19252,0.091191,1.426,-2.20548,0.066866,1.3791,-1.79904,-0.115974,1.42676,-1.90524,-0.105933,1.45026,-1.95883,-0.102081,1.41798,-2.0168,0.097623,1.36561,-2.06801,0.102081,1.07916,-1.73739,-0.020589,1.03987,-1.78671,0.005986,0.959983,-1.80602,0.105574,0.863855,-1.77986,0.072129,0.677516,-1.7821,0.047334,0.60648,-1.79783,-0.033603,0.714524,-1.79613,-0.056453,0.646055,-1.8091,-0.087203,0.426666,-1.8338,-0.197678,0.367166,-1.91297,0.05862,0.383088,-1.86639,0.028728,0.336091,-1.79413,0.183394,1.10154,-2.11355,0.226408,1.02988,-2.09328,0.060324,1.03065,-2.09143,0.102555,0.961667,-2.07393,0.19876,0.862397,-2.06422,0.038441,0.792588,-2.05387,0.036088,0.90386,-2.08349,-0.033649,0.899186,-2.07963,-0.263817,0.856914,-2.06327,-0.33657,0.942517,-2.01826,-0.330375,0.660033,-2.01231,-0.370923,0.70283,-2.08333,-0.006318,1.28789,-1.82512,0.016363,1.27521,-2.03879},
/*17*/{0.113371,1.83728,-1.71145,0.181486,1.78747,-1.86568,0.057349,1.68487,-1.60605,0.025041,1.5706,-1.53083,0.174766,1.54595,-1.59634,0.263928,1.52666,-1.61446,0.11794,1.87545,-2.10836,0.189345,1.79464,-1.9408,-0.020337,1.84755,-2.02149,-0.091509,1.72297,-2.18171,-0.089031,1.62655,-2.24366,0.049119,1.48624,-2.1939,0.081881,1.42961,-2.20676,0.066727,1.37876,-1.79926,-0.116338,1.42702,-1.90454,-0.106372,1.45109,-1.95857,-0.102951,1.41854,-2.0155,0.09716,1.36782,-2.06844,0.094536,1.07653,-1.73791,-0.029724,1.0407,-1.78812,-0.003481,0.95968,-1.80697,0.090458,0.858841,-1.78018,0.056172,0.6746,-1.78266,0.03163,0.604679,-1.79852,-0.048897,0.712517,-1.79693,-0.07259,0.645589,-1.80792,-0.107644,0.428154,-1.83406,-0.218718,0.367867,-1.91323,0.038412,0.383247,-1.8662,0.006633,0.336217,-1.79472,0.190498,1.10973,-2.11224,0.235213,1.03852,-2.09346,0.069355,1.03424,-2.09286,0.113324,0.967101,-2.07449,0.212698,0.869325,-2.06485,0.054563,0.794786,-2.05486,0.049281,0.906053,-2.08414,-0.020798,0.898105,-2.08057,-0.249337,0.846058,-2.06973,-0.329241,0.930051,-2.01955,-0.305758,0.647213,-2.01435,-0.347502,0.687734,-2.08529,-0.006097,1.28769,-1.82582,0.016089,1.27678,-2.03963},
/*18*/{0.115178,1.83963,-1.71275,0.182032,1.78811,-1.86615,0.06146,1.6873,-1.60589,0.032973,1.57251,-1.53038,0.182003,1.55144,-1.59811,0.271077,1.53504,-1.61821,0.115404,1.8771,-2.10918,0.188895,1.79526,-1.94205,-0.020943,1.84832,-2.02036,-0.097112,1.72694,-2.17747,-0.097084,1.63263,-2.24246,0.040663,1.49031,-2.19399,0.072524,1.43364,-2.20701,0.06614,1.37863,-1.7998,-0.117299,1.42818,-1.9047,-0.106991,1.45219,-1.95804,-0.103754,1.41944,-2.01534,0.096577,1.36976,-2.06864,0.085972,1.0751,-1.73831,-0.038352,1.04121,-1.78776,-0.014058,0.959908,-1.80662,0.075494,0.854177,-1.78082,0.040971,0.672438,-1.78335,0.013272,0.602639,-1.79957,-0.064593,0.712307,-1.7975,-0.089109,0.644757,-1.80829,-0.127937,0.428985,-1.83406,-0.239893,0.369028,-1.9134,0.017402,0.383073,-1.8663,-0.013639,0.336924,-1.79349,0.196144,1.11745,-2.11276,0.242873,1.04836,-2.09364,0.077195,1.03865,-2.09329,0.124529,0.973181,-2.07498,0.226514,0.876898,-2.06519,0.070495,0.797047,-2.05534,0.060968,0.908202,-2.08417,-0.008616,0.897423,-2.08131,-0.236706,0.843215,-2.07347,-0.320432,0.915417,-2.02026,-0.279934,0.634803,-2.01634,-0.324979,0.672661,-2.08716,-0.006736,1.28791,-1.82665,0.015386,1.27836,-2.04053},
/*19*/{0.1169,1.84236,-1.7137,0.181774,1.79032,-1.86751,0.065369,1.69012,-1.60605,0.041126,1.57469,-1.52974,0.189481,1.55733,-1.60041,0.277886,1.54359,-1.62188,0.112567,1.87905,-2.10943,0.188519,1.79694,-1.94391,-0.022641,1.85062,-2.0191,-0.103006,1.73213,-2.17574,-0.104604,1.63866,-2.24189,0.031428,1.49563,-2.1933,0.063,1.43913,-2.20714,0.066133,1.37899,-1.80017,-0.117799,1.42962,-1.9049,-0.10782,1.45362,-1.95781,-0.10444,1.42084,-2.01518,0.096756,1.37186,-2.0692,0.077045,1.07304,-1.74014,-0.046025,1.04164,-1.78837,-0.024642,0.959928,-1.80688,0.059511,0.851086,-1.78222,0.02442,0.671188,-1.7844,-0.003681,0.602075,-1.80122,-0.079605,0.712807,-1.7982,-0.104862,0.646452,-1.80883,-0.149193,0.429344,-1.83369,-0.260233,0.370455,-1.91335,-0.003257,0.382342,-1.86671,-0.034438,0.336832,-1.79371,0.201234,1.12532,-2.11286,0.249923,1.05819,-2.09416,0.084976,1.04213,-2.09236,0.133031,0.978714,-2.07472,0.239471,0.885146,-2.06542,0.086511,0.799682,-2.05674,0.072648,0.909723,-2.08425,0.003289,0.896194,-2.08207,-0.22294,0.82726,-2.06671,-0.31136,0.898796,-2.0195,-0.252966,0.622054,-2.01871,-0.298385,0.657498,-2.08984,-0.006925,1.28859,-1.8275,0.015081,1.28027,-2.04144},
/*20*/{0.119208,1.84549,-1.71445,0.182676,1.7919,-1.86885,0.068922,1.69299,-1.60643,0.047808,1.57712,-1.53073,0.195985,1.56447,-1.60238,0.283817,1.55285,-1.62564,0.10974,1.88094,-2.11021,0.187921,1.79873,-1.94527,-0.024434,1.85156,-2.01741,-0.109792,1.73758,-2.17331,-0.113305,1.64461,-2.23988,0.022727,1.50107,-2.1934,0.054645,1.44513,-2.20672,0.066568,1.37916,-1.80002,-0.116796,1.431,-1.90397,-0.107321,1.45546,-1.9565,-0.104293,1.42275,-2.01527,0.094598,1.37369,-2.06943,0.071114,1.07044,-1.7413,-0.056289,1.04296,-1.78896,-0.034947,0.960224,-1.80795,0.042509,0.849163,-1.78344,0.009096,0.67054,-1.78535,-0.019433,0.601907,-1.80079,-0.0951,0.714057,-1.79821,-0.121781,0.648127,-1.80905,-0.16804,0.43041,-1.83361,-0.280626,0.372131,-1.91243,-0.023973,0.381993,-1.86588,-0.055265,0.336601,-1.79419,0.205018,1.13353,-2.11326,0.256145,1.06767,-2.09409,0.091783,1.04705,-2.09313,0.142571,0.985644,-2.07552,0.251455,0.895484,-2.06593,0.102332,0.802513,-2.05806,0.0835,0.912175,-2.08496,0.014736,0.895462,-2.08332,-0.207714,0.81618,-2.06716,-0.302147,0.88247,-2.02091,-0.226148,0.609316,-2.02109,-0.273094,0.643119,-2.09274,-0.006903,1.2892,-1.82791,0.013916,1.28197,-2.04201},
/*21*/{0.120733,1.84893,-1.7155,0.183488,1.79466,-1.87033,0.073068,1.69611,-1.60657,0.054771,1.58005,-1.53061,0.201915,1.57127,-1.60552,0.289832,1.56203,-1.62989,0.106101,1.8841,-2.1106,0.186776,1.80102,-1.94738,-0.025426,1.85398,-2.01627,-0.116322,1.74331,-2.17179,-0.121351,1.6511,-2.23852,0.014862,1.50752,-2.19296,0.045816,1.45106,-2.20618,0.066572,1.37966,-1.80009,-0.116274,1.43311,-1.90226,-0.107262,1.45689,-1.95545,-0.103751,1.42489,-2.01502,0.095398,1.37664,-2.06949,0.063834,1.06868,-1.74168,-0.064906,1.04333,-1.78878,-0.045477,0.961445,-1.80784,0.026033,0.848565,-1.78575,-0.008717,0.669715,-1.78722,-0.037504,0.60181,-1.80311,-0.111041,0.714342,-1.79937,-0.137608,0.649932,-1.8096,-0.188491,0.430746,-1.83422,-0.301352,0.373683,-1.91243,-0.044789,0.381957,-1.86597,-0.076622,0.336887,-1.79371,0.210049,1.14169,-2.11385,0.262571,1.07724,-2.09453,0.098645,1.05235,-2.09299,0.150644,0.991725,-2.07494,0.263004,0.906633,-2.0665,0.117282,0.805737,-2.05925,0.09399,0.913099,-2.08543,0.025245,0.894952,-2.08374,-0.194487,0.804728,-2.06849,-0.292387,0.863576,-2.02037,-0.197289,0.597878,-2.02525,-0.248099,0.627345,-2.09503,-0.006435,1.29,-1.82841,0.014313,1.28462,-2.04257},
/*22*/{0.122665,1.85246,-1.71673,0.183315,1.79822,-1.8723,0.077505,1.69926,-1.60738,0.061629,1.58344,-1.53138,0.206655,1.57782,-1.60817,0.294677,1.57127,-1.63377,0.102947,1.88732,-2.1108,0.18672,1.80427,-1.94887,-0.026879,1.85544,-2.01425,-0.122687,1.74883,-2.17012,-0.128363,1.65727,-2.23737,0.006893,1.5141,-2.19249,0.037231,1.45783,-2.2054,0.066578,1.37986,-1.79999,-0.115928,1.43499,-1.90191,-0.107341,1.45909,-1.95477,-0.103888,1.42687,-2.01396,0.095193,1.37965,-2.06918,0.054795,1.06977,-1.7457,-0.073261,1.04572,-1.78899,-0.056622,0.964253,-1.80881,0.010672,0.849378,-1.78739,-0.025281,0.670127,-1.78835,-0.054694,0.602831,-1.80375,-0.127511,0.716111,-1.80057,-0.156269,0.65031,-1.81099,-0.208998,0.43273,-1.83418,-0.321612,0.376889,-1.91218,-0.065828,0.381438,-1.86693,-0.097983,0.336945,-1.79455,0.213768,1.14976,-2.11407,0.267324,1.087,-2.09596,0.104731,1.05811,-2.09328,0.158761,0.999042,-2.07444,0.27357,0.917685,-2.06785,0.132117,0.809565,-2.06134,0.103992,0.914521,-2.08595,0.035838,0.893975,-2.08466,-0.179386,0.792148,-2.06834,-0.282405,0.84437,-2.01934,-0.169167,0.586214,-2.02873,-0.222107,0.613651,-2.09798,-0.006554,1.29077,-1.82901,0.014099,1.28724,-2.04322},
/*23*/{0.124548,1.85636,-1.7183,0.183689,1.80127,-1.87388,0.082199,1.70265,-1.60829,0.066992,1.58677,-1.53173,0.211006,1.58529,-1.61116,0.298607,1.58103,-1.63785,0.099084,1.89099,-2.11118,0.186432,1.80743,-1.95145,-0.028625,1.85801,-2.01276,-0.128382,1.7547,-2.16832,-0.135721,1.66357,-2.23586,-0.001159,1.52079,-2.19094,0.030007,1.46431,-2.20414,0.066867,1.38065,-1.79967,-0.11513,1.4371,-1.90096,-0.106182,1.46117,-1.95345,-0.103337,1.42994,-2.01362,0.095196,1.38309,-2.06853,0.048981,1.06849,-1.74697,-0.081871,1.05183,-1.78961,-0.067979,0.967651,-1.80991,-0.002908,0.851071,-1.79014,-0.041873,0.670686,-1.79041,-0.07335,0.602655,-1.80629,-0.143909,0.717505,-1.80148,-0.17276,0.652829,-1.81213,-0.228522,0.435075,-1.8342,-0.341545,0.380861,-1.91206,-0.086051,0.381176,-1.86696,-0.11852,0.336868,-1.79491,0.216917,1.15812,-2.115,0.27241,1.09712,-2.09599,0.110282,1.06391,-2.09289,0.165632,1.00557,-2.07416,0.283881,0.92907,-2.06801,0.146296,0.813,-2.06248,0.110134,0.919892,-2.08717,0.045297,0.892689,-2.08447,-0.163764,0.78133,-2.07179,-0.271572,0.82499,-2.01825,-0.141229,0.574572,-2.03294,-0.196039,0.59893,-2.10072,-0.006206,1.2919,-1.82949,0.014463,1.29038,-2.04373},
/*24*/{0.126595,1.86074,-1.71948,0.184374,1.80498,-1.87604,0.086812,1.7064,-1.60922,0.072869,1.59008,-1.53215,0.215538,1.59312,-1.61423,0.303044,1.59043,-1.64265,0.095239,1.89482,-2.11153,0.186324,1.81103,-1.95339,-0.029986,1.85996,-2.01082,-0.13403,1.7609,-2.16678,-0.142846,1.6698,-2.23422,-0.009007,1.52664,-2.18934,0.022878,1.47173,-2.20326,0.068358,1.38154,-1.79895,-0.114367,1.4395,-1.89997,-0.106364,1.46388,-1.95234,-0.102895,1.4334,-2.01332,0.09556,1.38659,-2.06756,0.044911,1.06981,-1.74914,-0.088263,1.05243,-1.7889,-0.078379,0.970443,-1.80932,-0.014782,0.853109,-1.79205,-0.058089,0.672117,-1.79228,-0.090139,0.605255,-1.80745,-0.160348,0.720353,-1.80216,-0.190782,0.655409,-1.81305,-0.246887,0.438177,-1.83367,-0.361263,0.385115,-1.91182,-0.105741,0.381242,-1.86725,-0.138964,0.336956,-1.79537,0.220361,1.1661,-2.11519,0.277033,1.10649,-2.09604,0.115715,1.06842,-2.09219,0.173033,1.0118,-2.0751,0.292016,0.940734,-2.06893,0.159297,0.816783,-2.06441,0.117981,0.920766,-2.08685,0.053801,0.890325,-2.08444,-0.148187,0.766875,-2.06772,-0.258728,0.80397,-2.01713,-0.114101,0.566401,-2.03884,-0.166143,0.585114,-2.10357,-0.005695,1.29343,-1.82981,0.014858,1.29378,-2.04406},
/*25*/{0.127829,1.8654,-1.72109,0.184973,1.80914,-1.87814,0.091491,1.71108,-1.60988,0.077839,1.59397,-1.53268,0.218785,1.60055,-1.61688,0.305522,1.59999,-1.6471,0.091403,1.89898,-2.1113,0.186243,1.81543,-1.95557,-0.031612,1.86331,-2.00926,-0.138517,1.76775,-2.16487,-0.149038,1.67627,-2.23225,-0.015596,1.53384,-2.18713,0.015844,1.47901,-2.20207,0.069347,1.38191,-1.79809,-0.112671,1.44218,-1.89876,-0.104672,1.4665,-1.94997,-0.102018,1.43708,-2.01264,0.09612,1.39044,-2.06639,0.03655,1.06951,-1.75127,-0.096083,1.05499,-1.78747,-0.08898,0.974661,-1.81008,-0.026885,0.855244,-1.79465,-0.075173,0.674445,-1.79396,-0.107023,0.607641,-1.80803,-0.177315,0.722316,-1.80336,-0.207357,0.657209,-1.81302,-0.266299,0.44193,-1.83432,-0.380652,0.390743,-1.9113,-0.125469,0.3812,-1.86734,-0.160659,0.338115,-1.79536,0.223287,1.17424,-2.11594,0.280914,1.1161,-2.09674,0.120134,1.07484,-2.09228,0.178579,1.01825,-2.07471,0.300279,0.952086,-2.06926,0.17218,0.822078,-2.06826,0.125003,0.922233,-2.08687,0.062736,0.888018,-2.08448,-0.12909,0.753057,-2.0674,-0.245311,0.783125,-2.01607,-0.08173,0.553596,-2.04039,-0.140382,0.572815,-2.1076,-0.005019,1.29454,-1.83014,0.0155,1.29745,-2.04437},
/*26*/{0.129495,1.8701,-1.72257,0.185783,1.81335,-1.88062,0.096285,1.7149,-1.61081,0.084261,1.59877,-1.53345,0.222392,1.60795,-1.62045,0.307543,1.60911,-1.65111,0.088589,1.90309,-2.11124,0.18568,1.8195,-1.95722,-0.033371,1.86627,-2.00795,-0.143725,1.77396,-2.16419,-0.155777,1.68287,-2.23086,-0.022099,1.54061,-2.18506,0.009074,1.48659,-2.2012,0.07091,1.38346,-1.79746,-0.112364,1.44463,-1.89814,-0.104122,1.46948,-1.9491,-0.101139,1.44109,-2.01187,0.096689,1.39443,-2.06535,0.030176,1.06979,-1.75425,-0.102832,1.06,-1.78755,-0.096541,0.977891,-1.8089,-0.03805,0.857248,-1.79681,-0.09181,0.677442,-1.79549,-0.125107,0.610053,-1.81069,-0.192908,0.726129,-1.80458,-0.224247,0.661152,-1.81452,-0.285665,0.445214,-1.83469,-0.399949,0.396924,-1.91069,-0.145761,0.379774,-1.86749,-0.181563,0.338556,-1.79519,0.225841,1.18211,-2.11596,0.284822,1.12443,-2.09593,0.124063,1.08133,-2.09308,0.183782,1.02551,-2.07446,0.30608,0.962642,-2.06999,0.184008,0.824369,-2.06805,0.13097,0.92341,-2.08721,0.071212,0.886002,-2.08427,-0.11275,0.740956,-2.06629,-0.229504,0.760519,-2.0144,-0.052063,0.544221,-2.04479,-0.111985,0.560659,-2.11078,-0.004297,1.29652,-1.83049,0.016338,1.30133,-2.04468},
/*27*/{0.130871,1.875,-1.72388,0.186187,1.81786,-1.88228,0.100782,1.71964,-1.61187,0.089821,1.60335,-1.53396,0.224795,1.61588,-1.62338,0.310266,1.6186,-1.65552,0.085636,1.90721,-2.11107,0.18536,1.82322,-1.95958,-0.03502,1.86965,-2.0065,-0.147062,1.78069,-2.16138,-0.161253,1.68965,-2.22837,-0.027768,1.54917,-2.18369,0.003117,1.49365,-2.19981,0.072155,1.38495,-1.797,-0.109963,1.44803,-1.8971,-0.103165,1.47301,-1.94655,-0.100015,1.44456,-2.01124,0.097563,1.39909,-2.06448,0.025857,1.07023,-1.75669,-0.108931,1.06665,-1.78897,-0.10737,0.984507,-1.80984,-0.049592,0.860452,-1.79936,-0.108287,0.680609,-1.79671,-0.142138,0.613504,-1.81172,-0.20897,0.730569,-1.80619,-0.240024,0.666479,-1.8144,-0.304224,0.450434,-1.83435,-0.418306,0.404525,-1.91059,-0.165136,0.377291,-1.86858,-0.201867,0.338844,-1.79557,0.22854,1.18931,-2.11546,0.288285,1.13312,-2.09556,0.12879,1.08743,-2.09321,0.187743,1.03315,-2.0747,0.311793,0.972684,-2.06978,0.196415,0.827926,-2.06908,0.137025,0.923974,-2.08709,0.079261,0.882768,-2.08355,-0.096062,0.727242,-2.06593,-0.213293,0.738161,-2.01272,-0.021217,0.534567,-2.04838,-0.083224,0.549472,-2.11456,-0.002964,1.29863,-1.83077,0.017335,1.30563,-2.04493},
/*28*/{0.132551,1.88057,-1.72544,0.187249,1.8219,-1.88464,0.105686,1.72384,-1.61364,0.095324,1.60724,-1.53399,0.227853,1.62266,-1.62596,0.312013,1.62732,-1.65929,0.082274,1.91134,-2.11105,0.184627,1.82815,-1.96161,-0.033228,1.87063,-2.00451,-0.151814,1.78724,-2.16052,-0.166819,1.69597,-2.22644,-0.034134,1.55598,-2.18155,-0.002681,1.50115,-2.19854,0.073435,1.38571,-1.79667,-0.108521,1.4514,-1.89595,-0.100752,1.47599,-1.94517,-0.099181,1.44989,-2.01091,0.098478,1.40371,-2.06363,0.021605,1.07304,-1.75896,-0.11453,1.07447,-1.78918,-0.114439,0.98983,-1.81094,-0.062667,0.863597,-1.8012,-0.124433,0.685197,-1.79738,-0.159528,0.617999,-1.81164,-0.225118,0.735408,-1.80718,-0.256256,0.671867,-1.81492,-0.321812,0.45443,-1.83246,-0.436927,0.413062,-1.90975,-0.184981,0.377791,-1.86813,-0.222367,0.339075,-1.79573,0.231136,1.19712,-2.11615,0.291211,1.14067,-2.09521,0.131955,1.0944,-2.09365,0.192119,1.04005,-2.07459,0.317617,0.983374,-2.06987,0.2074,0.831019,-2.07092,0.142439,0.923105,-2.08678,0.087197,0.879182,-2.08328,-0.082287,0.713415,-2.06608,-0.198092,0.716621,-2.0112,0.009466,0.527444,-2.05292,-0.053613,0.539036,-2.11813,-0.00232,1.30029,-1.83188,0.018115,1.3103,-2.04591},
/*29*/{0.134002,1.88444,-1.72741,0.188577,1.82701,-1.88687,0.109384,1.72881,-1.61451,0.099089,1.61261,-1.53505,0.229821,1.63024,-1.62848,0.313622,1.6366,-1.66403,0.0805,1.91493,-2.1112,0.184373,1.83286,-1.96337,-0.035159,1.87445,-2.00277,-0.155134,1.79359,-2.15838,-0.171577,1.7027,-2.22423,-0.040538,1.56291,-2.17941,-0.008403,1.50808,-2.19723,0.075621,1.38724,-1.79662,-0.105957,1.454,-1.89416,-0.099848,1.47983,-1.94297,-0.097126,1.45375,-2.00998,0.098624,1.40788,-2.06257,0.014496,1.07435,-1.76236,-0.120562,1.08151,-1.79034,-0.125285,0.996184,-1.81208,-0.076335,0.868495,-1.80172,-0.140111,0.691166,-1.79793,-0.174309,0.624593,-1.81137,-0.240449,0.741283,-1.80705,-0.272291,0.677976,-1.81559,-0.338583,0.460698,-1.83223,-0.454132,0.421848,-1.90923,-0.204663,0.377469,-1.86854,-0.243306,0.339582,-1.79637,0.233567,1.20435,-2.11607,0.293332,1.1486,-2.09511,0.135084,1.10045,-2.09449,0.195398,1.04717,-2.07421,0.320047,0.992524,-2.07041,0.217729,0.833763,-2.07221,0.147596,0.922776,-2.08609,0.094987,0.875226,-2.08226,-0.064927,0.700706,-2.06578,-0.180939,0.695498,-2.01068,0.039382,0.520767,-2.05766,-0.024605,0.530157,-2.12235,-0.00058,1.30235,-1.83209,0.018911,1.31441,-2.0461},
/*30*/{0.135311,1.88917,-1.72879,0.189713,1.83133,-1.88888,0.113256,1.73376,-1.61551,0.102509,1.61736,-1.53552,0.231416,1.63711,-1.63166,0.314317,1.6441,-1.6683,0.078604,1.91889,-2.11134,0.18415,1.83711,-1.96551,-0.035549,1.87783,-2.00247,-0.15797,1.79979,-2.15617,-0.176789,1.709,-2.22184,-0.044343,1.57054,-2.1768,-0.013134,1.51553,-2.1959,0.078212,1.38814,-1.79626,-0.103451,1.45774,-1.89312,-0.098715,1.48327,-1.94124,-0.096251,1.45916,-2.00907,0.099827,1.41268,-2.06201,0.00984,1.07599,-1.76505,-0.124539,1.08678,-1.7889,-0.131782,1.00247,-1.81069,-0.09133,0.875112,-1.80255,-0.154665,0.696709,-1.79808,-0.191225,0.629889,-1.8122,-0.255321,0.748064,-1.80845,-0.287853,0.684201,-1.81614,-0.354641,0.465612,-1.83088,-0.471302,0.431329,-1.909,-0.224222,0.376635,-1.86855,-0.264609,0.340049,-1.79699,0.235128,1.21077,-2.11587,0.295964,1.1562,-2.09457,0.138471,1.10628,-2.09593,0.198353,1.05429,-2.07485,0.321886,1.00042,-2.07038,0.22791,0.836458,-2.07361,0.152353,0.921082,-2.08622,0.10241,0.869169,-2.08112,-0.042513,0.687235,-2.06482,-0.162023,0.672575,-2.0091,0.069841,0.514752,-2.06216,0.003935,0.522506,-2.12668,0.000874,1.30441,-1.83312,0.019751,1.31935,-2.04701},
/*31*/{0.136843,1.89459,-1.73068,0.189298,1.83556,-1.89125,0.116252,1.73847,-1.61673,0.107229,1.62231,-1.53598,0.23254,1.644,-1.63371,0.314849,1.6526,-1.67168,0.077054,1.9224,-2.11141,0.183933,1.84182,-1.96744,-0.03542,1.88132,-2.00137,-0.160336,1.80564,-2.15488,-0.181269,1.71543,-2.2192,-0.050111,1.57686,-2.17511,-0.017683,1.52164,-2.19443,0.079877,1.38993,-1.79749,-0.102031,1.46124,-1.89295,-0.097035,1.48672,-1.93955,-0.094147,1.46381,-2.00863,0.100401,1.41746,-2.06212,0.005652,1.07849,-1.76663,-0.128469,1.09363,-1.78914,-0.139201,1.01004,-1.81163,-0.105181,0.881302,-1.8029,-0.170091,0.702819,-1.7979,-0.206044,0.636116,-1.81099,-0.269474,0.754835,-1.80875,-0.302548,0.69185,-1.81646,-0.372552,0.471659,-1.83005,-0.487452,0.442009,-1.90891,-0.243828,0.375897,-1.86859,-0.285039,0.340561,-1.79711,0.237106,1.21838,-2.11614,0.298769,1.1638,-2.09408,0.140944,1.11208,-2.09603,0.201143,1.05993,-2.0747,0.322711,1.00821,-2.07109,0.238224,0.83814,-2.07473,0.156583,0.918112,-2.0857,0.110895,0.863904,-2.08085,-0.024375,0.673742,-2.06456,-0.141544,0.649006,-2.00609,0.099985,0.509739,-2.06617,0.033913,0.512931,-2.12875,0.002283,1.30669,-1.83465,0.020596,1.32416,-2.04839},
/*32*/{0.138099,1.89892,-1.7321,0.189753,1.84039,-1.893,0.119535,1.74343,-1.61731,0.110027,1.62737,-1.53713,0.23349,1.65082,-1.63717,0.315779,1.66025,-1.67519,0.075893,1.926,-2.11174,0.183225,1.84578,-1.96872,-0.036477,1.88498,-2.00058,-0.162481,1.8115,-2.15287,-0.185413,1.72161,-2.21613,-0.053792,1.58318,-2.17265,-0.02182,1.52852,-2.19309,0.083063,1.39143,-1.79923,-0.099371,1.46486,-1.89131,-0.095213,1.49111,-1.93794,-0.093438,1.46847,-2.00789,0.100193,1.42191,-2.06153,0.001705,1.08094,-1.76934,-0.132219,1.10065,-1.7891,-0.146225,1.01763,-1.81177,-0.117122,0.888436,-1.80234,-0.183382,0.709963,-1.797,-0.220124,0.644082,-1.80972,-0.282949,0.762869,-1.80931,-0.315599,0.700082,-1.81552,-0.387084,0.478986,-1.82904,-0.503431,0.453127,-1.90825,-0.263824,0.375804,-1.86898,-0.306479,0.341536,-1.79801,0.238362,1.22483,-2.1158,0.300087,1.17022,-2.09381,0.143267,1.11785,-2.09627,0.203397,1.06525,-2.07492,0.322734,1.01418,-2.07161,0.247446,0.840121,-2.07616,0.161567,0.914337,-2.08468,0.118353,0.857276,-2.07997,-0.005664,0.660267,-2.06369,-0.119983,0.627848,-2.00592,0.129239,0.506081,-2.0697,0.063239,0.505917,-2.13131,0.004199,1.30917,-1.83578,0.02052,1.3288,-2.04949},
/*33*/{0.139705,1.90394,-1.73374,0.19112,1.84426,-1.89503,0.121893,1.74842,-1.6187,0.113133,1.63161,-1.53684,0.23496,1.65721,-1.63974,0.316075,1.66746,-1.67919,0.074171,1.92871,-2.11208,0.183189,1.85027,-1.97027,-0.036459,1.88842,-2.00002,-0.165394,1.81691,-2.15155,-0.188941,1.72755,-2.21362,-0.057234,1.58938,-2.17072,-0.025061,1.53446,-2.19224,0.086432,1.39282,-1.8009,-0.097068,1.46852,-1.89034,-0.094591,1.49521,-1.93548,-0.091274,1.47394,-2.007,0.100949,1.42693,-2.06171,-0.002045,1.08367,-1.77109,-0.13591,1.10798,-1.78945,-0.152095,1.025,-1.81018,-0.12878,0.895612,-1.8032,-0.196154,0.717728,-1.79617,-0.233481,0.651705,-1.80817,-0.294649,0.770798,-1.80949,-0.328243,0.707933,-1.81627,-0.402749,0.484868,-1.82753,-0.516619,0.465469,-1.90658,-0.283286,0.376275,-1.86904,-0.328047,0.34272,-1.79849,0.239642,1.2308,-2.11535,0.301494,1.17638,-2.09303,0.144081,1.12326,-2.09668,0.204017,1.07381,-2.07907,0.320599,1.01904,-2.07266,0.255781,0.840341,-2.07744,0.165623,0.908843,-2.08439,0.127014,0.850753,-2.07996,0.015682,0.646812,-2.06296,-0.096343,0.605883,-2.00313,0.159197,0.502564,-2.07246,0.092688,0.498998,-2.13299,0.006347,1.31148,-1.83756,0.021062,1.33424,-2.05108},
/*34*/{0.141664,1.90844,-1.73542,0.190851,1.8491,-1.897,0.125085,1.75301,-1.61941,0.116177,1.63646,-1.53751,0.234943,1.66348,-1.64178,0.315818,1.6749,-1.68265,0.072628,1.93201,-2.11232,0.182837,1.8538,-1.97229,-0.036473,1.89167,-1.99946,-0.166949,1.82235,-2.14923,-0.192844,1.73293,-2.21094,-0.061664,1.5946,-2.16886,-0.029072,1.54015,-2.19085,0.088385,1.39458,-1.80275,-0.095356,1.47279,-1.88852,-0.091802,1.49894,-1.93413,-0.089973,1.47834,-2.00636,0.101197,1.43178,-2.06221,-0.006109,1.08703,-1.77285,-0.137955,1.11458,-1.78779,-0.158413,1.03351,-1.81063,-0.137215,0.90285,-1.8029,-0.20787,0.725279,-1.79513,-0.244497,0.659861,-1.80651,-0.306275,0.778497,-1.80905,-0.340107,0.715908,-1.81629,-0.415574,0.493065,-1.82544,-0.530892,0.479772,-1.90624,-0.301891,0.375934,-1.86953,-0.34918,0.344489,-1.79839,0.240656,1.23613,-2.11454,0.302563,1.18102,-2.09172,0.14519,1.12926,-2.09745,0.204392,1.07878,-2.07979,0.319515,1.02362,-2.07349,0.26506,0.84115,-2.07877,0.171024,0.904136,-2.08339,0.135271,0.843245,-2.07986,0.036259,0.633337,-2.06176,-0.072516,0.583818,-2.00101,0.188632,0.500236,-2.07441,0.120796,0.49254,-2.13466,0.007984,1.31403,-1.83902,0.021166,1.33908,-2.05239},
/*35*/{0.142448,1.91274,-1.73734,0.191083,1.85239,-1.89827,0.127285,1.7574,-1.62025,0.119793,1.6408,-1.53862,0.235851,1.66895,-1.64459,0.316163,1.68127,-1.68676,0.071861,1.93528,-2.11275,0.1831,1.85799,-1.97411,-0.036461,1.89409,-1.99918,-0.168549,1.82653,-2.14715,-0.195533,1.73817,-2.20901,-0.063721,1.60007,-2.16706,-0.032048,1.54534,-2.18987,0.090938,1.39654,-1.80453,-0.093524,1.47631,-1.88867,-0.090204,1.50294,-1.93269,-0.088457,1.4838,-2.00583,0.101657,1.43562,-2.06304,-0.007464,1.09175,-1.77315,-0.140892,1.12126,-1.78785,-0.162937,1.04086,-1.81085,-0.14581,0.910055,-1.80281,-0.218433,0.732659,-1.79385,-0.255359,0.667836,-1.8039,-0.31602,0.787021,-1.80864,-0.350384,0.724075,-1.81595,-0.42788,0.499835,-1.8236,-0.542267,0.493219,-1.90475,-0.321782,0.376278,-1.86964,-0.369252,0.345887,-1.79892,0.241196,1.24032,-2.11406,0.302412,1.18584,-2.09141,0.144495,1.13428,-2.09851,0.204921,1.08372,-2.08069,0.318443,1.02674,-2.07441,0.273691,0.840718,-2.07928,0.176103,0.898832,-2.08349,0.144839,0.835527,-2.08014,0.05445,0.620332,-2.06172,-0.048199,0.56404,-2.00039,0.21663,0.498107,-2.07547,0.149501,0.487425,-2.13591,0.009378,1.31668,-1.84072,0.021194,1.34369,-2.05393},
/*36*/{0.144206,1.91697,-1.73869,0.193049,1.857,-1.90002,0.129404,1.7617,-1.62115,0.120918,1.645,-1.53954,0.236246,1.67434,-1.64692,0.316741,1.68723,-1.68966,0.071069,1.93773,-2.11344,0.182507,1.86113,-1.9752,-0.035927,1.89706,-1.99878,-0.169851,1.8312,-2.14595,-0.198561,1.74294,-2.20524,-0.066365,1.60535,-2.16533,-0.034848,1.54989,-2.18858,0.093939,1.39867,-1.8059,-0.090914,1.48003,-1.88783,-0.088918,1.50681,-1.932,-0.086468,1.48857,-2.00487,0.101669,1.43979,-2.06344,-0.011773,1.09325,-1.77403,-0.142703,1.12883,-1.78736,-0.167932,1.04893,-1.81109,-0.153345,0.91721,-1.80248,-0.228128,0.740088,-1.79244,-0.266503,0.674278,-1.80229,-0.325243,0.794103,-1.80881,-0.360403,0.731832,-1.81559,-0.438982,0.507426,-1.82151,-0.552512,0.507233,-1.9036,-0.340887,0.377397,-1.86848,-0.390072,0.34832,-1.79918,0.24202,1.24445,-2.11278,0.302705,1.18935,-2.0904,0.144223,1.13948,-2.09907,0.204094,1.08666,-2.08103,0.317265,1.02841,-2.07508,0.281772,0.839673,-2.08047,0.181575,0.892271,-2.08369,0.15275,0.828214,-2.08037,0.073161,0.606858,-2.06156,-0.025325,0.545115,-2.0004,0.24478,0.496551,-2.07549,0.178326,0.48104,-2.13527,0.011347,1.31956,-1.84187,0.021476,1.34813,-2.05496},
/*37*/{0.146434,1.92114,-1.73999,0.193185,1.86006,-1.90158,0.131025,1.76617,-1.62166,0.123645,1.64913,-1.53968,0.236695,1.67949,-1.64908,0.316523,1.69277,-1.69315,0.070103,1.94052,-2.11368,0.183238,1.86447,-1.97643,-0.03598,1.90008,-1.99933,-0.170283,1.83585,-2.14389,-0.201162,1.74788,-2.20248,-0.068075,1.60956,-2.1644,-0.037086,1.55437,-2.18712,0.096504,1.40136,-1.80789,-0.089454,1.48411,-1.88666,-0.087365,1.51024,-1.93153,-0.085098,1.49391,-2.00427,0.102692,1.44429,-2.06456,-0.014464,1.09731,-1.77406,-0.143695,1.13371,-1.7856,-0.17072,1.05588,-1.80997,-0.159984,0.923624,-1.8026,-0.235805,0.747045,-1.79134,-0.274161,0.682319,-1.80048,-0.33317,0.801814,-1.80848,-0.36777,0.740251,-1.81317,-0.449966,0.51422,-1.81865,-0.561811,0.523012,-1.90228,-0.357696,0.378289,-1.86832,-0.410559,0.351446,-1.79919,0.242145,1.24758,-2.11261,0.302531,1.19147,-2.09026,0.143477,1.14309,-2.10013,0.202664,1.08941,-2.08288,0.31578,1.02962,-2.07694,0.288828,0.838708,-2.08261,0.187008,0.886,-2.0836,0.161404,0.819922,-2.07867,0.093574,0.595389,-2.06174,-0.000287,0.526266,-1.99913,0.272571,0.494941,-2.07439,0.207112,0.476083,-2.13454,0.013264,1.32268,-1.84345,0.021925,1.35304,-2.05636},
/*38*/{0.147034,1.92448,-1.74204,0.193239,1.86395,-1.90286,0.133215,1.77005,-1.62283,0.125482,1.65322,-1.54081,0.236989,1.6835,-1.65103,0.315839,1.69779,-1.69652,0.069484,1.94292,-2.11396,0.183393,1.86806,-1.9779,-0.035355,1.90236,-1.99888,-0.170918,1.84011,-2.14257,-0.203498,1.75201,-2.19952,-0.069787,1.61345,-2.16265,-0.039521,1.55814,-2.18595,0.097827,1.40328,-1.80925,-0.087068,1.48761,-1.88657,-0.086218,1.51452,-1.93023,-0.082367,1.49786,-2.00321,0.102166,1.44787,-2.06545,-0.017905,1.10002,-1.77368,-0.146031,1.14001,-1.78561,-0.1743,1.06188,-1.81011,-0.16475,0.929697,-1.80293,-0.242539,0.754177,-1.79021,-0.280909,0.689368,-1.79923,-0.339864,0.809922,-1.80653,-0.375202,0.74726,-1.81244,-0.459529,0.522164,-1.81728,-0.568921,0.539993,-1.90129,-0.374852,0.379791,-1.86694,-0.430644,0.354931,-1.7986,0.241824,1.25009,-2.11231,0.300954,1.193,-2.08962,0.141757,1.14611,-2.10132,0.200336,1.09251,-2.08429,0.314351,1.02983,-2.07847,0.296681,0.837346,-2.08335,0.191484,0.879121,-2.08473,0.169558,0.810637,-2.07887,0.113708,0.583699,-2.06145,0.025079,0.509521,-2.00023,0.299805,0.494362,-2.0723,0.23635,0.471237,-2.13306,0.014206,1.32527,-1.84459,0.021584,1.35703,-2.05734},
/*39*/{0.149317,1.92832,-1.74267,0.195164,1.86743,-1.90378,0.134653,1.77367,-1.62369,0.127873,1.65591,-1.54121,0.237154,1.68796,-1.65334,0.315565,1.70214,-1.7,0.068826,1.94556,-2.11447,0.183994,1.87127,-1.97942,-0.03504,1.90473,-1.99699,-0.17182,1.84368,-2.14032,-0.205307,1.75567,-2.19647,-0.071426,1.61718,-2.16141,-0.040983,1.56186,-2.18514,0.099971,1.40589,-1.81008,-0.084988,1.49207,-1.88458,-0.084371,1.51787,-1.92944,-0.08087,1.50197,-2.00181,0.102153,1.45139,-2.06624,-0.019317,1.10343,-1.77309,-0.14692,1.14616,-1.78616,-0.17735,1.06769,-1.81064,-0.169003,0.934911,-1.80354,-0.248653,0.760871,-1.78925,-0.286967,0.697176,-1.79698,-0.345024,0.81711,-1.806,-0.380928,0.754514,-1.80918,-0.468457,0.530356,-1.81395,-0.575404,0.555745,-1.89881,-0.392727,0.381381,-1.86553,-0.450272,0.35923,-1.79903,0.241108,1.25192,-2.11208,0.299336,1.19321,-2.08996,0.140267,1.14944,-2.102,0.197891,1.09407,-2.08537,0.312622,1.02944,-2.07983,0.303014,0.835834,-2.08391,0.19707,0.872489,-2.08574,0.176895,0.804973,-2.07938,0.13592,0.573122,-2.06157,0.04901,0.49436,-2.00037,0.324886,0.494508,-2.06974,0.263953,0.46619,-2.13039,0.015826,1.32849,-1.84471,0.021287,1.36077,-2.05744},
/*40*/{0.150145,1.9312,-1.74375,0.195657,1.87076,-1.90568,0.135924,1.77681,-1.62468,0.128175,1.65946,-1.54129,0.237392,1.69189,-1.65516,0.315806,1.70642,-1.70246,0.06841,1.94784,-2.11518,0.184278,1.87431,-1.98038,-0.034089,1.9074,-1.99761,-0.172572,1.84654,-2.13976,-0.207321,1.75878,-2.19355,-0.072848,1.62065,-2.16021,-0.042545,1.56469,-2.1839,0.100995,1.40886,-1.811,-0.083757,1.49525,-1.8844,-0.083394,1.52171,-1.92896,-0.079922,1.50573,-2.00097,0.102896,1.45511,-2.06653,-0.020895,1.10756,-1.77212,-0.150681,1.14968,-1.78635,-0.179321,1.07262,-1.81086,-0.171626,0.939956,-1.8041,-0.254419,0.766586,-1.78808,-0.294475,0.702792,-1.79504,-0.349033,0.823563,-1.80294,-0.385783,0.761556,-1.80783,-0.474727,0.536185,-1.81012,-0.580246,0.572086,-1.89562,-0.409468,0.383815,-1.86528,-0.469675,0.365004,-1.79885,0.240206,1.25253,-2.11197,0.297506,1.19296,-2.09007,0.137651,1.15073,-2.10287,0.194756,1.09478,-2.08687,0.309574,1.02805,-2.08147,0.309419,0.83386,-2.08503,0.200554,0.865238,-2.08594,0.184877,0.799547,-2.07982,0.15671,0.562781,-2.06195,0.072428,0.479236,-2.00319,0.34911,0.49463,-2.0664,0.29136,0.462251,-2.12736,0.016843,1.33155,-1.84533,0.021737,1.3647,-2.05794},
/*41*/{0.151667,1.93391,-1.7453,0.195878,1.87397,-1.9071,0.137636,1.78055,-1.62558,0.129082,1.66201,-1.5423,0.237741,1.69592,-1.65729,0.315447,1.70966,-1.70526,0.068825,1.94966,-2.11559,0.184502,1.87676,-1.98142,-0.033539,1.90912,-1.9968,-0.172271,1.849,-2.1363,-0.208412,1.76161,-2.19114,-0.074118,1.62321,-2.15939,-0.043149,1.56723,-2.18291,0.102451,1.41179,-1.81201,-0.082531,1.49898,-1.88373,-0.082147,1.52563,-1.92853,-0.078998,1.50957,-1.99976,0.103348,1.45827,-2.06669,-0.021933,1.10973,-1.77118,-0.151428,1.15403,-1.786,-0.181104,1.07759,-1.81033,-0.17382,0.944031,-1.80536,-0.257927,0.771911,-1.78762,-0.299062,0.708305,-1.79391,-0.352121,0.830242,-1.8019,-0.389395,0.769298,-1.80544,-0.483309,0.547903,-1.80871,-0.583463,0.588901,-1.89102,-0.427992,0.386615,-1.86498,-0.48914,0.371279,-1.79959,0.238143,1.25173,-2.11169,0.294915,1.192,-2.09074,0.13449,1.15188,-2.10343,0.190991,1.09455,-2.08862,0.306325,1.0268,-2.08336,0.316547,0.831629,-2.0854,0.205778,0.858405,-2.08738,0.19314,0.788273,-2.08001,0.176031,0.553067,-2.06236,0.096536,0.465891,-2.00056,0.37274,0.495308,-2.06388,0.317474,0.458375,-2.1243,0.017804,1.3348,-1.84549,0.021677,1.36831,-2.05807},
/*42*/{0.153229,1.93662,-1.74647,0.196928,1.87705,-1.90795,0.138829,1.78359,-1.62688,0.1299,1.66438,-1.54318,0.238411,1.69763,-1.65966,0.315199,1.71231,-1.70816,0.06864,1.95177,-2.11647,0.18516,1.87885,-1.98275,-0.032918,1.91132,-1.99714,-0.172693,1.85119,-2.13527,-0.208934,1.76391,-2.18941,-0.074573,1.62525,-2.15785,-0.043895,1.56967,-2.18187,0.102209,1.41421,-1.81233,-0.081373,1.50231,-1.88224,-0.080955,1.52936,-1.92839,-0.078529,1.51254,-1.99931,0.103627,1.46093,-2.06649,-0.022716,1.11243,-1.77104,-0.152261,1.15744,-1.78645,-0.181661,1.08107,-1.81025,-0.174652,0.948042,-1.80553,-0.261421,0.777153,-1.78741,-0.30294,0.714164,-1.79316,-0.354541,0.836615,-1.8017,-0.392713,0.776185,-1.80408,-0.489983,0.555086,-1.80515,-0.585746,0.605729,-1.88473,-0.444778,0.391521,-1.86625,-0.507022,0.379256,-1.80083,0.235653,1.25093,-2.11204,0.292063,1.18992,-2.09171,0.131105,1.15209,-2.10396,0.186605,1.09382,-2.08918,0.303593,1.02425,-2.08504,0.320824,0.829615,-2.08662,0.209533,0.850364,-2.08948,0.200685,0.780004,-2.0815,0.195386,0.543884,-2.06197,0.120946,0.453798,-2.00116,0.395525,0.496283,-2.05933,0.343024,0.454485,-2.12064,0.017716,1.3376,-1.84527,0.021338,1.37126,-2.05783},
/*43*/{0.15465,1.9391,-1.74766,0.19775,1.87952,-1.9094,0.140129,1.78588,-1.62774,0.130465,1.66611,-1.5433,0.238379,1.69929,-1.66004,0.314682,1.71428,-1.71059,0.068766,1.95357,-2.11686,0.185341,1.88074,-1.98392,-0.03213,1.91337,-1.99666,-0.172489,1.85383,-2.13487,-0.209681,1.76512,-2.18718,-0.074728,1.62684,-2.15711,-0.044028,1.57114,-2.18129,0.103671,1.41763,-1.81229,-0.080373,1.50528,-1.88113,-0.081082,1.53232,-1.92731,-0.077754,1.51588,-1.99771,0.103232,1.46333,-2.06597,-0.023981,1.11496,-1.77076,-0.151626,1.16063,-1.78722,-0.181447,1.08413,-1.81104,-0.174994,0.950552,-1.80555,-0.26346,0.782054,-1.78686,-0.30599,0.719812,-1.79186,-0.355333,0.842427,-1.80125,-0.395411,0.78349,-1.80233,-0.493122,0.564684,-1.80267,-0.587839,0.622382,-1.87793,-0.461,0.398887,-1.86866,-0.522088,0.387836,-1.80188,0.234182,1.24842,-2.11217,0.289583,1.18657,-2.09244,0.126941,1.15133,-2.10476,0.18228,1.0925,-2.09022,0.300194,1.02134,-2.08734,0.324638,0.827542,-2.0877,0.212485,0.84186,-2.09062,0.20705,0.772863,-2.08308,0.215025,0.536396,-2.06225,0.14335,0.443508,-2.0014,0.41654,0.49689,-2.05489,0.367262,0.451712,-2.11677,0.018781,1.34084,-1.8442,0.02107,1.37397,-2.05686},
/*44*/{0.156111,1.9403,-1.74854,0.198782,1.88185,-1.91094,0.141469,1.788,-1.62907,0.131452,1.66881,-1.54353,0.238341,1.70092,-1.66144,0.314608,1.71514,-1.71266,0.069411,1.95478,-2.11745,0.185965,1.88253,-1.98593,-0.031427,1.91566,-1.9969,-0.172775,1.85471,-2.13329,-0.21003,1.76665,-2.18543,-0.074699,1.62797,-2.15605,-0.04444,1.5721,-2.18052,0.103873,1.41962,-1.81155,-0.079835,1.50863,-1.88098,-0.080578,1.53529,-1.92703,-0.076638,1.51825,-1.99729,0.103466,1.46485,-2.06563,-0.025843,1.11766,-1.77145,-0.151543,1.16157,-1.78866,-0.180142,1.0863,-1.81146,-0.174042,0.952519,-1.80636,-0.264533,0.784727,-1.78709,-0.308839,0.723367,-1.7911,-0.355613,0.848196,-1.80035,-0.39613,0.789527,-1.8006,-0.497603,0.572899,-1.79913,-0.590015,0.638,-1.87001,-0.476813,0.407726,-1.87216,-0.538193,0.397097,-1.80528,0.230761,1.24604,-2.11329,0.284795,1.18345,-2.09387,0.123132,1.15063,-2.106,0.176864,1.09071,-2.09139,0.296506,1.01763,-2.08898,0.328453,0.825362,-2.08907,0.215059,0.834203,-2.0929,0.212965,0.764543,-2.08638,0.233167,0.529103,-2.06236,0.163119,0.433132,-2.00078,0.435842,0.498285,-2.0517,0.39,0.448008,-2.11157,0.018415,1.34341,-1.84337,0.020909,1.37588,-2.05612},
/*45*/{0.157728,1.94247,-1.75074,0.198445,1.8835,-1.91185,0.142096,1.79,-1.63007,0.131088,1.67045,-1.54483,0.237926,1.70183,-1.66351,0.313732,1.71584,-1.71476,0.06925,1.95625,-2.11922,0.186706,1.88398,-1.98625,-0.030078,1.91667,-1.99823,-0.17317,1.85494,-2.13223,-0.209988,1.76681,-2.18377,-0.073263,1.6294,-2.15456,-0.043968,1.57305,-2.18,0.104358,1.42237,-1.81209,-0.079976,1.51077,-1.88039,-0.080107,1.53812,-1.9273,-0.077575,1.52069,-1.99643,0.103444,1.46693,-2.06506,-0.026071,1.11979,-1.77185,-0.150011,1.16229,-1.78962,-0.178329,1.08669,-1.81161,-0.170936,0.954041,-1.80609,-0.264336,0.787452,-1.78642,-0.310336,0.726963,-1.79081,-0.353853,0.853205,-1.79841,-0.396508,0.795914,-1.7996,-0.50214,0.581658,-1.79912,-0.592008,0.653819,-1.86045,-0.493776,0.416238,-1.87716,-0.55295,0.407095,-1.8077,0.227541,1.24289,-2.11427,0.281421,1.17841,-2.09495,0.1181,1.1487,-2.10699,0.171406,1.08796,-2.09186,0.293433,1.01369,-2.0905,0.331077,0.822558,-2.08975,0.217657,0.827785,-2.09594,0.21889,0.757111,-2.08816,0.24696,0.520677,-2.0616,0.182718,0.424933,-2.00012,0.454334,0.499494,-2.04853,0.411456,0.44553,-2.1072,0.018677,1.346,-1.84297,0.020605,1.37816,-2.05579},
/*46*/{0.15915,1.94364,-1.75113,0.198594,1.88629,-1.91377,0.142896,1.79136,-1.63126,0.131049,1.67126,-1.54513,0.237614,1.70228,-1.66434,0.311763,1.71612,-1.71684,0.070671,1.9571,-2.11995,0.187447,1.88525,-1.98783,-0.028733,1.91801,-1.99868,-0.17063,1.85573,-2.12966,-0.209798,1.76698,-2.18241,-0.073334,1.62949,-2.15375,-0.043155,1.57266,-2.1791,0.104636,1.42513,-1.81186,-0.079135,1.51286,-1.8805,-0.080448,1.54025,-1.92477,-0.077017,1.52234,-1.99601,0.104384,1.46853,-2.0645,-0.023914,1.1204,-1.77229,-0.148183,1.16566,-1.79033,-0.174921,1.08592,-1.81094,-0.167004,0.953808,-1.80677,-0.262893,0.789159,-1.7864,-0.311401,0.730051,-1.79174,-0.350964,0.857552,-1.79679,-0.394937,0.801462,-1.79773,-0.509184,0.590157,-1.7979,-0.597036,0.668921,-1.85206,-0.508709,0.429481,-1.88081,-0.564177,0.418968,-1.81048,0.224153,1.23899,-2.11507,0.276417,1.1743,-2.09626,0.113635,1.14627,-2.1073,0.165544,1.08555,-2.0929,0.288425,1.00863,-2.09201,0.334343,0.820983,-2.08993,0.220143,0.820402,-2.09845,0.224386,0.751022,-2.09066,0.265048,0.515904,-2.06207,0.201654,0.417607,-1.99816,0.470533,0.500063,-2.04455,0.430565,0.443486,-2.10301,0.019432,1.34827,-1.84198,0.021114,1.38,-2.05485},
/*47*/{0.160098,1.94429,-1.75252,0.198679,1.88719,-1.91437,0.143776,1.79247,-1.63239,0.130575,1.67222,-1.54558,0.237214,1.70154,-1.66623,0.312194,1.71606,-1.71911,0.07163,1.95744,-2.12098,0.188196,1.88607,-1.98859,-0.027792,1.91932,-1.99878,-0.170834,1.85578,-2.12919,-0.209178,1.76667,-2.18172,-0.072405,1.62868,-2.15269,-0.041627,1.57217,-2.17864,0.104975,1.42681,-1.81132,-0.079185,1.5142,-1.87982,-0.080741,1.54223,-1.92566,-0.077161,1.52363,-1.99559,0.104002,1.46923,-2.06378,-0.022335,1.12093,-1.77241,-0.145909,1.16227,-1.78954,-0.171506,1.08533,-1.81274,-0.162637,0.952821,-1.80682,-0.262213,0.789844,-1.78637,-0.311704,0.733055,-1.7925,-0.346499,0.861939,-1.79376,-0.392858,0.806766,-1.79486,-0.512563,0.600187,-1.79635,-0.602013,0.683543,-1.84336,-0.520758,0.441876,-1.88565,-0.574317,0.431284,-1.81375,0.21962,1.2347,-2.11658,0.271907,1.16939,-2.09774,0.108424,1.14398,-2.10817,0.15957,1.0816,-2.0935,0.283341,1.00382,-2.09297,0.33592,0.818734,-2.08957,0.223049,0.813505,-2.10088,0.229672,0.74375,-2.09222,0.279355,0.510509,-2.0623,0.218217,0.412439,-1.99769,0.484499,0.501367,-2.04171,0.44794,0.441815,-2.09925,0.019256,1.35007,-1.84105,0.020825,1.38084,-2.05407},
/*48*/{0.161582,1.94457,-1.75316,0.200124,1.88803,-1.9162,0.143548,1.7931,-1.63367,0.129764,1.6729,-1.54682,0.236341,1.7012,-1.66762,0.310909,1.71279,-1.72017,0.073075,1.95798,-2.12206,0.188133,1.88642,-1.98971,-0.02679,1.92048,-2.00038,-0.170339,1.8551,-2.12807,-0.207544,1.76531,-2.18011,-0.069419,1.62805,-2.15197,-0.039799,1.57101,-2.17771,0.104888,1.42876,-1.81133,-0.078888,1.51561,-1.87957,-0.081143,1.54368,-1.92559,-0.076674,1.52395,-1.99553,0.104889,1.4708,-2.06273,-0.01642,1.12093,-1.77347,-0.142018,1.16042,-1.78989,-0.16726,1.08297,-1.81198,-0.156655,0.950447,-1.80692,-0.259548,0.790117,-1.78724,-0.312461,0.735134,-1.79324,-0.342204,0.865818,-1.79194,-0.390884,0.812358,-1.79354,-0.518735,0.610373,-1.79674,-0.606723,0.697205,-1.83613,-0.532601,0.456653,-1.89041,-0.584143,0.443243,-1.8161,0.216844,1.22965,-2.11742,0.266557,1.16406,-2.09913,0.103199,1.14152,-2.10845,0.152621,1.07875,-2.09348,0.278011,0.998799,-2.09378,0.338712,0.816976,-2.08799,0.226251,0.806624,-2.10394,0.234627,0.73791,-2.09495,0.291757,0.505392,-2.06141,0.233177,0.40701,-1.99665,0.497573,0.503339,-2.03952,0.46324,0.441094,-2.09601,0.019777,1.35168,-1.84044,0.021823,1.38207,-2.0535},
/*49*/{0.162863,1.94485,-1.75438,0.199384,1.88821,-1.91685,0.142953,1.79364,-1.63504,0.128781,1.67267,-1.54707,0.235686,1.69957,-1.66892,0.310354,1.71002,-1.72197,0.074403,1.95786,-2.12357,0.188596,1.88632,-1.99064,-0.025549,1.9209,-2.00187,-0.169358,1.85437,-2.1266,-0.206259,1.76414,-2.18011,-0.068104,1.62619,-2.15091,-0.037832,1.56969,-2.17746,0.104232,1.43064,-1.81093,-0.079088,1.51594,-1.87945,-0.081433,1.54508,-1.926,-0.077103,1.5245,-1.99563,0.106764,1.47154,-2.0619,-0.016291,1.11903,-1.77369,-0.137332,1.1606,-1.78974,-0.162179,1.08066,-1.81296,-0.149553,0.948246,-1.80691,-0.257537,0.789576,-1.78858,-0.313172,0.737091,-1.79504,-0.336665,0.869851,-1.78961,-0.387972,0.8186,-1.79062,-0.521573,0.621894,-1.79607,-0.611452,0.711181,-1.82963,-0.542453,0.470218,-1.89432,-0.591889,0.455571,-1.81933,0.212596,1.22518,-2.11842,0.261905,1.15817,-2.1002,0.097708,1.13962,-2.10754,0.147132,1.07496,-2.09442,0.271921,0.993132,-2.09476,0.339906,0.81484,-2.08622,0.229507,0.801096,-2.10663,0.240591,0.733088,-2.09716,0.302834,0.502508,-2.06174,0.24591,0.403101,-1.99708,0.507752,0.504948,-2.038,0.477038,0.441549,-2.09307,0.019835,1.35297,-1.83979,0.023016,1.38289,-2.05291},
/*50*/{0.163621,1.94417,-1.7558,0.199706,1.88865,-1.91824,0.142407,1.79336,-1.63631,0.126211,1.67348,-1.54853,0.234177,1.6978,-1.66976,0.30831,1.70697,-1.72328,0.075669,1.9572,-2.12433,0.189339,1.88611,-1.99098,-0.024926,1.92177,-2.00237,-0.167231,1.85271,-2.12574,-0.204491,1.76209,-2.17989,-0.065519,1.62449,-2.15046,-0.036297,1.56731,-2.17727,0.104306,1.43141,-1.81051,-0.079754,1.51644,-1.88024,-0.081442,1.54525,-1.92568,-0.077342,1.52413,-1.99581,0.106586,1.4715,-2.06105,-0.01238,1.11717,-1.77575,-0.131533,1.15738,-1.78887,-0.156364,1.07718,-1.813,-0.141467,0.945332,-1.80722,-0.255092,0.789219,-1.78964,-0.313031,0.739768,-1.79608,-0.330347,0.872734,-1.78698,-0.38368,0.824175,-1.78883,-0.527219,0.632245,-1.79525,-0.615505,0.725189,-1.82463,-0.551901,0.486268,-1.89738,-0.598183,0.469628,-1.82142,0.209231,1.22006,-2.11949,0.257497,1.15226,-2.10186,0.092757,1.13617,-2.10759,0.140769,1.0706,-2.09379,0.266342,0.988805,-2.09545,0.341165,0.812834,-2.08501,0.231438,0.795898,-2.10778,0.244768,0.728432,-2.09831,0.311855,0.499024,-2.06271,0.256873,0.399105,-1.99495,0.516367,0.505951,-2.03615,0.487598,0.441753,-2.09167,0.019732,1.35359,-1.83907,0.023204,1.38269,-2.0523},
/*51*/{0.16499,1.9441,-1.75668,0.20132,1.88816,-1.91893,0.141457,1.79347,-1.63728,0.124478,1.67335,-1.55011,0.232775,1.69527,-1.67088,0.307055,1.70314,-1.72538,0.076632,1.95641,-2.12592,0.190314,1.88592,-1.99161,-0.023199,1.92138,-2.0052,-0.166097,1.85064,-2.1254,-0.202667,1.75971,-2.18023,-0.0635,1.62196,-2.15037,-0.033736,1.5646,-2.17699,0.104832,1.43242,-1.80997,-0.079782,1.51594,-1.88051,-0.081442,1.54525,-1.92568,-0.077367,1.52332,-1.99547,0.106406,1.47159,-2.05988,0.004514,1.11913,-1.77544,-0.126687,1.15426,-1.78799,-0.150193,1.07375,-1.81293,-0.13355,0.941381,-1.80687,-0.252703,0.789466,-1.79086,-0.31238,0.743009,-1.79685,-0.324318,0.876384,-1.78467,-0.377988,0.830762,-1.78657,-0.530773,0.645045,-1.79446,-0.617619,0.740227,-1.82081,-0.559494,0.501146,-1.89941,-0.605343,0.483455,-1.82223,0.205447,1.21502,-2.12029,0.25297,1.14649,-2.10272,0.087306,1.13245,-2.10734,0.134906,1.06645,-2.09397,0.260508,0.983475,-2.09538,0.341343,0.810659,-2.08302,0.231788,0.791568,-2.10787,0.247444,0.724226,-2.09856,0.318236,0.4967,-2.06246,0.266049,0.39445,-1.99648,0.523432,0.508103,-2.03643,0.495726,0.441269,-2.08999,0.020463,1.35407,-1.83811,0.02394,1.38232,-2.05145},
/*52*/{0.165338,1.9433,-1.75824,0.200526,1.88763,-1.9197,0.139536,1.79316,-1.63822,0.12195,1.67206,-1.55072,0.231629,1.69242,-1.67216,0.306009,1.69892,-1.72615,0.077757,1.95557,-2.12693,0.190326,1.88555,-1.99206,-0.02308,1.9212,-2.00634,-0.165022,1.84893,-2.12502,-0.200134,1.75684,-2.18046,-0.061235,1.61895,-2.15,-0.030995,1.56122,-2.17685,0.104735,1.43288,-1.8097,-0.079867,1.51574,-1.88097,-0.081586,1.54509,-1.92571,-0.07804,1.52157,-1.99621,0.106693,1.47141,-2.0593,0.009503,1.11771,-1.77801,-0.122008,1.14726,-1.78705,-0.143034,1.06928,-1.81214,-0.125206,0.937652,-1.80739,-0.250055,0.790261,-1.79136,-0.311763,0.74569,-1.79776,-0.317686,0.879942,-1.78387,-0.374713,0.83704,-1.78441,-0.532635,0.65962,-1.79452,-0.618348,0.755658,-1.81916,-0.566678,0.516183,-1.89889,-0.612511,0.499341,-1.82308,0.202032,1.20961,-2.12107,0.247726,1.14067,-2.10391,0.082988,1.12952,-2.10679,0.128984,1.06304,-2.09392,0.254234,0.978836,-2.09527,0.339805,0.809057,-2.08184,0.231264,0.787828,-2.10722,0.246778,0.72018,-2.0981,0.323731,0.493337,-2.06194,0.272002,0.391327,-1.99662,0.527768,0.508408,-2.03693,0.502183,0.440951,-2.09015,0.020796,1.35424,-1.8375,0.024552,1.38157,-2.05096},
/*53*/{0.16545,1.94126,-1.75878,0.200154,1.88722,-1.92003,0.13819,1.79244,-1.63948,0.119802,1.67176,-1.55239,0.230059,1.68916,-1.67348,0.304261,1.69398,-1.72731,0.078817,1.95409,-2.12789,0.190605,1.88423,-1.99346,-0.022692,1.92083,-2.00807,-0.162066,1.84601,-2.1247,-0.197925,1.75338,-2.18142,-0.057645,1.61556,-2.14975,-0.028227,1.55756,-2.17729,0.104587,1.43283,-1.80919,-0.080466,1.5144,-1.88162,-0.082098,1.54414,-1.92616,-0.078152,1.52063,-1.99663,0.106868,1.47077,-2.05854,0.016831,1.11505,-1.77889,-0.116807,1.14264,-1.78691,-0.136678,1.06465,-1.81268,-0.115957,0.932716,-1.80812,-0.246254,0.79203,-1.79184,-0.309321,0.750597,-1.79906,-0.310099,0.88401,-1.78214,-0.36956,0.843239,-1.78462,-0.535846,0.672197,-1.7926,-0.616607,0.772417,-1.82027,-0.572761,0.530855,-1.897,-0.620154,0.516192,-1.82162,0.198651,1.20496,-2.12206,0.244107,1.13507,-2.10503,0.078644,1.12661,-2.1067,0.12434,1.05944,-2.0931,0.248326,0.97441,-2.09501,0.338161,0.807361,-2.08142,0.229172,0.784622,-2.10531,0.245202,0.717435,-2.09694,0.32677,0.491003,-2.06203,0.277545,0.387882,-1.99589,0.531622,0.508197,-2.03674,0.505859,0.440822,-2.09043,0.020791,1.35375,-1.83718,0.025277,1.38071,-2.05068},
/*54*/{0.166056,1.94023,-1.76027,0.200167,1.88529,-1.92105,0.13564,1.79108,-1.64065,0.116036,1.67091,-1.55362,0.227476,1.68561,-1.67388,0.302088,1.68863,-1.72862,0.079944,1.95245,-2.12953,0.190076,1.88287,-1.99334,-0.02154,1.91956,-2.0097,-0.16019,1.84226,-2.12447,-0.194833,1.74886,-2.18221,-0.054859,1.61127,-2.15026,-0.024548,1.55357,-2.17775,0.10467,1.43278,-1.80883,-0.080885,1.51299,-1.88164,-0.082378,1.54265,-1.92693,-0.078526,1.51902,-1.99802,0.107509,1.46909,-2.05817,0.023005,1.11356,-1.77971,-0.111398,1.13889,-1.78754,-0.128897,1.05992,-1.81299,-0.106676,0.928485,-1.80952,-0.24261,0.793605,-1.79248,-0.307993,0.754513,-1.79835,-0.303383,0.887973,-1.78145,-0.362468,0.849321,-1.78286,-0.536304,0.687244,-1.79196,-0.613827,0.789442,-1.82223,-0.578307,0.544162,-1.89338,-0.626715,0.533409,-1.81844,0.195593,1.20026,-2.12275,0.240936,1.12976,-2.10634,0.075363,1.12365,-2.10561,0.119716,1.05653,-2.09236,0.242528,0.969509,-2.09458,0.334844,0.804974,-2.08135,0.225341,0.780898,-2.1034,0.243672,0.713685,-2.09416,0.328198,0.488389,-2.06189,0.277268,0.386176,-1.99803,0.533121,0.507383,-2.03792,0.508562,0.440721,-2.09145,0.021031,1.35321,-1.83654,0.026044,1.3789,-2.05017},
/*55*/{0.166007,1.93918,-1.76145,0.20058,1.88344,-1.92158,0.134475,1.78987,-1.64162,0.113068,1.66893,-1.55482,0.225718,1.68139,-1.67467,0.299729,1.68295,-1.72922,0.080897,1.9504,-2.13044,0.190496,1.88115,-1.99374,-0.021424,1.91862,-2.01226,-0.158681,1.83818,-2.12438,-0.191655,1.74452,-2.18327,-0.05142,1.60723,-2.15137,-0.020526,1.54907,-2.17842,0.104697,1.43235,-1.80864,-0.080849,1.51131,-1.88173,-0.083066,1.54085,-1.92769,-0.078607,1.51636,-1.9976,0.106326,1.46768,-2.05843,0.029403,1.11289,-1.78085,-0.106008,1.1347,-1.78624,-0.122097,1.05348,-1.81194,-0.098132,0.92467,-1.80979,-0.237637,0.79585,-1.79167,-0.303765,0.759649,-1.79943,-0.294972,0.893003,-1.78064,-0.35634,0.856729,-1.78244,-0.536487,0.701573,-1.79164,-0.609437,0.806281,-1.82565,-0.581988,0.557725,-1.88959,-0.634224,0.55187,-1.81492,0.192401,1.19568,-2.12506,0.236875,1.12501,-2.10724,0.071896,1.1208,-2.10533,0.115389,1.05271,-2.09163,0.237513,0.965814,-2.09444,0.33033,0.802721,-2.08275,0.220597,0.776828,-2.10151,0.24053,0.709995,-2.09247,0.328752,0.486323,-2.06161,0.282289,0.382798,-1.99556,0.533614,0.506965,-2.03941,0.507252,0.439633,-2.09275,0.021593,1.35228,-1.83593,0.025939,1.37683,-2.04972},
/*56*/{0.165742,1.93786,-1.762,0.200019,1.8819,-1.92192,0.131008,1.78855,-1.64245,0.109085,1.66738,-1.55625,0.222333,1.67609,-1.67542,0.29839,1.67652,-1.72985,0.082317,1.94803,-2.1312,0.190468,1.87878,-1.99404,-0.021123,1.91698,-2.0127,-0.156804,1.83416,-2.12574,-0.1881,1.73934,-2.18529,-0.048451,1.60229,-2.15222,-0.017219,1.54451,-2.17934,0.10464,1.43184,-1.8084,-0.082252,1.50935,-1.88375,-0.082194,1.53858,-1.92797,-0.079273,1.5142,-1.99913,0.10681,1.46553,-2.05891,0.035602,1.10835,-1.78116,-0.100867,1.12932,-1.78555,-0.115224,1.04842,-1.81148,-0.08882,0.921298,-1.81076,-0.23309,0.798581,-1.79103,-0.301893,0.764516,-1.79691,-0.286935,0.897313,-1.78029,-0.349338,0.863509,-1.78248,-0.536565,0.716118,-1.78952,-0.603137,0.823355,-1.8305,-0.584534,0.571973,-1.88417,-0.639429,0.570094,-1.81153,0.191135,1.19177,-2.12536,0.234339,1.12113,-2.10843,0.068924,1.1188,-2.1045,0.11207,1.05046,-2.09047,0.232431,0.961812,-2.09376,0.32499,0.799094,-2.08316,0.215201,0.77288,-2.10005,0.23599,0.705766,-2.09046,0.326853,0.483197,-2.0603,0.282058,0.378982,-1.9928,0.532626,0.504642,-2.03926,0.505266,0.437424,-2.09399,0.02167,1.35114,-1.83587,0.026693,1.37452,-2.04977},
/*57*/{0.165515,1.93491,-1.76276,0.200159,1.88017,-1.92263,0.128367,1.78681,-1.64294,0.105558,1.66569,-1.55751,0.219666,1.67154,-1.67617,0.29465,1.66988,-1.73006,0.083587,1.94509,-2.1328,0.190596,1.87627,-1.99426,-0.020751,1.9152,-2.01629,-0.154905,1.82932,-2.12609,-0.185354,1.73403,-2.18634,-0.044021,1.59763,-2.15365,-0.01404,1.53939,-2.18086,0.104317,1.43051,-1.8084,-0.082016,1.50725,-1.88383,-0.081637,1.53623,-1.92828,-0.07875,1.5119,-1.99961,0.10606,1.46319,-2.05932,0.041639,1.10614,-1.78054,-0.095091,1.12375,-1.78496,-0.107835,1.04347,-1.8111,-0.080324,0.917414,-1.81063,-0.228038,0.801919,-1.78983,-0.297046,0.770635,-1.79618,-0.277753,0.902759,-1.78064,-0.341927,0.870222,-1.78302,-0.536643,0.730238,-1.78725,-0.596344,0.839156,-1.83567,-0.586716,0.584817,-1.87856,-0.642435,0.588658,-1.80789,0.189325,1.18783,-2.12624,0.231414,1.11712,-2.10993,0.066337,1.11642,-2.10416,0.108986,1.04796,-2.08976,0.228294,0.958447,-2.09387,0.320449,0.795873,-2.08382,0.210485,0.768476,-2.09869,0.231618,0.701712,-2.08879,0.320737,0.478753,-2.05962,0.279089,0.376612,-1.98961,0.529868,0.501032,-2.03983,0.502637,0.434757,-2.09412,0.02184,1.34943,-1.83563,0.026632,1.37202,-2.04962},
/*58*/{0.16453,1.93205,-1.76334,0.200634,1.8764,-1.92287,0.125826,1.78426,-1.64352,0.10208,1.66419,-1.55907,0.216184,1.66674,-1.67671,0.292682,1.66324,-1.7304,0.084066,1.94222,-2.13383,0.190832,1.87378,-1.99461,-0.020347,1.91214,-2.01792,-0.152761,1.82357,-2.1281,-0.182221,1.72796,-2.18876,-0.040386,1.59186,-2.15579,-0.009464,1.53354,-2.18195,0.104538,1.42871,-1.80874,-0.082105,1.50489,-1.88373,-0.082742,1.53374,-1.92902,-0.079608,1.50893,-2.00001,0.106768,1.46088,-2.05979,0.044857,1.10484,-1.7817,-0.090028,1.11792,-1.78483,-0.101754,1.03772,-1.81198,-0.072121,0.91428,-1.81051,-0.222951,0.804958,-1.78822,-0.292812,0.776447,-1.79399,-0.269413,0.90728,-1.78161,-0.334748,0.877452,-1.78332,-0.533184,0.745203,-1.78508,-0.588396,0.854234,-1.84087,-0.586789,0.598937,-1.87307,-0.644713,0.606931,-1.80364,0.18718,1.18456,-2.12799,0.228755,1.11256,-2.1113,0.064079,1.11505,-2.10402,0.105422,1.0455,-2.08903,0.225968,0.95569,-2.0932,0.314302,0.792053,-2.08468,0.205192,0.764713,-2.09752,0.226736,0.698245,-2.08798,0.319478,0.475922,-2.05796,0.274564,0.373331,-1.98926,0.525421,0.497027,-2.04079,0.497646,0.42991,-2.0938,0.022271,1.34742,-1.83566,0.026935,1.36951,-2.0497},
/*59*/{0.163495,1.92923,-1.76335,0.200155,1.87364,-1.92331,0.122698,1.78242,-1.64411,0.097048,1.66085,-1.56008,0.212536,1.66108,-1.67691,0.288604,1.65516,-1.73013,0.084176,1.93892,-2.13441,0.191122,1.87067,-1.99498,-0.021332,1.90994,-2.0194,-0.150815,1.81717,-2.13015,-0.179307,1.72125,-2.19107,-0.037182,1.58606,-2.15753,-0.006131,1.52765,-2.18339,0.104627,1.42733,-1.80869,-0.082702,1.50179,-1.88458,-0.082864,1.53041,-1.92944,-0.080316,1.5057,-2.00054,0.105079,1.45786,-2.06051,0.050539,1.10193,-1.78187,-0.084585,1.11209,-1.78437,-0.094622,1.03194,-1.81226,-0.063252,0.910725,-1.81092,-0.216949,0.808723,-1.78698,-0.286394,0.782319,-1.79262,-0.260318,0.912251,-1.78272,-0.325232,0.885191,-1.78441,-0.528359,0.76051,-1.78671,-0.579834,0.868586,-1.84558,-0.585624,0.61178,-1.86827,-0.644594,0.624444,-1.79935,0.185425,1.18144,-2.12853,0.225767,1.10913,-2.11304,0.061738,1.11257,-2.10235,0.103248,1.04386,-2.08854,0.223876,0.953138,-2.09304,0.309646,0.787463,-2.0852,0.200389,0.76068,-2.09695,0.220978,0.694273,-2.08704,0.312685,0.471168,-2.0568,0.268141,0.369589,-1.98533,0.520008,0.49049,-2.03926,0.491828,0.424002,-2.09197,0.022584,1.3454,-1.83533,0.026451,1.3661,-2.04954},
/*60*/{0.162156,1.92692,-1.76392,0.200339,1.87001,-1.92354,0.120351,1.77901,-1.64403,0.092562,1.65869,-1.5612,0.208422,1.65586,-1.67731,0.284858,1.64718,-1.72912,0.084219,1.93527,-2.13636,0.191404,1.86766,-1.9955,-0.020293,1.90667,-2.02173,-0.14891,1.81048,-2.13133,-0.176212,1.71427,-2.19329,-0.032132,1.58046,-2.16061,-0.001709,1.52129,-2.1854,0.104611,1.42513,-1.80847,-0.082688,1.49922,-1.88416,-0.082462,1.5275,-1.92943,-0.080736,1.50188,-2.00069,0.104875,1.45517,-2.06162,0.058017,1.09892,-1.77993,-0.079628,1.10732,-1.78417,-0.087108,1.02586,-1.81028,-0.05422,0.907777,-1.80971,-0.210239,0.811705,-1.78544,-0.281597,0.787544,-1.78969,-0.250537,0.917009,-1.78407,-0.316513,0.891655,-1.7851,-0.521548,0.774078,-1.78699,-0.571013,0.881192,-1.84921,-0.583084,0.624272,-1.86193,-0.642717,0.641879,-1.79697,0.183433,1.17822,-2.12975,0.223571,1.10558,-2.11367,0.05953,1.11061,-2.1013,0.100399,1.04116,-2.08826,0.221917,0.950582,-2.09266,0.305757,0.782756,-2.08524,0.19547,0.757143,-2.09594,0.215471,0.690241,-2.08597,0.305021,0.465839,-2.05544,0.260208,0.364914,-1.98364,0.513203,0.484203,-2.0393,0.484265,0.416044,-2.09002,0.023157,1.34297,-1.83507,0.026389,1.36296,-2.04935},
/*61*/{0.161836,1.92375,-1.76414,0.20015,1.86703,-1.92342,0.117061,1.7765,-1.64518,0.087356,1.65596,-1.56347,0.204131,1.64942,-1.67746,0.281071,1.63876,-1.72876,0.085059,1.93106,-2.13721,0.190919,1.86414,-1.99591,-0.020668,1.90336,-2.02368,-0.148911,1.80362,-2.13465,-0.173477,1.70672,-2.19572,-0.028657,1.57334,-2.16269,0.002694,1.51461,-2.18687,0.10553,1.42315,-1.80889,-0.082639,1.49561,-1.88409,-0.083275,1.52347,-1.92944,-0.081551,1.49804,-2.00041,0.104526,1.45269,-2.06213,0.062656,1.09598,-1.77905,-0.074822,1.10363,-1.7843,-0.080229,1.0205,-1.81139,-0.045475,0.903806,-1.80855,-0.203046,0.814764,-1.7844,-0.275728,0.791602,-1.78937,-0.240821,0.921578,-1.78687,-0.307579,0.89797,-1.78588,-0.516288,0.788293,-1.78561,-0.561714,0.893786,-1.85347,-0.578933,0.636822,-1.85769,-0.639447,0.657697,-1.79307,0.181939,1.17471,-2.13067,0.221175,1.10237,-2.11466,0.057427,1.10857,-2.10116,0.097878,1.03861,-2.08799,0.219878,0.947505,-2.09255,0.300921,0.777666,-2.0857,0.190636,0.753249,-2.09547,0.209792,0.686298,-2.08542,0.297087,0.460617,-2.05431,0.250341,0.361621,-1.98147,0.504868,0.475674,-2.03817,0.475367,0.40731,-2.08752,0.024625,1.34028,-1.83503,0.026786,1.35984,-2.04936},
/*62*/{0.160805,1.9202,-1.76401,0.199964,1.86308,-1.92413,0.114056,1.77341,-1.64514,0.081731,1.65306,-1.56497,0.199566,1.64325,-1.67753,0.277426,1.62979,-1.72702,0.085599,1.92684,-2.13786,0.190735,1.86046,-1.9961,-0.020796,1.89895,-2.02608,-0.146029,1.79566,-2.13742,-0.17013,1.69866,-2.19842,-0.025075,1.56622,-2.16597,0.007281,1.50765,-2.18928,0.106088,1.42066,-1.8096,-0.082959,1.49125,-1.88389,-0.083874,1.52042,-1.92945,-0.082575,1.49456,-2.00044,0.103601,1.45002,-2.06301,0.067433,1.09375,-1.77864,-0.068786,1.09786,-1.78408,-0.074166,1.01525,-1.81135,-0.036627,0.899917,-1.8073,-0.195788,0.818249,-1.78231,-0.269314,0.796385,-1.78719,-0.229376,0.925279,-1.78831,-0.298402,0.903483,-1.78847,-0.508742,0.799285,-1.78537,-0.551243,0.90493,-1.85666,-0.574287,0.648249,-1.854,-0.634569,0.672279,-1.79005,0.179534,1.1717,-2.13108,0.21925,1.09889,-2.11554,0.055331,1.10577,-2.10104,0.095638,1.03529,-2.08831,0.217456,0.944251,-2.0923,0.295978,0.772437,-2.08573,0.186381,0.747517,-2.09078,0.20439,0.682135,-2.08507,0.288597,0.455897,-2.05332,0.239786,0.359029,-1.97976,0.496442,0.467006,-2.03587,0.464105,0.397583,-2.08486,0.025442,1.33722,-1.83553,0.026453,1.35687,-2.04986},
/*63*/{0.160152,1.91641,-1.76404,0.199532,1.85839,-1.92402,0.11073,1.77047,-1.64524,0.076997,1.64991,-1.56539,0.195309,1.63655,-1.67749,0.272779,1.62089,-1.72582,0.086134,1.9222,-2.13915,0.190806,1.85627,-1.99649,-0.02078,1.89505,-2.02793,-0.145451,1.78771,-2.14067,-0.166522,1.69046,-2.20151,-0.021162,1.55871,-2.16948,0.011513,1.50061,-2.19048,0.105812,1.41764,-1.81018,-0.082879,1.48765,-1.884,-0.082933,1.51601,-1.92935,-0.083241,1.49039,-1.99938,0.103121,1.44674,-2.06463,0.07193,1.0904,-1.77682,-0.065774,1.09121,-1.78549,-0.065832,1.00922,-1.81098,-0.028045,0.896457,-1.80581,-0.187148,0.821239,-1.78056,-0.260791,0.801615,-1.78564,-0.218209,0.928057,-1.78937,-0.287612,0.909072,-1.7902,-0.501723,0.811413,-1.78641,-0.541348,0.915448,-1.85822,-0.56846,0.659219,-1.85044,-0.627712,0.685027,-1.78641,0.178507,1.16889,-2.13187,0.217991,1.0951,-2.1165,0.053514,1.10296,-2.09983,0.093777,1.03273,-2.08764,0.215277,0.940667,-2.09239,0.290981,0.765422,-2.08556,0.179853,0.746001,-2.09614,0.197559,0.677692,-2.08518,0.277794,0.449924,-2.05257,0.22823,0.354035,-1.97765,0.485878,0.457458,-2.03269,0.454643,0.388262,-2.08103,0.026254,1.33369,-1.83582,0.026151,1.35318,-2.05017},
/*64*/{0.158518,1.91147,-1.76382,0.199699,1.85374,-1.92354,0.107329,1.76674,-1.64587,0.070396,1.64686,-1.56718,0.189893,1.63001,-1.67789,0.267921,1.61141,-1.72428,0.086558,1.91713,-2.14026,0.191527,1.85205,-1.99681,-0.021671,1.89025,-2.02983,-0.143457,1.77894,-2.14422,-0.16327,1.68141,-2.20524,-0.015362,1.55178,-2.17246,0.016848,1.49284,-2.19265,0.105634,1.41514,-1.81056,-0.083303,1.48318,-1.88363,-0.083539,1.51214,-1.9291,-0.08421,1.486,-1.99869,0.102295,1.44362,-2.06531,0.076734,1.08839,-1.77584,-0.060492,1.08588,-1.78578,-0.060597,1.00353,-1.81093,-0.018797,0.892924,-1.80388,-0.179412,0.823783,-1.77968,-0.252153,0.806221,-1.78492,-0.207347,0.931648,-1.79263,-0.27636,0.913349,-1.792,-0.492454,0.82009,-1.78436,-0.531539,0.923988,-1.85946,-0.561891,0.668485,-1.8469,-0.620421,0.697067,-1.78355,0.17643,1.16509,-2.13261,0.216349,1.09201,-2.11668,0.051936,1.09992,-2.09993,0.091882,1.02923,-2.08794,0.212656,0.935909,-2.09249,0.286188,0.760505,-2.08436,0.174016,0.741502,-2.09501,0.189989,0.673444,-2.08506,0.266188,0.443195,-2.05082,0.213176,0.350649,-1.97547,0.474524,0.447543,-2.02982,0.442769,0.378449,-2.07806,0.027009,1.33041,-1.83571,0.02591,1.34959,-2.05009},
/*65*/{0.157032,1.90776,-1.76408,0.200699,1.84958,-1.92328,0.103678,1.76218,-1.64577,0.065619,1.64423,-1.56857,0.184679,1.62252,-1.67733,0.263245,1.60176,-1.72328,0.086789,1.912,-2.14178,0.191309,1.84736,-1.99701,-0.02196,1.88544,-2.03225,-0.142824,1.77028,-2.14816,-0.160068,1.67269,-2.20827,-0.011273,1.54353,-2.17584,0.022092,1.48513,-2.19377,0.105904,1.4118,-1.81155,-0.084027,1.47867,-1.88397,-0.083694,1.50775,-1.92923,-0.084531,1.48073,-1.99806,0.101517,1.44047,-2.06693,0.081429,1.08466,-1.77319,-0.055087,1.08009,-1.78624,-0.053784,0.997766,-1.81091,-0.01003,0.889389,-1.80226,-0.169114,0.825774,-1.77701,-0.244017,0.809892,-1.78268,-0.19521,0.933724,-1.79525,-0.265366,0.917867,-1.7944,-0.48176,0.830164,-1.78555,-0.521941,0.933063,-1.86082,-0.554272,0.677428,-1.84445,-0.61176,0.707425,-1.78076,0.174896,1.16153,-2.13274,0.21471,1.08825,-2.11758,0.050281,1.09646,-2.09971,0.090624,1.02533,-2.08786,0.209704,0.930625,-2.09265,0.279703,0.75391,-2.08385,0.167936,0.737105,-2.09536,0.182299,0.668828,-2.08477,0.254869,0.438389,-2.05011,0.196985,0.349465,-1.97567,0.462559,0.43715,-2.02687,0.428313,0.367829,-2.07432,0.02811,1.3265,-1.83641,0.02585,1.34573,-2.05078},
/*66*/{0.156295,1.90374,-1.76376,0.199787,1.84401,-1.92321,0.100587,1.75827,-1.64609,0.05874,1.64038,-1.56969,0.178925,1.61518,-1.67674,0.257617,1.59185,-1.72179,0.087433,1.90624,-2.14283,0.191256,1.84256,-1.99749,-0.022687,1.88016,-2.03371,-0.142014,1.76076,-2.15297,-0.156594,1.66303,-2.2116,-0.006799,1.5344,-2.17814,0.027722,1.47738,-2.19566,0.106417,1.40855,-1.8129,-0.083522,1.47376,-1.88331,-0.084436,1.50355,-1.92945,-0.085775,1.47601,-1.99749,0.100689,1.43743,-2.0681,0.085808,1.08236,-1.77188,-0.049978,1.07634,-1.78785,-0.046611,0.993056,-1.81245,-0.001074,0.886711,-1.79989,-0.159604,0.827848,-1.77561,-0.234041,0.812928,-1.7801,-0.183339,0.935157,-1.79686,-0.253258,0.920519,-1.79665,-0.472058,0.83777,-1.78417,-0.511302,0.941138,-1.86087,-0.544678,0.685242,-1.84299,-0.601958,0.716352,-1.77895,0.173045,1.1572,-2.13325,0.212781,1.08461,-2.11759,0.049131,1.09212,-2.10004,0.089317,1.02084,-2.08804,0.207126,0.925255,-2.09288,0.273862,0.747153,-2.08338,0.161826,0.732504,-2.09524,0.174542,0.664281,-2.08525,0.24377,0.435314,-2.04908,0.177988,0.355551,-1.97587,0.44704,0.424559,-2.02484,0.410418,0.357291,-2.07203,0.029509,1.32265,-1.83715,0.02557,1.3421,-2.05147},
/*67*/{0.155222,1.8986,-1.76356,0.198668,1.83804,-1.92283,0.096896,1.75374,-1.64646,0.051537,1.6381,-1.57051,0.17339,1.6079,-1.67698,0.251675,1.58175,-1.71964,0.087656,1.90071,-2.14405,0.191632,1.83717,-1.99715,-0.023275,1.87419,-2.03558,-0.140104,1.7512,-2.15573,-0.15216,1.65357,-2.21526,-0.001167,1.52759,-2.18127,0.03337,1.46906,-2.19705,0.105979,1.40468,-1.81326,-0.083589,1.46832,-1.88273,-0.085228,1.49887,-1.92879,-0.086223,1.47058,-1.99642,0.101046,1.43457,-2.06963,0.090294,1.07833,-1.77038,-0.0449,1.07011,-1.78823,-0.03948,0.987019,-1.81177,0.007641,0.883938,-1.79794,-0.149616,0.829542,-1.77478,-0.224056,0.816705,-1.77818,-0.169928,0.936447,-1.7986,-0.241348,0.92403,-1.79851,-0.461196,0.844407,-1.78542,-0.500458,0.947913,-1.86163,-0.535068,0.692848,-1.84172,-0.591161,0.724122,-1.77632,0.171973,1.15331,-2.1334,0.211447,1.08022,-2.11829,0.047705,1.0878,-2.10062,0.088465,1.01664,-2.08786,0.204594,0.919312,-2.09297,0.267652,0.740632,-2.08281,0.154915,0.727951,-2.09501,0.16646,0.658857,-2.0849,0.227609,0.424874,-2.05029,0.160516,0.352359,-1.97504,0.432278,0.409113,-2.02282,0.392418,0.344352,-2.07032,0.030707,1.31806,-1.83782,0.02604,1.3385,-2.05203},
/*68*/{0.153779,1.89357,-1.7632,0.199478,1.83281,-1.92236,0.093438,1.74917,-1.64703,0.045532,1.6339,-1.57096,0.167301,1.60024,-1.67609,0.245261,1.57113,-1.71737,0.088266,1.89523,-2.14572,0.191961,1.83312,-1.99688,-0.023534,1.86866,-2.03827,-0.138277,1.74088,-2.15996,-0.147939,1.64361,-2.21876,0.004432,1.51869,-2.18333,0.039866,1.46088,-2.19838,0.106643,1.40044,-1.8141,-0.084272,1.46333,-1.88251,-0.086337,1.49349,-1.9301,-0.087875,1.46537,-1.99583,0.099776,1.4304,-2.07134,0.094057,1.07668,-1.76974,-0.040219,1.06306,-1.79014,-0.032745,0.981187,-1.81251,0.016976,0.881112,-1.79622,-0.139281,0.829774,-1.77366,-0.212822,0.817995,-1.77769,-0.157413,0.936863,-1.80134,-0.228872,0.925645,-1.79955,-0.449761,0.850703,-1.78316,-0.490012,0.954245,-1.86116,-0.524656,0.698099,-1.83992,-0.580048,0.730772,-1.77455,0.169757,1.14875,-2.13345,0.210259,1.07634,-2.11949,0.046037,1.08324,-2.10049,0.086821,1.01262,-2.08819,0.201272,0.913508,-2.09271,0.260681,0.733615,-2.0815,0.14773,0.723512,-2.0952,0.157271,0.653733,-2.08401,0.212878,0.425419,-2.04615,0.138053,0.355908,-1.97377,0.417881,0.395314,-2.01613,0.373416,0.338793,-2.06859,0.031389,1.31361,-1.83856,0.025211,1.33381,-2.05276},
/*69*/{0.153108,1.88843,-1.76285,0.199672,1.82785,-1.92206,0.089725,1.74462,-1.647,0.039283,1.63125,-1.57187,0.161247,1.59235,-1.67491,0.239054,1.56126,-1.71543,0.089598,1.88926,-2.14716,0.192187,1.82709,-1.99697,-0.024598,1.8636,-2.03998,-0.13507,1.73099,-2.16413,-0.143438,1.63336,-2.22263,0.009808,1.50934,-2.18521,0.04607,1.45239,-2.19923,0.106549,1.39606,-1.8154,-0.085038,1.4574,-1.88249,-0.086363,1.4883,-1.92972,-0.08921,1.45999,-1.99574,0.099522,1.42602,-2.07368,0.09896,1.07214,-1.76606,-0.035185,1.05661,-1.78964,-0.026128,0.975327,-1.81277,0.027228,0.878294,-1.79388,-0.127774,0.829829,-1.77219,-0.203616,0.81994,-1.7767,-0.143929,0.937881,-1.80224,-0.215818,0.92705,-1.80051,-0.436337,0.856612,-1.78386,-0.477826,0.959315,-1.86103,-0.512797,0.703802,-1.83777,-0.568166,0.736188,-1.77284,0.167956,1.14443,-2.13419,0.209668,1.07004,-2.1184,0.043777,1.07847,-2.10055,0.08429,1.00776,-2.08799,0.197512,0.908302,-2.09273,0.252976,0.725827,-2.07939,0.141382,0.718897,-2.0948,0.149368,0.649566,-2.08355,0.194777,0.422542,-2.03957,0.11734,0.353807,-1.97215,0.398042,0.389045,-2.00684,0.351447,0.340964,-2.06864,0.032182,1.30858,-1.83971,0.024718,1.32919,-2.05383},
/*70*/{0.152139,1.883,-1.76242,0.200546,1.82257,-1.921,0.086379,1.7398,-1.6478,0.033012,1.62756,-1.57287,0.154987,1.58453,-1.67445,0.231715,1.55109,-1.71306,0.090461,1.88322,-2.14833,0.192082,1.82177,-1.99707,-0.02547,1.85676,-2.04229,-0.133357,1.7206,-2.16933,-0.138381,1.62281,-2.22628,0.017115,1.50036,-2.1872,0.053096,1.44358,-2.20047,0.107241,1.39182,-1.81685,-0.086128,1.45254,-1.8814,-0.087653,1.48287,-1.92984,-0.091217,1.45563,-1.99528,0.09777,1.42195,-2.07558,0.104061,1.06885,-1.76496,-0.030399,1.05279,-1.79109,-0.018517,0.96942,-1.81227,0.036362,0.87558,-1.79188,-0.11634,0.830048,-1.771,-0.190789,0.820629,-1.77389,-0.130637,0.937296,-1.80348,-0.203111,0.928233,-1.80148,-0.424947,0.859247,-1.78366,-0.466409,0.963633,-1.86064,-0.500672,0.707863,-1.83663,-0.555416,0.741565,-1.77095,0.165027,1.14013,-2.13603,0.20488,1.06648,-2.12072,0.040663,1.07509,-2.10101,0.080671,1.00463,-2.08788,0.192795,0.902875,-2.09301,0.245899,0.718903,-2.075,0.134238,0.714906,-2.09372,0.140307,0.6459,-2.08163,0.178938,0.424223,-2.03385,0.093511,0.353913,-1.97144,0.374619,0.387128,-2.00663,0.328501,0.342432,-2.06724,0.032721,1.30408,-1.84069,0.023075,1.32491,-2.0547},
/*71*/{0.150978,1.87769,-1.76203,0.200207,1.81597,-1.92084,0.082681,1.73451,-1.64823,0.026408,1.62437,-1.57333,0.148376,1.57698,-1.67322,0.225133,1.54181,-1.71048,0.091722,1.87709,-2.14986,0.192738,1.81635,-1.99632,-0.026041,1.85112,-2.04423,-0.129551,1.70959,-2.17388,-0.133226,1.61234,-2.22956,0.022606,1.4913,-2.18856,0.060128,1.43475,-2.20139,0.106771,1.38677,-1.81804,-0.08692,1.44675,-1.88121,-0.089383,1.47731,-1.93005,-0.09332,1.45141,-1.99533,0.095553,1.41771,-2.0768,0.108359,1.06621,-1.76345,-0.02529,1.04712,-1.79175,-0.011605,0.963498,-1.81274,0.046994,0.87221,-1.78859,-0.103724,0.829436,-1.76957,-0.177726,0.820931,-1.77335,-0.11702,0.93598,-1.80495,-0.187882,0.92823,-1.80053,-0.410856,0.864007,-1.78397,-0.453797,0.967053,-1.85986,-0.487831,0.711976,-1.83496,-0.541503,0.744273,-1.76966,0.161238,1.1365,-2.13951,0.201143,1.06271,-2.12432,0.036812,1.07359,-2.1009,0.076906,1.00285,-2.08704,0.187967,0.897019,-2.09369,0.240704,0.713837,-2.07059,0.128789,0.713598,-2.09236,0.13105,0.644172,-2.07749,0.151529,0.423158,-2.02953,0.070417,0.354202,-1.96863,0.349949,0.387525,-2.00273,0.304924,0.341454,-2.06715,0.032244,1.2988,-1.84206,0.021268,1.32055,-2.05592},
/*72*/{0.150477,1.87256,-1.76112,0.200568,1.80969,-1.91942,0.078402,1.72961,-1.64874,0.019888,1.62146,-1.57387,0.141325,1.56944,-1.6719,0.217954,1.53189,-1.70782,0.092946,1.87174,-2.15154,0.193952,1.81057,-1.99676,-0.025457,1.8457,-2.0452,-0.127193,1.69833,-2.17919,-0.126807,1.6016,-2.23362,0.030631,1.4822,-2.19016,0.067503,1.42654,-2.20202,0.106104,1.38137,-1.81888,-0.08959,1.44135,-1.88047,-0.091473,1.47129,-1.92922,-0.097062,1.44687,-1.99515,0.09361,1.41452,-2.07799,0.112731,1.06326,-1.7618,-0.018245,1.04022,-1.79155,-0.004713,0.957852,-1.81361,0.057596,0.86949,-1.78796,-0.091053,0.828252,-1.76865,-0.166432,0.820187,-1.77206,-0.102908,0.934513,-1.80393,-0.175372,0.927757,-1.80186,-0.39834,0.866954,-1.78258,-0.44169,0.969426,-1.85963,-0.473772,0.713796,-1.8331,-0.527507,0.746884,-1.76785,0.157026,1.13401,-2.14463,0.196857,1.0594,-2.12882,0.033757,1.07299,-2.10053,0.07294,1.00229,-2.08666,0.18134,0.892684,-2.09445,0.234144,0.71174,-2.06614,0.122939,0.716429,-2.08828,0.122207,0.647234,-2.07303,0.128096,0.424406,-2.02527,0.048287,0.35612,-1.96607,0.329503,0.383732,-2.00245,0.282736,0.342814,-2.0654,0.031386,1.29335,-1.84353,0.019168,1.31685,-2.05713},
/*73*/{0.149454,1.86677,-1.76095,0.20252,1.8045,-1.91916,0.07429,1.72479,-1.6492,0.012876,1.61847,-1.5751,0.134264,1.56248,-1.6699,0.209697,1.52341,-1.70518,0.094395,1.86638,-2.15355,0.194558,1.80515,-1.99608,-0.024355,1.84362,-2.04533,-0.122707,1.68779,-2.18528,-0.120788,1.59041,-2.23715,0.037798,1.47327,-2.19161,0.075654,1.41867,-2.20276,0.10494,1.37684,-1.82074,-0.091463,1.43601,-1.88028,-0.093506,1.46561,-1.92847,-0.099905,1.44356,-1.99495,0.090313,1.41142,-2.07907,0.117398,1.05983,-1.76097,-0.013396,1.0346,-1.79181,0.004729,0.952022,-1.81363,0.069605,0.866322,-1.78575,-0.077682,0.826428,-1.76787,-0.152463,0.818892,-1.77215,-0.088604,0.93298,-1.80493,-0.159273,0.927297,-1.79972,-0.384378,0.865858,-1.78237,-0.428736,0.97094,-1.85935,-0.459247,0.714817,-1.83327,-0.513163,0.747264,-1.7666,0.153619,1.13097,-2.14843,0.192984,1.05713,-2.13139,0.031083,1.07345,-2.10046,0.070683,1.00143,-2.08628,0.17753,0.891822,-2.09474,0.226166,0.710352,-2.06395,0.115318,0.721115,-2.08493,0.110094,0.652088,-2.07042,0.113543,0.428076,-2.02425,0.027035,0.356611,-1.9674,0.308231,0.383411,-2.00028,0.259612,0.341678,-2.06452,0.030459,1.28839,-1.84536,0.016513,1.31354,-2.05866},
/*74*/{0.148476,1.86205,-1.75955,0.202141,1.79843,-1.91794,0.071031,1.72071,-1.64959,0.005666,1.61607,-1.57652,0.127636,1.55637,-1.66846,0.201318,1.51464,-1.70226,0.095677,1.86117,-2.15554,0.195917,1.79935,-1.99599,-0.023595,1.84098,-2.04559,-0.117731,1.67735,-2.19197,-0.113375,1.57952,-2.24067,0.045782,1.46565,-2.19253,0.085057,1.41115,-2.20328,0.103725,1.37194,-1.82339,-0.093663,1.43172,-1.87998,-0.096456,1.46114,-1.92745,-0.102731,1.43943,-1.99386,0.087201,1.40855,-2.08053,0.12201,1.05797,-1.76021,-0.006863,1.02833,-1.79242,0.012706,0.94677,-1.81363,0.082074,0.863916,-1.78522,-0.06491,0.824115,-1.76745,-0.139473,0.819393,-1.77234,-0.073397,0.931517,-1.80275,-0.144951,0.927182,-1.79956,-0.370197,0.867901,-1.78268,-0.415819,0.971142,-1.85905,-0.44393,0.715075,-1.83226,-0.498246,0.748097,-1.76504,0.151009,1.12972,-2.14969,0.190807,1.0561,-2.13175,0.028993,1.07123,-2.09949,0.069274,1.00052,-2.08517,0.176271,0.892344,-2.09472,0.215749,0.709084,-2.06295,0.105661,0.725881,-2.08401,0.097681,0.657043,-2.06926,0.095102,0.430313,-2.02165,0.003836,0.358283,-1.96607,0.285751,0.381957,-1.99953,0.237401,0.341806,-2.06452,0.02921,1.28358,-1.84731,0.013136,1.31045,-2.06026},
/*75*/{0.148395,1.85805,-1.75853,0.200939,1.79464,-1.9166,0.067171,1.71682,-1.65002,-0.001543,1.61425,-1.5776,0.120345,1.55028,-1.6671,0.193373,1.50709,-1.69951,0.097705,1.85602,-2.15669,0.196287,1.79492,-1.99544,-0.023209,1.8387,-2.04507,-0.109403,1.66721,-2.19921,-0.105687,1.56929,-2.24393,0.0548,1.45803,-2.19331,0.094411,1.40424,-2.20343,0.102567,1.36754,-1.82551,-0.096038,1.42687,-1.87851,-0.098758,1.45768,-1.92757,-0.105655,1.43665,-1.9922,0.085191,1.40615,-2.08226,0.126645,1.05888,-1.76018,-0.001582,1.02036,-1.79298,0.022509,0.941981,-1.81392,0.095093,0.861483,-1.78524,-0.051231,0.821559,-1.76749,-0.125509,0.817511,-1.77311,-0.059197,0.929916,-1.80084,-0.130531,0.926027,-1.79696,-0.356001,0.868062,-1.78195,-0.403381,0.970522,-1.85922,-0.428954,0.71366,-1.83073,-0.483341,0.745998,-1.76628,0.14648,1.12854,-2.14919,0.187848,1.05522,-2.13181,0.026204,1.06821,-2.09804,0.067289,0.999023,-2.08441,0.177423,0.893526,-2.09345,0.20381,0.708387,-2.06448,0.094287,0.729151,-2.08246,0.084563,0.660485,-2.06899,0.07788,0.430898,-2.01977,-0.017945,0.357355,-1.96413,0.265336,0.381474,-1.99902,0.216015,0.342406,-2.06313,0.027964,1.27914,-1.84928,0.010209,1.30814,-2.06181},
/*76*/{0.147976,1.85369,-1.7574,0.201374,1.79023,-1.91621,0.063144,1.71426,-1.65004,-0.009334,1.61307,-1.57854,0.112964,1.5453,-1.6654,0.184789,1.50017,-1.69682,0.098641,1.85144,-2.15768,0.196324,1.79067,-1.99434,-0.022383,1.83714,-2.04614,-0.102779,1.65709,-2.20575,-0.095022,1.55876,-2.24642,0.06437,1.45167,-2.19381,0.104448,1.39849,-2.20369,0.101475,1.36414,-1.82758,-0.097517,1.42263,-1.87716,-0.099458,1.45664,-1.92658,-0.108414,1.43427,-1.99023,0.082612,1.40465,-2.08377,0.132987,1.06084,-1.75961,0.00497,1.01983,-1.79208,0.031281,0.939859,-1.81333,0.109581,0.86049,-1.78458,-0.036594,0.81968,-1.76808,-0.11321,0.814949,-1.77411,-0.045277,0.928855,-1.79973,-0.116668,0.925011,-1.79699,-0.343119,0.865973,-1.7807,-0.391538,0.968455,-1.85725,-0.41195,0.710946,-1.83048,-0.467811,0.742757,-1.76539,0.143198,1.12715,-2.14878,0.18483,1.05438,-2.13243,0.022643,1.06657,-2.09772,0.064379,0.996557,-2.0839,0.178154,0.894285,-2.09172,0.193991,0.707738,-2.06739,0.082969,0.730641,-2.08213,0.071291,0.66256,-2.06908,0.056348,0.43207,-2.02103,-0.040417,0.359436,-1.96491,0.242494,0.380097,-1.99995,0.193959,0.341795,-2.06299,0.027022,1.27569,-1.85102,0.00704,1.30674,-2.06306},
/*77*/{0.147389,1.8503,-1.75652,0.20102,1.78717,-1.91561,0.057897,1.71259,-1.65096,-0.017168,1.61305,-1.58058,0.10507,1.54154,-1.66394,0.175311,1.49452,-1.69389,0.100943,1.84803,-2.15742,0.196227,1.78694,-1.99366,-0.022185,1.83457,-2.0464,-0.095746,1.64942,-2.2118,-0.084568,1.54976,-2.24836,0.074383,1.44591,-2.19392,0.115418,1.39277,-2.20323,0.100595,1.35968,-1.829,-0.099421,1.42024,-1.87529,-0.100731,1.45473,-1.92592,-0.109384,1.43202,-1.98806,0.080778,1.40352,-2.0854,0.136916,1.06441,-1.76307,0.013322,1.01772,-1.79043,0.041187,0.938367,-1.81237,0.123996,0.860344,-1.7848,-0.022791,0.818174,-1.76827,-0.097486,0.814875,-1.77289,-0.030649,0.927434,-1.79801,-0.101615,0.924181,-1.79451,-0.328567,0.864274,-1.78185,-0.380637,0.965339,-1.85625,-0.394785,0.708399,-1.83018,-0.450308,0.737238,-1.76554,0.138776,1.12492,-2.14918,0.179918,1.05181,-2.13381,0.018259,1.06433,-2.09644,0.05947,0.994342,-2.08378,0.178918,0.894858,-2.08947,0.180984,0.704209,-2.07057,0.071095,0.730739,-2.08351,0.058172,0.663448,-2.06868,0.038126,0.432171,-2.01883,-0.061588,0.360507,-1.96377,0.222238,0.379601,-1.99899,0.171619,0.341202,-2.06353,0.02568,1.27201,-1.85267,0.004221,1.30555,-2.0642},
/*78*/{0.147369,1.84712,-1.75548,0.202182,1.78438,-1.91488,0.053706,1.71134,-1.65122,-0.024736,1.6142,-1.58244,0.097369,1.53884,-1.66312,0.167512,1.49066,-1.6913,0.102874,1.84509,-2.15701,0.197007,1.78465,-1.99322,-0.021737,1.83313,-2.04704,-0.088149,1.64136,-2.21664,-0.074002,1.54202,-2.25049,0.084764,1.44178,-2.19339,0.126891,1.38904,-2.20279,0.099093,1.35634,-1.82955,-0.100485,1.41878,-1.87426,-0.102471,1.45423,-1.92605,-0.111354,1.43131,-1.98592,0.078726,1.40247,-2.08694,0.143459,1.06703,-1.7631,0.020731,1.01637,-1.79008,0.051116,0.938289,-1.81026,0.1385,0.861838,-1.78449,-0.00826,0.817,-1.76838,-0.083468,0.813235,-1.77382,-0.017719,0.92716,-1.79595,-0.088201,0.923165,-1.79264,-0.314328,0.858186,-1.78032,-0.371108,0.960955,-1.85483,-0.376547,0.703215,-1.82953,-0.433413,0.730299,-1.76477,0.133806,1.12143,-2.14986,0.174129,1.04745,-2.13438,0.013011,1.05995,-2.09482,0.053415,0.991709,-2.0827,0.174911,0.893405,-2.08936,0.168044,0.699951,-2.07272,0.058182,0.729512,-2.08477,0.04374,0.662631,-2.06972,0.014273,0.430891,-2.01983,-0.083004,0.362395,-1.96455,0.200065,0.378587,-1.9993,0.150726,0.341557,-2.06347,0.023489,1.26958,-1.85384,0.000978,1.30483,-2.06498},
/*79*/{0.146653,1.84354,-1.75472,0.200714,1.78212,-1.91444,0.048539,1.71179,-1.65166,-0.032825,1.61693,-1.58399,0.088782,1.5367,-1.66193,0.158569,1.48641,-1.68812,0.105015,1.84308,-2.15603,0.196896,1.78195,-1.99256,-0.020964,1.83116,-2.0475,-0.079994,1.63473,-2.22034,-0.062874,1.5364,-2.25162,0.095405,1.43729,-2.19287,0.138694,1.387,-2.20219,0.097878,1.354,-1.83083,-0.101636,1.41875,-1.87268,-0.104085,1.4532,-1.92524,-0.111324,1.43047,-1.9845,0.077186,1.40134,-2.08848,0.150489,1.06958,-1.76299,0.029506,1.01599,-1.78881,0.062138,0.939047,-1.80901,0.152209,0.863883,-1.78488,0.00499,0.816871,-1.76946,-0.069317,0.813579,-1.77406,-0.004262,0.927092,-1.7947,-0.07538,0.922144,-1.79151,-0.300983,0.853501,-1.78068,-0.361399,0.955681,-1.85434,-0.35788,0.697551,-1.83033,-0.414413,0.723056,-1.76405,0.129164,1.11786,-2.15046,0.167991,1.04359,-2.13522,0.008268,1.05824,-2.09452,0.047923,0.987758,-2.08105,0.167443,0.888424,-2.09064,0.155911,0.695143,-2.07305,0.047685,0.727677,-2.08653,0.029834,0.662496,-2.07004,-0.00517,0.432135,-2.02081,-0.105054,0.362059,-1.96448,0.17842,0.377541,-1.99968,0.128015,0.340764,-2.06412,0.022053,1.26787,-1.85451,-0.001664,1.30403,-2.06536},
/*80*/{0.14619,1.84213,-1.75435,0.200608,1.78022,-1.91318,0.043225,1.71231,-1.65199,-0.040416,1.61974,-1.58648,0.080787,1.53669,-1.66119,0.150165,1.48394,-1.68569,0.106982,1.8413,-2.15555,0.197186,1.77941,-1.99171,-0.020216,1.83019,-2.04816,-0.070672,1.62897,-2.22207,-0.052691,1.53161,-2.25222,0.106324,1.43525,-2.19138,0.15103,1.38609,-2.20124,0.095882,1.35197,-1.83018,-0.102208,1.41842,-1.87229,-0.104126,1.45276,-1.92559,-0.112453,1.43049,-1.98353,0.075768,1.40018,-2.08954,0.160627,1.07433,-1.76226,0.038114,1.01672,-1.78802,0.073521,0.940485,-1.80817,0.166683,0.867365,-1.7856,0.019312,0.817451,-1.77015,-0.056784,0.812526,-1.77446,0.007323,0.927619,-1.79351,-0.064128,0.92192,-1.79,-0.289825,0.853981,-1.78181,-0.353036,0.948376,-1.85218,-0.337483,0.690773,-1.83165,-0.394188,0.712883,-1.76403,0.122924,1.11375,-2.15141,0.161703,1.03877,-2.13649,0.001923,1.05601,-2.0945,0.040586,0.984378,-2.08012,0.156735,0.8827,-2.09181,0.142913,0.689477,-2.07174,0.035695,0.724948,-2.08757,0.016932,0.659269,-2.06963,-0.024507,0.433369,-2.02071,-0.126383,0.36313,-1.96617,0.156909,0.376282,-2.00103,0.105686,0.340252,-2.06488,0.019901,1.26649,-1.85473,-0.0038,1.30325,-2.06547},
/*81*/{0.145903,1.84052,-1.75437,0.199016,1.77768,-1.91201,0.038495,1.7143,-1.65273,-0.04812,1.62364,-1.58824,0.073005,1.53748,-1.66013,0.14107,1.4827,-1.68282,0.109264,1.83972,-2.15542,0.197586,1.77851,-1.99057,-0.019929,1.82939,-2.0488,-0.064078,1.62522,-2.2244,-0.043075,1.5283,-2.25297,0.117974,1.4346,-2.19028,0.162498,1.38707,-2.19973,0.094712,1.35035,-1.83038,-0.102494,1.41876,-1.87202,-0.10534,1.45192,-1.92612,-0.112521,1.43057,-1.98338,0.07491,1.39941,-2.09044,0.166042,1.07955,-1.76418,0.04684,1.01772,-1.7874,0.084962,0.942754,-1.80724,0.181045,0.871342,-1.78871,0.032823,0.817739,-1.77119,-0.041534,0.810664,-1.77615,0.019188,0.928805,-1.79165,-0.051649,0.921362,-1.79046,-0.272398,0.844303,-1.7818,-0.345315,0.94051,-1.85118,-0.317657,0.684204,-1.83169,-0.372613,0.703374,-1.76296,0.117984,1.11017,-2.15239,0.154425,1.03449,-2.13691,-0.004073,1.05573,-2.09502,0.03297,0.982402,-2.08153,0.146441,0.877958,-2.09321,0.129352,0.685323,-2.07222,0.023807,0.722133,-2.08832,0.003713,0.655204,-2.06984,-0.046756,0.43318,-2.02264,-0.147963,0.363394,-1.9643,0.13555,0.376445,-2.0008,0.084554,0.340187,-2.06535,0.018423,1.2655,-1.85526,-0.005246,1.30276,-2.06592},
/*82*/{0.145118,1.84026,-1.75387,0.198605,1.77703,-1.91171,0.032963,1.71628,-1.65323,-0.055362,1.62772,-1.59018,0.065407,1.53803,-1.65902,0.132791,1.48203,-1.68098,0.111435,1.83923,-2.15484,0.197491,1.77754,-1.99006,-0.018468,1.82816,-2.04955,-0.056249,1.62325,-2.22575,-0.034015,1.52554,-2.25357,0.129654,1.43643,-2.18901,0.174176,1.38951,-2.19771,0.09387,1.35038,-1.8311,-0.102926,1.41876,-1.87244,-0.105392,1.45171,-1.92636,-0.113116,1.43049,-1.98377,0.074236,1.39839,-2.09112,0.173312,1.08473,-1.7644,0.056362,1.0187,-1.78609,0.096134,0.946051,-1.80846,0.195094,0.877308,-1.78855,0.046809,0.819763,-1.77187,-0.02749,0.810446,-1.77857,0.030288,0.929948,-1.79021,-0.040724,0.920623,-1.78853,-0.260104,0.838225,-1.7825,-0.337455,0.931433,-1.85105,-0.296247,0.676863,-1.8329,-0.351683,0.692856,-1.76238,0.112252,1.10678,-2.15304,0.147881,1.02985,-2.1381,-0.010218,1.05432,-2.0959,0.024984,0.981188,-2.08348,0.134396,0.873065,-2.09404,0.114846,0.678287,-2.07095,0.010932,0.719645,-2.08855,-0.012109,0.655487,-2.07297,-0.066287,0.434008,-2.02375,-0.169709,0.364111,-1.96755,0.113781,0.376138,-2.00128,0.0624,0.339672,-2.06617,0.017721,1.26539,-1.8554,-0.006208,1.30207,-2.06613},
/*83*/{0.14353,1.84009,-1.75345,0.19767,1.77561,-1.91,0.028591,1.71832,-1.65363,-0.063579,1.6323,-1.59237,0.058828,1.53986,-1.65773,0.124003,1.48312,-1.67989,0.113976,1.83902,-2.15417,0.197698,1.77634,-1.98847,-0.017893,1.82782,-2.0506,-0.04978,1.62039,-2.22691,-0.025123,1.52346,-2.25421,0.138897,1.43835,-2.18716,0.185828,1.3933,-2.19523,0.092663,1.35118,-1.82977,-0.103282,1.41891,-1.87286,-0.105428,1.45168,-1.92669,-0.113024,1.43019,-1.98461,0.072717,1.39628,-2.09295,0.181233,1.0915,-1.76518,0.065446,1.02214,-1.78534,0.106333,0.948859,-1.80631,0.207299,0.882939,-1.78877,0.06038,0.82046,-1.77313,-0.014503,0.810557,-1.77833,0.041759,0.931632,-1.78871,-0.029295,0.919226,-1.7865,-0.24628,0.830897,-1.78326,-0.329237,0.920411,-1.85087,-0.273823,0.668343,-1.8338,-0.329092,0.681638,-1.76242,0.107298,1.10366,-2.15339,0.139992,1.02573,-2.13841,-0.017646,1.05447,-2.09725,0.016517,0.980063,-2.08401,0.122521,0.867547,-2.09445,0.099788,0.674487,-2.07148,-0.003276,0.716786,-2.08885,-0.027708,0.65314,-2.07393,-0.085058,0.434448,-2.02344,-0.191168,0.364237,-1.9675,0.092074,0.375727,-2.0029,0.041316,0.340078,-2.06654,0.016809,1.26591,-1.85429,-0.007334,1.30032,-2.06538},
/*84*/{0.141083,1.84097,-1.75306,0.19767,1.77561,-1.91,0.022878,1.72238,-1.65436,-0.070652,1.63797,-1.59423,0.050294,1.5421,-1.65681,0.115912,1.48434,-1.67736,0.115838,1.83945,-2.15367,0.197347,1.7762,-1.98798,-0.01675,1.82749,-2.0519,-0.042597,1.61969,-2.22816,-0.01669,1.52275,-2.25463,0.148857,1.44201,-2.18524,0.197528,1.39871,-2.19224,0.091872,1.35238,-1.82885,-0.103552,1.41949,-1.87384,-0.106434,1.45203,-1.92784,-0.112977,1.43101,-1.98558,0.076628,1.39614,-2.09274,0.18792,1.09718,-1.76532,0.073876,1.02528,-1.78479,0.116961,0.953331,-1.80648,0.21967,0.888813,-1.78948,0.073509,0.821891,-1.7745,-0.000215,0.808876,-1.78059,0.051713,0.932743,-1.78729,-0.019469,0.9186,-1.78651,-0.231254,0.82455,-1.78505,-0.321253,0.908914,-1.85137,-0.251156,0.660192,-1.83414,-0.305101,0.67053,-1.76268,0.101669,1.10067,-2.15318,0.132255,1.02102,-2.13896,-0.025982,1.05416,-2.09841,0.00751,0.978476,-2.08576,0.109125,0.861851,-2.09556,0.083973,0.671138,-2.07177,-0.019115,0.714109,-2.08931,-0.044819,0.650302,-2.07424,-0.109511,0.433945,-2.0222,-0.210201,0.364733,-1.96588,0.07144,0.375926,-2.00302,0.01876,0.339642,-2.06715,0.016451,1.26682,-1.85371,-0.005197,1.3006,-2.06517},
/*85*/{0.139014,1.84212,-1.75186,0.196433,1.77618,-1.9077,0.017346,1.7266,-1.65519,-0.07722,1.64276,-1.59589,0.042498,1.54579,-1.65615,0.1075,1.48664,-1.67535,0.118455,1.84065,-2.15309,0.197833,1.77664,-1.98622,-0.015374,1.82786,-2.053,-0.037331,1.61844,-2.22903,-0.00853,1.52256,-2.25464,0.158084,1.44695,-2.18257,0.207954,1.40583,-2.18922,0.09106,1.35375,-1.82821,-0.1046,1.41955,-1.87465,-0.106301,1.45209,-1.92856,-0.113069,1.4314,-1.98703,0.083814,1.39715,-2.09135,0.19638,1.1032,-1.76435,0.086478,1.02927,-1.78373,0.12641,0.958245,-1.80571,0.231525,0.895896,-1.7901,0.0876,0.824516,-1.77571,0.013451,0.80782,-1.78235,0.061143,0.933687,-1.78424,-0.009639,0.917174,-1.78515,-0.216109,0.817642,-1.78666,-0.3131,0.895733,-1.85217,-0.228229,0.651709,-1.83432,-0.282624,0.658916,-1.7622,0.095889,1.09745,-2.15317,0.124209,1.01764,-2.13941,-0.032278,1.05454,-2.09953,-0.001826,0.977935,-2.08678,0.094689,0.855773,-2.09601,0.066975,0.666531,-2.0695,-0.034298,0.71238,-2.08961,-0.061153,0.649402,-2.07394,-0.13419,0.43488,-2.02314,-0.234504,0.367738,-1.96703,0.049721,0.375657,-2.00296,-0.002264,0.339869,-2.06698,0.016819,1.2675,-1.85336,-0.000838,1.30173,-2.06512},
/*86*/{0.136568,1.84428,-1.75116,0.196172,1.7786,-1.90648,0.012741,1.73057,-1.65494,-0.084778,1.64832,-1.59743,0.035513,1.55002,-1.65541,0.098468,1.49069,-1.67453,0.120926,1.84227,-2.15181,0.198117,1.77863,-1.98472,-0.014679,1.82808,-2.0545,-0.034142,1.61812,-2.22968,-0.001162,1.5227,-2.25495,0.167127,1.45341,-2.17994,0.218348,1.41378,-2.18584,0.089836,1.35629,-1.82817,-0.10512,1.42011,-1.87613,-0.106681,1.45231,-1.92977,-0.112804,1.43143,-1.98843,0.075855,1.39578,-2.09297,0.201795,1.11074,-1.76425,0.092178,1.03385,-1.7831,0.138131,0.963976,-1.80541,0.24279,0.902618,-1.79053,0.100513,0.825724,-1.7773,0.027508,0.807405,-1.78344,0.070005,0.934548,-1.78431,-0.000225,0.91539,-1.78435,-0.204288,0.805887,-1.78798,-0.304053,0.881959,-1.85343,-0.20579,0.643058,-1.8349,-0.259436,0.647704,-1.76208,0.089691,1.09492,-2.15294,0.115614,1.01389,-2.13937,-0.038913,1.05483,-2.09983,-0.01199,0.977606,-2.08732,0.080784,0.851364,-2.09613,0.050518,0.663464,-2.06892,-0.050745,0.712065,-2.08925,-0.077458,0.649325,-2.07424,-0.146907,0.43712,-2.02301,-0.255022,0.3684,-1.96742,0.027921,0.375405,-2.00353,-0.024039,0.340187,-2.06717,0.015803,1.2693,-1.85275,-0.004395,1.3001,-2.06481},
/*87*/{0.134118,1.84643,-1.7508,0.196036,1.7798,-1.90481,0.00627,1.73557,-1.65544,-0.091842,1.65331,-1.59869,0.027627,1.5545,-1.65537,0.091689,1.4942,-1.67301,0.122823,1.84479,-2.15104,0.198524,1.77966,-1.98287,-0.014308,1.82826,-2.05474,-0.029752,1.61814,-2.22963,0.006187,1.52416,-2.25501,0.175534,1.46051,-2.17766,0.227947,1.42249,-2.18168,0.089572,1.35724,-1.82633,-0.104959,1.42137,-1.87755,-0.106198,1.45269,-1.93077,-0.112738,1.43211,-1.99009,0.077838,1.39488,-2.09298,0.207207,1.11783,-1.76508,0.099583,1.03781,-1.783,0.144444,0.968433,-1.80627,0.254027,0.910386,-1.79153,0.113477,0.828054,-1.77862,0.041002,0.806245,-1.78439,0.078358,0.935693,-1.78345,0.008865,0.913089,-1.78344,-0.190625,0.797282,-1.78886,-0.294782,0.866581,-1.85568,-0.182219,0.634405,-1.83493,-0.234605,0.637068,-1.76137,0.082957,1.09264,-2.15261,0.106834,1.01085,-2.13891,-0.047154,1.05639,-2.10085,-0.022487,0.978559,-2.08804,0.063845,0.848446,-2.09571,0.034534,0.663289,-2.06883,-0.06653,0.712181,-2.08912,-0.094728,0.649045,-2.07355,-0.172022,0.439051,-2.02447,-0.275614,0.369798,-1.96761,0.006667,0.375299,-2.00354,-0.046026,0.340113,-2.0672,0.015245,1.27039,-1.85171,-0.003096,1.29959,-2.06417},
/*88*/{0.130987,1.84905,-1.74974,0.195739,1.78168,-1.90283,0.001377,1.74065,-1.65626,-0.099086,1.65936,-1.60026,0.020465,1.5595,-1.65551,0.084116,1.4988,-1.67258,0.124622,1.84783,-2.14992,0.199094,1.78176,-1.98093,-0.013224,1.8298,-2.05537,-0.025277,1.61898,-2.22958,0.012901,1.52598,-2.25537,0.1835,1.46885,-2.1748,0.237508,1.43272,-2.17786,0.088685,1.35849,-1.8257,-0.105551,1.42254,-1.87911,-0.105473,1.45481,-1.93216,-0.112307,1.43367,-1.99116,0.075405,1.39355,-2.09376,0.212453,1.12504,-1.7647,0.106846,1.0424,-1.78375,0.153683,0.974954,-1.80599,0.263581,0.918709,-1.79215,0.126936,0.830809,-1.77937,0.05448,0.805858,-1.78492,0.086336,0.936212,-1.78254,0.017977,0.910685,-1.78438,-0.176016,0.787143,-1.79103,-0.284726,0.850867,-1.85773,-0.15743,0.626204,-1.83369,-0.211918,0.625911,-1.7615,0.076701,1.09072,-2.15186,0.097263,1.00841,-2.13759,-0.055823,1.05816,-2.10108,-0.032621,0.97912,-2.08898,0.04868,0.847557,-2.09465,0.017026,0.661733,-2.06815,-0.082667,0.713382,-2.08783,-0.111753,0.650358,-2.07264,-0.255607,0.422182,-2.02033,-0.29619,0.372203,-1.96753,-0.014359,0.375638,-2.00427,-0.066571,0.33988,-2.06725,0.013464,1.27181,-1.85121,-0.004783,1.29913,-2.06393},
/*89*/{0.127683,1.8521,-1.74901,0.195396,1.78474,-1.90138,-0.003525,1.7457,-1.65633,-0.105529,1.66565,-1.60227,0.013755,1.56535,-1.65569,0.076613,1.50419,-1.67138,0.126508,1.85132,-2.1489,0.198843,1.78438,-1.97926,-0.01229,1.83074,-2.05597,-0.021632,1.62024,-2.22863,0.020261,1.52815,-2.25535,0.190533,1.47628,-2.17171,0.246554,1.44255,-2.17379,0.088651,1.36103,-1.82549,-0.104591,1.42384,-1.88068,-0.104708,1.45569,-1.93341,-0.110905,1.43509,-1.99266,0.077282,1.39404,-2.09342,0.21468,1.1322,-1.76527,0.110655,1.04615,-1.78435,0.160909,0.980121,-1.80635,0.27268,0.927717,-1.79304,0.138936,0.833253,-1.7802,0.068178,0.804804,-1.78695,0.093348,0.936497,-1.78224,0.027646,0.907672,-1.78281,-0.161217,0.777365,-1.79187,-0.273688,0.834149,-1.86072,-0.134237,0.617709,-1.83383,-0.188492,0.615191,-1.76118,0.069667,1.08929,-2.15086,0.088922,1.0062,-2.13596,-0.06364,1.05979,-2.10121,-0.043028,0.980916,-2.0893,0.032429,0.847232,-2.09496,-0.001811,0.662365,-2.06824,-0.100021,0.71455,-2.08707,-0.130436,0.653738,-2.07239,-0.215616,0.441118,-2.0238,-0.317426,0.374352,-1.96812,-0.036455,0.374903,-2.00384,-0.088456,0.340392,-2.06727,0.014077,1.27377,-1.85084,-0.002763,1.29981,-2.06383},
/*90*/{0.125173,1.85548,-1.74824,0.195876,1.78782,-1.89926,-0.007868,1.75047,-1.65709,-0.111946,1.67216,-1.60396,0.006727,1.57144,-1.65691,0.069377,1.50964,-1.67098,0.128314,1.85541,-2.14788,0.19959,1.78782,-1.97696,-0.011438,1.8323,-2.05685,-0.016147,1.62215,-2.22752,0.02696,1.53066,-2.25552,0.198486,1.48569,-2.16838,0.255493,1.45294,-2.16859,0.090215,1.36378,-1.82427,-0.10492,1.42625,-1.88244,-0.10413,1.45839,-1.93483,-0.109925,1.437,-1.99472,0.079235,1.39423,-2.09322,0.219923,1.13998,-1.76573,0.117246,1.05155,-1.78494,0.169113,0.986634,-1.80737,0.282696,0.93729,-1.79338,0.150316,0.835882,-1.7809,0.081655,0.804367,-1.78782,0.100329,0.937016,-1.78201,0.035258,0.904792,-1.78366,-0.147544,0.76832,-1.795,-0.262244,0.816449,-1.86348,-0.110962,0.609113,-1.83358,-0.164471,0.604383,-1.76086,0.062822,1.08814,-2.1495,0.078822,1.00479,-2.13469,-0.07166,1.0624,-2.10176,-0.051418,0.982447,-2.09002,0.016504,0.847663,-2.09425,-0.017821,0.662385,-2.06749,-0.116696,0.716445,-2.08611,-0.148041,0.654158,-2.07192,-0.232701,0.44713,-2.02935,-0.338085,0.377247,-1.96696,-0.057748,0.374948,-2.00378,-0.110526,0.340314,-2.06743,0.014253,1.27668,-1.84989,-0.001118,1.30059,-2.06324},
/*91*/{0.121382,1.85885,-1.74788,0.194648,1.79188,-1.89747,-0.012969,1.75572,-1.65762,-0.119431,1.67815,-1.60609,0.00081,1.57776,-1.65719,0.063181,1.51589,-1.67114,0.129404,1.85886,-2.14672,0.200281,1.79134,-1.97556,-0.010373,1.83449,-2.05752,-0.012341,1.62413,-2.2265,0.03325,1.53387,-2.25595,0.205257,1.49499,-2.16504,0.263117,1.46424,-2.16431,0.089893,1.36639,-1.82491,-0.10405,1.42883,-1.88335,-0.102262,1.46034,-1.93648,-0.108363,1.43884,-1.99625,0.078093,1.39476,-2.0956,0.222053,1.14694,-1.76606,0.123067,1.05594,-1.78569,0.175575,0.993327,-1.80722,0.290389,0.946542,-1.79348,0.161608,0.837828,-1.78079,0.095521,0.802843,-1.78876,0.106707,0.936167,-1.78225,0.044306,0.901501,-1.78492,-0.133212,0.756773,-1.7961,-0.249632,0.798495,-1.86689,-0.085637,0.600673,-1.83265,-0.140697,0.593945,-1.76039,0.056915,1.08697,-2.14782,0.070251,1.00349,-2.13264,-0.078909,1.06605,-2.10198,-0.062967,0.983727,-2.09051,0.001735,0.848633,-2.09285,-0.036564,0.664225,-2.067,-0.134529,0.71846,-2.08532,-0.166042,0.656978,-2.07111,-0.249735,0.448746,-2.02406,-0.359427,0.382828,-1.97024,-0.080101,0.375011,-2.00322,-0.132334,0.340467,-2.06704,0.014388,1.27912,-1.85034,-0.001534,1.3014,-2.06383},
/*92*/{0.118627,1.86285,-1.74689,0.194065,1.79492,-1.89536,-0.017384,1.76075,-1.65847,-0.124262,1.68494,-1.60814,-0.004673,1.58489,-1.65813,0.056149,1.52205,-1.67063,0.130362,1.86319,-2.14588,0.200738,1.79518,-1.97387,-0.009739,1.83711,-2.05824,-0.008936,1.62645,-2.22537,0.039969,1.53754,-2.25588,0.211432,1.50487,-2.16105,0.269907,1.47587,-2.1597,0.089542,1.36939,-1.82494,-0.103092,1.43096,-1.88573,-0.101935,1.46215,-1.93846,-0.106654,1.44155,-1.99807,0.080646,1.395,-2.09523,0.225161,1.15432,-1.76649,0.128445,1.06089,-1.78603,0.182223,0.998997,-1.80815,0.29769,0.955852,-1.79403,0.17293,0.840409,-1.78119,0.107307,0.802681,-1.78906,0.112798,0.936009,-1.78387,0.051794,0.898128,-1.78649,-0.118238,0.745345,-1.79816,-0.236681,0.780154,-1.87161,-0.061773,0.593109,-1.83115,-0.116758,0.583234,-1.76015,0.050335,1.08733,-2.14661,0.060556,1.00281,-2.13017,-0.086977,1.07005,-2.10232,-0.073833,0.988305,-2.08874,-0.012581,0.849711,-2.09154,-0.053491,0.665128,-2.06583,-0.150354,0.721561,-2.08397,-0.183238,0.66009,-2.0704,-0.273945,0.452188,-2.02465,-0.380013,0.388598,-1.9695,-0.101221,0.374878,-2.00283,-0.154124,0.340545,-2.06754,0.01422,1.28174,-1.85006,0.000386,1.30246,-2.06385},
/*93*/{0.115203,1.8664,-1.74666,0.194269,1.79826,-1.89307,-0.021673,1.76631,-1.6588,-0.130253,1.69207,-1.61022,-0.010755,1.59132,-1.65956,0.050521,1.52881,-1.67139,0.132003,1.8679,-2.14475,0.201117,1.79906,-1.97143,-0.008394,1.83952,-2.05818,-0.006429,1.63118,-2.22499,0.046766,1.5417,-2.25617,0.216501,1.51456,-2.15705,0.276237,1.48853,-2.15508,0.091362,1.37321,-1.82512,-0.101257,1.43468,-1.88713,-0.099994,1.46548,-1.93953,-0.104534,1.44396,-1.99944,0.082549,1.39558,-2.09496,0.229029,1.16152,-1.76684,0.133607,1.06532,-1.78581,0.188214,1.00577,-1.8085,0.304805,0.963724,-1.79452,0.183362,0.84326,-1.78085,0.12046,0.801214,-1.78964,0.119521,0.933815,-1.7842,0.059552,0.89453,-1.7884,-0.102056,0.734981,-1.80041,-0.223324,0.761515,-1.87604,-0.037153,0.585512,-1.83088,-0.092521,0.573753,-1.75977,0.043285,1.08687,-2.14436,0.052433,1.0028,-2.12894,-0.093463,1.07418,-2.10152,-0.083948,0.992743,-2.08886,-0.025749,0.851695,-2.0892,-0.070523,0.668539,-2.06485,-0.167156,0.725901,-2.0834,-0.199657,0.663447,-2.06991,-0.293314,0.455355,-2.02448,-0.398587,0.394381,-1.96943,-0.122129,0.374995,-2.00262,-0.173976,0.341464,-2.06584,0.015494,1.28556,-1.84909,0.002079,1.30375,-2.06313},
/*94*/{0.112771,1.87085,-1.74613,0.193659,1.80315,-1.89234,-0.025476,1.77178,-1.65971,-0.13627,1.69809,-1.61187,-0.016291,1.59754,-1.66022,0.044412,1.53541,-1.67077,0.133763,1.87264,-2.14321,0.201815,1.80311,-1.97025,-0.008216,1.8425,-2.05848,-0.002144,1.63418,-2.22418,0.053061,1.54608,-2.25563,0.222049,1.52519,-2.15371,0.282356,1.50095,-2.15039,0.092033,1.37674,-1.82518,-0.100161,1.43828,-1.88794,-0.098674,1.46798,-1.94176,-0.101979,1.44686,-2.00109,0.083575,1.39551,-2.09596,0.231141,1.16811,-1.76598,0.137338,1.06999,-1.78788,0.192484,1.01137,-1.80896,0.310305,0.973508,-1.79503,0.193006,0.845268,-1.78061,0.132105,0.800401,-1.78934,0.12403,0.934197,-1.78584,0.068907,0.891704,-1.79075,-0.086744,0.723364,-1.80176,-0.207104,0.742403,-1.87901,-0.012234,0.578774,-1.82964,-0.068023,0.564135,-1.75984,0.037217,1.08796,-2.14236,0.043292,1.00311,-2.12593,-0.102767,1.07851,-2.10056,-0.093281,0.997028,-2.08833,-0.038591,0.854454,-2.08722,-0.087647,0.672172,-2.06387,-0.183458,0.729742,-2.08277,-0.217036,0.668439,-2.06923,-0.315918,0.459643,-2.02413,-0.419191,0.401351,-1.97004,-0.143344,0.375572,-2.00219,-0.197102,0.340961,-2.06632,0.015797,1.28907,-1.84844,0.002892,1.30465,-2.06272},
/*95*/{0.110561,1.87445,-1.74585,0.194162,1.8061,-1.88998,-0.029027,1.77725,-1.66058,-0.140668,1.7053,-1.61482,-0.021795,1.6046,-1.66168,0.039997,1.54159,-1.67127,0.134608,1.87759,-2.14207,0.202494,1.80758,-1.96819,-0.006748,1.84609,-2.05863,0.001704,1.6381,-2.224,0.058704,1.55082,-2.25623,0.22567,1.534,-2.14987,0.287677,1.5134,-2.14478,0.09326,1.3804,-1.82557,-0.098602,1.44159,-1.88994,-0.095964,1.47096,-1.94296,-0.099976,1.45026,-2.00151,0.087671,1.39562,-2.09494,0.233717,1.17472,-1.7661,0.140405,1.07507,-1.78674,0.197215,1.01788,-1.80943,0.314628,0.981569,-1.7953,0.200797,0.84773,-1.77979,0.143249,0.799702,-1.78979,0.1292,0.934543,-1.78687,0.074548,0.887172,-1.79278,-0.070222,0.711596,-1.80329,-0.191529,0.722991,-1.88224,0.012991,0.571741,-1.82979,-0.042369,0.554846,-1.75942,0.031943,1.08815,-2.14005,0.034842,1.00385,-2.12295,-0.108335,1.08383,-2.10057,-0.102398,1.00207,-2.08836,-0.051622,0.857127,-2.08423,-0.104308,0.675812,-2.06297,-0.199929,0.734368,-2.08192,-0.234255,0.674035,-2.06941,-0.333658,0.464856,-2.02469,-0.437224,0.4079,-1.969,-0.165374,0.376173,-2.00188,-0.217562,0.341802,-2.06538,0.016702,1.29257,-1.84742,0.005364,1.30609,-2.06194},
/*96*/{0.10809,1.87871,-1.74551,0.193548,1.81249,-1.88901,-0.031905,1.78244,-1.66114,-0.146185,1.71202,-1.6172,-0.026282,1.61166,-1.66343,0.034709,1.5487,-1.67186,0.135873,1.88275,-2.14112,0.202928,1.81198,-1.96651,-0.005667,1.84935,-2.05875,0.005129,1.6426,-2.22441,0.064609,1.55602,-2.25682,0.230197,1.54546,-2.14622,0.291937,1.52616,-2.14052,0.095943,1.38504,-1.82738,-0.096925,1.44541,-1.89039,-0.094039,1.47398,-1.94498,-0.097102,1.45305,-2.00329,0.089737,1.39587,-2.09486,0.23519,1.18202,-1.76679,0.143542,1.08072,-1.78843,0.202257,1.02501,-1.80859,0.319349,0.989628,-1.7947,0.21224,0.849395,-1.78082,0.155123,0.799088,-1.7899,0.134496,0.931866,-1.78977,0.082681,0.882345,-1.79447,-0.054083,0.701513,-1.80661,-0.173844,0.703191,-1.88531,0.038078,0.56506,-1.82916,-0.016825,0.54593,-1.75899,0.026902,1.08896,-2.1383,0.026984,1.00532,-2.12062,-0.113859,1.08956,-2.10112,-0.111704,1.00703,-2.08792,-0.064543,0.861868,-2.08246,-0.121339,0.680459,-2.06255,-0.216086,0.739484,-2.08084,-0.250753,0.679831,-2.06869,-0.345409,0.472149,-2.02529,-0.455772,0.416463,-1.96822,-0.186219,0.376804,-2.0011,-0.239974,0.342213,-2.06563,0.018815,1.29694,-1.84669,0.007209,1.30732,-2.06136},
/*97*/{0.106341,1.88267,-1.74506,0.193594,1.81668,-1.88713,-0.035294,1.78744,-1.66238,-0.150882,1.7188,-1.6193,-0.030666,1.61801,-1.66411,0.030927,1.55485,-1.67249,0.137745,1.88821,-2.1392,0.20385,1.81663,-1.96482,-0.004218,1.85195,-2.05874,0.009506,1.64638,-2.22415,0.070875,1.56142,-2.25689,0.233554,1.555,-2.14224,0.295814,1.53869,-2.13599,0.097865,1.3892,-1.82772,-0.094575,1.44991,-1.89122,-0.092061,1.47768,-1.94691,-0.09391,1.45636,-2.00426,0.092373,1.3965,-2.09556,0.238744,1.18835,-1.76555,0.145673,1.08617,-1.78621,0.205451,1.02986,-1.80886,0.32242,0.996303,-1.79511,0.221019,0.851798,-1.77984,0.168004,0.797539,-1.78986,0.139952,0.929707,-1.79376,0.090505,0.878469,-1.79718,-0.037555,0.689074,-1.80737,-0.155911,0.683344,-1.88844,0.06318,0.558638,-1.82805,0.00872,0.537018,-1.75867,0.021253,1.0907,-2.13585,0.019176,1.00713,-2.11758,-0.119246,1.09529,-2.10131,-0.119761,1.01371,-2.08765,-0.079214,0.86672,-2.08198,-0.136788,0.68487,-2.0627,-0.231453,0.746037,-2.08089,-0.267187,0.687063,-2.06852,-0.361641,0.478028,-2.02618,-0.474108,0.426588,-1.96868,-0.208379,0.37585,-1.99992,-0.26088,0.34233,-2.06459,0.020282,1.30129,-1.84593,0.00901,1.30906,-2.06073},
/*98*/{0.104765,1.88632,-1.74505,0.194039,1.82161,-1.88613,-0.038559,1.79286,-1.66377,-0.154195,1.72547,-1.62203,-0.035594,1.62435,-1.66562,0.025821,1.56108,-1.67257,0.138828,1.89317,-2.13838,0.205428,1.82054,-1.96279,-0.003569,1.85535,-2.05893,0.012847,1.65184,-2.22513,0.075758,1.56662,-2.25712,0.23628,1.56425,-2.13783,0.299026,1.55059,-2.13146,0.099026,1.39254,-1.82878,-0.092675,1.45431,-1.8929,-0.089245,1.48096,-1.94899,-0.09054,1.45937,-2.00541,0.094139,1.39676,-2.09544,0.241284,1.19504,-1.76569,0.150329,1.09224,-1.78366,0.208884,1.03611,-1.80898,0.324455,1.00348,-1.79521,0.228783,0.852948,-1.78021,0.178954,0.797115,-1.78949,0.14483,0.926692,-1.79564,0.098052,0.872412,-1.80038,-0.019668,0.675779,-1.80966,-0.136845,0.66402,-1.89148,0.08866,0.553263,-1.82821,0.034977,0.529329,-1.75897,0.015118,1.09231,-2.13347,0.011294,1.00856,-2.11544,-0.125275,1.10188,-2.10126,-0.128269,1.02008,-2.08768,-0.093732,0.871411,-2.08196,-0.152427,0.69068,-2.06253,-0.246247,0.752739,-2.08101,-0.281613,0.693219,-2.06888,-0.37917,0.484459,-2.02694,-0.491585,0.436875,-1.96866,-0.231393,0.376168,-2.0004,-0.284329,0.342624,-2.06499,0.02092,1.30502,-1.84548,0.010286,1.31043,-2.06039},
/*99*/{0.103264,1.88994,-1.74431,0.193867,1.82476,-1.88424,-0.042012,1.79848,-1.66505,-0.157604,1.73203,-1.62521,-0.039559,1.63095,-1.66675,0.022368,1.56783,-1.67322,0.140922,1.89861,-2.13767,0.205251,1.82459,-1.96116,-0.001953,1.85919,-2.05958,0.016099,1.65655,-2.2254,0.08221,1.57196,-2.25732,0.238674,1.57499,-2.1347,0.302388,1.56185,-2.12815,0.101484,1.39746,-1.82901,-0.090984,1.45914,-1.894,-0.086773,1.48497,-1.95062,-0.087648,1.46287,-2.00584,0.097337,1.39761,-2.0955,0.242531,1.20093,-1.76543,0.153056,1.09896,-1.78305,0.211973,1.0432,-1.80674,0.324561,1.00886,-1.79547,0.237059,0.853637,-1.78055,0.189959,0.79565,-1.79088,0.14988,0.92409,-1.79765,0.104329,0.867152,-1.80316,-0.000266,0.665513,-1.81096,-0.117698,0.644761,-1.89374,0.113384,0.547864,-1.82805,0.060925,0.520836,-1.75963,0.010368,1.09437,-2.13154,0.003083,1.01104,-2.11257,-0.130375,1.10818,-2.10072,-0.135897,1.02659,-2.08656,-0.10764,0.877277,-2.08134,-0.167883,0.697054,-2.06292,-0.261027,0.759584,-2.08052,-0.299456,0.699724,-2.06884,-0.396446,0.491116,-2.02759,-0.507831,0.447878,-1.9692,-0.252741,0.375882,-1.99943,-0.30655,0.343387,-2.06444,0.022726,1.31005,-1.84425,0.012493,1.31246,-2.05923},
/*100*/{0.102153,1.89382,-1.74439,0.192625,1.82997,-1.88283,-0.044626,1.80349,-1.66665,-0.162468,1.73816,-1.62772,-0.043367,1.63663,-1.66772,0.017865,1.57329,-1.67339,0.142759,1.90361,-2.13542,0.205877,1.82969,-1.95994,-0.000951,1.862,-2.05965,0.020177,1.66145,-2.22547,0.086989,1.57723,-2.2578,0.240573,1.58447,-2.13198,0.304777,1.57311,-2.12422,0.103087,1.40165,-1.83072,-0.088153,1.46354,-1.89428,-0.084153,1.48821,-1.95275,-0.084798,1.46665,-2.00673,0.100751,1.39759,-2.09507,0.242719,1.20586,-1.76543,0.155477,1.10458,-1.78341,0.215313,1.04806,-1.80665,0.325827,1.01468,-1.7959,0.24552,0.854449,-1.78043,0.201159,0.793329,-1.79045,0.154365,0.9195,-1.79983,0.113438,0.861132,-1.80527,0.017937,0.652022,-1.81287,-0.097549,0.626134,-1.89521,0.139032,0.542436,-1.82897,0.087838,0.513441,-1.7603,0.005888,1.09664,-2.1294,-0.005111,1.01307,-2.1107,-0.134056,1.11502,-2.1012,-0.143565,1.03367,-2.08701,-0.120768,0.883409,-2.08134,-0.1825,0.704483,-2.0638,-0.274976,0.76769,-2.08033,-0.313266,0.7072,-2.06883,-0.41128,0.49774,-2.02886,-0.523194,0.458017,-1.96908,-0.275,0.37688,-2.00011,-0.328954,0.344617,-2.06511,0.024228,1.31434,-1.84343,0.014334,1.31404,-2.05843},
/*101*/{0.101149,1.89703,-1.74405,0.193543,1.83312,-1.88171,-0.046662,1.8084,-1.66792,-0.165796,1.74449,-1.63084,-0.046728,1.64292,-1.66932,0.013983,1.57886,-1.67355,0.143376,1.90883,-2.13449,0.206011,1.83374,-1.95799,0.000491,1.86573,-2.06037,0.024543,1.66727,-2.22658,0.092293,1.58271,-2.25813,0.242397,1.5938,-2.12908,0.306648,1.58421,-2.12069,0.103653,1.4057,-1.83073,-0.085581,1.46795,-1.89442,-0.081924,1.49171,-1.95389,-0.081456,1.46997,-2.00833,0.101536,1.39852,-2.09489,0.244704,1.21132,-1.76623,0.156755,1.10878,-1.78049,0.215209,1.05286,-1.80695,0.325947,1.0191,-1.79575,0.25285,0.854443,-1.7805,0.211132,0.790947,-1.79111,0.159973,0.915067,-1.80185,0.121135,0.853786,-1.80707,0.038057,0.639773,-1.81457,-0.076311,0.607725,-1.89717,0.164542,0.53804,-1.83073,0.114735,0.505742,-1.76137,0.001494,1.09866,-2.12756,-0.012563,1.01628,-2.10844,-0.139222,1.12245,-2.1013,-0.150645,1.04065,-2.08673,-0.133571,0.890236,-2.08108,-0.196135,0.711849,-2.06447,-0.289837,0.775324,-2.08015,-0.32734,0.715936,-2.0684,-0.426659,0.503652,-2.03003,-0.539565,0.471932,-1.96969,-0.296794,0.376995,-1.99999,-0.350851,0.344203,-2.06418,0.024854,1.31856,-1.84248,0.015244,1.31593,-2.05748},
/*102*/{0.100218,1.90054,-1.74417,0.193961,1.83819,-1.88106,-0.049193,1.81374,-1.66934,-0.168846,1.75029,-1.6338,-0.049955,1.64795,-1.67073,0.011138,1.58407,-1.67344,0.144661,1.91302,-2.13293,0.206352,1.83728,-1.95705,0.002226,1.86807,-2.061,0.028005,1.67157,-2.22713,0.097831,1.58814,-2.25849,0.244237,1.60243,-2.12576,0.308627,1.59471,-2.11703,0.105964,1.40961,-1.83172,-0.083079,1.4722,-1.89519,-0.078812,1.4946,-1.95587,-0.077597,1.47292,-2.00845,0.105175,1.39907,-2.09419,0.246491,1.21654,-1.7663,0.158237,1.11205,-1.78155,0.216248,1.05758,-1.80663,0.325929,1.024,-1.79631,0.260404,0.853742,-1.78048,0.223251,0.788841,-1.79059,0.165008,0.909693,-1.80501,0.129146,0.847268,-1.80985,0.057607,0.628188,-1.81529,-0.054489,0.589385,-1.89818,0.189876,0.533518,-1.83147,0.141709,0.498717,-1.76228,-0.002215,1.10148,-2.12608,-0.019199,1.01896,-2.10605,-0.141868,1.12925,-2.10131,-0.157243,1.04886,-2.08679,-0.144959,0.897442,-2.08127,-0.209865,0.720386,-2.0659,-0.303376,0.783367,-2.08035,-0.339651,0.725337,-2.06991,-0.448594,0.509187,-2.03109,-0.551876,0.485573,-1.96839,-0.318777,0.377212,-2.00013,-0.372817,0.346524,-2.06516,0.026974,1.32266,-1.84151,0.017971,1.31754,-2.0565},
/*103*/{0.099471,1.90377,-1.74403,0.193577,1.84129,-1.87949,-0.051184,1.81853,-1.67128,-0.172341,1.75608,-1.63736,-0.053283,1.65336,-1.67154,0.007637,1.58895,-1.67349,0.146668,1.91738,-2.13148,0.207121,1.84142,-1.95592,0.003445,1.87132,-2.06128,0.032076,1.67636,-2.2283,0.102191,1.5934,-2.25905,0.246315,1.61118,-2.12347,0.309932,1.60439,-2.11384,0.107041,1.4146,-1.83252,-0.080511,1.47687,-1.89575,-0.077041,1.49855,-1.95666,-0.074945,1.47638,-2.01014,0.107494,1.40011,-2.09379,0.247952,1.22107,-1.76613,0.157491,1.11651,-1.7808,0.217951,1.06266,-1.80445,0.324463,1.02652,-1.79635,0.267895,0.853121,-1.78085,0.233167,0.785892,-1.79072,0.169784,0.903158,-1.80778,0.135503,0.839946,-1.81278,0.077237,0.615997,-1.8166,-0.032156,0.571292,-1.89942,0.214464,0.529527,-1.8332,0.16885,0.49149,-1.76453,-0.006183,1.10369,-2.12482,-0.025258,1.02152,-2.10424,-0.1447,1.13644,-2.10133,-0.162714,1.05745,-2.0868,-0.155942,0.905441,-2.08094,-0.222586,0.72793,-2.06746,-0.314768,0.791598,-2.08025,-0.352714,0.731611,-2.06892,-0.45326,0.517867,-2.03348,-0.562746,0.499288,-1.96918,-0.34104,0.377755,-2.00171,-0.395549,0.346781,-2.06419,0.028237,1.32764,-1.8405,0.019546,1.31976,-2.05541},
/*104*/{0.098631,1.90659,-1.74386,0.193601,1.8459,-1.87878,-0.052747,1.8229,-1.67326,-0.174481,1.76157,-1.64057,-0.055249,1.65788,-1.67213,0.004768,1.59316,-1.67362,0.147923,1.92164,-2.13048,0.207155,1.84512,-1.9544,0.005393,1.87472,-2.06235,0.035008,1.68129,-2.22932,0.106361,1.59853,-2.25915,0.246301,1.61813,-2.12153,0.311487,1.61358,-2.11077,0.108016,1.41817,-1.83251,-0.077185,1.48109,-1.89599,-0.07402,1.50201,-1.95847,-0.071302,1.47927,-2.01017,0.109928,1.40056,-2.0927,0.248911,1.22423,-1.76614,0.15722,1.12277,-1.78088,0.21746,1.06633,-1.80449,0.323403,1.0297,-1.79743,0.274632,0.851946,-1.78107,0.24299,0.783112,-1.7906,0.174745,0.897622,-1.80955,0.14601,0.83154,-1.81334,0.097501,0.60516,-1.81746,-0.009427,0.554385,-1.90039,0.240251,0.526144,-1.8344,0.196723,0.484744,-1.76631,-0.009925,1.10616,-2.12388,-0.033029,1.02645,-2.10333,-0.147333,1.14434,-2.10182,-0.167215,1.06465,-2.08685,-0.16544,0.913314,-2.08152,-0.233515,0.736024,-2.0687,-0.326695,0.800156,-2.08123,-0.363995,0.739251,-2.06908,-0.463125,0.524434,-2.03509,-0.573194,0.51438,-1.96892,-0.361153,0.377857,-2.0027,-0.416774,0.349014,-2.06426,0.029293,1.33163,-1.83913,0.021309,1.32134,-2.05397},
/*105*/{0.098141,1.90935,-1.74383,0.192459,1.84889,-1.87779,-0.054534,1.82745,-1.67505,-0.178656,1.76592,-1.64384,-0.058151,1.66195,-1.67345,0.002324,1.59707,-1.67294,0.149791,1.92546,-2.12842,0.207666,1.84835,-1.95302,0.007072,1.8767,-2.06249,0.039355,1.6845,-2.23037,0.110342,1.60361,-2.26007,0.247624,1.62521,-2.11892,0.312548,1.62213,-2.10775,0.1104,1.42222,-1.83305,-0.075433,1.48624,-1.89681,-0.071432,1.5054,-1.96,-0.06795,1.48199,-2.01121,0.112125,1.4014,-2.09244,0.250548,1.22751,-1.76607,0.157323,1.12495,-1.7798,0.216083,1.06894,-1.80346,0.322576,1.03076,-1.79709,0.281076,0.850097,-1.78118,0.25351,0.780464,-1.79213,0.179645,0.890522,-1.81189,0.152318,0.823101,-1.81557,0.117977,0.59314,-1.81828,0.013124,0.538461,-1.90044,0.263881,0.522436,-1.83744,0.223873,0.478371,-1.76905,-0.013569,1.10849,-2.1225,-0.039355,1.0301,-2.1026,-0.149212,1.15083,-2.10204,-0.171958,1.07191,-2.08708,-0.175177,0.921772,-2.08208,-0.242361,0.743793,-2.07043,-0.337324,0.808126,-2.08217,-0.373324,0.747385,-2.06947,-0.476929,0.532656,-2.03692,-0.581191,0.530091,-1.96903,-0.380454,0.377897,-2.0042,-0.437658,0.351776,-2.06327,0.030903,1.33628,-1.83818,0.023033,1.32316,-2.05287},
/*106*/{0.09771,1.9122,-1.74359,0.193194,1.85229,-1.87727,-0.05551,1.83126,-1.67697,-0.180304,1.77055,-1.64727,-0.059968,1.66634,-1.67434,0.000377,1.60094,-1.67287,0.151,1.92863,-2.12737,0.208261,1.85136,-1.95219,0.008198,1.87926,-2.06274,0.043953,1.68873,-2.23225,0.114726,1.60745,-2.2607,0.249484,1.63173,-2.1177,0.31378,1.62945,-2.10525,0.111513,1.42549,-1.83414,-0.07423,1.48998,-1.89762,-0.068598,1.50906,-1.96072,-0.065927,1.48504,-2.01211,0.114345,1.40152,-2.0914,0.250669,1.22944,-1.76625,0.157124,1.12832,-1.77881,0.214849,1.07066,-1.80253,0.320339,1.03133,-1.79751,0.287998,0.847949,-1.78124,0.263832,0.776765,-1.79068,0.184701,0.883599,-1.8127,0.161728,0.815004,-1.81658,0.137719,0.582421,-1.81911,0.036308,0.523347,-1.901,0.287783,0.520351,-1.83805,0.249566,0.472057,-1.77181,-0.01611,1.11132,-2.12236,-0.044077,1.03411,-2.10262,-0.150789,1.1571,-2.1023,-0.176087,1.07978,-2.08735,-0.1846,0.929132,-2.08296,-0.252542,0.753138,-2.07211,-0.34704,0.815786,-2.08158,-0.382611,0.754205,-2.06975,-0.486975,0.54008,-2.0379,-0.588639,0.546172,-1.96878,-0.397587,0.378203,-2.00482,-0.460305,0.3559,-2.06286,0.031384,1.34002,-1.83737,0.023953,1.32481,-2.05194},
/*107*/{0.097565,1.91443,-1.74363,0.194158,1.85535,-1.8755,-0.056768,1.83557,-1.67836,-0.182833,1.77504,-1.65132,-0.061936,1.66991,-1.67543,-0.001081,1.60418,-1.67257,0.152893,1.93193,-2.12623,0.209627,1.8545,-1.95073,0.010399,1.881,-2.06271,0.047102,1.69261,-2.23361,0.118709,1.611,-2.26102,0.250152,1.63792,-2.11621,0.314247,1.63676,-2.10276,0.112249,1.42895,-1.83414,-0.071538,1.49427,-1.89851,-0.066489,1.51207,-1.96244,-0.06373,1.48891,-2.01324,0.116526,1.40221,-2.09031,0.250965,1.23171,-1.76716,0.156066,1.13071,-1.778,0.213001,1.07379,-1.80233,0.318769,1.03081,-1.79809,0.294141,0.845151,-1.78137,0.273817,0.772954,-1.79113,0.189569,0.876296,-1.81473,0.170936,0.806274,-1.81685,0.15778,0.571755,-1.81962,0.059154,0.508291,-1.90149,0.310677,0.516828,-1.84046,0.27614,0.466853,-1.7734,-0.018998,1.11437,-2.12242,-0.048663,1.03692,-2.10299,-0.152843,1.1629,-2.10224,-0.17974,1.08633,-2.08661,-0.19318,0.936766,-2.08297,-0.261164,0.759892,-2.07353,-0.354878,0.823896,-2.08255,-0.391871,0.762683,-2.07085,-0.492774,0.548537,-2.04036,-0.594116,0.561706,-1.96842,-0.416054,0.379183,-2.00683,-0.481323,0.362082,-2.06223,0.031643,1.34405,-1.83656,0.02516,1.32678,-2.051},
/*108*/{0.097591,1.91649,-1.74338,0.194668,1.85745,-1.87482,-0.057975,1.83869,-1.68028,-0.183741,1.77839,-1.65405,-0.063303,1.67328,-1.67599,-0.003126,1.60733,-1.67238,0.154765,1.93427,-2.12451,0.210052,1.85708,-1.94984,0.012191,1.88344,-2.06335,0.052999,1.69606,-2.23556,0.121796,1.61476,-2.26173,0.251412,1.64277,-2.11528,0.315053,1.64222,-2.10057,0.113548,1.43203,-1.83443,-0.069334,1.49751,-1.89822,-0.063981,1.51516,-1.96311,-0.060417,1.49156,-2.01389,0.118062,1.40347,-2.09005,0.253512,1.23221,-1.76743,0.154854,1.1341,-1.77781,0.21138,1.07445,-1.79943,0.316858,1.02938,-1.79765,0.300138,0.843073,-1.78128,0.283333,0.768888,-1.79114,0.194722,0.868119,-1.81591,0.178366,0.798444,-1.81857,0.177774,0.562055,-1.82048,0.082121,0.494618,-1.90191,0.33308,0.514144,-1.84191,0.302113,0.460895,-1.77627,-0.02135,1.11705,-2.12273,-0.05323,1.04085,-2.10334,-0.154397,1.16801,-2.1013,-0.182896,1.09194,-2.08642,-0.198619,0.944174,-2.08251,-0.268155,0.767745,-2.07506,-0.362131,0.830445,-2.08177,-0.398237,0.77062,-2.07269,-0.502325,0.556957,-2.04212,-0.599215,0.57823,-1.96734,-0.432847,0.378549,-2.00878,-0.50261,0.368349,-2.0605,0.032961,1.34727,-1.83604,0.026598,1.3288,-2.05039},
/*109*/{0.097719,1.91884,-1.74312,0.195136,1.85965,-1.87419,-0.058366,1.84158,-1.68165,-0.185567,1.78113,-1.65695,-0.064454,1.67632,-1.67726,-0.003449,1.61017,-1.67202,0.156336,1.93686,-2.1236,0.211002,1.85973,-1.94845,0.014308,1.88527,-2.06351,0.057202,1.69948,-2.23733,0.125326,1.61774,-2.26233,0.252504,1.64735,-2.11445,0.315692,1.64731,-2.09851,0.112689,1.43489,-1.83632,-0.067754,1.50102,-1.89879,-0.062147,1.51878,-1.96421,-0.058201,1.4943,-2.01364,0.12009,1.40437,-2.08963,0.253309,1.23215,-1.76774,0.153313,1.1358,-1.77767,0.208688,1.07482,-1.80113,0.313703,1.02791,-1.79863,0.305431,0.840418,-1.78079,0.292175,0.76565,-1.7913,0.199102,0.859483,-1.8171,0.186379,0.789082,-1.81927,0.197674,0.552182,-1.82041,0.10491,0.481868,-1.90273,0.35542,0.512059,-1.84373,0.327316,0.456993,-1.77922,-0.023997,1.11998,-2.1236,-0.055145,1.04378,-2.1046,-0.155916,1.17347,-2.10106,-0.18456,1.09651,-2.0852,-0.202697,0.950096,-2.08203,-0.27498,0.774017,-2.07585,-0.367446,0.839843,-2.08304,-0.405111,0.779101,-2.07278,-0.508435,0.566028,-2.04311,-0.601893,0.594294,-1.96827,-0.450014,0.379462,-2.00945,-0.524833,0.375927,-2.05978,0.032817,1.35039,-1.83594,0.027111,1.33094,-2.05022},
/*110*/{0.097667,1.92007,-1.7432,0.196158,1.86181,-1.87329,-0.059182,1.84411,-1.68327,-0.185824,1.78337,-1.65951,-0.065081,1.67856,-1.67768,-0.005272,1.6121,-1.67162,0.15854,1.93912,-2.12184,0.211631,1.86156,-1.94751,0.015327,1.88775,-2.06473,0.060723,1.70288,-2.23863,0.128618,1.62002,-2.26353,0.252985,1.65143,-2.11399,0.315918,1.65149,-2.09697,0.114624,1.4384,-1.83624,-0.066257,1.50417,-1.89967,-0.060614,1.52191,-1.96464,-0.056176,1.49727,-2.01448,0.121538,1.40603,-2.08885,0.251359,1.23074,-1.76823,0.151136,1.13587,-1.77858,0.205624,1.07508,-1.80091,0.311084,1.02552,-1.79829,0.309797,0.837248,-1.7809,0.301638,0.762334,-1.79104,0.203188,0.851695,-1.81692,0.193817,0.779645,-1.81991,0.217217,0.543373,-1.82145,0.127526,0.470097,-1.9028,0.377575,0.511974,-1.84604,0.351707,0.453308,-1.78217,-0.025656,1.12294,-2.12385,-0.059018,1.04806,-2.10603,-0.156528,1.17722,-2.10055,-0.185724,1.10078,-2.08472,-0.20476,0.954272,-2.08145,-0.280109,0.78041,-2.07704,-0.371297,0.847204,-2.08251,-0.410385,0.786886,-2.07368,-0.523595,0.574607,-2.04393,-0.606279,0.611085,-1.96913,-0.469046,0.377191,-2.00886,-0.544592,0.385232,-2.05776,0.034094,1.3541,-1.83532,0.028599,1.33315,-2.04947},
/*111*/{0.097953,1.92189,-1.74287,0.197398,1.86155,-1.87205,-0.059782,1.84652,-1.68498,-0.185865,1.78527,-1.66129,-0.066352,1.67997,-1.67858,-0.005974,1.61332,-1.67081,0.158495,1.94068,-2.12153,0.213155,1.86363,-1.94673,0.01734,1.88931,-2.06474,0.065743,1.70552,-2.24076,0.131184,1.62223,-2.26439,0.253342,1.6541,-2.11338,0.316297,1.65479,-2.09573,0.115136,1.44083,-1.83615,-0.064132,1.50714,-1.89934,-0.059863,1.52489,-1.96487,-0.0545,1.49986,-2.01438,0.121883,1.40753,-2.08847,0.250994,1.22975,-1.76833,0.15056,1.13647,-1.77904,0.202125,1.07372,-1.80086,0.307652,1.0228,-1.79824,0.31485,0.832759,-1.78133,0.308738,0.759308,-1.79157,0.206871,0.842321,-1.8164,0.200864,0.770435,-1.81957,0.237182,0.535336,-1.82186,0.149494,0.458041,-1.90354,0.397212,0.509705,-1.84849,0.373939,0.450156,-1.78507,-0.026396,1.12583,-2.12456,-0.05886,1.0501,-2.10667,-0.157645,1.18097,-2.09923,-0.18741,1.10455,-2.08343,-0.204921,0.957844,-2.08144,-0.284625,0.784926,-2.07814,-0.375437,0.852888,-2.08207,-0.414596,0.79404,-2.07388,-0.526519,0.585725,-2.04674,-0.610266,0.626314,-1.97108,-0.486034,0.376287,-2.00907,-0.560465,0.395284,-2.05634,0.034541,1.35691,-1.83479,0.028792,1.33523,-2.04885},
/*112*/{0.098533,1.92303,-1.74231,0.191808,1.866,-1.87308,-0.06034,1.84844,-1.68623,-0.190168,1.78636,-1.66445,-0.066587,1.68113,-1.67879,-0.00604,1.61457,-1.67083,0.159991,1.94201,-2.1209,0.213521,1.86636,-1.94645,0.018724,1.89097,-2.0645,0.070448,1.70787,-2.24269,0.134233,1.62339,-2.26513,0.254116,1.65695,-2.11359,0.317145,1.65632,-2.09431,0.115979,1.44294,-1.83668,-0.063289,1.50916,-1.89944,-0.057967,1.52711,-1.96442,-0.052951,1.503,-2.01473,0.122836,1.40915,-2.08804,0.248384,1.22674,-1.76888,0.146721,1.13612,-1.77949,0.19817,1.07256,-1.80122,0.303772,1.01966,-1.79791,0.318592,0.82938,-1.78153,0.317107,0.754214,-1.79188,0.210216,0.83388,-1.81476,0.207874,0.761262,-1.81892,0.25554,0.52792,-1.82263,0.170163,0.447467,-1.90419,0.415917,0.510072,-1.85142,0.397292,0.448101,-1.78626,-0.026244,1.12841,-2.12495,-0.059582,1.0525,-2.10715,-0.156344,1.18337,-2.09796,-0.186578,1.1076,-2.08407,-0.204481,0.960049,-2.08139,-0.288352,0.788143,-2.07872,-0.37786,0.858733,-2.08212,-0.418191,0.801015,-2.07436,-0.53343,0.595904,-2.04793,-0.613871,0.642272,-1.97248,-0.508692,0.380071,-2.00806,-0.581519,0.406523,-2.0556,0.035163,1.35896,-1.83485,0.029532,1.33743,-2.04893},
/*113*/{0.098747,1.92466,-1.74214,0.192504,1.86722,-1.87228,-0.059992,1.84924,-1.68733,-0.189857,1.78685,-1.66676,-0.067046,1.68223,-1.67966,-0.005763,1.61517,-1.66984,0.161652,1.94317,-2.12027,0.214169,1.86712,-1.94526,0.020035,1.89337,-2.06498,0.073657,1.70979,-2.24311,0.135992,1.6248,-2.26579,0.255401,1.65839,-2.11321,0.317348,1.65797,-2.09362,0.116713,1.44606,-1.8366,-0.062933,1.51144,-1.90054,-0.05747,1.52921,-1.96498,-0.052287,1.50531,-2.01543,0.124333,1.41165,-2.08791,0.24577,1.22346,-1.76905,0.142653,1.13426,-1.78094,0.194111,1.06947,-1.80141,0.30028,1.01489,-1.7976,0.321975,0.82517,-1.78214,0.324181,0.749929,-1.79309,0.213801,0.824702,-1.81155,0.214564,0.752173,-1.8173,0.271616,0.520634,-1.8247,0.190827,0.437207,-1.90513,0.434638,0.511003,-1.85282,0.418429,0.447136,-1.7886,-0.025463,1.13001,-2.12541,-0.058598,1.05379,-2.10769,-0.155413,1.18448,-2.09709,-0.185168,1.10905,-2.0824,-0.203326,0.961104,-2.08156,-0.291267,0.7911,-2.07921,-0.377516,0.86562,-2.08251,-0.42065,0.807606,-2.07433,-0.540694,0.604933,-2.04916,-0.617757,0.657177,-1.97432,-0.527393,0.393265,-2.00589,-0.598936,0.418178,-2.05375,0.035981,1.36181,-1.83493,0.03111,1.33975,-2.04897},
/*114*/{0.099471,1.92529,-1.7419,0.19939,1.86449,-1.86973,-0.059591,1.8498,-1.688,-0.189805,1.78674,-1.66805,-0.066796,1.68281,-1.67977,-0.005539,1.61488,-1.6689,0.162882,1.94369,-2.11958,0.216201,1.86788,-1.94456,0.022113,1.89472,-2.06518,0.077291,1.71193,-2.24449,0.137609,1.62557,-2.2662,0.255576,1.66053,-2.11288,0.317565,1.65812,-2.09287,0.117007,1.44752,-1.83687,-0.062512,1.51418,-1.89978,-0.056971,1.53187,-1.96531,-0.051979,1.50726,-2.01533,0.124457,1.4138,-2.08787,0.243421,1.22051,-1.76983,0.140402,1.13472,-1.77967,0.189096,1.06694,-1.80122,0.297656,1.01064,-1.79748,0.327165,0.821048,-1.78222,0.332247,0.746459,-1.79367,0.216771,0.815024,-1.80886,0.220904,0.743636,-1.81544,0.2872,0.514479,-1.8249,0.209959,0.427876,-1.90508,0.450963,0.511761,-1.85603,0.438346,0.447865,-1.79156,-0.02395,1.1314,-2.12531,-0.056784,1.05468,-2.1072,-0.154599,1.18543,-2.09684,-0.183655,1.10924,-2.08176,-0.20123,0.961662,-2.082,-0.292948,0.792897,-2.07897,-0.377562,0.868653,-2.08255,-0.421805,0.813115,-2.07413,-0.549519,0.615039,-2.04956,-0.625048,0.672118,-1.97721,-0.544126,0.403636,-2.00312,-0.6136,0.431463,-2.05165,0.035999,1.36378,-1.83502,0.030904,1.34199,-2.04909},
/*115*/{0.100052,1.9256,-1.7417,0.200715,1.86623,-1.86925,-0.059147,1.84996,-1.68872,-0.190783,1.78589,-1.67016,-0.066796,1.68281,-1.67977,-0.004821,1.61372,-1.66846,0.1649,1.94437,-2.11947,0.216357,1.86872,-1.94426,0.023086,1.89464,-2.06415,0.079094,1.71272,-2.24524,0.138902,1.62599,-2.26716,0.255984,1.65972,-2.11245,0.318086,1.65741,-2.09227,0.117156,1.44899,-1.83742,-0.062141,1.51526,-1.90082,-0.056012,1.5343,-1.96455,-0.05103,1.50965,-2.01525,0.125477,1.41535,-2.08754,0.242234,1.21525,-1.7691,0.134036,1.13007,-1.78065,0.183634,1.06369,-1.80113,0.293821,1.00577,-1.79764,0.331224,0.816433,-1.78336,0.338958,0.742462,-1.79518,0.220325,0.806794,-1.80586,0.227958,0.734848,-1.81257,0.30443,0.509215,-1.82598,0.228769,0.419297,-1.90572,0.465841,0.513905,-1.85804,0.457411,0.449288,-1.79345,-0.020868,1.13281,-2.12566,-0.052795,1.05603,-2.10866,-0.152097,1.18508,-2.09624,-0.180662,1.10966,-2.08174,-0.198084,0.961231,-2.08193,-0.294648,0.793958,-2.07875,-0.376749,0.872457,-2.08351,-0.421849,0.8186,-2.07471,-0.554844,0.627839,-2.04934,-0.630917,0.686806,-1.97923,-0.558445,0.414826,-1.99951,-0.626327,0.445051,-2.04925,0.03607,1.36515,-1.8354,0.031483,1.34399,-2.04954},
/*116*/{0.100714,1.92592,-1.74146,0.202349,1.86564,-1.86908,-0.059068,1.84936,-1.68904,-0.190855,1.78416,-1.67184,-0.065377,1.68093,-1.68036,-0.003974,1.61267,-1.66654,0.166357,1.94469,-2.11902,0.218094,1.86958,-1.94377,0.024394,1.89719,-2.06453,0.082355,1.7134,-2.24552,0.139531,1.62608,-2.26777,0.256545,1.65823,-2.11166,0.318982,1.65624,-2.09219,0.116887,1.45067,-1.83737,-0.061406,1.51607,-1.90014,-0.05588,1.53545,-1.96444,-0.05079,1.51103,-2.01471,0.126589,1.4175,-2.08727,0.238221,1.21008,-1.7699,0.132172,1.12969,-1.77904,0.177027,1.05973,-1.80234,0.289704,1.00031,-1.79754,0.335208,0.81267,-1.78466,0.344817,0.738397,-1.79767,0.224497,0.797275,-1.80308,0.233534,0.727729,-1.81074,0.316394,0.504391,-1.82611,0.245412,0.411283,-1.90731,0.48018,0.515859,-1.8593,0.473178,0.450942,-1.7958,-0.018507,1.13322,-2.12545,-0.049086,1.05557,-2.108,-0.149753,1.18532,-2.09631,-0.176852,1.10776,-2.08115,-0.193885,0.959688,-2.08179,-0.295486,0.79476,-2.0785,-0.374266,0.87625,-2.08435,-0.421273,0.824413,-2.07635,-0.564733,0.637796,-2.0502,-0.637714,0.700968,-1.98206,-0.574388,0.427479,-1.99716,-0.637793,0.458462,-2.04842,0.036721,1.36631,-1.83536,0.032568,1.34574,-2.04957},
/*117*/{0.101365,1.92615,-1.74083,0.202533,1.86567,-1.86901,-0.058936,1.84876,-1.68951,-0.189454,1.78316,-1.67303,-0.063968,1.67907,-1.6794,-0.002103,1.61047,-1.66493,0.167181,1.94457,-2.11856,0.218514,1.86954,-1.9429,0.025731,1.89842,-2.06435,0.083168,1.71445,-2.2462,0.139529,1.6257,-2.26806,0.257174,1.65643,-2.1119,0.318796,1.65331,-2.09187,0.119213,1.45168,-1.83756,-0.06177,1.51698,-1.89948,-0.055789,1.53577,-1.9642,-0.050796,1.51123,-2.01418,0.126457,1.41924,-2.08725,0.235398,1.20504,-1.7702,0.124013,1.12337,-1.78012,0.170711,1.05586,-1.8025,0.285605,0.994223,-1.79733,0.339656,0.809412,-1.78589,0.350923,0.735438,-1.79915,0.227685,0.790354,-1.79966,0.240013,0.719769,-1.80787,0.333004,0.501049,-1.82748,0.260363,0.40467,-1.90696,0.490748,0.517035,-1.86132,0.488233,0.452331,-1.79762,-0.015188,1.13301,-2.12534,-0.044746,1.05511,-2.10804,-0.147371,1.18351,-2.09597,-0.173901,1.10566,-2.08084,-0.188729,0.957725,-2.08189,-0.295842,0.79506,-2.07779,-0.371682,0.880108,-2.08529,-0.422045,0.831024,-2.0775,-0.570726,0.650077,-2.04989,-0.644229,0.716693,-1.98478,-0.586071,0.440994,-1.99437,-0.651484,0.472436,-2.04736,0.038617,1.36733,-1.83521,0.033329,1.34667,-2.04939},
/*118*/{0.102437,1.92572,-1.73999,0.203276,1.86691,-1.86912,-0.058538,1.84698,-1.69091,-0.187785,1.78014,-1.67378,-0.063182,1.67681,-1.67952,-0.001174,1.60781,-1.66398,0.169047,1.94351,-2.11833,0.218995,1.86957,-1.94255,0.02648,1.89832,-2.06389,0.083878,1.71369,-2.24529,0.13906,1.62485,-2.2678,0.25788,1.6544,-2.11172,0.31974,1.65025,-2.09207,0.120372,1.45197,-1.83764,-0.061638,1.51655,-1.89992,-0.055856,1.53638,-1.96368,-0.050149,1.51235,-2.01362,0.127737,1.42103,-2.08708,0.230708,1.19917,-1.77032,0.123876,1.12322,-1.77917,0.163834,1.05091,-1.80374,0.280691,0.988198,-1.79708,0.34169,0.806728,-1.78778,0.355938,0.732977,-1.80155,0.231565,0.783395,-1.7977,0.245607,0.714215,-1.80524,0.340268,0.497188,-1.82762,0.273258,0.40014,-1.9067,0.50166,0.517143,-1.86228,0.500482,0.451136,-1.79955,-0.010928,1.13227,-2.12474,-0.040237,1.05357,-2.10767,-0.143165,1.18071,-2.09607,-0.169124,1.1029,-2.08091,-0.182726,0.955097,-2.08145,-0.296149,0.796024,-2.07722,-0.368244,0.883431,-2.08605,-0.420126,0.835281,-2.07866,-0.578261,0.662307,-2.05023,-0.649939,0.731098,-1.98675,-0.599743,0.453592,-1.99099,-0.660487,0.486145,-2.04636,0.039655,1.3673,-1.83582,0.034751,1.34801,-2.05013},
/*119*/{0.102843,1.92555,-1.73987,0.203536,1.86635,-1.86843,-0.057236,1.84514,-1.69045,-0.186435,1.77706,-1.67421,-0.060996,1.67378,-1.67885,0.000628,1.60506,-1.66228,0.170398,1.94267,-2.11788,0.219321,1.86956,-1.94242,0.027241,1.89912,-2.06311,0.083394,1.71367,-2.24485,0.138262,1.62415,-2.26778,0.25752,1.65155,-2.11209,0.320177,1.64604,-2.0918,0.120955,1.45212,-1.8379,-0.061712,1.51645,-1.89865,-0.055865,1.53648,-1.96358,-0.050427,1.51228,-2.01265,0.128055,1.42207,-2.0871,0.227618,1.19327,-1.77031,0.113678,1.11606,-1.7826,0.156923,1.04735,-1.80537,0.274614,0.982232,-1.79807,0.343719,0.80421,-1.79023,0.360262,0.730949,-1.80302,0.233704,0.778083,-1.79693,0.250005,0.708768,-1.80413,0.350121,0.493876,-1.82735,0.283473,0.396104,-1.9068,0.510568,0.517089,-1.8643,0.510391,0.451155,-1.8014,-0.006488,1.13107,-2.12428,-0.034591,1.05211,-2.10818,-0.139763,1.17811,-2.09609,-0.164262,1.09968,-2.08117,-0.176544,0.952221,-2.08082,-0.295157,0.797156,-2.0763,-0.362996,0.887953,-2.08732,-0.417595,0.842981,-2.0786,-0.583367,0.675589,-2.05034,-0.655199,0.746753,-1.98949,-0.609734,0.468636,-1.98777,-0.669271,0.500869,-2.04516,0.040577,1.36726,-1.83582,0.035176,1.34857,-2.05018},
/*120*/{0.104568,1.92453,-1.73899,0.20393,1.86634,-1.86807,-0.056627,1.84241,-1.69048,-0.184506,1.77356,-1.67434,-0.059209,1.67085,-1.6785,0.002456,1.60166,-1.66018,0.170886,1.94164,-2.11718,0.21994,1.86892,-1.94168,0.028257,1.89965,-2.06304,0.082098,1.71283,-2.24388,0.136387,1.62374,-2.26721,0.257233,1.64855,-2.11258,0.320531,1.64144,-2.09249,0.121922,1.45215,-1.83794,-0.061098,1.51526,-1.89813,-0.05596,1.53648,-1.96347,-0.050536,1.51245,-2.01217,0.128527,1.42302,-2.08733,0.222716,1.18683,-1.77072,0.108021,1.11291,-1.78319,0.148696,1.04192,-1.80592,0.268685,0.976684,-1.79858,0.343707,0.801987,-1.79171,0.361448,0.728521,-1.8044,0.235343,0.773078,-1.79641,0.252939,0.703651,-1.80351,0.35663,0.489967,-1.82655,0.292202,0.392698,-1.90618,0.517764,0.517034,-1.86603,0.520182,0.451324,-1.80374,-0.001513,1.1295,-2.12361,-0.028612,1.05044,-2.1069,-0.135917,1.17355,-2.09569,-0.158948,1.09588,-2.08068,-0.170157,0.949031,-2.08034,-0.296344,0.797356,-2.07494,-0.3593,0.891187,-2.08766,-0.415318,0.848456,-2.07869,-0.589135,0.6885,-2.04931,-0.658913,0.76287,-1.99159,-0.618989,0.484142,-1.98542,-0.676282,0.516989,-2.04428,0.041796,1.36686,-1.8362,0.036046,1.34903,-2.05062},
/*121*/{0.105838,1.92305,-1.73815,0.204828,1.86634,-1.86822,-0.0546,1.83933,-1.69038,-0.181978,1.76918,-1.67467,-0.057082,1.66705,-1.67638,0.004379,1.59754,-1.65833,0.172424,1.9402,-2.11713,0.220769,1.8684,-1.94171,0.028777,1.89963,-2.06263,0.080026,1.71214,-2.24296,0.134445,1.62248,-2.26668,0.258167,1.6437,-2.11294,0.320448,1.63567,-2.09284,0.122519,1.45218,-1.83832,-0.060787,1.51394,-1.89823,-0.056234,1.53565,-1.96283,-0.050723,1.51181,-2.01213,0.128735,1.42333,-2.0874,0.219669,1.18045,-1.77054,0.101756,1.10832,-1.78431,0.14321,1.03801,-1.80717,0.261869,0.971407,-1.79874,0.342464,0.800589,-1.79296,0.359506,0.727879,-1.80526,0.234122,0.768295,-1.79726,0.253589,0.699938,-1.80479,0.363086,0.488883,-1.82732,0.298612,0.389192,-1.90592,0.523005,0.516395,-1.86739,0.526976,0.449533,-1.80496,0.003679,1.12765,-2.123,-0.021689,1.04826,-2.1065,-0.131575,1.16938,-2.09577,-0.153853,1.09026,-2.08036,-0.162387,0.945131,-2.07981,-0.294216,0.799013,-2.0734,-0.352381,0.89524,-2.088,-0.410714,0.85633,-2.08025,-0.592005,0.702545,-2.04952,-0.659066,0.777846,-1.99252,-0.628564,0.49898,-1.98324,-0.682558,0.532879,-2.04346,0.042902,1.36633,-1.83642,0.036807,1.3488,-2.05086},
/*122*/{0.10691,1.92146,-1.73783,0.205115,1.8652,-1.8676,-0.053388,1.836,-1.68928,-0.179733,1.76485,-1.67393,-0.053985,1.6623,-1.67499,0.007336,1.59352,-1.65635,0.172931,1.93853,-2.11659,0.220002,1.86718,-1.94142,0.029229,1.89934,-2.06237,0.076569,1.7117,-2.24155,0.132405,1.62149,-2.26606,0.258429,1.63854,-2.11336,0.32054,1.62917,-2.09385,0.121948,1.45119,-1.8386,-0.06111,1.51254,-1.89789,-0.056346,1.53522,-1.96285,-0.050938,1.51012,-2.01176,0.129699,1.4234,-2.08748,0.214642,1.17491,-1.77042,0.098234,1.10708,-1.78376,0.135923,1.03424,-1.80838,0.255104,0.965566,-1.79924,0.338894,0.797802,-1.79334,0.359443,0.724968,-1.80459,0.231432,0.763795,-1.79988,0.252812,0.695778,-1.80571,0.366459,0.485898,-1.82794,0.303365,0.385904,-1.90606,0.526132,0.51547,-1.86791,0.53096,0.448879,-1.80618,0.008964,1.12514,-2.12201,-0.015098,1.04483,-2.10571,-0.126538,1.16463,-2.09554,-0.147341,1.08608,-2.08049,-0.155108,0.940331,-2.08246,-0.290759,0.801066,-2.07283,-0.347049,0.89925,-2.08841,-0.406891,0.861162,-2.07939,-0.593292,0.716819,-2.0495,-0.659171,0.795729,-1.99454,-0.635777,0.515527,-1.98291,-0.689607,0.551234,-2.04372,0.043078,1.36506,-1.83678,0.03752,1.34836,-2.0513},
/*123*/{0.108045,1.91935,-1.73727,0.206363,1.86285,-1.8675,-0.051689,1.83154,-1.68784,-0.176052,1.76009,-1.67266,-0.051717,1.65772,-1.67326,0.009928,1.58879,-1.65454,0.172494,1.93646,-2.11595,0.220589,1.86576,-1.94135,0.029106,1.89867,-2.06128,0.074043,1.71081,-2.24056,0.129314,1.6204,-2.26511,0.258297,1.63388,-2.11426,0.319976,1.62285,-2.09543,0.12213,1.44954,-1.83854,-0.060318,1.50986,-1.89772,-0.056029,1.53312,-1.96204,-0.050648,1.50844,-2.01152,0.129941,1.42331,-2.08755,0.211589,1.169,-1.76943,0.091705,1.10046,-1.78356,0.130656,1.02952,-1.80878,0.248261,0.960033,-1.79895,0.335093,0.794828,-1.79306,0.356729,0.724092,-1.80607,0.228361,0.759753,-1.80206,0.250723,0.692302,-1.80798,0.36817,0.483114,-1.8288,0.30599,0.382339,-1.90653,0.527204,0.513945,-1.86898,0.534554,0.448272,-1.80761,0.014787,1.12245,-2.12172,-0.007612,1.04247,-2.10539,-0.123134,1.15913,-2.09572,-0.140926,1.07997,-2.07971,-0.147052,0.935406,-2.07853,-0.287102,0.802557,-2.07146,-0.339646,0.902505,-2.0875,-0.400447,0.867199,-2.07912,-0.591278,0.732093,-2.05157,-0.657494,0.813623,-1.99652,-0.643523,0.531882,-1.98237,-0.696601,0.56846,-2.04459,0.044099,1.36279,-1.8373,0.038576,1.34741,-2.05192},
/*124*/{0.109376,1.91674,-1.7362,0.206665,1.86156,-1.86749,-0.050355,1.82775,-1.68752,-0.173943,1.75423,-1.6716,-0.048093,1.65229,-1.67164,0.013555,1.58435,-1.65241,0.173206,1.93427,-2.11575,0.220749,1.86427,-1.94103,0.029204,1.89756,-2.06016,0.070225,1.70979,-2.23944,0.126065,1.61863,-2.26418,0.258855,1.62899,-2.11582,0.319382,1.61573,-2.09668,0.122052,1.44805,-1.8388,-0.061021,1.50784,-1.89701,-0.055693,1.53129,-1.96215,-0.050213,1.50668,-2.01102,0.130425,1.42303,-2.08774,0.20912,1.16261,-1.76809,0.088964,1.09902,-1.78611,0.126061,1.02636,-1.8103,0.240621,0.954906,-1.7999,0.330785,0.791307,-1.79277,0.353743,0.718098,-1.80399,0.224521,0.754797,-1.8039,0.246992,0.687607,-1.81017,0.368063,0.479506,-1.82997,0.307503,0.378175,-1.90814,0.527602,0.511679,-1.86976,0.533932,0.446779,-1.80876,0.019973,1.11979,-2.12108,-0.000863,1.03875,-2.10466,-0.118126,1.15336,-2.09536,-0.13494,1.0737,-2.07908,-0.138543,0.930093,-2.07903,-0.284786,0.8033,-2.07132,-0.331577,0.905613,-2.08652,-0.394597,0.872172,-2.07725,-0.590584,0.746393,-2.05178,-0.652176,0.830061,-1.99593,-0.649552,0.548746,-1.98272,-0.701442,0.586994,-2.04486,0.044656,1.36085,-1.83774,0.039415,1.34648,-2.05243},
/*125*/{0.110674,1.91394,-1.73556,0.20625,1.86074,-1.86806,-0.048206,1.82318,-1.68548,-0.16963,1.74844,-1.66937,-0.044977,1.64668,-1.66896,0.017506,1.57862,-1.64969,0.173224,1.93221,-2.11554,0.2207,1.86208,-1.94093,0.028991,1.89715,-2.05955,0.066978,1.70775,-2.23795,0.122635,1.6171,-2.26309,0.256846,1.62179,-2.11697,0.318497,1.60713,-2.09859,0.122366,1.44541,-1.83904,-0.060332,1.50503,-1.89654,-0.055298,1.52848,-1.96183,-0.050702,1.50413,-2.01087,0.131148,1.42204,-2.08792,0.206765,1.15807,-1.76684,0.085254,1.09641,-1.78639,0.122158,1.02277,-1.8114,0.236895,0.95097,-1.79932,0.326524,0.786378,-1.7924,0.350369,0.715461,-1.80497,0.219762,0.74947,-1.80567,0.243935,0.68258,-1.81186,0.366783,0.475866,-1.83074,0.306644,0.374603,-1.90945,0.525616,0.509942,-1.87167,0.532829,0.443741,-1.80946,0.025831,1.11627,-2.12088,0.006565,1.03471,-2.10421,-0.113182,1.14771,-2.09491,-0.128746,1.06728,-2.07825,-0.130157,0.926624,-2.07887,-0.279722,0.804575,-2.07076,-0.322724,0.908834,-2.08553,-0.386278,0.879685,-2.07677,-0.588239,0.759973,-2.05117,-0.647057,0.846213,-1.9958,-0.654583,0.564957,-1.98359,-0.704349,0.606254,-2.04525,0.045602,1.35794,-1.83834,0.040303,1.34475,-2.05311},
/*126*/{0.11146,1.91042,-1.73437,0.20688,1.85825,-1.86842,-0.046346,1.81798,-1.68416,-0.167979,1.74148,-1.66717,-0.040945,1.64093,-1.66658,0.021394,1.57328,-1.64641,0.172928,1.92886,-2.1157,0.22116,1.86002,-1.94076,0.029442,1.89487,-2.05875,0.062707,1.70634,-2.23654,0.118918,1.61521,-2.26183,0.25569,1.61477,-2.11778,0.316833,1.59851,-2.10064,0.122071,1.44273,-1.83891,-0.06081,1.50233,-1.89693,-0.055884,1.52566,-1.96171,-0.050666,1.50157,-2.01118,0.131652,1.42107,-2.08788,0.203323,1.1543,-1.76609,0.08254,1.09328,-1.78635,0.120538,1.01987,-1.81224,0.234833,0.947296,-1.79942,0.32169,0.781622,-1.79231,0.343808,0.70994,-1.80526,0.215261,0.74467,-1.80744,0.239519,0.677383,-1.81466,0.364475,0.471642,-1.83245,0.303441,0.370806,-1.91181,0.522669,0.505231,-1.87256,0.529861,0.4392,-1.81095,0.031247,1.11299,-2.12125,0.014231,1.03008,-2.10299,-0.107831,1.1414,-2.09421,-0.122736,1.06108,-2.07797,-0.121536,0.91966,-2.07677,-0.274517,0.805945,-2.07037,-0.312613,0.911058,-2.08536,-0.378496,0.883763,-2.07691,-0.585022,0.773983,-2.05153,-0.639972,0.861193,-1.99514,-0.660026,0.580964,-1.98432,-0.707849,0.624291,-2.0459,0.045599,1.35505,-1.83902,0.041113,1.34305,-2.05388},
/*127*/{0.112959,1.90673,-1.73364,0.206099,1.85521,-1.8684,-0.044691,1.81231,-1.68237,-0.164364,1.73531,-1.66452,-0.037693,1.6347,-1.6632,0.025933,1.56798,-1.64507,0.17322,1.92637,-2.11583,0.220896,1.85714,-1.9406,0.029453,1.89328,-2.05824,0.058962,1.70469,-2.23518,0.114626,1.61294,-2.26153,0.255049,1.60802,-2.1193,0.315687,1.58965,-2.10337,0.119929,1.43855,-1.83911,-0.060711,1.49916,-1.89655,-0.055561,1.52201,-1.96171,-0.051539,1.49864,-2.01108,0.132043,1.41877,-2.08794,0.200604,1.15123,-1.76493,0.081027,1.08975,-1.78714,0.119012,1.01699,-1.81333,0.233929,0.945398,-1.79958,0.317535,0.775942,-1.79236,0.341033,0.704699,-1.80468,0.21095,0.739551,-1.80875,0.235429,0.671812,-1.81573,0.360761,0.468318,-1.8345,0.298577,0.367226,-1.91506,0.518828,0.499669,-1.87305,0.524896,0.432892,-1.81161,0.035098,1.10911,-2.12151,0.021225,1.0268,-2.10303,-0.104448,1.1347,-2.09387,-0.116352,1.05411,-2.07735,-0.112367,0.914649,-2.07681,-0.268949,0.805875,-2.06966,-0.303484,0.913538,-2.08509,-0.370181,0.887801,-2.0764,-0.580022,0.787327,-2.05205,-0.630593,0.877316,-1.99545,-0.663035,0.597041,-1.98576,-0.709521,0.643662,-2.04649,0.0444,1.35082,-1.83982,0.040844,1.34049,-2.05478},
/*128*/{0.113679,1.90276,-1.73323,0.207103,1.8509,-1.86801,-0.042685,1.80607,-1.68069,-0.160975,1.72785,-1.66183,-0.033828,1.62832,-1.66031,0.030726,1.56246,-1.64271,0.171904,1.92285,-2.11599,0.220945,1.85411,-1.94088,0.02894,1.89101,-2.05724,0.054683,1.70277,-2.23327,0.110718,1.61012,-2.26043,0.252891,1.59985,-2.12118,0.313493,1.57995,-2.10608,0.119945,1.43584,-1.83839,-0.061055,1.49621,-1.89598,-0.055474,1.51908,-1.96139,-0.051393,1.49512,-2.01127,0.132402,1.41703,-2.08779,0.200583,1.14795,-1.76448,0.078515,1.08684,-1.78837,0.115846,1.01342,-1.81398,0.233385,0.943246,-1.7999,0.313014,0.771183,-1.79258,0.335638,0.699353,-1.80525,0.206996,0.734449,-1.80972,0.230418,0.666593,-1.81744,0.351964,0.4614,-1.83613,0.292352,0.363301,-1.91884,0.513061,0.49357,-1.87386,0.517158,0.42481,-1.81149,0.040833,1.1055,-2.1217,0.027459,1.02305,-2.10274,-0.099076,1.12815,-2.09331,-0.109833,1.04768,-2.07664,-0.103813,0.909006,-2.07639,-0.263103,0.805804,-2.06914,-0.292877,0.914941,-2.0848,-0.360634,0.891185,-2.07608,-0.573506,0.799629,-2.05242,-0.621291,0.891328,-1.99437,-0.664687,0.612702,-1.98712,-0.709519,0.661268,-2.04776,0.044796,1.3479,-1.83973,0.041674,1.33805,-2.05472},
/*129*/{0.11473,1.89869,-1.73229,0.206524,1.84823,-1.8685,-0.040688,1.79973,-1.67869,-0.158662,1.71938,-1.6577,-0.029384,1.62132,-1.65667,0.035282,1.55655,-1.64003,0.171568,1.91901,-2.11656,0.220917,1.85156,-1.94116,0.027918,1.88706,-2.05549,0.050005,1.70024,-2.23205,0.105994,1.60718,-2.25978,0.250368,1.59144,-2.12299,0.311054,1.56969,-2.10879,0.120057,1.43393,-1.83702,-0.061152,1.49251,-1.89645,-0.055935,1.51537,-1.96151,-0.051275,1.49169,-2.01139,0.132901,1.41501,-2.08748,0.197605,1.14501,-1.76375,0.077071,1.08489,-1.78919,0.114244,1.01033,-1.81376,0.231412,0.940425,-1.79982,0.308453,0.765181,-1.79274,0.329037,0.693718,-1.80599,0.201801,0.730349,-1.8114,0.223901,0.66281,-1.82007,0.345089,0.456457,-1.83852,0.283562,0.358739,-1.92243,0.506591,0.486011,-1.8731,0.509273,0.41555,-1.81375,0.046029,1.10125,-2.12162,0.033903,1.01914,-2.1031,-0.093673,1.12165,-2.09274,-0.103312,1.04102,-2.07573,-0.094994,0.902823,-2.07632,-0.255983,0.805722,-2.06937,-0.282611,0.916335,-2.08446,-0.350141,0.894878,-2.076,-0.56656,0.812179,-2.05329,-0.6112,0.904978,-1.99456,-0.663926,0.626889,-1.98921,-0.704283,0.678562,-2.04892,0.045511,1.34533,-1.83929,0.043174,1.33519,-2.05428},
/*130*/{0.115624,1.89356,-1.73147,0.207099,1.84488,-1.86902,-0.038308,1.79313,-1.67625,-0.154836,1.71189,-1.65359,-0.024555,1.61524,-1.65416,0.041659,1.55077,-1.63761,0.170477,1.91545,-2.11678,0.221157,1.84813,-1.94051,0.028231,1.88371,-2.05489,0.04589,1.6974,-2.23095,0.101881,1.60389,-2.25931,0.247766,1.58374,-2.12499,0.30789,1.55884,-2.11194,0.119919,1.42963,-1.83754,-0.06153,1.48887,-1.89632,-0.057039,1.51276,-1.96185,-0.051513,1.48724,-2.01154,0.132743,1.41091,-2.08825,0.195584,1.1433,-1.76485,0.074496,1.08275,-1.79038,0.112223,1.00875,-1.81351,0.229458,0.936036,-1.80014,0.303258,0.759403,-1.79335,0.324298,0.688552,-1.80763,0.196177,0.725892,-1.81175,0.217415,0.657818,-1.82103,0.335997,0.448466,-1.83978,0.273721,0.354725,-1.92605,0.497387,0.476877,-1.87373,0.500126,0.407783,-1.81555,0.050532,1.09797,-2.12141,0.040634,1.01555,-2.10349,-0.090637,1.11503,-2.0926,-0.097255,1.0341,-2.07588,-0.085936,0.897098,-2.07595,-0.248757,0.806094,-2.07001,-0.270321,0.915716,-2.08333,-0.339011,0.898989,-2.0768,-0.558303,0.822872,-2.05402,-0.599986,0.917509,-1.99455,-0.661825,0.641021,-1.99047,-0.704728,0.69603,-2.04988,0.045036,1.34144,-1.83969,0.042394,1.33135,-2.05467},
/*131*/{0.11658,1.88895,-1.73059,0.208766,1.83941,-1.86883,-0.035432,1.78617,-1.67352,-0.150756,1.7033,-1.6496,-0.019369,1.60748,-1.65015,0.047186,1.54494,-1.63473,0.169376,1.91138,-2.11699,0.22083,1.84452,-1.94096,0.027148,1.8803,-2.05452,0.042537,1.69262,-2.229,0.096744,1.6002,-2.25857,0.244295,1.57378,-2.12678,0.304825,1.54804,-2.11508,0.119778,1.42638,-1.83708,-0.061687,1.48475,-1.89691,-0.056455,1.50849,-1.96113,-0.05195,1.48328,-2.0115,0.133688,1.4086,-2.08694,0.195107,1.13867,-1.76402,0.073108,1.07993,-1.7905,0.110357,1.00527,-1.81391,0.226925,0.931316,-1.79988,0.297494,0.753099,-1.7935,0.317121,0.680777,-1.80827,0.190329,0.721459,-1.81279,0.211659,0.653247,-1.82126,0.325149,0.441495,-1.84107,0.26179,0.350492,-1.92876,0.488018,0.467821,-1.87481,0.488217,0.396506,-1.81752,0.055681,1.09388,-2.12151,0.047583,1.01115,-2.10345,-0.085176,1.10816,-2.09181,-0.089467,1.02677,-2.07543,-0.076207,0.891305,-2.0761,-0.240937,0.805612,-2.06909,-0.259788,0.916458,-2.08336,-0.329401,0.901685,-2.07672,-0.549579,0.834034,-2.05387,-0.587446,0.928754,-1.99454,-0.657382,0.654483,-1.99201,-0.698737,0.710156,-2.05214,0.045503,1.33775,-1.83949,0.043839,1.32818,-2.05451},
/*132*/{0.117993,1.88334,-1.72992,0.208701,1.83479,-1.86866,-0.0332,1.77816,-1.67093,-0.147652,1.69382,-1.64504,-0.014721,1.60013,-1.64703,0.053232,1.53911,-1.63216,0.167209,1.90725,-2.11778,0.220916,1.84041,-1.94109,0.026536,1.87562,-2.05348,0.037379,1.68926,-2.22837,0.091903,1.59661,-2.25836,0.241507,1.56462,-2.12946,0.300936,1.53669,-2.11876,0.119476,1.42322,-1.8362,-0.061535,1.48077,-1.8968,-0.056512,1.50445,-1.96116,-0.051155,1.47786,-2.01221,0.133902,1.406,-2.08643,0.193003,1.13576,-1.76406,0.070728,1.07722,-1.79238,0.107606,1.00162,-1.81421,0.223928,0.925948,-1.79961,0.291577,0.746761,-1.79467,0.310779,0.673773,-1.8085,0.183671,0.717476,-1.81414,0.203575,0.649557,-1.82315,0.315237,0.436745,-1.84208,0.249192,0.347013,-1.93069,0.477408,0.458982,-1.87578,0.476854,0.387753,-1.81916,0.061659,1.09001,-2.12205,0.054924,1.00611,-2.10377,-0.079173,1.10071,-2.09153,-0.082737,1.0196,-2.07434,-0.067086,0.885415,-2.07653,-0.233485,0.804307,-2.06977,-0.248227,0.917035,-2.08239,-0.317101,0.903288,-2.07671,-0.54034,0.842121,-2.05393,-0.575123,0.939434,-1.99454,-0.652482,0.666937,-1.99392,-0.692544,0.723512,-2.05387,0.046115,1.33421,-1.83914,0.045256,1.32445,-2.05415},
/*133*/{0.119029,1.87781,-1.72874,0.207882,1.83188,-1.86895,-0.030042,1.77011,-1.66778,-0.141801,1.68521,-1.64024,-0.008738,1.59299,-1.6438,0.059377,1.5328,-1.63004,0.16684,1.90287,-2.11842,0.221508,1.83619,-1.94109,0.025823,1.87195,-2.05196,0.032964,1.68632,-2.22747,0.086314,1.59251,-2.25829,0.237464,1.55441,-2.13213,0.297022,1.52424,-2.12253,0.120293,1.42054,-1.83574,-0.062919,1.47654,-1.89701,-0.057239,1.50083,-1.96216,-0.052455,1.47368,-2.01234,0.133195,1.40241,-2.0875,0.191456,1.13268,-1.76491,0.070663,1.07394,-1.79245,0.106337,0.99881,-1.81401,0.21985,0.920311,-1.79983,0.284505,0.740137,-1.79569,0.304003,0.667592,-1.81019,0.177023,0.712909,-1.8146,0.194569,0.643027,-1.82442,0.300215,0.431128,-1.84347,0.230598,0.353718,-1.93061,0.465837,0.447756,-1.87772,0.460711,0.376194,-1.8209,0.06731,1.08613,-2.12231,0.063172,1.00228,-2.10481,-0.073187,1.09406,-2.09095,-0.075071,1.01312,-2.07399,-0.056925,0.880296,-2.07732,-0.224973,0.804427,-2.07012,-0.23653,0.917398,-2.08249,-0.305954,0.90545,-2.07643,-0.53194,0.851962,-2.05359,-0.562705,0.947972,-1.99381,-0.644866,0.677527,-1.99636,-0.6843,0.735446,-2.05535,0.046592,1.33124,-1.83908,0.045121,1.32056,-2.05405},
/*134*/{0.11992,1.87226,-1.72832,0.209089,1.82578,-1.86874,-0.0277,1.76187,-1.6648,-0.139556,1.67586,-1.63574,-0.003165,1.58512,-1.63944,0.066439,1.52661,-1.62707,0.165855,1.89821,-2.11894,0.221466,1.83157,-1.94188,0.024713,1.86719,-2.05154,0.029487,1.68213,-2.2266,0.08146,1.58822,-2.25807,0.233722,1.54474,-2.13465,0.291531,1.5117,-2.12677,0.119927,1.41592,-1.8337,-0.063097,1.47108,-1.89852,-0.057222,1.49642,-1.96213,-0.052676,1.46861,-2.01268,0.133502,1.39954,-2.08663,0.191526,1.12797,-1.7644,0.068428,1.07109,-1.794,0.104737,0.995039,-1.8152,0.215989,0.915038,-1.80031,0.277699,0.733288,-1.79624,0.294951,0.660676,-1.81114,0.168749,0.707798,-1.81623,0.186502,0.638281,-1.82514,0.286811,0.426597,-1.84554,0.212265,0.351004,-1.93343,0.450342,0.434848,-1.88059,0.440532,0.363802,-1.82172,0.07304,1.08178,-2.12346,0.070769,0.998321,-2.10562,-0.066852,1.08706,-2.08968,-0.067256,1.00604,-2.07345,-0.04671,0.874414,-2.07798,-0.216256,0.803586,-2.07054,-0.224841,0.91666,-2.08316,-0.293992,0.906813,-2.07662,-0.518872,0.858763,-2.05435,-0.549611,0.956287,-1.99332,-0.637154,0.687067,-1.99865,-0.675266,0.746328,-2.05661,0.046301,1.32643,-1.83916,0.046488,1.31664,-2.05417},
/*135*/{0.12065,1.86667,-1.72762,0.208836,1.82166,-1.86904,-0.023669,1.75285,-1.66146,-0.134028,1.66646,-1.6305,0.00332,1.57786,-1.63586,0.073655,1.52076,-1.62458,0.164119,1.89355,-2.11934,0.221175,1.82644,-1.94213,0.024195,1.86255,-2.05066,0.02527,1.67767,-2.2264,0.076397,1.58419,-2.25832,0.229109,1.53368,-2.13785,0.286302,1.49895,-2.13085,0.120209,1.41227,-1.8325,-0.063179,1.46624,-1.8978,-0.058018,1.49177,-1.96182,-0.052759,1.46326,-2.01304,0.134142,1.39576,-2.08667,0.189598,1.12336,-1.76393,0.066584,1.06528,-1.79387,0.103484,0.990759,-1.81505,0.211799,0.910231,-1.80057,0.269429,0.726253,-1.79746,0.285618,0.653789,-1.8124,0.160687,0.702915,-1.81711,0.17658,0.6342,-1.82661,0.273601,0.422794,-1.8479,0.193518,0.354056,-1.93457,0.436983,0.421145,-1.88308,0.42344,0.350393,-1.82374,0.079386,1.07758,-2.12391,0.077762,0.994653,-2.10683,-0.061149,1.07987,-2.08965,-0.060014,0.99908,-2.07291,-0.035688,0.86894,-2.07825,-0.20624,0.802822,-2.07147,-0.212358,0.915817,-2.08342,-0.281897,0.907269,-2.07586,-0.508024,0.866435,-2.05423,-0.538362,0.963308,-1.99321,-0.628591,0.694259,-2.00206,-0.665032,0.754808,-2.05807,0.047084,1.32237,-1.83859,0.047556,1.31227,-2.05359},
/*136*/{0.121615,1.86103,-1.72689,0.209032,1.81693,-1.86949,-0.019969,1.74437,-1.65812,-0.129343,1.65573,-1.62492,0.010189,1.5704,-1.6323,0.08155,1.5153,-1.62195,0.164134,1.88882,-2.12007,0.221194,1.82209,-1.94279,0.023714,1.85719,-2.04975,0.021042,1.67406,-2.22547,0.070481,1.57948,-2.25849,0.224831,1.52372,-2.14138,0.28098,1.48644,-2.13496,0.119808,1.40896,-1.83147,-0.064285,1.46207,-1.89898,-0.058049,1.48678,-1.96155,-0.053756,1.4584,-2.01408,0.134298,1.39216,-2.08561,0.187912,1.11861,-1.76352,0.065721,1.06316,-1.79423,0.100535,0.987022,-1.81476,0.206368,0.904505,-1.80031,0.261738,0.720655,-1.79779,0.27582,0.647165,-1.81342,0.152304,0.69922,-1.81773,0.166818,0.629272,-1.82856,0.259633,0.418322,-1.85037,0.173292,0.353999,-1.93538,0.421269,0.407565,-1.8854,0.404654,0.339736,-1.82748,0.0854,1.07345,-2.12468,0.085551,0.989732,-2.10725,-0.054879,1.07355,-2.08885,-0.051701,0.992028,-2.07295,-0.025892,0.863332,-2.0793,-0.196217,0.801849,-2.07314,-0.198569,0.914631,-2.08337,-0.270375,0.908386,-2.07616,-0.494629,0.872904,-2.05411,-0.525392,0.969537,-1.99344,-0.618056,0.701283,-2.00353,-0.653104,0.76221,-2.06104,0.046811,1.31875,-1.83804,0.048392,1.308,-2.053},
/*137*/{0.123299,1.8556,-1.72579,0.210612,1.80994,-1.86904,-0.015582,1.73537,-1.65456,-0.121942,1.6465,-1.61956,0.017164,1.56319,-1.62912,0.090286,1.50938,-1.62007,0.163051,1.88456,-2.12044,0.221279,1.81699,-1.94343,0.022232,1.8524,-2.04786,0.016712,1.66969,-2.22512,0.065103,1.57576,-2.2587,0.219411,1.51228,-2.14472,0.274594,1.47382,-2.13916,0.118659,1.40474,-1.8298,-0.065667,1.45705,-1.89953,-0.059072,1.48176,-1.96139,-0.054754,1.45237,-2.0145,0.133619,1.38685,-2.08527,0.184902,1.11399,-1.76362,0.063851,1.05841,-1.79332,0.097809,0.982189,-1.81469,0.199609,0.898497,-1.80001,0.254696,0.714536,-1.7997,0.26659,0.640619,-1.81568,0.143745,0.696773,-1.81902,0.156419,0.62627,-1.82815,0.241284,0.415,-1.85311,0.152644,0.355147,-1.9345,0.405857,0.398994,-1.89103,0.385872,0.336332,-1.82738,0.09053,1.06943,-2.12567,0.093588,0.985593,-2.10797,-0.048851,1.0662,-2.08882,-0.044167,0.985563,-2.07266,-0.015029,0.857893,-2.08019,-0.18521,0.801104,-2.07358,-0.185046,0.913039,-2.08386,-0.255502,0.908771,-2.07645,-0.483108,0.877728,-2.05453,-0.512178,0.97394,-1.99125,-0.605347,0.707876,-2.0058,-0.643184,0.769584,-2.06315,0.045731,1.31436,-1.83704,0.048067,1.30248,-2.05193},
/*138*/{0.124449,1.8498,-1.72497,0.211694,1.80475,-1.86902,-0.011917,1.72579,-1.65181,-0.116782,1.63616,-1.61407,0.024872,1.55591,-1.62555,0.099217,1.50451,-1.61686,0.162122,1.88002,-2.12111,0.222076,1.81152,-1.94376,0.021843,1.84821,-2.04671,0.01327,1.66547,-2.22483,0.059188,1.57136,-2.25892,0.213403,1.50155,-2.14836,0.268125,1.46083,-2.14309,0.117674,1.40044,-1.82803,-0.067931,1.45268,-1.90035,-0.061291,1.47704,-1.96222,-0.055455,1.44774,-2.01496,0.134402,1.383,-2.08356,0.181926,1.10931,-1.76158,0.059062,1.05525,-1.79382,0.09515,0.97893,-1.81653,0.19409,0.891919,-1.7999,0.247195,0.709704,-1.8019,0.256728,0.636207,-1.81783,0.136374,0.695927,-1.81898,0.146755,0.625747,-1.82953,0.225451,0.414456,-1.85715,0.130257,0.355136,-1.93446,0.386758,0.395553,-1.89715,0.364148,0.339665,-1.82987,0.096255,1.06589,-2.12613,0.101106,0.981902,-2.10864,-0.043126,1.05926,-2.08814,-0.036129,0.97837,-2.07178,-0.003148,0.852104,-2.08112,-0.173421,0.799152,-2.07484,-0.172248,0.913286,-2.0834,-0.242005,0.908075,-2.07668,-0.468965,0.88262,-2.05457,-0.499734,0.978127,-1.99147,-0.592988,0.710797,-2.00826,-0.627565,0.772585,-2.06533,0.044061,1.31018,-1.83641,0.048668,1.29827,-2.05127},
/*139*/{0.125715,1.84515,-1.72443,0.211395,1.80011,-1.87011,-0.006106,1.71676,-1.64802,-0.10903,1.62678,-1.60848,0.03325,1.54906,-1.62213,0.108801,1.49903,-1.61471,0.16096,1.87604,-2.12167,0.22243,1.80606,-1.94509,0.020941,1.84385,-2.04508,0.008191,1.66154,-2.22428,0.053981,1.56745,-2.25911,0.207751,1.48977,-2.15196,0.260885,1.44859,-2.14779,0.115965,1.39679,-1.82756,-0.070312,1.44845,-1.90056,-0.063042,1.47099,-1.9627,-0.057861,1.44207,-2.01594,0.133664,1.37909,-2.08381,0.177229,1.10608,-1.75843,0.054793,1.05194,-1.79424,0.091154,0.977681,-1.81671,0.186934,0.884723,-1.80065,0.242084,0.709387,-1.80357,0.248388,0.635204,-1.82063,0.130308,0.698749,-1.81962,0.138049,0.628325,-1.83032,0.205754,0.418699,-1.85906,0.109018,0.355884,-1.93625,0.363881,0.392403,-1.90166,0.341472,0.340156,-1.83129,0.102482,1.06222,-2.12648,0.109412,0.978322,-2.10917,-0.036826,1.05236,-2.08866,-0.027727,0.971833,-2.07192,0.008565,0.843667,-2.08133,-0.161214,0.797556,-2.07596,-0.157957,0.911828,-2.08531,-0.226981,0.908089,-2.07654,-0.455713,0.88578,-2.05563,-0.486977,0.981332,-1.99126,-0.580387,0.714113,-2.0106,-0.611824,0.775641,-2.06786,0.04302,1.30614,-1.83624,0.048236,1.29357,-2.05105},
/*140*/{0.12706,1.84055,-1.72327,0.212156,1.79334,-1.86941,-0.000368,1.70822,-1.64507,-0.101048,1.61597,-1.6022,0.042028,1.54264,-1.61976,0.117815,1.49527,-1.61342,0.160417,1.87218,-2.12216,0.223819,1.80074,-1.94563,0.02038,1.84118,-2.04303,0.005186,1.65859,-2.22413,0.047865,1.56359,-2.25912,0.201758,1.47969,-2.15616,0.251363,1.43785,-2.15298,0.113481,1.39354,-1.82723,-0.073907,1.44508,-1.90244,-0.065189,1.46605,-1.96419,-0.059653,1.43708,-2.01746,0.132794,1.37525,-2.08259,0.173257,1.10393,-1.75425,0.050485,1.05374,-1.79426,0.08711,0.977588,-1.81821,0.182414,0.882371,-1.80132,0.236668,0.709908,-1.80436,0.240511,0.635788,-1.82155,0.124761,0.704912,-1.81857,0.129116,0.634973,-1.83113,0.184695,0.421363,-1.86146,0.086231,0.357433,-1.93672,0.342248,0.392073,-1.90309,0.319347,0.338916,-1.8308,0.107523,1.05965,-2.12667,0.117359,0.975634,-2.10977,-0.030858,1.04532,-2.08837,-0.019048,0.965025,-2.07206,0.019786,0.841432,-2.08431,-0.148039,0.795767,-2.07658,-0.143417,0.910588,-2.08578,-0.213768,0.906671,-2.07717,-0.443265,0.891528,-2.05526,-0.4724,0.982752,-1.99014,-0.564457,0.715855,-2.0134,-0.597324,0.7771,-2.07024,0.040359,1.30287,-1.83599,0.047626,1.28921,-2.05067},
/*141*/{0.1287,1.83642,-1.72265,0.213585,1.78888,-1.86985,0.005052,1.69974,-1.64217,-0.091098,1.60722,-1.59692,0.052814,1.53748,-1.6161,0.128333,1.4915,-1.61131,0.159143,1.8689,-2.12372,0.224913,1.79626,-1.94678,0.019466,1.83877,-2.04049,0.001791,1.65565,-2.22445,0.04193,1.56056,-2.25872,0.194232,1.47043,-2.16038,0.242748,1.42676,-2.15748,0.109927,1.39069,-1.82508,-0.077468,1.44212,-1.90292,-0.068734,1.462,-1.96571,-0.062395,1.43257,-2.01871,0.13238,1.37101,-2.08002,0.171766,1.10437,-1.75107,0.049835,1.05483,-1.79676,0.085722,0.978641,-1.81931,0.183381,0.886729,-1.80021,0.232025,0.710012,-1.80622,0.23271,0.635509,-1.82238,0.120272,0.710569,-1.81814,0.121017,0.639049,-1.83032,0.164514,0.42256,-1.86192,0.064812,0.358881,-1.93787,0.320276,0.390069,-1.9032,0.296971,0.338935,-1.83191,0.112938,1.05776,-2.12668,0.124934,0.974239,-2.10976,-0.02481,1.03881,-2.08841,-0.011367,0.959006,-2.0723,0.031633,0.836623,-2.08414,-0.134903,0.795219,-2.07666,-0.12767,0.908233,-2.08593,-0.198283,0.905602,-2.07735,-0.421456,0.886908,-2.05336,-0.459672,0.983947,-1.99101,-0.548993,0.715438,-2.01527,-0.580866,0.777695,-2.07279,0.036372,1.30021,-1.83436,0.046515,1.28491,-2.04881},
/*142*/{0.129625,1.83396,-1.72191,0.213229,1.7856,-1.8706,0.011633,1.69282,-1.63993,-0.082956,1.59807,-1.59172,0.061669,1.53283,-1.61447,0.139024,1.48804,-1.60923,0.159051,1.86628,-2.12491,0.225254,1.79357,-1.94845,0.019489,1.83759,-2.03864,-0.000894,1.65349,-2.22427,0.036029,1.55808,-2.25811,0.186303,1.46168,-2.163,0.233715,1.41712,-2.16179,0.107147,1.38804,-1.82377,-0.080646,1.43865,-1.90674,-0.071186,1.45865,-1.96696,-0.065514,1.42755,-2.01992,0.130939,1.36685,-2.07847,0.167521,1.10434,-1.74981,0.049367,1.05458,-1.79732,0.084231,0.978826,-1.81838,0.186806,0.893701,-1.7989,0.226012,0.709184,-1.80671,0.219869,0.635247,-1.82484,0.113376,0.714629,-1.81645,0.110381,0.643322,-1.82836,0.144439,0.421882,-1.86128,0.043371,0.359819,-1.93829,0.30039,0.389292,-1.90246,0.2763,0.338523,-1.83024,0.118798,1.05743,-2.12634,0.133035,0.974396,-2.11013,-0.019087,1.03441,-2.08894,-0.00248,0.954778,-2.07347,0.044137,0.831393,-2.08298,-0.119601,0.792647,-2.07638,-0.112492,0.903584,-2.08665,-0.182851,0.903695,-2.07779,-0.410759,0.890133,-2.05774,-0.445985,0.984617,-1.99279,-0.531307,0.714719,-2.01839,-0.564678,0.775959,-2.07468,0.032891,1.29772,-1.83366,0.045219,1.28048,-2.04785},
/*143*/{0.13055,1.83116,-1.72191,0.213701,1.78244,-1.87236,0.018144,1.68773,-1.6385,-0.073375,1.59062,-1.58704,0.072751,1.52895,-1.61186,0.151015,1.48641,-1.60827,0.159787,1.86427,-2.1255,0.22543,1.78979,-1.95033,0.02018,1.83684,-2.03651,-0.00347,1.65319,-2.22288,0.030713,1.55675,-2.25729,0.178542,1.45555,-2.1652,0.224178,1.40779,-2.1662,0.104143,1.38653,-1.82137,-0.082742,1.43653,-1.90912,-0.073376,1.45709,-1.96746,-0.067119,1.42387,-2.0224,0.129311,1.36414,-2.07704,0.165077,1.1056,-1.74896,0.046566,1.05102,-1.79556,0.084789,0.977885,-1.81877,0.19291,0.899578,-1.79773,0.218318,0.709087,-1.80718,0.207581,0.634726,-1.82483,0.105077,0.716963,-1.81465,0.099214,0.646712,-1.82696,0.127021,0.424857,-1.86246,0.022197,0.360665,-1.93795,0.279093,0.387966,-1.90149,0.255422,0.337874,-1.82974,0.123835,1.05876,-2.12555,0.141733,0.976463,-2.10951,-0.013494,1.03085,-2.08962,0.005934,0.951072,-2.07326,0.058565,0.830117,-2.08248,-0.104898,0.790986,-2.07543,-0.097215,0.902246,-2.08678,-0.167279,0.901397,-2.07846,-0.396443,0.887874,-2.05762,-0.433509,0.982872,-1.99398,-0.513715,0.711533,-2.01984,-0.547711,0.772922,-2.07706,0.02944,1.29632,-1.8328,0.044166,1.27754,-2.04671},
/*144*/{0.131738,1.82868,-1.72208,0.214139,1.78066,-1.87364,0.024571,1.68278,-1.63713,-0.061382,1.58433,-1.58295,0.084814,1.5269,-1.61198,0.162493,1.48493,-1.60764,0.160499,1.86224,-2.12554,0.225433,1.78713,-1.95133,0.020778,1.83669,-2.03651,-0.007374,1.65386,-2.22098,0.024642,1.55731,-2.25637,0.169772,1.45023,-2.16765,0.21408,1.40111,-2.17094,0.101176,1.38704,-1.81823,-0.085112,1.43544,-1.91052,-0.074634,1.45578,-1.96817,-0.070856,1.41828,-2.02458,0.128558,1.36126,-2.07632,0.163127,1.1056,-1.74965,0.0441,1.04869,-1.79593,0.082178,0.976257,-1.81869,0.198578,0.901279,-1.7999,0.207096,0.708,-1.80561,0.199898,0.634218,-1.82233,0.094556,0.719603,-1.81338,0.088658,0.649144,-1.82438,0.107419,0.424182,-1.86217,0.001257,0.36145,-1.93775,0.258833,0.387344,-1.90168,0.233799,0.337281,-1.82951,0.129753,1.06044,-2.12535,0.149995,0.979024,-2.10896,-0.007075,1.02776,-2.09106,0.015148,0.949142,-2.07533,0.073614,0.829362,-2.08187,-0.089091,0.789138,-2.07446,-0.082124,0.900135,-2.08773,-0.151291,0.900275,-2.07892,-0.380883,0.886554,-2.05936,-0.419634,0.978968,-1.99532,-0.495159,0.70688,-2.02271,-0.529358,0.768137,-2.07942,0.026881,1.29669,-1.83061,0.043369,1.27418,-2.04403},
/*145*/{0.133216,1.82681,-1.72254,0.214008,1.77928,-1.87432,0.029442,1.68018,-1.63619,-0.05151,1.57954,-1.57908,0.095621,1.52404,-1.6099,0.17495,1.4855,-1.60636,0.160887,1.86057,-2.12544,0.225396,1.78512,-1.9517,0.021446,1.83689,-2.03703,-0.011545,1.65592,-2.21872,0.017694,1.55902,-2.2558,0.160573,1.4456,-2.17019,0.204533,1.39495,-2.17525,0.098202,1.38621,-1.81535,-0.08768,1.43499,-1.91311,-0.07645,1.45603,-1.96926,-0.073255,1.41729,-2.02613,0.127114,1.35998,-2.0752,0.159355,1.10436,-1.7486,0.039311,1.04907,-1.79595,0.078239,0.975196,-1.8176,0.198857,0.89941,-1.80047,0.195561,0.705793,-1.80425,0.184491,0.631699,-1.82142,0.084018,0.720962,-1.81275,0.075325,0.650922,-1.8233,0.086866,0.423847,-1.86173,-0.019634,0.36219,-1.93767,0.238141,0.386177,-1.90154,0.212663,0.336661,-1.82901,0.13673,1.06346,-2.12482,0.159826,0.981532,-2.10808,0.001038,1.02572,-2.09184,0.024973,0.948001,-2.07668,0.08942,0.831106,-2.08029,-0.073928,0.788042,-2.07346,-0.066639,0.89777,-2.08835,-0.135904,0.897746,-2.07931,-0.366223,0.882958,-2.05918,-0.408796,0.976481,-1.99834,-0.475119,0.701937,-2.02338,-0.511418,0.760874,-2.0812,0.022702,1.29635,-1.83017,0.041626,1.27309,-2.04331},
/*146*/{0.134979,1.82568,-1.72348,0.212845,1.77772,-1.87481,0.036344,1.67846,-1.6351,-0.042001,1.57539,-1.5761,0.107484,1.52339,-1.60977,0.188096,1.48687,-1.60692,0.162383,1.85869,-2.12532,0.224488,1.78381,-1.95223,0.022253,1.83665,-2.03845,-0.016031,1.65886,-2.21606,0.011203,1.56142,-2.25517,0.151789,1.4437,-2.17291,0.194046,1.39104,-2.17916,0.095033,1.38576,-1.81317,-0.088347,1.43368,-1.91381,-0.077183,1.45551,-1.96943,-0.073962,1.41646,-2.02706,0.124859,1.35855,-2.07398,0.152696,1.10163,-1.74835,0.035108,1.04779,-1.79541,0.072213,0.973315,-1.81675,0.193654,0.895493,-1.79985,0.183315,0.702663,-1.80228,0.171929,0.629459,-1.81897,0.071794,0.719992,-1.81269,0.06124,0.650433,-1.82369,0.065526,0.425885,-1.8625,-0.041043,0.362427,-1.93704,0.216892,0.386093,-1.90013,0.190996,0.336318,-1.82871,0.145002,1.06624,-2.12432,0.169728,0.98519,-2.10789,0.009021,1.02597,-2.09436,0.035606,0.946557,-2.07795,0.106592,0.833394,-2.0796,-0.056538,0.784085,-2.07155,-0.0504,0.895961,-2.08922,-0.120148,0.895294,-2.0808,-0.346832,0.877313,-2.05913,-0.39819,0.97168,-2.00034,-0.455658,0.694445,-2.02456,-0.490601,0.751689,-2.08375,0.019769,1.29574,-1.82933,0.040235,1.27177,-2.04224},
/*147*/{0.137003,1.82525,-1.72406,0.213646,1.77337,-1.87587,0.040796,1.67687,-1.63412,-0.031332,1.57265,-1.57342,0.119281,1.52372,-1.6089,0.199999,1.48934,-1.60745,0.162723,1.85758,-2.12553,0.224618,1.78201,-1.95191,0.022074,1.83678,-2.03918,-0.020519,1.66295,-2.2132,0.003699,1.56506,-2.25484,0.143549,1.44215,-2.17588,0.184014,1.38795,-2.18276,0.092756,1.38663,-1.81063,-0.089794,1.43348,-1.91418,-0.078774,1.4561,-1.96976,-0.075788,1.41761,-2.02825,0.123364,1.35847,-2.0733,0.150447,1.09994,-1.74756,0.029571,1.04632,-1.79613,0.066798,0.971453,-1.81834,0.185029,0.891525,-1.7982,0.169784,0.699288,-1.80187,0.156212,0.625496,-1.81859,0.058463,0.720148,-1.81206,0.045857,0.649494,-1.82638,0.045545,0.424287,-1.86007,-0.061981,0.363135,-1.93668,0.195864,0.385456,-1.90021,0.169519,0.335594,-1.82774,0.152919,1.07008,-2.12454,0.18059,0.989936,-2.10737,0.018048,1.02509,-2.09582,0.047456,0.946623,-2.07919,0.123236,0.836213,-2.07822,-0.039993,0.781791,-2.06939,-0.036027,0.894464,-2.09015,-0.104724,0.893163,-2.08248,-0.335925,0.873971,-2.06159,-0.387081,0.963967,-2.00148,-0.434632,0.686239,-2.0253,-0.470754,0.741717,-2.0858,0.017064,1.2964,-1.82872,0.038853,1.27204,-2.04146},
/*148*/{0.138325,1.82561,-1.7246,0.213637,1.77325,-1.87613,0.04667,1.67634,-1.63363,-0.020729,1.57021,-1.57067,0.129806,1.52511,-1.60868,0.212907,1.49274,-1.60884,0.163579,1.857,-2.12541,0.224322,1.78198,-1.9523,0.022217,1.83673,-2.03969,-0.025937,1.6675,-2.21045,-0.002714,1.56942,-2.25481,0.134474,1.44162,-2.1788,0.173473,1.38699,-2.1858,0.090624,1.38677,-1.809,-0.091548,1.43341,-1.9143,-0.079971,1.4559,-1.96926,-0.075438,1.42188,-2.0276,0.121951,1.35922,-2.07265,0.142093,1.09456,-1.74706,0.022161,1.0435,-1.79648,0.05989,0.96878,-1.81776,0.173134,0.887104,-1.79736,0.155186,0.694946,-1.80068,0.139165,0.622534,-1.8183,0.044969,0.71877,-1.81141,0.031241,0.64959,-1.82413,0.026363,0.425581,-1.86079,-0.083161,0.363192,-1.93613,0.175143,0.385156,-1.89949,0.148522,0.335587,-1.82767,0.161446,1.0743,-2.12423,0.191139,0.995712,-2.10638,0.028457,1.02429,-2.09628,0.060344,0.947081,-2.07967,0.139581,0.840189,-2.07746,-0.023391,0.781939,-2.06828,-0.021434,0.89355,-2.09035,-0.090327,0.891437,-2.08302,-0.316334,0.864671,-2.05956,-0.376997,0.957216,-2.00363,-0.412037,0.677165,-2.02639,-0.449236,0.731071,-2.08774,0.01455,1.29621,-1.82886,0.037614,1.27352,-2.04165},
/*149*/{0.139592,1.82575,-1.72522,0.213663,1.77289,-1.87641,0.051034,1.67672,-1.6321,-0.012056,1.56889,-1.56835,0.141183,1.52802,-1.60814,0.225771,1.49836,-1.6104,0.16394,1.85686,-2.12548,0.223421,1.78051,-1.9522,0.021873,1.83753,-2.04091,-0.029869,1.67386,-2.20826,-0.010899,1.57432,-2.25496,0.126071,1.44226,-2.18167,0.163116,1.3874,-2.18935,0.088345,1.38853,-1.8071,-0.092918,1.43312,-1.91445,-0.081012,1.45673,-1.96813,-0.075338,1.42147,-2.02654,0.120691,1.3607,-2.07251,0.13666,1.09123,-1.74758,0.015413,1.04306,-1.79665,0.048279,0.967487,-1.81763,0.160309,0.881775,-1.79636,0.139887,0.690429,-1.80107,0.122648,0.618657,-1.81788,0.030903,0.717781,-1.81203,0.014572,0.647607,-1.82424,0.006826,0.425515,-1.85879,-0.103851,0.363749,-1.93578,0.154235,0.384657,-1.8989,0.127615,0.335396,-1.82648,0.170311,1.07949,-2.12341,0.202907,1.00171,-2.10621,0.038854,1.02497,-2.09851,0.072741,0.949128,-2.08107,0.155697,0.843982,-2.07762,-0.007175,0.781655,-2.06758,-0.006724,0.89354,-2.09039,-0.076296,0.89128,-2.08351,-0.305778,0.861903,-2.06317,-0.367319,0.94918,-2.00535,-0.387796,0.667076,-2.0259,-0.427792,0.718843,-2.08994,0.013648,1.29713,-1.82787,0.037538,1.2744,-2.04057},
/*150*/{0.14035,1.82719,-1.72569,0.212421,1.77425,-1.87705,0.054903,1.67758,-1.63143,-0.00093,1.5678,-1.56571,0.151639,1.5309,-1.60886,0.237743,1.50402,-1.61244,0.163927,1.85712,-2.12573,0.222524,1.78043,-1.95279,0.0223,1.83914,-2.04123,-0.035548,1.67978,-2.20592,-0.018085,1.58012,-2.25522,0.117743,1.44485,-2.18416,0.153357,1.38984,-2.19183,0.087005,1.38931,-1.80607,-0.093647,1.43343,-1.91445,-0.081153,1.45699,-1.96784,-0.076634,1.42234,-2.02535,0.119137,1.36272,-2.07194,0.129161,1.08677,-1.7482,0.007896,1.04506,-1.79681,0.039958,0.966422,-1.81762,0.147705,0.876795,-1.79621,0.125683,0.68647,-1.80124,0.106737,0.61499,-1.81844,0.016001,0.71558,-1.81318,-0.001874,0.645966,-1.82625,-0.013976,0.425553,-1.85916,-0.124317,0.364374,-1.93577,0.133766,0.384305,-1.89813,0.106776,0.335364,-1.82682,0.178656,1.08559,-2.12339,0.214301,1.00915,-2.10564,0.049515,1.0262,-2.09874,0.086969,0.950519,-2.08063,0.171571,0.849174,-2.0782,0.009428,0.781901,-2.06771,0.007683,0.894514,-2.09112,-0.061865,0.889943,-2.08403,-0.290978,0.854679,-2.06373,-0.357728,0.938642,-2.0081,-0.36431,0.656278,-2.0265,-0.405298,0.705887,-2.09142,0.012905,1.29766,-1.82759,0.037061,1.27565,-2.04033},
/*151*/{0.141093,1.82929,-1.72691,0.211285,1.77468,-1.87791,0.059611,1.6793,-1.63039,0.008194,1.5668,-1.56336,0.162202,1.53512,-1.60923,0.24906,1.51078,-1.61446,0.16372,1.85765,-2.12611,0.221387,1.7808,-1.95364,0.021224,1.84054,-2.04159,-0.039608,1.68683,-2.20406,-0.025606,1.58565,-2.25572,0.109595,1.44996,-2.18651,0.142803,1.39291,-2.19383,0.085026,1.38934,-1.80464,-0.094714,1.43355,-1.91349,-0.081566,1.45722,-1.96696,-0.078624,1.42381,-2.02387,0.119445,1.36657,-2.0713,0.123603,1.08454,-1.74802,0.000149,1.04469,-1.7964,0.029724,0.966512,-1.81832,0.133333,0.871219,-1.79609,0.110436,0.683095,-1.80146,0.08876,0.611036,-1.81912,0.001672,0.71336,-1.814,-0.017246,0.644913,-1.82633,-0.033243,0.425971,-1.85883,-0.145727,0.365992,-1.93596,0.113252,0.384455,-1.89884,0.086747,0.335378,-1.82639,0.187353,1.09208,-2.12276,0.224856,1.01732,-2.10499,0.059352,1.02846,-2.0994,0.098001,0.957456,-2.08342,0.186312,0.853512,-2.07845,0.025827,0.782918,-2.06747,0.022028,0.895928,-2.09099,-0.048133,0.888838,-2.08436,-0.272954,0.845522,-2.06323,-0.349323,0.928517,-2.01113,-0.340052,0.645415,-2.02677,-0.382306,0.693536,-2.09321,0.012305,1.29733,-1.82791,0.037587,1.27828,-2.0408},
/*152*/{0.142377,1.83209,-1.72697,0.210519,1.77615,-1.87851,0.064068,1.68094,-1.63023,0.018201,1.56732,-1.56159,0.172286,1.54007,-1.61019,0.259896,1.5188,-1.61704,0.162238,1.85874,-2.1263,0.221298,1.78246,-1.95422,0.020974,1.84315,-2.04116,-0.044998,1.69321,-2.20264,-0.032997,1.59268,-2.25613,0.101362,1.45388,-2.18802,0.133802,1.39695,-2.19562,0.084637,1.3908,-1.80423,-0.094841,1.4349,-1.91361,-0.083149,1.45834,-1.9663,-0.079794,1.4248,-2.02323,0.11929,1.36937,-2.07115,0.116632,1.08272,-1.74815,-0.005143,1.04612,-1.79646,0.021449,0.966419,-1.81875,0.118508,0.866153,-1.7961,0.094439,0.679659,-1.80197,0.072427,0.608934,-1.82096,-0.013881,0.71163,-1.81539,-0.033356,0.64308,-1.82726,-0.053304,0.425694,-1.85902,-0.165798,0.366096,-1.93563,0.092868,0.383928,-1.89835,0.065904,0.335621,-1.8261,0.194213,1.09965,-2.12322,0.234878,1.02575,-2.10487,0.069444,1.03104,-2.09988,0.110071,0.96219,-2.084,0.200454,0.859289,-2.07885,0.043093,0.785024,-2.0685,0.035754,0.897469,-2.09131,-0.034175,0.888693,-2.08563,-0.261463,0.839118,-2.06577,-0.340436,0.916441,-2.01113,-0.314089,0.635222,-2.02896,-0.358184,0.679887,-2.09502,0.012431,1.29866,-1.8279,0.037717,1.28036,-2.04086},
/*153*/{0.144299,1.83487,-1.72801,0.211571,1.77783,-1.87959,0.069105,1.68322,-1.6299,0.026871,1.56856,-1.56007,0.182129,1.54604,-1.61158,0.27011,1.52688,-1.62105,0.160269,1.86109,-2.12727,0.220339,1.78359,-1.95571,0.020419,1.84609,-2.04072,-0.049648,1.7002,-2.20144,-0.040517,1.59945,-2.25653,0.093006,1.45985,-2.18901,0.124738,1.40241,-2.19681,0.083239,1.39031,-1.80255,-0.094952,1.43524,-1.91318,-0.083039,1.45989,-1.96595,-0.081139,1.42612,-2.02319,0.118186,1.37214,-2.07098,0.108784,1.08213,-1.74965,-0.014173,1.0474,-1.7958,0.010025,0.966621,-1.8178,0.103009,0.861867,-1.79608,0.077651,0.678121,-1.80309,0.057163,0.606944,-1.82088,-0.029175,0.711284,-1.81428,-0.049746,0.64338,-1.82842,-0.073799,0.427169,-1.85972,-0.186439,0.366849,-1.93622,0.071885,0.383947,-1.8989,0.044463,0.335458,-1.8254,0.202003,1.10729,-2.12223,0.243874,1.03503,-2.10441,0.078357,1.03571,-2.10095,0.120967,0.967104,-2.08447,0.215241,0.865731,-2.07888,0.05956,0.787622,-2.0692,0.048335,0.900429,-2.09031,-0.020681,0.888829,-2.08647,-0.247476,0.830144,-2.06635,-0.33076,0.903398,-2.01223,-0.288477,0.623421,-2.02964,-0.334413,0.666609,-2.09689,0.011314,1.29844,-1.82852,0.037254,1.28237,-2.04159},
/*154*/{0.146131,1.83809,-1.72852,0.21182,1.78083,-1.88051,0.074492,1.68596,-1.62946,0.037518,1.57087,-1.5591,0.190902,1.55187,-1.61324,0.279501,1.53583,-1.62491,0.158748,1.86328,-2.12747,0.219854,1.78572,-1.95645,0.019567,1.84748,-2.03993,-0.054906,1.70712,-2.20066,-0.046942,1.6069,-2.25664,0.08522,1.46638,-2.19016,0.116002,1.40865,-2.19785,0.082991,1.39083,-1.80203,-0.095771,1.43816,-1.91309,-0.083108,1.46149,-1.96522,-0.081691,1.42803,-2.02273,0.117834,1.37481,-2.07079,0.103768,1.08177,-1.75069,-0.022772,1.04948,-1.79633,4.1e-005,0.967098,-1.81779,0.086662,0.859366,-1.79716,0.062415,0.676845,-1.80415,0.040147,0.606466,-1.82138,-0.044698,0.711036,-1.81534,-0.064988,0.644208,-1.82826,-0.094167,0.426568,-1.85911,-0.206273,0.367673,-1.93635,0.052106,0.383115,-1.89867,0.024496,0.33552,-1.82569,0.208409,1.11612,-2.12124,0.252753,1.04483,-2.10422,0.086794,1.03972,-2.10124,0.131635,0.9733,-2.08442,0.229253,0.873797,-2.07859,0.076236,0.790208,-2.07006,0.06065,0.902374,-2.09067,-0.00792,0.887929,-2.08588,-0.232084,0.820722,-2.06769,-0.319933,0.888957,-2.01272,-0.262985,0.611931,-2.03144,-0.310945,0.652462,-2.0984,0.010624,1.29963,-1.82876,0.036671,1.28469,-2.04189},
/*155*/{0.148654,1.84175,-1.72968,0.212552,1.78335,-1.88182,0.080158,1.68914,-1.62898,0.045215,1.57229,-1.55758,0.199265,1.55817,-1.61466,0.287799,1.54491,-1.62862,0.156587,1.86602,-2.12853,0.219845,1.78893,-1.95803,0.0178,1.8506,-2.03975,-0.060751,1.71402,-2.20046,-0.05428,1.61385,-2.25747,0.077291,1.47321,-2.19151,0.107887,1.41516,-2.19843,0.082949,1.39111,-1.80189,-0.095677,1.43989,-1.91166,-0.083597,1.4633,-1.96479,-0.081173,1.42947,-2.02202,0.116993,1.37671,-2.07074,0.09733,1.07837,-1.75041,-0.030778,1.05118,-1.79604,-0.007608,0.968556,-1.81636,0.069032,0.858198,-1.79929,0.046851,0.676183,-1.80493,0.023628,0.606036,-1.82326,-0.05983,0.712217,-1.81595,-0.080785,0.644842,-1.82819,-0.114261,0.427378,-1.85938,-0.226599,0.368524,-1.93642,0.032077,0.38358,-1.89879,0.004203,0.335609,-1.82552,0.214219,1.12477,-2.12116,0.260231,1.05468,-2.10369,0.094523,1.04533,-2.10102,0.141884,0.979674,-2.08417,0.242638,0.883274,-2.07876,0.092108,0.79354,-2.07144,0.072363,0.904939,-2.09122,0.003905,0.888904,-2.08803,-0.218015,0.810062,-2.06734,-0.309299,0.873287,-2.01289,-0.236491,0.600424,-2.03379,-0.286523,0.638529,-2.10011,0.010419,1.30038,-1.82885,0.036001,1.28643,-2.0421},
/*156*/{0.151406,1.84564,-1.73021,0.213086,1.78642,-1.88322,0.086463,1.69245,-1.6284,0.054007,1.5761,-1.5574,0.207284,1.56572,-1.61698,0.295743,1.55471,-1.63248,0.153208,1.86962,-2.12884,0.218968,1.79167,-1.95903,0.016665,1.85316,-2.0386,-0.067005,1.72104,-2.20009,-0.060825,1.62103,-2.25764,0.06921,1.48037,-2.19224,0.100215,1.42254,-2.19915,0.08506,1.3916,-1.80265,-0.095068,1.44232,-1.91091,-0.083128,1.46597,-1.9627,-0.080848,1.43192,-2.02181,0.117153,1.37996,-2.07064,0.089732,1.07806,-1.75249,-0.040249,1.05229,-1.79624,-0.020537,0.970986,-1.81826,0.053168,0.85778,-1.79995,0.030666,0.675641,-1.80672,0.004671,0.60548,-1.82366,-0.075166,0.713397,-1.81691,-0.098864,0.645995,-1.82914,-0.134549,0.431214,-1.85977,-0.246748,0.369957,-1.93619,0.011153,0.383548,-1.89898,-0.01626,0.335541,-1.82579,0.219259,1.13346,-2.12113,0.267412,1.0651,-2.10394,0.10228,1.05056,-2.10106,0.150605,0.986421,-2.08372,0.255708,0.894014,-2.07875,0.107867,0.797102,-2.07247,0.082883,0.907559,-2.0921,0.016165,0.889138,-2.08826,-0.202654,0.799845,-2.06875,-0.298444,0.856993,-2.01226,-0.208699,0.589393,-2.03672,-0.262102,0.62536,-2.10205,0.011693,1.30149,-1.82958,0.036105,1.28943,-2.04309},
/*157*/{0.153802,1.85013,-1.73133,0.212155,1.79035,-1.88428,0.092132,1.69607,-1.6284,0.063112,1.57992,-1.55706,0.215001,1.57338,-1.62027,0.302877,1.5646,-1.6372,0.150768,1.87343,-2.1291,0.21888,1.79527,-1.96021,0.01471,1.85584,-2.03718,-0.072727,1.72749,-2.19953,-0.06797,1.62855,-2.25743,0.06192,1.48783,-2.1924,0.092652,1.43039,-2.20032,0.085755,1.39243,-1.80205,-0.094342,1.44501,-1.9101,-0.082371,1.46821,-1.96161,-0.080609,1.43429,-2.02112,0.117056,1.38328,-2.07073,0.081842,1.07797,-1.75245,-0.048105,1.05479,-1.79475,-0.031034,0.974143,-1.81815,0.038105,0.859065,-1.80166,0.014409,0.675762,-1.80837,-0.009862,0.60719,-1.82578,-0.091205,0.714557,-1.81735,-0.11479,0.64812,-1.82938,-0.151588,0.428551,-1.85928,-0.266506,0.372027,-1.93545,-0.008716,0.38305,-1.89869,-0.036497,0.335954,-1.82664,0.222975,1.14168,-2.1212,0.273893,1.07522,-2.10364,0.109213,1.05616,-2.101,0.15949,0.993156,-2.08423,0.267884,0.905305,-2.0791,0.123016,0.801379,-2.0743,0.093723,0.911454,-2.09211,0.027272,0.887039,-2.088,-0.187695,0.789891,-2.06979,-0.288286,0.840733,-2.01271,-0.185208,0.57789,-2.03733,-0.237498,0.611134,-2.10379,0.012245,1.30285,-1.82988,0.036214,1.29231,-2.04351},
/*158*/{0.156567,1.85476,-1.73242,0.21284,1.79403,-1.88533,0.098469,1.70032,-1.62865,0.071864,1.58344,-1.55561,0.221122,1.58116,-1.62272,0.30968,1.57451,-1.64147,0.1477,1.87747,-2.13015,0.217629,1.79876,-1.96219,0.013504,1.85829,-2.0357,-0.077507,1.73463,-2.19931,-0.074399,1.63553,-2.2577,0.054627,1.4958,-2.19314,0.085484,1.43839,-2.20096,0.086428,1.39282,-1.80186,-0.092003,1.44803,-1.90799,-0.082778,1.47045,-1.96089,-0.080603,1.43711,-2.02005,0.117396,1.38666,-2.0706,0.075438,1.0777,-1.75534,-0.055997,1.05781,-1.79565,-0.043076,0.97732,-1.81846,0.024928,0.860376,-1.80355,-0.002345,0.676627,-1.80993,-0.03035,0.606903,-1.82657,-0.107126,0.716806,-1.81823,-0.130647,0.650803,-1.82967,-0.170952,0.4317,-1.85956,-0.286926,0.375137,-1.93529,-0.028398,0.383348,-1.89891,-0.056366,0.336059,-1.82605,0.227578,1.15046,-2.121,0.279756,1.08406,-2.10332,0.115097,1.06201,-2.10038,0.167873,1.00042,-2.08376,0.279642,0.916875,-2.07903,0.138097,0.805681,-2.0756,0.102776,0.913234,-2.09227,0.037311,0.887675,-2.08828,-0.171626,0.778185,-2.07068,-0.275458,0.821658,-2.01228,-0.1529,0.56868,-2.04256,-0.210688,0.597015,-2.10624,0.012958,1.30405,-1.83022,0.036129,1.29538,-2.04403},
/*159*/{0.158703,1.85979,-1.7339,0.213959,1.79849,-1.88703,0.105632,1.70484,-1.62897,0.079176,1.58744,-1.55501,0.227645,1.58925,-1.62602,0.315666,1.58524,-1.64634,0.14444,1.88211,-2.13026,0.217171,1.8024,-1.96403,0.011898,1.86141,-2.03391,-0.081718,1.74127,-2.19978,-0.080497,1.64285,-2.25724,0.048729,1.50459,-2.19306,0.079597,1.44723,-2.20119,0.087504,1.39369,-1.80183,-0.092258,1.45074,-1.9076,-0.081807,1.47347,-1.95947,-0.079975,1.44065,-2.01943,0.117637,1.39037,-2.06997,0.068079,1.07755,-1.75866,-0.062094,1.06278,-1.79463,-0.053129,0.980565,-1.81787,0.013377,0.862471,-1.80583,-0.019029,0.678035,-1.81132,-0.045882,0.608979,-1.82834,-0.12394,0.718946,-1.81924,-0.150253,0.652677,-1.83086,-0.19122,0.432541,-1.85874,-0.306587,0.377977,-1.93475,-0.048827,0.381987,-1.89935,-0.077678,0.336239,-1.82678,0.232094,1.15903,-2.12075,0.284776,1.09473,-2.10367,0.121674,1.0678,-2.10028,0.17507,1.00698,-2.08324,0.289562,0.927933,-2.07882,0.152658,0.810052,-2.077,0.111661,0.915369,-2.0916,0.047851,0.886028,-2.08815,-0.156767,0.766158,-2.07151,-0.262042,0.802818,-2.01206,-0.125428,0.55806,-2.04533,-0.186096,0.583767,-2.10799,0.013221,1.30554,-1.83087,0.036327,1.29898,-2.04476},
/*160*/{0.161579,1.8655,-1.73552,0.214657,1.80262,-1.88864,0.112446,1.70925,-1.62926,0.087124,1.5933,-1.55544,0.232744,1.59775,-1.62926,0.320742,1.59487,-1.65198,0.140614,1.88687,-2.13056,0.217292,1.807,-1.96565,0.010397,1.86458,-2.03211,-0.086824,1.74863,-2.19984,-0.086813,1.65037,-2.25681,0.042356,1.51324,-2.19362,0.073933,1.45552,-2.20208,0.088722,1.39454,-1.80094,-0.090165,1.45329,-1.90559,-0.080821,1.4769,-1.95717,-0.078614,1.4441,-2.01783,0.117945,1.39392,-2.06932,0.064236,1.07679,-1.76076,-0.070734,1.06605,-1.79455,-0.063899,0.98386,-1.81826,0.002493,0.865032,-1.80815,-0.036338,0.679652,-1.81319,-0.063953,0.611092,-1.82944,-0.140848,0.720873,-1.82061,-0.167558,0.654483,-1.83272,-0.209558,0.43666,-1.85901,-0.325763,0.382853,-1.93379,-0.068469,0.382234,-1.89992,-0.097832,0.3369,-1.8275,0.235428,1.16777,-2.12057,0.290226,1.10496,-2.10312,0.12737,1.07294,-2.09876,0.182294,1.01434,-2.08319,0.298286,0.939044,-2.07934,0.166589,0.816183,-2.07922,0.120374,0.918236,-2.09222,0.057817,0.885322,-2.08755,-0.14069,0.75447,-2.07277,-0.24868,0.784628,-2.01187,-0.095638,0.549532,-2.04891,-0.158252,0.570438,-2.11034,0.014262,1.30698,-1.83072,0.036644,1.3025,-2.04474},
/*161*/{0.163528,1.8713,-1.73713,0.215537,1.80731,-1.89058,0.118569,1.71441,-1.62969,0.093825,1.59833,-1.55577,0.238673,1.60612,-1.63189,0.325866,1.60512,-1.65724,0.13723,1.89186,-2.13062,0.21701,1.81141,-1.96769,0.008979,1.86762,-2.03068,-0.091092,1.75572,-2.19976,-0.091753,1.6577,-2.25609,0.036819,1.52207,-2.19318,0.068576,1.46439,-2.20289,0.091091,1.3959,-1.80072,-0.088861,1.45636,-1.90452,-0.079694,1.48021,-1.95583,-0.07809,1.44832,-2.01669,0.118387,1.39808,-2.06882,0.056744,1.0779,-1.76369,-0.07717,1.07201,-1.79415,-0.073513,0.988365,-1.81782,-0.007536,0.866987,-1.80973,-0.052569,0.682337,-1.81392,-0.082136,0.613394,-1.83038,-0.157534,0.724648,-1.82127,-0.184874,0.658405,-1.83137,-0.229726,0.440561,-1.8587,-0.344665,0.389388,-1.93332,-0.086917,0.381765,-1.90005,-0.119108,0.337212,-1.82687,0.238689,1.17584,-2.11985,0.293993,1.11548,-2.1032,0.132418,1.07925,-2.09854,0.188624,1.02069,-2.08272,0.307292,0.951012,-2.07962,0.179612,0.817755,-2.08004,0.127907,0.919647,-2.09164,0.067136,0.883875,-2.08769,-0.123735,0.741668,-2.07299,-0.234638,0.763872,-2.01088,-0.065981,0.539867,-2.05125,-0.132042,0.557678,-2.11232,0.015652,1.30902,-1.83118,0.037151,1.30655,-2.04532},
/*162*/{0.166033,1.8769,-1.73833,0.216372,1.8122,-1.89249,0.124502,1.71967,-1.63039,0.101879,1.60324,-1.55452,0.243471,1.61403,-1.6346,0.329359,1.61485,-1.66249,0.133962,1.89657,-2.13053,0.21672,1.81627,-1.96938,0.007167,1.87087,-2.02878,-0.095092,1.76211,-2.19973,-0.098776,1.66514,-2.25454,0.031446,1.53103,-2.19306,0.063611,1.47342,-2.20331,0.092208,1.39662,-1.80008,-0.0872,1.45978,-1.90225,-0.078553,1.48356,-1.95378,-0.077631,1.45237,-2.01606,0.119335,1.40269,-2.06813,0.050137,1.08052,-1.76548,-0.085288,1.07559,-1.79474,-0.082516,0.993799,-1.81868,-0.019827,0.86935,-1.81266,-0.069237,0.685622,-1.81511,-0.098113,0.617501,-1.83171,-0.174206,0.728589,-1.82204,-0.200894,0.662623,-1.83236,-0.246323,0.443743,-1.85883,-0.362857,0.395785,-1.93343,-0.106667,0.38106,-1.90054,-0.138628,0.337726,-1.82782,0.241734,1.18412,-2.11941,0.298902,1.12455,-2.10228,0.137378,1.08558,-2.09878,0.194929,1.0281,-2.08265,0.314321,0.962278,-2.07901,0.191767,0.822906,-2.08147,0.134592,0.921164,-2.09154,0.075953,0.881519,-2.0869,-0.10459,0.72905,-2.07223,-0.217524,0.743915,-2.01038,-0.03673,0.530304,-2.05389,-0.104272,0.544606,-2.11463,0.016497,1.31062,-1.83165,0.037657,1.31093,-2.04584},
/*163*/{0.167831,1.88277,-1.74009,0.216721,1.81692,-1.89397,0.130099,1.72544,-1.6314,0.107499,1.60918,-1.5547,0.246568,1.6219,-1.63707,0.332207,1.62515,-1.66537,0.131242,1.90177,-2.13048,0.216979,1.82118,-1.97153,0.006465,1.87383,-2.02695,-0.099139,1.76865,-2.20038,-0.103531,1.67241,-2.25347,0.0256,1.53942,-2.19244,0.058468,1.48193,-2.20361,0.09469,1.39815,-1.80005,-0.086014,1.46322,-1.90102,-0.07703,1.48699,-1.95134,-0.075753,1.45739,-2.0148,0.119642,1.40707,-2.06726,0.044696,1.08203,-1.76824,-0.09115,1.08124,-1.79522,-0.092875,0.999129,-1.8198,-0.03348,0.873487,-1.8136,-0.085598,0.690047,-1.81599,-0.115926,0.621603,-1.83137,-0.18994,0.733409,-1.82288,-0.216211,0.668375,-1.83236,-0.264811,0.448797,-1.85824,-0.381172,0.402913,-1.93287,-0.125838,0.379311,-1.90129,-0.159588,0.337625,-1.8279,0.244558,1.19224,-2.1195,0.302647,1.13385,-2.10137,0.141902,1.09297,-2.0987,0.199835,1.03662,-2.08254,0.320115,0.973132,-2.07906,0.204604,0.827446,-2.08243,0.14152,0.922083,-2.0908,0.085466,0.879486,-2.08723,-0.086257,0.715888,-2.07239,-0.202061,0.723995,-2.01125,-0.007693,0.522538,-2.057,-0.07509,0.533129,-2.11681,0.017945,1.31278,-1.83203,0.038253,1.31543,-2.04629},
/*164*/{0.170062,1.88982,-1.74224,0.217355,1.82233,-1.89641,0.135821,1.73127,-1.63214,0.1155,1.61525,-1.55452,0.250572,1.63042,-1.63981,0.335175,1.63503,-1.67012,0.12746,1.90645,-2.13125,0.216412,1.8254,-1.97316,0.005455,1.87747,-2.02521,-0.102539,1.77559,-2.20023,-0.109239,1.67962,-2.2527,0.020206,1.54674,-2.19164,0.05435,1.48995,-2.2039,0.09552,1.39863,-1.79961,-0.08424,1.46636,-1.90005,-0.075703,1.49093,-1.94926,-0.074815,1.46245,-2.01461,0.120776,1.41189,-2.0668,0.037973,1.08259,-1.77045,-0.095368,1.08851,-1.79423,-0.09964,1.00574,-1.81843,-0.049888,0.877575,-1.8143,-0.101681,0.695332,-1.81624,-0.132962,0.626005,-1.83205,-0.205114,0.739578,-1.82359,-0.232789,0.674308,-1.83372,-0.282244,0.453574,-1.8571,-0.398615,0.411343,-1.9332,-0.144603,0.378499,-1.90106,-0.179522,0.338089,-1.82831,0.247277,1.20036,-2.11919,0.306442,1.14171,-2.10047,0.145854,1.10067,-2.09931,0.203787,1.04385,-2.08211,0.324103,0.982561,-2.0796,0.21522,0.830736,-2.08394,0.14782,0.922999,-2.09056,0.093579,0.876969,-2.08788,-0.068661,0.703693,-2.07248,-0.183801,0.704084,-2.01208,0.023592,0.515546,-2.05996,-0.045635,0.522359,-2.11954,0.018316,1.31426,-1.83336,0.03887,1.32036,-2.04752},
/*165*/{0.171457,1.89442,-1.74441,0.218503,1.8265,-1.89815,0.140613,1.73722,-1.63301,0.120441,1.62163,-1.55424,0.253678,1.63887,-1.64286,0.337989,1.6439,-1.67402,0.12528,1.91128,-2.13114,0.216698,1.83087,-1.97489,0.003962,1.88137,-2.02414,-0.106201,1.78099,-2.19975,-0.114097,1.68724,-2.25116,0.016862,1.55427,-2.19037,0.050054,1.49792,-2.20443,0.098949,1.40059,-1.80063,-0.081374,1.46998,-1.89882,-0.074664,1.49522,-1.94758,-0.073238,1.46787,-2.0136,0.121121,1.41658,-2.06659,0.03359,1.08544,-1.77299,-0.101618,1.09563,-1.79498,-0.108594,1.01171,-1.81811,-0.065562,0.883032,-1.8145,-0.116899,0.70055,-1.8163,-0.147954,0.632764,-1.83192,-0.220787,0.746049,-1.8244,-0.249358,0.679854,-1.8344,-0.30005,0.458887,-1.85861,-0.415387,0.420438,-1.93357,-0.163396,0.377205,-1.90145,-0.199179,0.339136,-1.82847,0.24972,1.20843,-2.11905,0.309117,1.15043,-2.0999,0.14923,1.10749,-2.09987,0.207587,1.05158,-2.08143,0.327869,0.992547,-2.07916,0.227034,0.834978,-2.08547,0.153458,0.92132,-2.08919,0.104087,0.872698,-2.08598,-0.052516,0.691263,-2.07458,-0.165914,0.684115,-2.01294,0.05388,0.510059,-2.06276,-0.015548,0.51313,-2.12215,0.020582,1.31697,-1.83433,0.039401,1.32528,-2.04858},
/*166*/{0.173414,1.90016,-1.74578,0.218423,1.83196,-1.90005,0.14444,1.74356,-1.63363,0.124315,1.62756,-1.55449,0.255593,1.64682,-1.64576,0.339916,1.65359,-1.67967,0.122796,1.91577,-2.13084,0.216056,1.83551,-1.97615,0.002719,1.88477,-2.02276,-0.107492,1.78675,-2.19908,-0.118821,1.69334,-2.24924,0.011181,1.56232,-2.18973,0.045992,1.50629,-2.20424,0.101937,1.40189,-1.80159,-0.079429,1.47401,-1.89746,-0.072389,1.49868,-1.94527,-0.071859,1.47253,-2.01235,0.122051,1.42169,-2.0658,0.028864,1.08757,-1.77523,-0.107042,1.1027,-1.79413,-0.116261,1.01871,-1.81859,-0.080617,0.889873,-1.81378,-0.132583,0.706701,-1.81546,-0.163289,0.639117,-1.83019,-0.235027,0.752692,-1.82503,-0.263858,0.687931,-1.83404,-0.31796,0.465523,-1.85849,-0.431882,0.430157,-1.93326,-0.182555,0.3772,-1.90175,-0.220266,0.339764,-1.82913,0.252067,1.2162,-2.11867,0.312219,1.15912,-2.09929,0.152949,1.11319,-2.1004,0.210841,1.05945,-2.0806,0.330277,1.00083,-2.0792,0.237903,0.83872,-2.08656,0.159125,0.920495,-2.08882,0.111935,0.868834,-2.08601,-0.033169,0.678495,-2.07462,-0.14554,0.663209,-2.01168,0.084056,0.504421,-2.06512,0.014963,0.503955,-2.12478,0.022724,1.31917,-1.83528,0.040358,1.33026,-2.0495},
/*167*/{0.175182,1.90618,-1.74761,0.220075,1.83671,-1.9023,0.148666,1.74961,-1.63438,0.128578,1.63353,-1.55395,0.257814,1.65403,-1.64808,0.341017,1.66212,-1.68357,0.120821,1.92018,-2.13134,0.215149,1.84043,-1.97789,0.002055,1.88929,-2.02199,-0.110974,1.79172,-2.19849,-0.122959,1.70048,-2.24812,0.008281,1.57008,-2.18895,0.042722,1.51366,-2.20455,0.10358,1.40307,-1.80216,-0.077246,1.47741,-1.89627,-0.070701,1.50336,-1.94304,-0.070054,1.47767,-2.01192,0.123436,1.42719,-2.06555,0.024239,1.09059,-1.77675,-0.111659,1.10739,-1.79381,-0.123856,1.02633,-1.8181,-0.093381,0.896963,-1.81372,-0.147378,0.713318,-1.81414,-0.177656,0.645837,-1.82927,-0.248888,0.760321,-1.8252,-0.277648,0.695232,-1.83467,-0.329543,0.470463,-1.85652,-0.447715,0.440304,-1.93365,-0.201408,0.377108,-1.90177,-0.241529,0.340561,-1.82974,0.253724,1.22376,-2.11838,0.313949,1.16706,-2.09884,0.155424,1.11965,-2.10012,0.213888,1.06551,-2.07998,0.331113,1.00866,-2.07942,0.247791,0.841437,-2.08784,0.165814,0.918926,-2.08871,0.120255,0.864045,-2.0858,-0.011452,0.665651,-2.07373,-0.124942,0.641889,-2.01251,0.114815,0.500216,-2.0679,0.045877,0.495794,-2.12768,0.024045,1.32123,-1.83689,0.041418,1.33586,-2.05092},
/*168*/{0.177384,1.91146,-1.7491,0.220477,1.84118,-1.90433,0.152322,1.75512,-1.63497,0.133547,1.63969,-1.55383,0.259752,1.66161,-1.65093,0.341558,1.67005,-1.68855,0.118338,1.92444,-2.13114,0.214992,1.84527,-1.97938,0.001305,1.89256,-2.0215,-0.114609,1.7971,-2.19677,-0.127738,1.70682,-2.24681,0.004875,1.57724,-2.18852,0.039068,1.52113,-2.20482,0.106495,1.40423,-1.80356,-0.074895,1.48118,-1.8951,-0.069661,1.50782,-1.9413,-0.068599,1.4826,-2.01057,0.124447,1.43223,-2.06559,0.019626,1.09314,-1.77758,-0.1153,1.11614,-1.79326,-0.13028,1.03459,-1.81721,-0.10501,0.90408,-1.81365,-0.16105,0.720549,-1.81357,-0.192155,0.65337,-1.82778,-0.262562,0.768332,-1.82569,-0.291874,0.703095,-1.83641,-0.347163,0.477525,-1.85602,-0.462642,0.451823,-1.93425,-0.220697,0.376494,-1.90175,-0.261374,0.341037,-1.8299,0.255072,1.22998,-2.11806,0.315921,1.17397,-2.09744,0.156964,1.12593,-2.10083,0.216037,1.07386,-2.08297,0.331783,1.01632,-2.0796,0.257444,0.843175,-2.08856,0.17106,0.91602,-2.08848,0.129847,0.859454,-2.08616,0.005849,0.654932,-2.07755,-0.103549,0.622726,-2.01204,0.145192,0.496221,-2.06967,0.07713,0.488994,-2.12857,0.02593,1.32348,-1.83845,0.041944,1.34112,-2.05236},
/*169*/{0.178999,1.91665,-1.75072,0.220847,1.84639,-1.90645,0.155416,1.76118,-1.63544,0.137393,1.64612,-1.55423,0.260999,1.6684,-1.653,0.343358,1.67743,-1.69148,0.116966,1.92837,-2.13172,0.214939,1.85017,-1.98101,0.001023,1.89583,-2.02124,-0.116808,1.80299,-2.19524,-0.131423,1.71292,-2.24561,0.001359,1.58353,-2.18738,0.035927,1.52752,-2.20483,0.109392,1.40539,-1.80484,-0.072407,1.48528,-1.89287,-0.067314,1.5113,-1.93914,-0.066715,1.48864,-2.01039,0.125284,1.43731,-2.06574,0.015501,1.09616,-1.77927,-0.117754,1.12469,-1.79259,-0.136489,1.04191,-1.81737,-0.114867,0.910486,-1.81363,-0.173744,0.728104,-1.81194,-0.20618,0.660976,-1.82591,-0.274823,0.775939,-1.82697,-0.305221,0.711836,-1.83585,-0.361643,0.484434,-1.85475,-0.476378,0.464319,-1.93225,-0.239638,0.376557,-1.90202,-0.282295,0.341825,-1.83038,0.256849,1.23692,-2.11787,0.317727,1.18012,-2.09654,0.158726,1.13283,-2.10104,0.216971,1.07987,-2.08381,0.331483,1.02228,-2.0804,0.267055,0.844523,-2.08914,0.176613,0.912578,-2.08796,0.137821,0.854242,-2.08649,0.025809,0.642438,-2.077,-0.080879,0.602501,-2.01264,0.175012,0.493875,-2.0711,0.107472,0.482231,-2.1305,0.027864,1.3257,-1.84015,0.042507,1.34657,-2.05387},
/*170*/{0.181091,1.92194,-1.75242,0.222288,1.85179,-1.90835,0.158584,1.76658,-1.63598,0.140559,1.6516,-1.55368,0.263047,1.67559,-1.6557,0.343275,1.68523,-1.69602,0.115039,1.93191,-2.1316,0.215081,1.85452,-1.98288,-0.000138,1.89938,-2.02094,-0.11992,1.80804,-2.19298,-0.135236,1.71784,-2.24332,-0.001801,1.58978,-2.18695,0.033777,1.53381,-2.20487,0.112469,1.40712,-1.80622,-0.0702,1.48934,-1.89177,-0.065798,1.51543,-1.93718,-0.064609,1.49381,-2.00871,0.123789,1.44282,-2.06611,0.01171,1.09896,-1.77975,-0.122419,1.13115,-1.79283,-0.142067,1.04995,-1.81739,-0.123559,0.917734,-1.8131,-0.185597,0.735526,-1.81111,-0.219172,0.667553,-1.82456,-0.286277,0.784554,-1.82717,-0.316046,0.720325,-1.83582,-0.374375,0.490675,-1.85302,-0.488897,0.47737,-1.93257,-0.258832,0.37636,-1.90204,-0.302799,0.343351,-1.8309,0.258843,1.24293,-2.11652,0.3178,1.18606,-2.09537,0.15888,1.13874,-2.10153,0.218016,1.0858,-2.0838,0.331395,1.02755,-2.08027,0.276058,0.845246,-2.08976,0.182264,0.908217,-2.08856,0.146701,0.84714,-2.08518,0.046791,0.62865,-2.07581,-0.056626,0.583854,-2.01126,0.20439,0.491743,-2.07264,0.137302,0.476637,-2.13133,0.029831,1.3284,-1.84162,0.042137,1.35197,-2.05521},
/*171*/{0.181604,1.92598,-1.75433,0.222217,1.85566,-1.90952,0.160994,1.77198,-1.63611,0.143785,1.65649,-1.55269,0.263218,1.68173,-1.65737,0.343997,1.69166,-1.69918,0.113661,1.93589,-2.13159,0.214714,1.85874,-1.98419,0.001406,1.90112,-2.01855,-0.12145,1.81404,-2.19073,-0.139267,1.72373,-2.24198,-0.004208,1.59512,-2.18647,0.031186,1.54006,-2.20424,0.114253,1.40873,-1.80676,-0.067618,1.49343,-1.89064,-0.063185,1.51878,-1.9358,-0.062538,1.49903,-2.00764,0.125201,1.44771,-2.06642,0.00939,1.10244,-1.78017,-0.123965,1.13778,-1.79188,-0.145745,1.05754,-1.81634,-0.132391,0.924849,-1.81265,-0.196755,0.743779,-1.80995,-0.228787,0.67731,-1.82235,-0.296971,0.792283,-1.82787,-0.32649,0.728105,-1.83523,-0.386083,0.497601,-1.85181,-0.500328,0.492012,-1.93273,-0.277287,0.376651,-1.90168,-0.32349,0.344999,-1.83154,0.25966,1.24774,-2.11619,0.318572,1.19074,-2.09412,0.159307,1.14451,-2.10228,0.218027,1.09083,-2.08472,0.331415,1.03126,-2.08052,0.285111,0.845806,-2.09019,0.188203,0.904159,-2.08943,0.15624,0.840202,-2.08785,0.068021,0.617443,-2.0756,-0.033086,0.564533,-2.01171,0.233347,0.491174,-2.07287,0.168054,0.471381,-2.13252,0.031436,1.33086,-1.84293,0.043202,1.35704,-2.05624},
/*172*/{0.183938,1.93062,-1.75563,0.223645,1.85939,-1.91142,0.162843,1.77709,-1.63671,0.146501,1.66165,-1.55343,0.2643,1.68731,-1.65949,0.344324,1.69798,-1.70267,0.112608,1.93888,-2.132,0.215017,1.86298,-1.98524,0.001118,1.90435,-2.01877,-0.123785,1.81913,-2.18885,-0.142123,1.72878,-2.23987,-0.006584,1.60088,-2.18623,0.029004,1.54554,-2.20412,0.11711,1.41067,-1.80776,-0.06588,1.4971,-1.8897,-0.061761,1.52317,-1.93499,-0.060853,1.50433,-2.00674,0.125724,1.45243,-2.06701,0.005498,1.10557,-1.77925,-0.124532,1.14288,-1.78952,-0.151393,1.0648,-1.81639,-0.139805,0.932016,-1.81167,-0.205953,0.751465,-1.80838,-0.238245,0.685214,-1.82023,-0.306336,0.80079,-1.82783,-0.336154,0.737045,-1.83534,-0.399235,0.505851,-1.85026,-0.510592,0.505869,-1.93211,-0.294909,0.377671,-1.90083,-0.344002,0.347598,-1.8319,0.259829,1.25266,-2.11508,0.318696,1.19478,-2.09278,0.158905,1.14971,-2.10304,0.217559,1.09498,-2.08619,0.329768,1.03373,-2.08145,0.293478,0.845758,-2.09058,0.193278,0.898424,-2.0898,0.164702,0.833538,-2.0879,0.087468,0.605775,-2.07536,-0.009824,0.547835,-2.01314,0.262553,0.490118,-2.07358,0.198152,0.467309,-2.1328,0.033073,1.33373,-1.84438,0.043594,1.36212,-2.05747},
/*173*/{0.185171,1.93452,-1.75715,0.223996,1.86362,-1.91298,0.164771,1.78168,-1.63727,0.149952,1.66676,-1.55277,0.265129,1.6924,-1.6614,0.343778,1.70411,-1.70662,0.111579,1.94243,-2.13237,0.21503,1.86699,-1.98666,0.002184,1.90613,-2.01784,-0.123986,1.82448,-2.18699,-0.144827,1.73358,-2.23838,-0.008261,1.60551,-2.18553,0.027646,1.55065,-2.20386,0.119917,1.41279,-1.80883,-0.062437,1.50064,-1.88862,-0.060035,1.52713,-1.93278,-0.060189,1.51001,-2.00584,0.126342,1.45728,-2.06701,0.002523,1.109,-1.77853,-0.128863,1.1493,-1.79013,-0.154968,1.07144,-1.8161,-0.146642,0.938481,-1.81237,-0.2144,0.759287,-1.80659,-0.248628,0.691961,-1.81828,-0.313529,0.808518,-1.82724,-0.34492,0.744003,-1.83544,-0.409795,0.514051,-1.84972,-0.519766,0.521574,-1.93238,-0.312722,0.378818,-1.90052,-0.364219,0.350741,-1.83188,0.259554,1.25626,-2.11461,0.317938,1.198,-2.09226,0.158577,1.15391,-2.10362,0.216582,1.09853,-2.08784,0.329147,1.03601,-2.082,0.301547,0.845688,-2.09168,0.199157,0.892551,-2.09104,0.174052,0.826288,-2.08686,0.111479,0.595467,-2.07447,0.014806,0.531691,-2.01338,0.289885,0.490651,-2.07241,0.226998,0.463453,-2.13262,0.035174,1.33657,-1.84559,0.043992,1.36735,-2.05843},
/*174*/{0.18639,1.93852,-1.75829,0.224417,1.86776,-1.91422,0.16673,1.7863,-1.63762,0.151729,1.67125,-1.5525,0.265748,1.69798,-1.66333,0.343592,1.70932,-1.70954,0.110856,1.94496,-2.13208,0.215256,1.8704,-1.98727,0.002409,1.90904,-2.01798,-0.125383,1.82742,-2.18202,-0.147717,1.7382,-2.2363,-0.010284,1.61064,-2.18525,0.025712,1.55575,-2.20384,0.121176,1.41404,-1.80961,-0.060691,1.50477,-1.88667,-0.059122,1.53085,-1.93178,-0.056532,1.51362,-2.00357,0.125698,1.46123,-2.06685,0.001199,1.11375,-1.77824,-0.128325,1.15659,-1.79086,-0.157883,1.07743,-1.81641,-0.152173,0.945331,-1.81234,-0.221202,0.766475,-1.80612,-0.255001,0.699463,-1.81699,-0.320279,0.81547,-1.82596,-0.351594,0.752086,-1.83363,-0.420002,0.521427,-1.84724,-0.527848,0.538504,-1.93179,-0.329982,0.380243,-1.89923,-0.385438,0.354435,-1.83261,0.259593,1.25926,-2.1135,0.317348,1.20016,-2.09169,0.157104,1.15761,-2.10481,0.214884,1.10106,-2.08858,0.327345,1.0371,-2.08213,0.309207,0.844506,-2.09183,0.204207,0.886057,-2.09184,0.182338,0.817419,-2.08736,0.129678,0.58473,-2.07515,0.039803,0.515193,-2.01408,0.316165,0.490924,-2.07143,0.255769,0.460472,-2.13166,0.035898,1.3389,-1.84607,0.04369,1.37146,-2.05869},
/*175*/{0.188441,1.9424,-1.75981,0.225084,1.87212,-1.91512,0.1681,1.79075,-1.63809,0.15429,1.67532,-1.55206,0.265895,1.70221,-1.66479,0.342809,1.71334,-1.71269,0.110334,1.94827,-2.1321,0.215549,1.8738,-1.98836,0.0024,1.91103,-2.01758,-0.126482,1.83158,-2.17988,-0.149744,1.74263,-2.23451,-0.011566,1.61472,-2.18525,0.024272,1.56015,-2.20344,0.123861,1.41693,-1.81008,-0.059459,1.50851,-1.88588,-0.057677,1.53501,-1.93026,-0.055023,1.51809,-2.00169,0.1269,1.46494,-2.06672,-0.003071,1.11622,-1.77593,-0.130528,1.16299,-1.79422,-0.160456,1.0848,-1.81595,-0.156845,0.951416,-1.81305,-0.227239,0.774118,-1.80438,-0.261427,0.706461,-1.81568,-0.325806,0.824166,-1.82321,-0.357894,0.759904,-1.83186,-0.429414,0.528673,-1.84463,-0.533794,0.554507,-1.93096,-0.347638,0.382358,-1.8983,-0.405279,0.359378,-1.83318,0.259738,1.26117,-2.11258,0.316487,1.20122,-2.0914,0.155722,1.16057,-2.10513,0.21238,1.10362,-2.08926,0.325436,1.0375,-2.08346,0.31626,0.843773,-2.09216,0.209826,0.8796,-2.09289,0.190622,0.812305,-2.08786,0.150847,0.575073,-2.0753,0.064516,0.499853,-2.01463,0.341579,0.492477,-2.07038,0.283577,0.457846,-2.13069,0.037626,1.34221,-1.84608,0.04432,1.37571,-2.05859},
/*176*/{0.189131,1.94538,-1.76113,0.22532,1.87489,-1.91638,0.169456,1.79463,-1.63853,0.155254,1.679,-1.55158,0.265892,1.70712,-1.66687,0.343013,1.71814,-1.71528,0.109606,1.95096,-2.13217,0.216491,1.87708,-1.989,0.003087,1.91375,-2.0167,-0.127479,1.83555,-2.17809,-0.151637,1.74631,-2.23265,-0.012721,1.61873,-2.1851,0.023542,1.56478,-2.20376,0.125271,1.41938,-1.81065,-0.056785,1.51169,-1.88484,-0.056246,1.53861,-1.92823,-0.053673,1.5219,-2.00061,0.126809,1.46799,-2.06655,-0.005115,1.12012,-1.77506,-0.13187,1.16704,-1.79552,-0.162443,1.08909,-1.81636,-0.158617,0.956695,-1.81332,-0.233136,0.779471,-1.80414,-0.268767,0.712617,-1.81453,-0.329511,0.83137,-1.82218,-0.363599,0.766791,-1.83097,-0.438016,0.53862,-1.84229,-0.539739,0.571077,-1.92871,-0.366093,0.384981,-1.89873,-0.42615,0.365683,-1.834,0.257838,1.26253,-2.1123,0.314828,1.20201,-2.0913,0.153315,1.16272,-2.10501,0.209246,1.10467,-2.08972,0.322945,1.03672,-2.0843,0.323707,0.8416,-2.09207,0.21527,0.87322,-2.09405,0.19932,0.803916,-2.08919,0.171684,0.566327,-2.07791,0.087044,0.485541,-2.01375,0.367645,0.494812,-2.06869,0.310235,0.456235,-2.1287,0.038838,1.34498,-1.84601,0.044136,1.37919,-2.05845},
/*177*/{0.190537,1.94856,-1.76215,0.227149,1.87905,-1.91796,0.171429,1.79884,-1.63945,0.156457,1.68197,-1.55144,0.266263,1.70977,-1.66813,0.342368,1.72172,-1.71827,0.109559,1.95334,-2.13254,0.21655,1.88001,-1.99055,0.00335,1.91474,-2.01658,-0.128778,1.83946,-2.17475,-0.153083,1.74973,-2.23095,-0.014014,1.62277,-2.18472,0.022232,1.56853,-2.20383,0.127321,1.42232,-1.8114,-0.054428,1.5153,-1.88302,-0.055156,1.54181,-1.92738,-0.052395,1.52581,-2.00038,0.127032,1.47078,-2.06612,-0.005908,1.1237,-1.77449,-0.132068,1.17107,-1.79716,-0.163337,1.09456,-1.81804,-0.159497,0.960795,-1.81423,-0.237206,0.785624,-1.80374,-0.272758,0.720202,-1.81293,-0.333668,0.837588,-1.82251,-0.367714,0.774573,-1.82831,-0.448185,0.549119,-1.84078,-0.543755,0.588607,-1.92517,-0.381817,0.390118,-1.89845,-0.4465,0.37235,-1.83556,0.257175,1.26265,-2.11143,0.312258,1.20074,-2.09099,0.150949,1.16432,-2.10527,0.206107,1.10549,-2.0905,0.320335,1.03583,-2.08606,0.329732,0.840609,-2.09217,0.218801,0.866114,-2.09524,0.207277,0.797127,-2.09178,0.19167,0.557963,-2.0758,0.110512,0.473509,-2.01145,0.389516,0.496826,-2.06699,0.336057,0.454757,-2.12691,0.040346,1.34819,-1.84564,0.044258,1.38237,-2.05811},
/*178*/{0.191252,1.9512,-1.76281,0.227771,1.88206,-1.91859,0.17202,1.80204,-1.6395,0.158173,1.68525,-1.55119,0.265742,1.7127,-1.6699,0.341611,1.72443,-1.72068,0.108703,1.95572,-2.13263,0.217218,1.88156,-1.99095,0.003275,1.91741,-2.01578,-0.128059,1.8426,-2.17249,-0.154751,1.75301,-2.2289,-0.013472,1.626,-2.1842,0.022103,1.57226,-2.20315,0.128609,1.42532,-1.81152,-0.053822,1.51892,-1.88231,-0.053987,1.5454,-1.92599,-0.051658,1.52929,-1.99841,0.127208,1.47352,-2.06563,-0.00635,1.12741,-1.77351,-0.132325,1.17446,-1.79797,-0.163272,1.09819,-1.81965,-0.15975,0.964394,-1.81456,-0.239547,0.790339,-1.80368,-0.27844,0.724945,-1.81264,-0.335264,0.844609,-1.82039,-0.370423,0.782231,-1.82658,-0.457243,0.557559,-1.83929,-0.548177,0.605917,-1.92064,-0.399137,0.396332,-1.89935,-0.463594,0.380475,-1.83716,0.255563,1.26217,-2.11163,0.309855,1.19898,-2.09147,0.147847,1.16508,-2.10565,0.202567,1.10565,-2.09156,0.317918,1.03408,-2.08733,0.335488,0.838357,-2.09234,0.222696,0.860866,-2.09748,0.214753,0.789032,-2.09294,0.210334,0.550261,-2.07523,0.135382,0.46086,-2.01286,0.411763,0.498975,-2.06415,0.361737,0.453912,-2.12436,0.04108,1.35139,-1.84487,0.044018,1.38558,-2.05736},
/*179*/{0.192432,1.95394,-1.76457,0.228446,1.88488,-1.92004,0.172703,1.80522,-1.64009,0.158809,1.68845,-1.55086,0.265469,1.71543,-1.67045,0.341124,1.72681,-1.72322,0.108957,1.95777,-2.133,0.217859,1.88407,-1.99241,0.004156,1.91934,-2.01585,-0.130087,1.8446,-2.16917,-0.156352,1.75584,-2.22719,-0.014031,1.62932,-2.18312,0.021386,1.57502,-2.20321,0.129404,1.42801,-1.81148,-0.052843,1.52159,-1.8815,-0.053338,1.54838,-1.92485,-0.0506,1.53178,-1.99716,0.127745,1.47596,-2.0655,-0.005076,1.13033,-1.7727,-0.132177,1.17666,-1.79764,-0.162609,1.10133,-1.82024,-0.158913,0.967198,-1.81517,-0.241639,0.793715,-1.80365,-0.280217,0.729035,-1.81172,-0.335134,0.850731,-1.81919,-0.372336,0.789361,-1.82404,-0.464208,0.568343,-1.83647,-0.553809,0.62199,-1.91582,-0.416029,0.404902,-1.90125,-0.480692,0.389317,-1.83993,0.252812,1.26026,-2.11177,0.306564,1.19662,-2.09147,0.144348,1.16506,-2.10612,0.198206,1.10417,-2.09177,0.315148,1.03174,-2.08875,0.339544,0.836463,-2.09321,0.227749,0.851948,-2.0988,0.220925,0.782879,-2.0948,0.229342,0.542443,-2.07513,0.155624,0.451688,-2.01261,0.432363,0.501642,-2.06139,0.384974,0.453107,-2.12102,0.041985,1.35402,-1.84428,0.044288,1.3882,-2.05677},
/*180*/{0.193294,1.95565,-1.7648,0.229106,1.8871,-1.92057,0.173136,1.80787,-1.64078,0.158877,1.69102,-1.55156,0.265249,1.71744,-1.67188,0.340115,1.72877,-1.72544,0.108202,1.95973,-2.1327,0.219102,1.88606,-1.99315,0.0042,1.92197,-2.01548,-0.130551,1.84718,-2.16689,-0.15685,1.75819,-2.22539,-0.013989,1.63198,-2.18272,0.02143,1.57813,-2.20329,0.130413,1.43074,-1.81162,-0.051621,1.52466,-1.88002,-0.05273,1.55122,-1.92451,-0.051287,1.53524,-1.99608,0.127693,1.47846,-2.06493,-0.005503,1.13267,-1.77246,-0.131025,1.17793,-1.79994,-0.160466,1.10277,-1.82216,-0.155733,0.968675,-1.81593,-0.242098,0.796539,-1.80405,-0.284177,0.734255,-1.81251,-0.335532,0.856895,-1.819,-0.372617,0.796228,-1.82321,-0.46774,0.577065,-1.83514,-0.557757,0.637631,-1.90817,-0.431967,0.413577,-1.90455,-0.49614,0.399128,-1.84265,0.250622,1.25759,-2.11159,0.30292,1.19423,-2.09247,0.140886,1.16473,-2.10702,0.193575,1.10379,-2.09257,0.311831,1.02867,-2.08988,0.343125,0.834629,-2.09399,0.230367,0.845582,-2.10082,0.227828,0.775508,-2.09529,0.247295,0.535873,-2.07512,0.177125,0.441325,-2.01342,0.451025,0.503951,-2.05874,0.406403,0.452005,-2.11826,0.042604,1.35695,-1.84363,0.043825,1.391,-2.05616},
/*181*/{0.193918,1.95787,-1.76596,0.230011,1.88926,-1.92145,0.173594,1.81038,-1.6416,0.15907,1.6925,-1.55072,0.264055,1.71905,-1.67306,0.337532,1.73189,-1.72716,0.10909,1.96133,-2.13368,0.218954,1.8873,-1.99448,0.005624,1.92356,-2.01557,-0.130576,1.84827,-2.16536,-0.158113,1.76066,-2.22387,-0.014546,1.63471,-2.18259,0.021381,1.5806,-2.20367,0.130893,1.43318,-1.81137,-0.0513,1.52737,-1.87988,-0.052652,1.5544,-1.92407,-0.050135,1.53698,-1.99578,0.129176,1.48027,-2.06474,-0.00238,1.13404,-1.77282,-0.129585,1.17832,-1.79722,-0.158427,1.10327,-1.82213,-0.153086,0.969304,-1.81652,-0.242162,0.799237,-1.80364,-0.285564,0.737853,-1.812,-0.333248,0.862322,-1.81682,-0.373628,0.802836,-1.82098,-0.47384,0.585486,-1.832,-0.56523,0.653278,-1.9018,-0.448907,0.424095,-1.9091,-0.509423,0.410592,-1.84494,0.247181,1.25515,-2.11242,0.299621,1.19016,-2.09296,0.136671,1.16287,-2.10752,0.187914,1.10141,-2.09296,0.308989,1.0248,-2.09141,0.346796,0.832948,-2.09461,0.233614,0.839159,-2.10226,0.234559,0.769182,-2.09671,0.263713,0.529559,-2.0748,0.196437,0.4339,-2.013,0.468183,0.506096,-2.05594,0.427556,0.452231,-2.11529,0.042998,1.3595,-1.84302,0.044588,1.39309,-2.05561},
/*182*/{0.195623,1.96064,-1.76667,0.229638,1.89058,-1.92252,0.173412,1.8124,-1.64184,0.158609,1.6951,-1.55114,0.26338,1.71986,-1.67388,0.336774,1.73037,-1.72889,0.109315,1.96263,-2.13397,0.220074,1.8887,-1.99506,0.005773,1.92521,-2.01579,-0.130717,1.84986,-2.16206,-0.15804,1.76258,-2.22268,-0.014794,1.63621,-2.18161,0.021498,1.5826,-2.20391,0.132451,1.4355,-1.81097,-0.050779,1.52925,-1.87953,-0.051678,1.5564,-1.92327,-0.049715,1.53889,-1.99503,0.129301,1.48157,-2.06395,0.002109,1.13516,-1.77519,-0.125241,1.17867,-1.79644,-0.154786,1.10339,-1.82316,-0.147791,0.969329,-1.81694,-0.241389,0.800604,-1.80481,-0.28725,0.740949,-1.81282,-0.330706,0.866742,-1.81556,-0.372628,0.80951,-1.8194,-0.480734,0.595368,-1.83077,-0.57207,0.668421,-1.89296,-0.462711,0.436299,-1.91392,-0.522852,0.421469,-1.84715,0.244783,1.25191,-2.11285,0.296798,1.1856,-2.09321,0.132664,1.16088,-2.10779,0.183288,1.09916,-2.09335,0.304397,1.02032,-2.09203,0.349828,0.831303,-2.09421,0.235922,0.83243,-2.10415,0.23747,0.761623,-2.0978,0.279105,0.524484,-2.07407,0.215195,0.426977,-2.01168,0.484451,0.508584,-2.0534,0.447002,0.451733,-2.11147,0.044029,1.36171,-1.84196,0.044923,1.39455,-2.05467},
/*183*/{0.196455,1.96099,-1.76729,0.230792,1.89287,-1.92356,0.17316,1.81431,-1.64238,0.158578,1.69595,-1.55138,0.262498,1.71976,-1.67458,0.335705,1.72905,-1.73065,0.109487,1.96369,-2.13431,0.220326,1.88917,-1.99602,0.006857,1.9266,-2.01588,-0.130105,1.85143,-2.16039,-0.158192,1.76377,-2.22047,-0.013725,1.63797,-2.18141,0.021344,1.58356,-2.20415,0.13338,1.4378,-1.81081,-0.050099,1.53103,-1.87819,-0.051538,1.55919,-1.92358,-0.049556,1.54047,-1.99401,0.130185,1.48251,-2.06346,0.004754,1.13532,-1.77593,-0.121321,1.17864,-1.79985,-0.149828,1.10156,-1.82191,-0.141541,0.968491,-1.81774,-0.239795,0.801499,-1.80535,-0.287593,0.743494,-1.81417,-0.325994,0.871002,-1.81282,-0.371708,0.815309,-1.81739,-0.487285,0.606383,-1.83006,-0.579686,0.6829,-1.8848,-0.476293,0.448596,-1.9187,-0.533257,0.433833,-1.84982,0.241453,1.24758,-2.1126,0.29215,1.18083,-2.0943,0.127897,1.15921,-2.10841,0.177989,1.09554,-2.09363,0.300518,1.01608,-2.09296,0.351658,0.830082,-2.09416,0.238632,0.825986,-2.10608,0.244834,0.756358,-2.09905,0.293223,0.520283,-2.07472,0.23196,0.421487,-2.01096,0.498871,0.509919,-2.05019,0.464062,0.450808,-2.10831,0.044701,1.36399,-1.84081,0.045107,1.39587,-2.05367},
/*184*/{0.196408,1.96107,-1.76799,0.230461,1.89326,-1.92438,0.173184,1.81506,-1.64303,0.156585,1.6967,-1.55154,0.261587,1.71932,-1.67594,0.334304,1.72754,-1.73229,0.110836,1.96427,-2.13497,0.220874,1.88945,-1.99687,0.008298,1.92781,-2.0159,-0.130662,1.85251,-2.15889,-0.158224,1.76513,-2.21941,-0.012793,1.63931,-2.18109,0.022206,1.58538,-2.20463,0.133611,1.43968,-1.81034,-0.049356,1.53226,-1.87807,-0.051741,1.56056,-1.92294,-0.049101,1.54086,-1.99304,0.130749,1.48306,-2.06252,0.010907,1.1349,-1.77719,-0.117084,1.17742,-1.79947,-0.144682,1.09987,-1.82339,-0.135431,0.96637,-1.81881,-0.23828,0.801939,-1.80595,-0.289071,0.746041,-1.81605,-0.32199,0.875354,-1.81094,-0.369309,0.822145,-1.81531,-0.492781,0.616758,-1.82993,-0.586105,0.696655,-1.8775,-0.488972,0.463131,-1.92262,-0.542726,0.446093,-1.85232,0.238304,1.24331,-2.11407,0.287963,1.17598,-2.09538,0.122469,1.15657,-2.10828,0.171989,1.09289,-2.09373,0.296734,1.01183,-2.09341,0.354143,0.828373,-2.09312,0.241576,0.819717,-2.10762,0.250136,0.750553,-2.10027,0.305051,0.515528,-2.07332,0.246892,0.416597,-2.01026,0.512005,0.511737,-2.04825,0.479388,0.450982,-2.10527,0.045267,1.36552,-1.83953,0.045595,1.39645,-2.05253},
/*185*/{0.19667,1.96125,-1.76869,0.230436,1.89383,-1.92504,0.172135,1.81624,-1.64379,0.154807,1.69741,-1.55242,0.259763,1.71873,-1.67662,0.332283,1.72597,-1.73353,0.111582,1.96461,-2.13544,0.22217,1.89022,-1.99715,0.008622,1.92924,-2.0166,-0.131049,1.8527,-2.15719,-0.158272,1.76545,-2.21762,-0.012615,1.63981,-2.18105,0.022731,1.58581,-2.20472,0.133997,1.44153,-1.80959,-0.049224,1.53316,-1.87775,-0.052001,1.5613,-1.92298,-0.048969,1.54125,-1.99307,0.131802,1.4833,-2.06224,0.016683,1.13374,-1.77954,-0.11223,1.17586,-1.79793,-0.138872,1.09706,-1.82352,-0.128566,0.964006,-1.8197,-0.236212,0.802085,-1.8081,-0.288676,0.749521,-1.8178,-0.317202,0.87978,-1.80816,-0.366922,0.82831,-1.81216,-0.497606,0.627456,-1.82867,-0.592479,0.711263,-1.86934,-0.500671,0.477549,-1.92649,-0.551377,0.459275,-1.85535,0.235271,1.23881,-2.11465,0.283419,1.17066,-2.09611,0.118543,1.15345,-2.10873,0.166649,1.0894,-2.09445,0.291359,1.00698,-2.09427,0.354782,0.826842,-2.09193,0.243787,0.814882,-2.10944,0.254519,0.745958,-2.10166,0.316973,0.512833,-2.07281,0.259424,0.413932,-2.00926,0.523337,0.513529,-2.04539,0.492425,0.450035,-2.10165,0.045893,1.36695,-1.83843,0.046404,1.39668,-2.0516},
/*186*/{0.197541,1.961,-1.7692,0.231108,1.89468,-1.92592,0.171406,1.81676,-1.6442,0.15355,1.69752,-1.55215,0.258436,1.71732,-1.67747,0.331001,1.72345,-1.73505,0.111994,1.96453,-2.13604,0.222619,1.89087,-1.9973,0.009579,1.93022,-2.01716,-0.128527,1.85223,-2.15515,-0.15868,1.76579,-2.21662,-0.012242,1.64,-2.18077,0.02361,1.58605,-2.20516,0.134704,1.44276,-1.80982,-0.049591,1.53323,-1.87814,-0.051884,1.56211,-1.92321,-0.049101,1.54086,-1.99304,0.132677,1.48362,-2.0616,0.023985,1.13237,-1.78165,-0.108068,1.17137,-1.79742,-0.132697,1.09281,-1.82143,-0.120642,0.961253,-1.82092,-0.233694,0.802508,-1.80955,-0.289546,0.752128,-1.81852,-0.311602,0.88358,-1.80586,-0.363461,0.834569,-1.81062,-0.502508,0.639983,-1.82767,-0.596894,0.725988,-1.86241,-0.511244,0.492626,-1.93051,-0.560413,0.47329,-1.85705,0.232195,1.23417,-2.11484,0.278697,1.16567,-2.09727,0.113894,1.15135,-2.10715,0.161185,1.08533,-2.09395,0.285611,1.00256,-2.09487,0.356803,0.825167,-2.09018,0.24558,0.809524,-2.11067,0.258657,0.74152,-2.10236,0.326607,0.509236,-2.07276,0.270329,0.409611,-2.0088,0.532041,0.514152,-2.04374,0.503844,0.450045,-2.09927,0.046659,1.36774,-1.838,0.047316,1.39684,-2.05126},
/*187*/{0.19833,1.96044,-1.77024,0.231197,1.89453,-1.92718,0.170189,1.81686,-1.645,0.151071,1.69738,-1.55266,0.257315,1.71547,-1.67827,0.329136,1.72052,-1.73576,0.113074,1.96438,-2.13673,0.22257,1.89097,-1.99785,0.009918,1.93023,-2.0181,-0.128716,1.85283,-2.1535,-0.157766,1.76534,-2.21587,-0.011512,1.6397,-2.18085,0.024525,1.58612,-2.20555,0.13492,1.44385,-1.80903,-0.049425,1.53283,-1.87848,-0.051884,1.56211,-1.92321,-0.048994,1.54055,-1.9935,0.133681,1.48356,-2.0607,0.030824,1.13119,-1.78516,-0.102798,1.16703,-1.79585,-0.126335,1.08916,-1.82269,-0.112813,0.957452,-1.82263,-0.231932,0.803196,-1.81107,-0.288684,0.755924,-1.81967,-0.304721,0.888162,-1.80319,-0.359757,0.840981,-1.80883,-0.506481,0.652068,-1.82573,-0.599754,0.741545,-1.85569,-0.521416,0.508164,-1.93282,-0.569319,0.487561,-1.85911,0.229027,1.22956,-2.11597,0.274342,1.15975,-2.09845,0.109505,1.14861,-2.10697,0.155592,1.0822,-2.09319,0.280782,0.997878,-2.09489,0.357346,0.822959,-2.08906,0.246613,0.804998,-2.11083,0.260547,0.736559,-2.10264,0.335307,0.507191,-2.07122,0.280265,0.405138,-2.00786,0.53962,0.515679,-2.0416,0.512856,0.449902,-2.09676,0.047247,1.36826,-1.83721,0.04859,1.39658,-2.05057},
/*188*/{0.19846,1.96011,-1.77007,0.231,1.89401,-1.92709,0.168849,1.81611,-1.6457,0.148229,1.6973,-1.55365,0.254758,1.7133,-1.67943,0.327171,1.71703,-1.73624,0.113903,1.96443,-2.13708,0.222044,1.89028,-1.99831,0.011517,1.93033,-2.01857,-0.128042,1.851,-2.15173,-0.156895,1.76454,-2.21457,-0.009301,1.63933,-2.18076,0.025364,1.58538,-2.20618,0.134935,1.44406,-1.80893,-0.049274,1.53235,-1.87687,-0.05208,1.56102,-1.92313,-0.048986,1.53832,-1.99366,0.134402,1.48349,-2.06008,0.035934,1.12926,-1.78774,-0.096747,1.16231,-1.79489,-0.119336,1.08481,-1.82266,-0.10387,0.953638,-1.82475,-0.229316,0.804472,-1.8122,-0.289649,0.759053,-1.82101,-0.29855,0.891897,-1.80181,-0.354966,0.847711,-1.80691,-0.509214,0.665027,-1.82446,-0.600625,0.758062,-1.85115,-0.53004,0.524174,-1.93337,-0.578394,0.502706,-1.85878,0.226112,1.22443,-2.11686,0.270814,1.15473,-2.09957,0.105935,1.14577,-2.10699,0.150524,1.07816,-2.09318,0.275025,0.993534,-2.09525,0.356909,0.820889,-2.08759,0.246858,0.800524,-2.11036,0.263193,0.732862,-2.10251,0.341325,0.504412,-2.07094,0.289762,0.403718,-2.0061,0.546823,0.516141,-2.03903,0.5209,0.450311,-2.09494,0.048292,1.36793,-1.83638,0.049556,1.39572,-2.04981},
/*189*/{0.198788,1.95857,-1.77036,0.230762,1.89355,-1.92735,0.167284,1.81565,-1.64626,0.147652,1.69661,-1.55371,0.252829,1.71012,-1.67959,0.325558,1.71321,-1.7373,0.114782,1.96336,-2.1375,0.22196,1.8896,-1.99873,0.011823,1.93025,-2.01902,-0.127169,1.85174,-2.15084,-0.156376,1.76332,-2.21414,-0.008122,1.63796,-2.18081,0.027224,1.58453,-2.20725,0.134979,1.44417,-1.80871,-0.049716,1.53103,-1.87733,-0.052142,1.56064,-1.92404,-0.048387,1.53659,-1.99429,0.135018,1.48284,-2.05949,0.042947,1.12751,-1.79079,-0.090173,1.15966,-1.79456,-0.112382,1.07998,-1.82268,-0.095298,0.949697,-1.82621,-0.225897,0.805848,-1.8131,-0.287977,0.763565,-1.82146,-0.290885,0.896237,-1.80068,-0.349421,0.854248,-1.80563,-0.513402,0.67842,-1.82263,-0.599529,0.7752,-1.84676,-0.537994,0.540485,-1.9327,-0.586051,0.519805,-1.85867,0.223464,1.22014,-2.11762,0.267861,1.14941,-2.10062,0.102192,1.14222,-2.10688,0.146831,1.07453,-2.09284,0.269996,0.989405,-2.09472,0.355867,0.819273,-2.08674,0.246162,0.796402,-2.10947,0.263216,0.729734,-2.10183,0.344788,0.50188,-2.06991,0.293956,0.400744,-2.00578,0.551259,0.516638,-2.03801,0.526045,0.45029,-2.09364,0.048693,1.36756,-1.83606,0.050737,1.39467,-2.04957},
/*190*/{0.198874,1.95766,-1.77091,0.231297,1.89312,-1.92778,0.165071,1.81449,-1.647,0.144837,1.69573,-1.5547,0.249851,1.70732,-1.68031,0.322725,1.70887,-1.73775,0.114929,1.96236,-2.13757,0.222211,1.88923,-1.99909,0.012638,1.9298,-2.01937,-0.127815,1.85077,-2.14858,-0.155082,1.76207,-2.21344,-0.007489,1.63682,-2.1815,0.028592,1.58276,-2.20736,0.135015,1.44417,-1.80869,-0.049445,1.52959,-1.87753,-0.051466,1.55912,-1.92421,-0.047925,1.53487,-1.99429,0.13592,1.48132,-2.05927,0.050117,1.12473,-1.79251,-0.083137,1.15399,-1.79408,-0.105233,1.07424,-1.82181,-0.085516,0.945288,-1.82811,-0.221194,0.808176,-1.81302,-0.286126,0.767822,-1.8212,-0.283105,0.900461,-1.80029,-0.343533,0.860725,-1.80508,-0.51355,0.692965,-1.82071,-0.597356,0.79261,-1.84502,-0.544706,0.555863,-1.93117,-0.594648,0.536647,-1.85741,0.221245,1.21549,-2.1188,0.264434,1.14415,-2.1019,0.099143,1.13937,-2.10546,0.142929,1.07119,-2.09212,0.265465,0.984928,-2.09493,0.354356,0.816504,-2.08566,0.244715,0.792902,-2.10801,0.262371,0.724909,-2.09985,0.348441,0.499439,-2.06918,0.298648,0.397083,-2.00412,0.553237,0.517107,-2.03788,0.529131,0.449657,-2.0929,0.049499,1.36682,-1.83542,0.051768,1.39302,-2.04905},
/*191*/{0.198963,1.95563,-1.77095,0.231027,1.89124,-1.92774,0.163146,1.81343,-1.64724,0.140684,1.69425,-1.55501,0.247734,1.70319,-1.6808,0.320823,1.70354,-1.7382,0.1159,1.96077,-2.13779,0.222338,1.88787,-1.99944,0.012834,1.92936,-2.02049,-0.125513,1.84962,-2.14923,-0.153955,1.75968,-2.21286,-0.006081,1.63452,-2.18191,0.029749,1.58138,-2.20797,0.135068,1.44381,-1.80862,-0.04992,1.52843,-1.87845,-0.049734,1.55668,-1.92581,-0.04796,1.53277,-1.99484,0.136228,1.48023,-2.05905,0.058437,1.12357,-1.79468,-0.077907,1.14698,-1.79329,-0.096794,1.06903,-1.82298,-0.076879,0.941211,-1.82922,-0.217261,0.810681,-1.81366,-0.284037,0.773143,-1.82087,-0.274925,0.905881,-1.80042,-0.336973,0.868809,-1.80412,-0.51555,0.707639,-1.81903,-0.59382,0.8106,-1.84362,-0.550245,0.571383,-1.92872,-0.602417,0.554411,-1.85673,0.219174,1.21073,-2.11992,0.262499,1.13864,-2.10295,0.096206,1.13676,-2.1057,0.139339,1.06822,-2.09168,0.260511,0.980168,-2.09448,0.350764,0.813719,-2.08556,0.241801,0.788745,-2.10627,0.260744,0.721257,-2.09787,0.348548,0.496303,-2.06764,0.301195,0.394038,-2.00352,0.554958,0.51602,-2.03721,0.529694,0.448655,-2.09183,0.050141,1.36593,-1.83528,0.052982,1.39121,-2.04901},
/*192*/{0.198025,1.95363,-1.77129,0.231606,1.89072,-1.92793,0.160557,1.81166,-1.6476,0.137237,1.69257,-1.55608,0.244702,1.69972,-1.68094,0.317631,1.69815,-1.73811,0.116513,1.95939,-2.13807,0.222081,1.88657,-1.99932,0.0137,1.92802,-2.02161,-0.124351,1.84615,-2.14887,-0.152352,1.7575,-2.2131,-0.003731,1.63258,-2.18234,0.032157,1.57892,-2.20903,0.135071,1.44275,-1.80855,-0.049329,1.52539,-1.87921,-0.050528,1.55446,-1.92672,-0.047817,1.53002,-1.99529,0.137363,1.47788,-2.05932,0.06418,1.11985,-1.7954,-0.071976,1.14118,-1.79317,-0.089791,1.06322,-1.82311,-0.067795,0.936671,-1.83045,-0.212469,0.812896,-1.81375,-0.279929,0.777097,-1.82143,-0.266354,0.910131,-1.80035,-0.329322,0.875665,-1.80353,-0.515515,0.721821,-1.8169,-0.588736,0.828541,-1.84356,-0.554742,0.586683,-1.9258,-0.608375,0.573522,-1.85436,0.217917,1.20643,-2.12043,0.25957,1.13415,-2.10439,0.094292,1.13406,-2.10491,0.136946,1.06519,-2.09154,0.256313,0.975939,-2.09448,0.347573,0.810322,-2.08522,0.238813,0.784197,-2.10389,0.258634,0.718044,-2.096,0.349946,0.494637,-2.06534,0.301165,0.389451,-2.00174,0.555114,0.514102,-2.03695,0.53024,0.446946,-2.09157,0.050894,1.36415,-1.83516,0.05419,1.38867,-2.04897},
/*193*/{0.197698,1.9508,-1.77098,0.231249,1.88872,-1.92804,0.158883,1.8096,-1.64785,0.132285,1.69027,-1.55745,0.241565,1.69541,-1.68172,0.315262,1.69212,-1.73804,0.117008,1.95744,-2.13841,0.222116,1.88474,-1.99958,0.013354,1.92687,-2.02222,-0.123157,1.8439,-2.14865,-0.151246,1.75414,-2.21312,-0.001592,1.62995,-2.18301,0.033992,1.57636,-2.20943,0.135536,1.44146,-1.8088,-0.048604,1.52344,-1.87945,-0.050768,1.55182,-1.92701,-0.046918,1.52777,-1.99648,0.137597,1.47538,-2.06,0.06991,1.11738,-1.79656,-0.06659,1.13627,-1.79287,-0.082144,1.05724,-1.8234,-0.058338,0.932319,-1.83104,-0.206992,0.815826,-1.81272,-0.275881,0.783029,-1.81917,-0.257037,0.915456,-1.80059,-0.321229,0.883166,-1.8038,-0.514163,0.736245,-1.81413,-0.582746,0.846189,-1.84342,-0.557767,0.601849,-1.92167,-0.613109,0.59206,-1.851,0.216277,1.20186,-2.1227,0.257331,1.12958,-2.10596,0.092494,1.13135,-2.1045,0.133901,1.06209,-2.09117,0.253342,0.971473,-2.09454,0.343834,0.807202,-2.08465,0.235294,0.780629,-2.10287,0.254917,0.713364,-2.09372,0.346888,0.491195,-2.06282,0.300802,0.386091,-1.99875,0.552964,0.510807,-2.03704,0.527702,0.444748,-2.09186,0.051648,1.36249,-1.8351,0.054735,1.38611,-2.04902},
/*194*/{0.197575,1.94904,-1.77114,0.230759,1.88654,-1.92792,0.15635,1.80725,-1.64792,0.128878,1.68737,-1.55804,0.238593,1.69071,-1.68182,0.312463,1.68563,-1.73775,0.117109,1.9554,-2.13846,0.22212,1.88239,-1.99937,0.013414,1.92567,-2.02326,-0.12243,1.84067,-2.1484,-0.150316,1.75068,-2.2133,0.000125,1.62675,-2.18413,0.03583,1.57326,-2.21055,0.135586,1.44028,-1.80888,-0.048684,1.52119,-1.8802,-0.050129,1.54887,-1.92806,-0.047495,1.52482,-1.99715,0.137908,1.47231,-2.06101,0.074656,1.1143,-1.79697,-0.06052,1.12929,-1.79218,-0.076097,1.05164,-1.82312,-0.050084,0.928879,-1.83186,-0.201373,0.818765,-1.81225,-0.272181,0.788535,-1.81823,-0.248275,0.920623,-1.80073,-0.313536,0.890242,-1.80314,-0.511769,0.752021,-1.81267,-0.575113,0.863531,-1.84452,-0.560009,0.616606,-1.91782,-0.616295,0.610577,-1.84789,0.215658,1.19726,-2.12379,0.255641,1.12545,-2.10719,0.09096,1.12919,-2.10414,0.131333,1.05887,-2.08964,0.249622,0.967033,-2.09437,0.340312,0.802888,-2.08355,0.231529,0.77634,-2.10096,0.252457,0.709764,-2.09133,0.344264,0.48809,-2.0608,0.297255,0.383197,-1.99585,0.54968,0.506854,-2.03648,0.524102,0.441051,-2.09159,0.052152,1.3608,-1.83482,0.055053,1.38289,-2.0489},
/*195*/{0.196571,1.94583,-1.7713,0.231087,1.88419,-1.92815,0.1538,1.80423,-1.64854,0.124559,1.68471,-1.55927,0.234996,1.68568,-1.682,0.309246,1.6789,-1.73723,0.117417,1.9529,-2.1386,0.222705,1.88048,-1.99935,0.014108,1.9231,-2.02391,-0.121534,1.83664,-2.14806,-0.148907,1.74653,-2.21439,0.001854,1.62327,-2.18542,0.038723,1.56995,-2.21148,0.136181,1.43841,-1.80943,-0.049031,1.5176,-1.88051,-0.049553,1.5469,-1.92851,-0.046872,1.52149,-1.99821,0.138792,1.47016,-2.0621,0.080093,1.11311,-1.79719,-0.055825,1.12474,-1.79265,-0.068441,1.04553,-1.82384,-0.040008,0.924523,-1.83233,-0.195568,0.820931,-1.81084,-0.265399,0.794027,-1.81642,-0.238908,0.925412,-1.80257,-0.304514,0.897577,-1.80316,-0.507021,0.766467,-1.81183,-0.566292,0.879941,-1.84616,-0.560263,0.631436,-1.91374,-0.618077,0.628153,-1.84418,0.214659,1.19343,-2.12503,0.253812,1.12086,-2.10898,0.08907,1.12668,-2.10344,0.12921,1.05658,-2.08916,0.248099,0.963256,-2.0933,0.336505,0.79918,-2.08391,0.227312,0.772543,-2.09967,0.248255,0.705843,-2.08991,0.339144,0.483537,-2.05831,0.2937,0.379584,-1.99011,0.546188,0.502778,-2.03677,0.519099,0.436437,-2.09129,0.053233,1.35836,-1.83548,0.056184,1.38045,-2.04956},
/*196*/{0.196307,1.94282,-1.77082,0.230569,1.88181,-1.92818,0.151424,1.80116,-1.64847,0.120124,1.68171,-1.56027,0.231369,1.68017,-1.68196,0.306425,1.6715,-1.73621,0.11677,1.94985,-2.13899,0.222673,1.87802,-1.99868,0.013226,1.92136,-2.02538,-0.119837,1.83295,-2.149,-0.147404,1.74225,-2.21535,0.003624,1.61896,-2.18656,0.04084,1.56588,-2.21212,0.136938,1.43611,-1.81015,-0.049932,1.5142,-1.88257,-0.049848,1.54277,-1.92919,-0.04712,1.51848,-1.99871,0.138868,1.46756,-2.06299,0.086609,1.10895,-1.79657,-0.050523,1.12196,-1.79419,-0.061022,1.03998,-1.82362,-0.032158,0.920557,-1.83231,-0.188583,0.82317,-1.81052,-0.260388,0.799123,-1.8154,-0.228486,0.927802,-1.8043,-0.29575,0.904098,-1.80279,-0.503281,0.779999,-1.81005,-0.55622,0.895178,-1.84679,-0.559641,0.645973,-1.909,-0.618222,0.647577,-1.83938,0.214043,1.18988,-2.12623,0.25256,1.11618,-2.11018,0.087838,1.12397,-2.10322,0.1271,1.05357,-2.08896,0.246144,0.959416,-2.09283,0.332915,0.79497,-2.0835,0.222916,0.768652,-2.09816,0.242979,0.701442,-2.08829,0.332531,0.478893,-2.05604,0.287412,0.377358,-1.98759,0.5403,0.496249,-2.03722,0.511989,0.429835,-2.08997,0.05399,1.35549,-1.83637,0.056887,1.3775,-2.05046},
/*197*/{0.195285,1.93965,-1.77004,0.231033,1.8788,-1.92736,0.148538,1.79778,-1.64848,0.115091,1.67824,-1.56106,0.227193,1.6744,-1.68167,0.302364,1.66433,-1.73622,0.11682,1.94678,-2.13931,0.222667,1.87527,-1.99866,0.012573,1.91835,-2.02606,-0.119476,1.82852,-2.1491,-0.145625,1.73694,-2.21598,0.005453,1.61506,-2.18779,0.043555,1.56241,-2.21375,0.137242,1.43372,-1.81038,-0.049565,1.51069,-1.8825,-0.049906,1.53963,-1.93033,-0.047733,1.51449,-1.99917,0.138928,1.46477,-2.06454,0.091321,1.10661,-1.79618,-0.045983,1.11624,-1.79375,-0.054992,1.03516,-1.82359,-0.023349,0.916533,-1.83187,-0.181629,0.82615,-1.80913,-0.254107,0.804534,-1.8139,-0.217569,0.93291,-1.80446,-0.284756,0.909562,-1.80303,-0.496605,0.794349,-1.80844,-0.546284,0.91043,-1.8495,-0.558367,0.659179,-1.90429,-0.616516,0.664832,-1.83528,0.213174,1.18659,-2.12782,0.250839,1.11272,-2.11116,0.086409,1.12302,-2.10255,0.12492,1.05124,-2.089,0.24502,0.956558,-2.09268,0.328925,0.789541,-2.08292,0.21845,0.764146,-2.0964,0.237983,0.697679,-2.08662,0.325983,0.473961,-2.05357,0.279935,0.372587,-1.98219,0.533031,0.48893,-2.03667,0.504419,0.421725,-2.08829,0.054926,1.35273,-1.83674,0.057189,1.37419,-2.05089},
/*198*/{0.193917,1.93588,-1.76944,0.231552,1.8764,-1.92748,0.146065,1.794,-1.64845,0.112161,1.67493,-1.56155,0.222779,1.66818,-1.68142,0.298896,1.65553,-1.73439,0.116863,1.94355,-2.13933,0.222829,1.87248,-1.99893,0.012543,1.91538,-2.02659,-0.119605,1.82364,-2.15129,-0.144466,1.73129,-2.21765,0.008198,1.61017,-2.18916,0.046053,1.55749,-2.21534,0.137133,1.43153,-1.8111,-0.04949,1.50714,-1.88327,-0.049558,1.53642,-1.93102,-0.048031,1.51021,-2.00027,0.139103,1.46186,-2.06547,0.096174,1.10335,-1.79501,-0.041227,1.10926,-1.79404,-0.049127,1.02996,-1.82601,-0.01417,0.9126,-1.83104,-0.174713,0.828181,-1.80767,-0.247505,0.808422,-1.8125,-0.206785,0.935932,-1.80547,-0.275329,0.915962,-1.8033,-0.4897,0.807914,-1.80587,-0.535958,0.924017,-1.85107,-0.554681,0.671815,-1.8995,-0.613628,0.681461,-1.83118,0.212003,1.18297,-2.12867,0.249546,1.10886,-2.11231,0.084789,1.12002,-2.10202,0.122818,1.04814,-2.08943,0.243353,0.953166,-2.0916,0.32454,0.784176,-2.08285,0.21372,0.760356,-2.09503,0.232501,0.693164,-2.08502,0.31785,0.468629,-2.05145,0.271654,0.367559,-1.97784,0.525658,0.481227,-2.03565,0.495459,0.413652,-2.0864,0.055667,1.34996,-1.83716,0.057795,1.37077,-2.05137},
/*199*/{0.192742,1.93201,-1.7687,0.231223,1.87257,-1.92715,0.143404,1.78957,-1.64795,0.105645,1.6713,-1.56271,0.218558,1.66158,-1.68109,0.295041,1.64737,-1.73327,0.116833,1.93975,-2.13951,0.222701,1.86982,-1.99892,0.012615,1.91135,-2.02775,-0.118279,1.81737,-2.15216,-0.142767,1.72534,-2.21861,0.010087,1.60487,-2.19111,0.04951,1.55249,-2.21628,0.136923,1.42859,-1.81274,-0.049419,1.5029,-1.88366,-0.051228,1.53227,-1.93224,-0.048031,1.50554,-2.00015,0.138751,1.45896,-2.06685,0.100872,1.10092,-1.79456,-0.036286,1.10397,-1.79542,-0.042303,1.02389,-1.82559,-0.006172,0.908964,-1.82914,-0.166518,0.830801,-1.80713,-0.240452,0.813216,-1.8103,-0.19532,0.939709,-1.80589,-0.264026,0.920713,-1.80449,-0.482656,0.819823,-1.80333,-0.524801,0.937296,-1.85299,-0.551288,0.683539,-1.89468,-0.609009,0.696515,-1.82704,0.211167,1.17924,-2.12875,0.247248,1.10474,-2.11331,0.083455,1.11667,-2.10172,0.121486,1.04568,-2.08909,0.241694,0.950103,-2.09141,0.319709,0.778804,-2.08276,0.208748,0.755825,-2.09383,0.226957,0.688552,-2.08319,0.308467,0.463121,-2.04872,0.26056,0.364309,-1.97578,0.516565,0.471921,-2.03368,0.48537,0.404295,-2.08429,0.056521,1.34638,-1.83817,0.057942,1.36726,-2.05239},
/*200*/{0.192019,1.92781,-1.76759,0.231822,1.86897,-1.92727,0.139864,1.78522,-1.64814,0.100642,1.66692,-1.56422,0.214336,1.65476,-1.68133,0.290629,1.63858,-1.73199,0.117199,1.93553,-2.13954,0.222376,1.86624,-1.99847,0.012319,1.90759,-2.02834,-0.11839,1.81102,-2.15499,-0.140989,1.71906,-2.21975,0.014243,1.59987,-2.19272,0.052099,1.54751,-2.21791,0.138549,1.42604,-1.81398,-0.049866,1.49858,-1.88413,-0.050519,1.52829,-1.93207,-0.049082,1.50205,-2.00109,0.13855,1.45572,-2.06803,0.105458,1.09784,-1.79303,-0.031312,1.09849,-1.79549,-0.035113,1.01856,-1.8255,0.00221,0.905346,-1.82748,-0.158541,0.832854,-1.80464,-0.23192,0.816037,-1.81009,-0.183897,0.942714,-1.80652,-0.253753,0.926313,-1.80469,-0.474586,0.833489,-1.80306,-0.513729,0.949355,-1.85601,-0.544341,0.695601,-1.8901,-0.60278,0.710864,-1.82247,0.208915,1.17626,-2.12969,0.246478,1.10115,-2.11402,0.082025,1.11312,-2.10129,0.119955,1.04178,-2.08882,0.239947,0.946359,-2.09134,0.31496,0.772097,-2.08275,0.203074,0.751437,-2.09317,0.219428,0.683922,-2.0818,0.298909,0.456994,-2.04699,0.248211,0.363025,-1.9736,0.506461,0.462314,-2.03229,0.47406,0.394421,-2.08144,0.058054,1.34317,-1.83892,0.058183,1.36382,-2.05317},
/*201*/{0.190695,1.92349,-1.76722,0.231811,1.86474,-1.92608,0.136923,1.78035,-1.64752,0.094605,1.66195,-1.5649,0.209787,1.64751,-1.68126,0.285938,1.62899,-1.73012,0.117349,1.93176,-2.13988,0.222072,1.86217,-1.9983,0.010957,1.90259,-2.02874,-0.117637,1.80396,-2.15671,-0.139116,1.71208,-2.22191,0.016961,1.59378,-2.19351,0.055382,1.54219,-2.21919,0.139129,1.42285,-1.81455,-0.050344,1.49351,-1.88484,-0.05067,1.5235,-1.93262,-0.04938,1.49662,-2.00073,0.137506,1.45193,-2.06937,0.109839,1.09508,-1.79121,-0.026427,1.096,-1.79797,-0.029331,1.01359,-1.82693,0.010971,0.902087,-1.82587,-0.150138,0.835239,-1.80255,-0.224332,0.821482,-1.80511,-0.172638,0.944961,-1.80916,-0.243034,0.930924,-1.80672,-0.465263,0.845229,-1.80298,-0.503453,0.959931,-1.85793,-0.537322,0.704944,-1.88589,-0.595605,0.723975,-1.81917,0.20851,1.17223,-2.1306,0.245286,1.09763,-2.11514,0.081088,1.10945,-2.10143,0.119947,1.03789,-2.08858,0.237501,0.941627,-2.09147,0.30996,0.765761,-2.0823,0.196992,0.747149,-2.09169,0.213169,0.678921,-2.08085,0.288271,0.451744,-2.04269,0.232548,0.358427,-1.96549,0.49602,0.452553,-2.03104,0.461808,0.384655,-2.07832,0.059277,1.33924,-1.83926,0.058306,1.35931,-2.05356},
/*202*/{0.189155,1.91888,-1.76614,0.230064,1.86056,-1.92562,0.133782,1.77543,-1.64816,0.088927,1.65798,-1.56678,0.204479,1.6399,-1.68012,0.281919,1.62044,-1.72843,0.117586,1.92765,-2.14027,0.222218,1.85829,-1.998,0.010872,1.89864,-2.03027,-0.11861,1.79665,-2.15781,-0.13692,1.70475,-2.22387,0.019904,1.58797,-2.19635,0.05888,1.53622,-2.2208,0.13918,1.41949,-1.8161,-0.050218,1.48858,-1.88512,-0.050707,1.51817,-1.93392,-0.050127,1.49202,-2.00096,0.137146,1.44868,-2.07076,0.114497,1.09233,-1.79,-0.022746,1.08938,-1.79939,-0.02162,1.00844,-1.82742,0.019903,0.899,-1.82345,-0.140978,0.836925,-1.80119,-0.215792,0.82489,-1.80276,-0.16077,0.947009,-1.81022,-0.231645,0.935076,-1.80787,-0.455206,0.855379,-1.80242,-0.491979,0.969708,-1.86039,-0.52939,0.714862,-1.88148,-0.586938,0.736828,-1.81396,0.206758,1.1678,-2.13136,0.244082,1.09321,-2.11601,0.079851,1.10541,-2.10089,0.118791,1.03384,-2.08859,0.235258,0.935987,-2.09135,0.302789,0.758475,-2.08231,0.19095,0.742282,-2.09099,0.205221,0.67428,-2.08042,0.277279,0.44485,-2.04312,0.222034,0.353712,-1.96651,0.484746,0.44215,-2.02826,0.449563,0.373998,-2.0755,0.060458,1.33511,-1.84047,0.058664,1.3554,-2.05474},
/*203*/{0.187994,1.9144,-1.76529,0.231036,1.85597,-1.92465,0.130454,1.77034,-1.64812,0.083636,1.65413,-1.56802,0.20008,1.63274,-1.67984,0.277988,1.61061,-1.72737,0.117459,1.92244,-2.14023,0.222168,1.85452,-1.9977,0.010103,1.89372,-2.03141,-0.11846,1.78876,-2.16073,-0.134714,1.69738,-2.22563,0.022557,1.5809,-2.19784,0.062786,1.52991,-2.22211,0.139202,1.41563,-1.81751,-0.050673,1.48396,-1.88449,-0.051605,1.51335,-1.9341,-0.050443,1.48629,-2.00055,0.136853,1.44571,-2.07214,0.118746,1.0889,-1.78703,-0.017773,1.08645,-1.80118,-0.016947,1.00308,-1.8267,0.028832,0.8961,-1.82113,-0.132626,0.83909,-1.7992,-0.207484,0.828689,-1.80306,-0.148938,0.949188,-1.81146,-0.219885,0.938455,-1.80947,-0.44546,0.865685,-1.80213,-0.481085,0.978692,-1.86291,-0.520807,0.7237,-1.87668,-0.577457,0.747872,-1.80989,0.205383,1.16332,-2.13172,0.242974,1.08929,-2.11696,0.078786,1.10094,-2.1005,0.11794,1.02856,-2.08773,0.233602,0.930016,-2.09138,0.297387,0.751156,-2.08236,0.184519,0.737478,-2.09062,0.197384,0.669004,-2.07956,0.265009,0.439438,-2.04244,0.207064,0.351479,-1.96537,0.472719,0.430565,-2.02489,0.435585,0.363121,-2.07238,0.061623,1.33075,-1.84135,0.058763,1.35155,-2.05556},
/*204*/{0.18667,1.90906,-1.76433,0.229679,1.85107,-1.92347,0.126547,1.76498,-1.64774,0.077449,1.65013,-1.56972,0.194254,1.62535,-1.67942,0.272529,1.60048,-1.72543,0.117626,1.91753,-2.14056,0.222812,1.85026,-1.99765,0.008715,1.8878,-2.03229,-0.115652,1.78055,-2.16374,-0.131939,1.68967,-2.22819,0.025865,1.574,-2.19939,0.067055,1.52342,-2.22366,0.140127,1.41215,-1.81877,-0.050342,1.47797,-1.88486,-0.051473,1.50827,-1.93437,-0.052312,1.48044,-2.00011,0.136178,1.44145,-2.07363,0.12264,1.08693,-1.78409,-0.014678,1.07889,-1.80149,-0.010959,0.99755,-1.82738,0.037265,0.89304,-1.81922,-0.122293,0.840594,-1.79626,-0.197285,0.832323,-1.80015,-0.136425,0.950558,-1.81243,-0.207729,0.942321,-1.81017,-0.434035,0.874684,-1.80163,-0.469954,0.986713,-1.86517,-0.510409,0.731174,-1.8726,-0.567185,0.756816,-1.80729,0.203871,1.15897,-2.13288,0.241727,1.08493,-2.11725,0.077547,1.09578,-2.1003,0.116731,1.02446,-2.08826,0.230886,0.9239,-2.09128,0.290678,0.744038,-2.08191,0.177231,0.732587,-2.09015,0.189443,0.663551,-2.07902,0.252646,0.435038,-2.04075,0.1882,0.356265,-1.96703,0.457588,0.417512,-2.02279,0.417085,0.352308,-2.06955,0.063405,1.3264,-1.8419,0.058735,1.34667,-2.05613},
/*205*/{0.184947,1.9038,-1.76334,0.230649,1.84542,-1.92281,0.123416,1.75964,-1.64814,0.071842,1.64634,-1.57135,0.189096,1.6172,-1.67911,0.26748,1.59013,-1.7232,0.118365,1.91267,-2.1413,0.222902,1.8448,-1.99718,0.008896,1.88211,-2.03363,-0.115645,1.7728,-2.16705,-0.129013,1.68151,-2.23017,0.031366,1.56712,-2.20114,0.070701,1.51674,-2.22552,0.140001,1.40811,-1.82037,-0.050098,1.47221,-1.88525,-0.051747,1.50206,-1.93472,-0.05287,1.47512,-2.00023,0.13583,1.43731,-2.0752,0.126959,1.0832,-1.7813,-0.009286,1.07218,-1.80191,-0.00455,0.991716,-1.82822,0.046023,0.890404,-1.81604,-0.112509,0.842027,-1.79374,-0.187181,0.834406,-1.79757,-0.123724,0.951583,-1.81408,-0.195613,0.94512,-1.81101,-0.421441,0.882187,-1.80037,-0.458001,0.993468,-1.86779,-0.500311,0.73821,-1.86887,-0.556357,0.766052,-1.80304,0.20209,1.15444,-2.13358,0.24078,1.08077,-2.11896,0.076084,1.09075,-2.10112,0.115305,1.01932,-2.08839,0.228134,0.9175,-2.09107,0.283965,0.736937,-2.08192,0.171098,0.727153,-2.08958,0.182477,0.657578,-2.07766,0.23923,0.429841,-2.04015,0.167747,0.35487,-1.96699,0.443837,0.401781,-2.01942,0.399367,0.340914,-2.06716,0.064647,1.32147,-1.84305,0.058973,1.34199,-2.05723},
/*206*/{0.18391,1.89942,-1.76232,0.232053,1.83955,-1.92236,0.119076,1.75468,-1.64785,0.065441,1.64165,-1.57175,0.18427,1.60868,-1.67802,0.261404,1.58012,-1.72168,0.118653,1.90758,-2.14164,0.22327,1.84045,-1.99694,0.008304,1.87525,-2.03416,-0.113426,1.76344,-2.16964,-0.125394,1.67268,-2.23259,0.034888,1.55949,-2.2031,0.075489,1.50931,-2.22701,0.140674,1.40395,-1.82147,-0.051236,1.46638,-1.88568,-0.052342,1.49676,-1.9355,-0.053476,1.46848,-1.99978,0.13591,1.43334,-2.07678,0.128951,1.07971,-1.78017,-0.005856,1.06621,-1.80245,0.002672,0.986123,-1.82784,0.056721,0.888298,-1.81398,-0.100861,0.843375,-1.79253,-0.176263,0.837737,-1.79531,-0.109871,0.953508,-1.81508,-0.181847,0.947702,-1.81264,-0.4109,0.888952,-1.80123,-0.446329,0.999364,-1.87011,-0.488505,0.74333,-1.86472,-0.544344,0.773554,-1.7994,0.199211,1.14853,-2.13488,0.239383,1.07441,-2.11859,0.07416,1.08562,-2.10157,0.113515,1.01416,-2.08815,0.224604,0.911535,-2.0912,0.277637,0.729971,-2.08077,0.163938,0.721876,-2.08941,0.173463,0.653,-2.07847,0.225188,0.425169,-2.0373,0.147363,0.356985,-1.96683,0.429315,0.38824,-2.00909,0.380368,0.340388,-2.06652,0.066034,1.3167,-1.84388,0.059517,1.33719,-2.05804},
/*207*/{0.18279,1.89304,-1.76129,0.231553,1.83378,-1.92106,0.116236,1.74873,-1.64794,0.059739,1.63758,-1.57333,0.178948,1.60119,-1.67766,0.256093,1.56979,-1.71925,0.119192,1.90209,-2.14206,0.223597,1.83475,-1.99589,0.007562,1.86971,-2.03593,-0.112013,1.75473,-2.17257,-0.121927,1.6641,-2.23549,0.038747,1.5535,-2.20589,0.080926,1.50236,-2.22861,0.140459,1.39891,-1.82249,-0.052299,1.46081,-1.8865,-0.052954,1.49034,-1.9362,-0.055193,1.46379,-2.00025,0.135118,1.42857,-2.07861,0.132363,1.0756,-1.77658,-0.000217,1.06078,-1.80364,0.009751,0.979422,-1.82803,0.066164,0.886915,-1.81117,-0.089843,0.844116,-1.7903,-0.163904,0.840365,-1.7944,-0.097291,0.95312,-1.81558,-0.169361,0.950083,-1.81452,-0.397629,0.894203,-1.80041,-0.434369,1.00401,-1.87195,-0.475139,0.74803,-1.86049,-0.531102,0.779859,-1.79662,0.196908,1.14382,-2.13699,0.236013,1.06929,-2.12052,0.070919,1.08021,-2.10124,0.11112,1.00902,-2.08846,0.220249,0.906393,-2.09198,0.270863,0.722658,-2.0785,0.157397,0.717371,-2.08909,0.164292,0.648241,-2.07768,0.207577,0.422769,-2.03047,0.124621,0.353646,-1.96586,0.407587,0.385522,-2.0044,0.357848,0.341239,-2.06716,0.065954,1.31135,-1.84527,0.058745,1.33227,-2.05936},
/*208*/{0.181141,1.8869,-1.76031,0.231133,1.82874,-1.91946,0.111462,1.74308,-1.64813,0.052295,1.63299,-1.57425,0.17319,1.5931,-1.67605,0.249801,1.55941,-1.71642,0.120332,1.89676,-2.14262,0.224398,1.82967,-1.99613,0.006797,1.86231,-2.03695,-0.109227,1.74475,-2.17575,-0.118016,1.6551,-2.23817,0.044493,1.54563,-2.20835,0.086288,1.49531,-2.23032,0.140129,1.3946,-1.82434,-0.052985,1.45436,-1.88556,-0.054424,1.48429,-1.93666,-0.05724,1.45794,-1.9996,0.134174,1.42376,-2.08062,0.137027,1.07217,-1.77471,0.005441,1.05604,-1.80432,0.01667,0.973083,-1.82833,0.07618,0.882667,-1.80943,-0.078025,0.844716,-1.78806,-0.153586,0.842473,-1.79288,-0.082148,0.95383,-1.81756,-0.154125,0.951264,-1.8132,-0.384108,0.900043,-1.79958,-0.422456,1.00744,-1.87421,-0.461446,0.752536,-1.85777,-0.51772,0.784769,-1.79327,0.193463,1.13808,-2.13976,0.231664,1.06421,-2.12402,0.067403,1.07737,-2.10257,0.106532,1.00567,-2.08859,0.214877,0.899885,-2.09324,0.264511,0.715104,-2.07392,0.151718,0.712977,-2.08844,0.156153,0.64461,-2.07566,0.187854,0.424517,-2.02496,0.101358,0.354534,-1.96257,0.38143,0.386402,-2.00752,0.332808,0.341767,-2.06671,0.06675,1.30619,-1.84619,0.057728,1.3271,-2.06021},
/*209*/{0.179337,1.88121,-1.75905,0.232528,1.82156,-1.91891,0.107234,1.73722,-1.64866,0.045916,1.63,-1.57546,0.167522,1.5853,-1.67543,0.243572,1.55023,-1.71404,0.121382,1.89156,-2.14394,0.225544,1.82365,-1.9947,0.006098,1.85702,-2.03808,-0.106206,1.73615,-2.17918,-0.112812,1.64605,-2.24138,0.049673,1.53781,-2.21065,0.092297,1.48804,-2.23178,0.139815,1.38948,-1.82462,-0.055071,1.44939,-1.88534,-0.05648,1.47799,-1.93641,-0.059411,1.45354,-2.00042,0.13232,1.41808,-2.082,0.141371,1.06808,-1.77261,0.009993,1.04963,-1.805,0.024845,0.96669,-1.82773,0.086938,0.880597,-1.80584,-0.065656,0.845252,-1.78597,-0.140469,0.844002,-1.7898,-0.068972,0.953603,-1.81747,-0.140686,0.952001,-1.81422,-0.370586,0.904086,-1.80076,-0.409507,1.0101,-1.87572,-0.448336,0.75548,-1.85402,-0.503426,0.788478,-1.79016,0.188752,1.13416,-2.14516,0.227057,1.05922,-2.12951,0.063169,1.07518,-2.10235,0.102371,1.00368,-2.08826,0.208162,0.893397,-2.09481,0.260163,0.709138,-2.06903,0.147543,0.711409,-2.08664,0.147459,0.64296,-2.07067,0.162037,0.425602,-2.01985,0.077332,0.354611,-1.96081,0.359353,0.382905,-2.00236,0.310017,0.340978,-2.066,0.065604,1.30107,-1.8466,0.05564,1.32169,-2.06061},
/*210*/{0.17767,1.87589,-1.75833,0.233136,1.81669,-1.91764,0.102904,1.73173,-1.64909,0.039122,1.62583,-1.57748,0.161209,1.57785,-1.67489,0.23778,1.54134,-1.7117,0.12223,1.88675,-2.14534,0.225815,1.81818,-1.99466,0.006505,1.8505,-2.03919,-0.104342,1.7266,-2.18338,-0.107127,1.63668,-2.24444,0.055622,1.52967,-2.21314,0.098634,1.48077,-2.2335,0.139668,1.38434,-1.82628,-0.057453,1.44335,-1.8857,-0.05835,1.47207,-1.9363,-0.062009,1.44887,-2.00108,0.129976,1.41421,-2.08231,0.146012,1.06625,-1.76981,0.016991,1.04229,-1.80403,0.03288,0.959946,-1.82667,0.097614,0.876751,-1.80339,-0.051971,0.844803,-1.7842,-0.127415,0.844636,-1.78831,-0.055612,0.952794,-1.81784,-0.126219,0.952183,-1.81385,-0.35866,0.906515,-1.79935,-0.397027,1.01226,-1.87753,-0.433727,0.75702,-1.85067,-0.489542,0.790905,-1.78719,0.183618,1.13069,-2.15097,0.222214,1.05536,-2.13501,0.06045,1.0736,-2.10084,0.098431,1.00164,-2.08773,0.201694,0.88958,-2.09516,0.25333,0.706946,-2.0647,0.141144,0.715599,-2.08382,0.137454,0.648005,-2.06801,0.141835,0.427397,-2.01808,0.055738,0.356028,-1.9578,0.336303,0.380536,-2.00332,0.286412,0.341806,-2.06458,0.064979,1.29563,-1.84818,0.05401,1.31747,-2.06203},
/*211*/{0.177203,1.87069,-1.75687,0.233775,1.81031,-1.91628,0.099466,1.72751,-1.64966,0.033235,1.62258,-1.57901,0.155103,1.57018,-1.67229,0.229768,1.53272,-1.70899,0.123817,1.88143,-2.14624,0.228125,1.81285,-1.9935,0.007222,1.8476,-2.03971,-0.099034,1.71732,-2.18699,-0.098869,1.62709,-2.2475,0.06209,1.52237,-2.21626,0.106014,1.47427,-2.23515,0.138923,1.37887,-1.82817,-0.05958,1.43712,-1.88658,-0.060671,1.46621,-1.93534,-0.064591,1.4443,-2.0007,0.12666,1.41056,-2.08352,0.150699,1.06258,-1.76882,0.020925,1.03344,-1.80436,0.04122,0.953781,-1.8271,0.110128,0.874004,-1.79974,-0.039223,0.843804,-1.78239,-0.114428,0.843966,-1.78746,-0.040788,0.951026,-1.81721,-0.111629,0.952463,-1.81469,-0.34317,0.906687,-1.79934,-0.383622,1.01247,-1.87885,-0.41854,0.757299,-1.8473,-0.473489,0.792463,-1.7839,0.181067,1.1272,-2.15429,0.218445,1.05208,-2.13772,0.057544,1.07273,-2.10052,0.095897,1.00056,-2.087,0.198238,0.888576,-2.09612,0.243547,0.706446,-2.0636,0.132698,0.720568,-2.08258,0.125664,0.652656,-2.06742,0.127357,0.430661,-2.01509,0.034158,0.357932,-1.95783,0.315269,0.382108,-1.9991,0.263952,0.34236,-2.06347,0.064145,1.28985,-1.85026,0.05149,1.3135,-2.06382},
/*212*/{0.176099,1.86558,-1.75526,0.233657,1.80412,-1.91464,0.095137,1.72272,-1.64983,0.026268,1.6198,-1.58049,0.148475,1.56443,-1.67103,0.223004,1.5251,-1.70573,0.125437,1.87711,-2.14808,0.228424,1.80693,-1.9929,0.00828,1.84695,-2.04025,-0.092749,1.70808,-2.19288,-0.099559,1.61901,-2.25031,0.06958,1.51574,-2.21874,0.114032,1.46797,-2.23649,0.137098,1.3743,-1.83077,-0.061821,1.43302,-1.88544,-0.063115,1.46138,-1.9356,-0.068458,1.44065,-2.00121,0.124309,1.40813,-2.08496,0.15521,1.06032,-1.76731,0.026918,1.02722,-1.80428,0.049779,0.948155,-1.82642,0.123155,0.870506,-1.79649,-0.02519,0.842319,-1.78134,-0.101002,0.842717,-1.78654,-0.02574,0.949559,-1.81661,-0.098171,0.951344,-1.81397,-0.328943,0.908431,-1.79895,-0.371082,1.01151,-1.87947,-0.402986,0.757149,-1.84493,-0.458258,0.792856,-1.78158,0.176959,1.12533,-2.15551,0.216189,1.05096,-2.13788,0.055137,1.07021,-2.10064,0.094105,0.998868,-2.08625,0.19825,0.88861,-2.09668,0.233506,0.705167,-2.06413,0.122941,0.726082,-2.08115,0.112029,0.65725,-2.06763,0.103505,0.429467,-2.01383,0.01151,0.359249,-1.95683,0.293907,0.38009,-2.00069,0.242232,0.342458,-2.06223,0.062652,1.28529,-1.85246,0.048602,1.3107,-2.06573},
/*213*/{0.17501,1.86097,-1.75379,0.234402,1.80018,-1.91385,0.091145,1.71793,-1.65012,0.018059,1.61727,-1.58189,0.142655,1.55818,-1.67044,0.214838,1.51869,-1.70331,0.1275,1.87297,-2.14936,0.229627,1.80296,-1.99178,0.009047,1.84404,-2.03995,-0.087045,1.69884,-2.19805,-0.086555,1.60805,-2.25357,0.078131,1.50887,-2.22063,0.121861,1.46162,-2.23762,0.135451,1.36947,-1.83132,-0.063955,1.42873,-1.88528,-0.065327,1.4584,-1.93557,-0.070483,1.43745,-1.99959,0.122101,1.40555,-2.08603,0.161124,1.06127,-1.76551,0.03256,1.02464,-1.80456,0.059161,0.944748,-1.82575,0.134696,0.866663,-1.79387,-0.011905,0.839811,-1.78223,-0.087085,0.841194,-1.78581,-0.011797,0.948624,-1.81485,-0.083079,0.949489,-1.81223,-0.313354,0.906598,-1.79828,-0.359115,1.01004,-1.88008,-0.38662,0.755045,-1.84225,-0.441866,0.790456,-1.77921,0.173427,1.12433,-2.15465,0.21262,1.04999,-2.13843,0.05242,1.06714,-2.10003,0.091569,0.996979,-2.08631,0.200463,0.888173,-2.09612,0.22189,0.704681,-2.06687,0.111164,0.728834,-2.08095,0.099176,0.660828,-2.06799,0.087196,0.430844,-2.0132,-0.009717,0.359824,-1.95792,0.272796,0.379489,-1.99946,0.220332,0.341956,-2.06261,0.060706,1.28082,-1.85379,0.045989,1.3081,-2.06678},
/*214*/{0.174461,1.85669,-1.75244,0.235122,1.79595,-1.91244,0.086497,1.71415,-1.64981,0.010663,1.61512,-1.58268,0.135517,1.55396,-1.66918,0.207683,1.51309,-1.70067,0.129761,1.8689,-2.15009,0.230508,1.79806,-1.98994,0.009551,1.84321,-2.04069,-0.080107,1.68968,-2.20326,-0.077763,1.59892,-2.25641,0.086798,1.50324,-2.22155,0.131686,1.4569,-2.23814,0.133795,1.36557,-1.83228,-0.065386,1.42487,-1.88369,-0.066001,1.45731,-1.93444,-0.073077,1.43512,-1.99734,0.12031,1.40432,-2.08783,0.165298,1.06556,-1.76855,0.040808,1.02201,-1.80257,0.069183,0.942652,-1.82292,0.147963,0.865018,-1.79268,0.001871,0.837973,-1.78187,-0.073129,0.838185,-1.78731,0.002455,0.947337,-1.81321,-0.069028,0.948714,-1.81263,-0.304282,0.908953,-1.80099,-0.34856,1.00737,-1.8811,-0.369312,0.752074,-1.83979,-0.425462,0.78649,-1.77889,0.170171,1.1231,-2.1546,0.208488,1.04894,-2.13972,0.049004,1.06354,-2.09889,0.088803,0.994896,-2.08676,0.20247,0.888546,-2.09509,0.209269,0.703365,-2.07176,0.099651,0.72917,-2.08253,0.085675,0.661593,-2.06758,0.064589,0.43251,-2.01333,-0.031735,0.361395,-1.95424,0.251996,0.378109,-2.00031,0.198186,0.341064,-2.06247,0.059401,1.27715,-1.85531,0.043132,1.30689,-2.06786},
/*215*/{0.17434,1.8529,-1.75063,0.235397,1.79328,-1.91117,0.081824,1.71226,-1.65075,0.003604,1.61448,-1.58404,0.128142,1.5511,-1.66841,0.200147,1.50754,-1.69879,0.131525,1.86548,-2.14963,0.230926,1.79553,-1.98954,0.009607,1.84063,-2.04073,-0.075742,1.6823,-2.20904,-0.068469,1.59069,-2.25862,0.096107,1.4991,-2.22221,0.141839,1.45326,-2.23886,0.131699,1.36197,-1.83385,-0.067317,1.42218,-1.88242,-0.067377,1.4563,-1.93377,-0.074275,1.43382,-1.99552,0.118648,1.40293,-2.08943,0.173058,1.06658,-1.76566,0.049656,1.02049,-1.80022,0.07857,0.941956,-1.82115,0.162721,0.866257,-1.79375,0.016249,0.836612,-1.78097,-0.059433,0.838363,-1.78677,0.015642,0.946222,-1.81129,-0.055566,0.946894,-1.8094,-0.287288,0.903335,-1.79889,-0.337887,1.00329,-1.8806,-0.35118,0.74757,-1.83947,-0.407237,0.780471,-1.77606,0.165698,1.12106,-2.15562,0.204389,1.04577,-2.1408,0.044788,1.06222,-2.09864,0.084752,0.990281,-2.08528,0.201953,0.888753,-2.0938,0.196011,0.698613,-2.07352,0.086742,0.728643,-2.08421,0.070937,0.661961,-2.06877,0.044278,0.432434,-2.01425,-0.053236,0.362709,-1.9557,0.229482,0.377217,-1.99985,0.17682,0.341272,-2.06243,0.057367,1.2739,-1.85691,0.040142,1.30594,-2.06905},
/*216*/{0.173541,1.8492,-1.74951,0.234834,1.79096,-1.90997,0.076695,1.71164,-1.65107,-0.005079,1.61515,-1.58647,0.120526,1.54871,-1.66703,0.193149,1.50376,-1.69614,0.13353,1.86321,-2.14929,0.231153,1.79253,-1.98797,0.01042,1.83957,-2.04134,-0.069079,1.67683,-2.21393,-0.059624,1.58374,-2.26089,0.105931,1.49599,-2.22258,0.152992,1.45113,-2.23889,0.130538,1.35877,-1.83357,-0.068613,1.42098,-1.88101,-0.069148,1.45568,-1.93411,-0.075391,1.43249,-1.99382,0.117105,1.40183,-2.09111,0.180061,1.06922,-1.76593,0.055242,1.01863,-1.79996,0.090063,0.941821,-1.81862,0.176725,0.86752,-1.79363,0.029375,0.835906,-1.78114,-0.045137,0.835486,-1.78776,0.028894,0.945847,-1.80908,-0.042974,0.946456,-1.80875,-0.273314,0.899913,-1.79941,-0.329493,0.997993,-1.87969,-0.332711,0.742213,-1.83914,-0.388421,0.773424,-1.77408,0.160562,1.11788,-2.15629,0.198281,1.0424,-2.14171,0.040363,1.06134,-2.09812,0.079326,0.98844,-2.08549,0.194531,0.886684,-2.09508,0.182802,0.696123,-2.07572,0.073648,0.726939,-2.08515,0.057617,0.66083,-2.0691,0.023619,0.432756,-2.01514,-0.07438,0.362935,-1.95603,0.208763,0.376595,-2.00091,0.153992,0.340789,-2.06319,0.055533,1.27166,-1.85759,0.037633,1.30492,-2.06948},
/*217*/{0.1726,1.84627,-1.74903,0.233637,1.78783,-1.90881,0.071252,1.71188,-1.65136,-0.013871,1.61657,-1.58898,0.113494,1.54727,-1.6667,0.186519,1.50095,-1.6932,0.135572,1.86107,-2.14856,0.231555,1.79033,-1.9871,0.011611,1.83744,-2.04141,-0.062943,1.67071,-2.21655,-0.049993,1.57834,-2.26259,0.116281,1.49358,-2.22225,0.164142,1.45009,-2.23841,0.127954,1.35565,-1.83368,-0.070653,1.42067,-1.88031,-0.06952,1.45445,-1.93376,-0.076043,1.43264,-1.99212,0.115063,1.40161,-2.09247,0.186326,1.07375,-1.7668,0.064521,1.01877,-1.79726,0.10113,0.943024,-1.817,0.191355,0.870302,-1.79343,0.042255,0.835846,-1.78081,-0.032799,0.835886,-1.78809,0.04103,0.945907,-1.80691,-0.030993,0.945786,-1.80748,-0.258909,0.893384,-1.79995,-0.321575,0.991167,-1.87897,-0.313607,0.735695,-1.83831,-0.368736,0.764233,-1.77246,0.155512,1.11428,-2.15732,0.191945,1.03837,-2.143,0.033359,1.05971,-2.09829,0.072786,0.987123,-2.0856,0.184645,0.881352,-2.09622,0.169615,0.690321,-2.07599,0.061021,0.725162,-2.08714,0.043291,0.659629,-2.07025,0.00253,0.433264,-2.0162,-0.0971,0.362994,-1.95609,0.186267,0.37678,-2.00101,0.132188,0.340391,-2.06369,0.052834,1.26938,-1.85886,0.034827,1.30492,-2.07038},
/*218*/{0.172977,1.84463,-1.74822,0.232717,1.78545,-1.9069,0.066434,1.7123,-1.65201,-0.020257,1.61964,-1.59113,0.105952,1.54705,-1.66604,0.178767,1.49861,-1.69146,0.138023,1.8595,-2.14763,0.231374,1.78842,-1.986,0.012249,1.83622,-2.04225,-0.056852,1.66583,-2.21721,-0.041402,1.57422,-2.2636,0.126878,1.49228,-2.22109,0.175283,1.45001,-2.2377,0.127012,1.35311,-1.83298,-0.070772,1.42069,-1.87967,-0.071208,1.4538,-1.93372,-0.076898,1.43241,-1.99132,0.114596,1.4006,-2.09302,0.194098,1.07943,-1.76655,0.074364,1.01948,-1.79439,0.111631,0.943981,-1.81515,0.205562,0.874462,-1.79246,0.055958,0.836637,-1.78073,-0.01898,0.834443,-1.78824,0.052402,0.946111,-1.80482,-0.019887,0.945485,-1.80584,-0.245073,0.888483,-1.80078,-0.31327,0.983701,-1.87843,-0.292823,0.728641,-1.83819,-0.347883,0.754443,-1.77125,0.149704,1.11147,-2.1582,0.184694,1.03451,-2.14398,0.027045,1.06056,-2.09971,0.065109,0.985077,-2.08608,0.173542,0.876831,-2.09801,0.155485,0.685979,-2.07628,0.048967,0.723419,-2.08867,0.027658,0.656073,-2.0705,-0.018169,0.434001,-2.01836,-0.118263,0.363914,-1.95712,0.164926,0.376557,-2.00252,0.110779,0.34008,-2.06476,0.05108,1.26789,-1.85903,0.033211,1.30424,-2.07042},
/*219*/{0.171982,1.84336,-1.74754,0.232677,1.78428,-1.90648,0.061039,1.71383,-1.65237,-0.026761,1.62296,-1.59325,0.099594,1.54733,-1.66471,0.170221,1.4984,-1.68906,0.140375,1.85828,-2.14692,0.231897,1.78738,-1.98444,0.012953,1.83608,-2.04306,-0.050645,1.66219,-2.21766,-0.032905,1.57073,-2.26481,0.137463,1.49204,-2.22053,0.187112,1.45116,-2.23605,0.124744,1.35176,-1.83242,-0.070859,1.42064,-1.87962,-0.07137,1.45301,-1.93347,-0.076989,1.43245,-1.99118,0.114339,1.39969,-2.0938,0.201726,1.08418,-1.76633,0.083381,1.0209,-1.79284,0.122923,0.946417,-1.81355,0.219354,0.878373,-1.79339,0.069689,0.837174,-1.78109,-0.004171,0.832847,-1.79037,0.063624,0.947276,-1.80278,-0.008007,0.943037,-1.80288,-0.231767,0.88192,-1.80177,-0.306273,0.974779,-1.8772,-0.271325,0.720673,-1.83885,-0.326141,0.743967,-1.76942,0.14502,1.10767,-2.15937,0.178752,1.03043,-2.14438,0.020554,1.0605,-2.1004,0.055498,0.982859,-2.08678,0.161125,0.873222,-2.09973,0.140943,0.681258,-2.0763,0.035728,0.72075,-2.08886,0.012773,0.654892,-2.07144,-0.038255,0.43468,-2.01984,-0.140511,0.364953,-1.96039,0.141939,0.373859,-2.00375,0.088394,0.33907,-2.06543,0.0494,1.26683,-1.85915,0.032183,1.30367,-2.07051},
/*220*/{0.170745,1.84279,-1.74713,0.231015,1.78271,-1.90457,0.055154,1.71591,-1.6528,-0.034897,1.6275,-1.59579,0.092096,1.54843,-1.66372,0.163286,1.49852,-1.68681,0.142527,1.85803,-2.14667,0.231643,1.78635,-1.98382,0.013559,1.83563,-2.04324,-0.043172,1.66013,-2.21789,-0.024635,1.56792,-2.2658,0.148629,1.49391,-2.21916,0.198114,1.45419,-2.23425,0.124165,1.35093,-1.83066,-0.071257,1.42067,-1.88002,-0.072795,1.4534,-1.9343,-0.077233,1.43293,-1.99138,0.115034,1.3994,-2.09374,0.209274,1.0897,-1.76591,0.092954,1.02297,-1.79153,0.13469,0.949656,-1.81192,0.232833,0.884024,-1.79318,0.083247,0.836983,-1.78154,0.009169,0.832296,-1.79025,0.074709,0.948651,-1.80121,0.003654,0.942583,-1.80126,-0.218062,0.874955,-1.80188,-0.299069,0.964202,-1.87625,-0.250964,0.712026,-1.8399,-0.303947,0.732567,-1.76838,0.13848,1.10444,-2.15908,0.169853,1.02586,-2.14533,0.013495,1.05841,-2.10036,0.046415,0.982208,-2.08829,0.148275,0.869072,-2.10036,0.125236,0.676857,-2.07601,0.021329,0.719704,-2.09067,-0.002013,0.654595,-2.0728,-0.057983,0.43541,-2.0204,-0.161404,0.365679,-1.96106,0.121526,0.375823,-2.00449,0.068866,0.339164,-2.06603,0.048092,1.26662,-1.85886,0.032265,1.30361,-2.0703},
/*221*/{0.169016,1.84339,-1.74634,0.231595,1.78261,-1.90387,0.05058,1.71845,-1.65342,-0.042823,1.63145,-1.5976,0.085539,1.55057,-1.66338,0.15666,1.49927,-1.68496,0.145683,1.85746,-2.14528,0.232126,1.78612,-1.98152,0.014604,1.83582,-2.04389,-0.037781,1.65816,-2.21818,-0.016347,1.56595,-2.26674,0.157786,1.49506,-2.21688,0.209105,1.4582,-2.23181,0.121776,1.35106,-1.82869,-0.072184,1.42037,-1.88047,-0.072902,1.4535,-1.93444,-0.077563,1.4333,-1.99248,0.113183,1.39868,-2.09446,0.216158,1.0967,-1.76628,0.101294,1.02556,-1.79036,0.146425,0.954111,-1.81044,0.246151,0.889812,-1.79314,0.097124,0.838373,-1.78277,0.022249,0.830113,-1.79098,0.084227,0.949647,-1.79988,0.011797,0.941661,-1.80066,-0.204977,0.867246,-1.80439,-0.292028,0.952475,-1.87594,-0.22879,0.704093,-1.83934,-0.281211,0.721937,-1.76747,0.13253,1.10214,-2.15892,0.161219,1.02197,-2.14555,0.00557,1.05829,-2.1018,0.036612,0.981912,-2.08959,0.134802,0.864692,-2.10073,0.109758,0.671632,-2.07605,0.006846,0.716465,-2.09034,-0.018696,0.653532,-2.07382,-0.081086,0.435315,-2.02113,-0.183007,0.368205,-1.95968,0.099514,0.375168,-2.00578,0.045347,0.338422,-2.06698,0.04613,1.26668,-1.8583,0.031127,1.30298,-2.06992},
/*222*/{0.166856,1.84394,-1.74498,0.229972,1.78386,-1.90126,0.044042,1.72233,-1.65411,-0.049188,1.6358,-1.59989,0.078354,1.5529,-1.66173,0.148662,1.5014,-1.6828,0.147922,1.85781,-2.14486,0.232553,1.78673,-1.9803,0.015779,1.83589,-2.04498,-0.03288,1.65652,-2.21798,-0.00769,1.56432,-2.26709,0.168354,1.49971,-2.21514,0.220603,1.46338,-2.22843,0.121031,1.35167,-1.82752,-0.072504,1.4208,-1.88145,-0.072704,1.45341,-1.93474,-0.077018,1.4335,-1.9934,0.114044,1.39864,-2.09407,0.221803,1.10349,-1.76552,0.109389,1.02846,-1.78933,0.156533,0.958297,-1.8091,0.258947,0.895612,-1.79329,0.110313,0.840564,-1.78339,0.037508,0.828999,-1.79165,0.093547,0.950779,-1.79808,0.023035,0.939883,-1.79889,-0.191905,0.859821,-1.80529,-0.284002,0.939477,-1.87602,-0.207157,0.694775,-1.83972,-0.258817,0.710171,-1.76676,0.125902,1.09957,-2.1587,0.153642,1.01872,-2.14535,-0.001955,1.05887,-2.10279,0.026742,0.981644,-2.09113,0.120845,0.859639,-2.10087,0.093421,0.668041,-2.07585,-0.008773,0.714235,-2.09079,-0.035224,0.65124,-2.07404,-0.102198,0.437317,-2.02119,-0.203112,0.368661,-1.95938,0.078296,0.374876,-2.00558,0.024118,0.339603,-2.06787,0.045713,1.26713,-1.85778,0.032109,1.30291,-2.06959},
/*223*/{0.163955,1.84658,-1.74453,0.230868,1.78424,-1.9008,0.038906,1.72615,-1.65439,-0.056348,1.64068,-1.60165,0.07196,1.55666,-1.66113,0.141467,1.5046,-1.68113,0.150073,1.85913,-2.14442,0.232742,1.78749,-1.97864,0.016797,1.83682,-2.04636,-0.026813,1.65488,-2.21775,0.000621,1.56324,-2.2679,0.177281,1.50352,-2.21273,0.230832,1.46937,-2.2249,0.119774,1.35316,-1.82629,-0.073457,1.42131,-1.88243,-0.072955,1.45427,-1.93601,-0.077262,1.43414,-1.99418,0.114432,1.39838,-2.09371,0.228253,1.10994,-1.7661,0.120697,1.03358,-1.78757,0.166516,0.964428,-1.80863,0.270611,0.902828,-1.79391,0.124458,0.842587,-1.784,0.051016,0.828969,-1.79281,0.10291,0.952277,-1.79638,0.03139,0.938601,-1.79758,-0.178377,0.849979,-1.80571,-0.276021,0.925726,-1.8765,-0.185073,0.685383,-1.83993,-0.235952,0.698252,-1.76644,0.12002,1.09705,-2.15825,0.143904,1.01491,-2.14484,-0.010364,1.05985,-2.10375,0.016803,0.982068,-2.09147,0.105051,0.854455,-2.10047,0.076798,0.665677,-2.07379,-0.025292,0.713101,-2.09037,-0.051253,0.648983,-2.07451,-0.121496,0.438705,-2.02198,-0.225601,0.368265,-1.96155,0.056463,0.374868,-2.0058,0.002175,0.339714,-2.06801,0.044663,1.26832,-1.85692,0.03251,1.30283,-2.06902},
/*224*/{0.161306,1.84882,-1.74353,0.229428,1.78601,-1.89855,0.033642,1.73034,-1.65537,-0.062909,1.64501,-1.60309,0.065314,1.56095,-1.66117,0.134634,1.50802,-1.67984,0.152904,1.86093,-2.143,0.232549,1.78883,-1.97662,0.017652,1.83696,-2.04668,-0.021086,1.65387,-2.2171,0.008791,1.56335,-2.26843,0.186778,1.50911,-2.2101,0.240798,1.47692,-2.2212,0.118613,1.35507,-1.82566,-0.073316,1.4224,-1.88336,-0.072573,1.45493,-1.93663,-0.076668,1.4349,-1.99587,0.114432,1.39819,-2.09376,0.235203,1.11781,-1.76461,0.129454,1.03854,-1.78678,0.175711,0.969134,-1.80833,0.282121,0.910587,-1.79356,0.137153,0.844219,-1.7849,0.063296,0.827979,-1.79301,0.111246,0.953353,-1.79471,0.040536,0.936556,-1.79688,-0.164501,0.839085,-1.80564,-0.267326,0.909476,-1.87678,-0.162536,0.676671,-1.84006,-0.213847,0.686218,-1.76678,0.113056,1.09485,-2.15748,0.134562,1.01254,-2.14436,-0.01826,1.06128,-2.10397,0.006173,0.982329,-2.09161,0.090047,0.850537,-2.1004,0.060598,0.664149,-2.07255,-0.040595,0.713031,-2.08987,-0.067982,0.649998,-2.07401,-0.144109,0.439481,-2.02177,-0.246745,0.370375,-1.96308,0.035018,0.374936,-2.00671,-0.019026,0.339411,-2.06823,0.044163,1.26977,-1.85625,0.032944,1.30279,-2.06864},
/*225*/{0.15771,1.85119,-1.74316,0.228989,1.78822,-1.89637,0.02764,1.73476,-1.65526,-0.070624,1.65002,-1.60497,0.0586,1.56557,-1.66155,0.127583,1.51273,-1.67928,0.154573,1.86312,-2.14188,0.23365,1.79109,-1.975,0.018133,1.83724,-2.04726,-0.016241,1.65286,-2.21669,0.016351,1.56379,-2.26909,0.195158,1.51499,-2.20681,0.250753,1.48471,-2.21655,0.119704,1.35714,-1.82493,-0.073457,1.42238,-1.8852,-0.072469,1.45499,-1.93709,-0.076271,1.43562,-1.99752,0.116202,1.39732,-2.09322,0.241024,1.12491,-1.76478,0.136475,1.04226,-1.78665,0.182983,0.973746,-1.80852,0.293839,0.919738,-1.79425,0.15045,0.845649,-1.78598,0.077569,0.826659,-1.794,0.118759,0.954614,-1.79335,0.049309,0.93457,-1.79627,-0.15325,0.829942,-1.80874,-0.257982,0.894123,-1.87856,-0.139776,0.666856,-1.83972,-0.191348,0.674299,-1.76629,0.106853,1.09328,-2.15665,0.125637,1.01002,-2.14345,-0.025879,1.06272,-2.104,-0.003748,0.983423,-2.0918,0.074502,0.84878,-2.0993,0.042332,0.663589,-2.07203,-0.057021,0.713943,-2.08906,-0.085296,0.650525,-2.07356,-0.193864,0.432279,-2.02065,-0.266991,0.371958,-1.96386,0.013999,0.374824,-2.00642,-0.040668,0.339408,-2.06909,0.044923,1.27111,-1.85536,0.034797,1.30232,-2.06808},
/*226*/{0.155229,1.85453,-1.74221,0.229194,1.79073,-1.89508,0.023413,1.73914,-1.65644,-0.077233,1.65501,-1.60687,0.05217,1.5706,-1.66159,0.121565,1.51727,-1.67817,0.156357,1.86554,-2.14064,0.233127,1.79286,-1.97288,0.019631,1.83834,-2.04832,-0.011611,1.65276,-2.21663,0.023746,1.56516,-2.27007,0.202401,1.52101,-2.20319,0.260482,1.49327,-2.21182,0.119533,1.35989,-1.82471,-0.072927,1.42385,-1.88684,-0.072155,1.45632,-1.93903,-0.074775,1.43657,-1.99799,0.117059,1.39695,-2.09355,0.245977,1.1328,-1.76481,0.142502,1.04662,-1.78645,0.192417,0.981474,-1.80875,0.303295,0.927458,-1.79471,0.162978,0.849066,-1.78586,0.090824,0.825896,-1.79444,0.126854,0.954598,-1.79304,0.057307,0.932029,-1.79544,-0.13705,0.817259,-1.8075,-0.248081,0.877534,-1.87967,-0.117329,0.656768,-1.83957,-0.169424,0.662412,-1.76633,0.100131,1.09226,-2.15537,0.117395,1.0082,-2.14128,-0.033474,1.0656,-2.10441,-0.015096,0.98516,-2.09235,0.058274,0.849211,-2.09859,0.025008,0.663482,-2.07125,-0.074102,0.715814,-2.08785,-0.102997,0.652391,-2.0729,-0.244482,0.427486,-2.01896,-0.287783,0.376903,-1.96264,-0.008222,0.374381,-2.00669,-0.063554,0.339322,-2.06839,0.045164,1.2733,-1.85455,0.035869,1.3023,-2.06762},
/*227*/{0.151202,1.85724,-1.74174,0.22878,1.79344,-1.89262,0.017776,1.74371,-1.65723,-0.08363,1.66066,-1.60955,0.045996,1.57643,-1.66209,0.11547,1.52259,-1.6775,0.157932,1.86877,-2.13949,0.233748,1.79627,-1.9708,0.020359,1.84042,-2.04982,-0.005506,1.65313,-2.21649,0.031844,1.56644,-2.27034,0.211264,1.52927,-2.20016,0.268936,1.50269,-2.20731,0.119135,1.3629,-1.82397,-0.072364,1.42583,-1.88799,-0.070636,1.45814,-1.94038,-0.074519,1.43811,-1.9999,0.117877,1.39698,-2.09349,0.249163,1.13987,-1.76513,0.148205,1.05119,-1.7878,0.200413,0.987405,-1.80903,0.313191,0.93681,-1.79498,0.175229,0.850892,-1.78649,0.104822,0.824603,-1.79538,0.134263,0.954884,-1.79196,0.065337,0.929558,-1.7953,-0.123765,0.806191,-1.80909,-0.236989,0.859464,-1.88156,-0.09478,0.647644,-1.83903,-0.14805,0.649863,-1.76602,0.093242,1.09095,-2.15367,0.107969,1.00662,-2.13913,-0.041919,1.06881,-2.10445,-0.024681,0.988385,-2.09312,0.043075,0.850498,-2.09724,0.007137,0.664538,-2.0707,-0.09171,0.717807,-2.08712,-0.121111,0.655679,-2.07212,-0.264962,0.430419,-2.01894,-0.310036,0.378881,-1.96427,-0.029131,0.375078,-2.00668,-0.084635,0.338914,-2.06817,0.045048,1.27592,-1.85359,0.036806,1.30268,-2.06699},
/*228*/{0.148174,1.86096,-1.74115,0.228517,1.79785,-1.89053,0.014181,1.74857,-1.6577,-0.090235,1.66554,-1.61153,0.040646,1.58258,-1.66233,0.109303,1.52813,-1.67683,0.160317,1.87252,-2.13831,0.234124,1.79944,-1.96913,0.021156,1.84135,-2.04958,-0.000767,1.6541,-2.21654,0.039451,1.56888,-2.27087,0.217682,1.53615,-2.19675,0.277818,1.5129,-2.20222,0.120697,1.36687,-1.82429,-0.071876,1.42835,-1.88963,-0.069345,1.46003,-1.94095,-0.072683,1.44043,-2.00112,0.118848,1.39716,-2.09362,0.253398,1.14772,-1.76498,0.155352,1.05664,-1.78722,0.209293,0.994335,-1.80945,0.321984,0.94658,-1.79466,0.187266,0.852937,-1.78683,0.117686,0.823185,-1.79598,0.140162,0.954749,-1.79185,0.075209,0.925634,-1.79468,-0.11036,0.794924,-1.81093,-0.224928,0.84144,-1.88332,-0.071364,0.638112,-1.83894,-0.125914,0.637266,-1.76676,0.086144,1.08975,-2.15227,0.098503,1.0056,-2.1367,-0.049985,1.07138,-2.10464,-0.034435,0.989686,-2.09303,0.027571,0.851888,-2.09572,-0.010166,0.666537,-2.06989,-0.109353,0.720746,-2.08598,-0.139198,0.657709,-2.07117,-0.226067,0.449221,-2.02253,-0.330084,0.383249,-1.96352,-0.05012,0.375069,-2.0066,-0.105696,0.339741,-2.06801,0.046264,1.27923,-1.85271,0.038125,1.30349,-2.06642},
/*229*/{0.144699,1.86459,-1.74101,0.227666,1.79968,-1.88862,0.008788,1.75346,-1.65834,-0.096628,1.67139,-1.61348,0.035178,1.58845,-1.66347,0.103638,1.53417,-1.67603,0.160927,1.8765,-2.13695,0.235039,1.80329,-1.96758,0.022297,1.84369,-2.05023,0.005549,1.65479,-2.21642,0.047249,1.57149,-2.27129,0.225232,1.54565,-2.19298,0.284847,1.5228,-2.19706,0.121189,1.3702,-1.82457,-0.070931,1.43066,-1.8911,-0.068309,1.46257,-1.94255,-0.071299,1.44204,-2.00243,0.119806,1.39702,-2.09376,0.255482,1.15542,-1.76501,0.159698,1.06135,-1.78909,0.215664,1.00032,-1.81031,0.330246,0.956527,-1.79531,0.197828,0.854754,-1.78655,0.130495,0.822029,-1.7956,0.146404,0.954552,-1.79146,0.083088,0.922373,-1.79542,-0.095119,0.781606,-1.81116,-0.212249,0.823206,-1.88535,-0.047891,0.628478,-1.8383,-0.103553,0.625203,-1.76604,0.080466,1.08938,-2.14975,0.089432,1.00487,-2.13398,-0.056435,1.07548,-2.1048,-0.044544,0.992003,-2.09316,0.012702,0.853857,-2.09402,-0.027498,0.668518,-2.06824,-0.125983,0.72398,-2.08449,-0.157657,0.663723,-2.06921,-0.24994,0.451527,-2.02078,-0.350193,0.38877,-1.96574,-0.071805,0.374949,-2.00609,-0.127917,0.339835,-2.06791,0.046667,1.28221,-1.85194,0.039064,1.30397,-2.06594},
/*230*/{0.141757,1.86852,-1.74034,0.228357,1.80542,-1.88727,0.004734,1.75819,-1.65888,-0.101186,1.67716,-1.61585,0.029683,1.595,-1.6644,0.097851,1.53992,-1.67583,0.161734,1.88071,-2.1358,0.236909,1.80656,-1.9645,0.0237,1.84549,-2.05042,0.0113,1.65624,-2.21691,0.054439,1.57507,-2.27203,0.231766,1.55396,-2.18896,0.291979,1.53378,-2.19262,0.12305,1.37396,-1.82444,-0.06913,1.43343,-1.89168,-0.065996,1.46406,-1.94337,-0.069186,1.44479,-2.0037,0.121279,1.39736,-2.09383,0.260623,1.16194,-1.76475,0.164949,1.06681,-1.78872,0.221816,1.00784,-1.81092,0.338355,0.9664,-1.79494,0.20913,0.857299,-1.78631,0.143732,0.821138,-1.7956,0.153388,0.953867,-1.79147,0.089936,0.918125,-1.79649,-0.080144,0.770217,-1.81068,-0.199265,0.804158,-1.88737,-0.024427,0.619642,-1.83718,-0.080803,0.613262,-1.76661,0.074265,1.08927,-2.14702,0.080586,1.00498,-2.13114,-0.064792,1.07913,-2.10533,-0.055366,0.997709,-2.09226,-0.001185,0.855627,-2.09149,-0.044925,0.671676,-2.06686,-0.14296,0.727723,-2.08344,-0.175439,0.666899,-2.06906,-0.266718,0.457358,-2.02174,-0.37014,0.39503,-1.96458,-0.09322,0.375111,-2.00573,-0.148188,0.340037,-2.06798,0.048396,1.28548,-1.85095,0.040851,1.3049,-2.06517},
/*231*/{0.138463,1.87289,-1.73982,0.227447,1.80853,-1.88453,0.000919,1.76335,-1.6603,-0.106837,1.68323,-1.61773,0.024944,1.60109,-1.66531,0.092951,1.54655,-1.67612,0.163921,1.88527,-2.13476,0.238023,1.81081,-1.96248,0.02434,1.84847,-2.05109,0.015807,1.65879,-2.21824,0.061907,1.57835,-2.27196,0.237689,1.56287,-2.18444,0.298473,1.5445,-2.18672,0.123902,1.3779,-1.8248,-0.068492,1.43708,-1.89276,-0.064591,1.46749,-1.94552,-0.067184,1.44768,-2.00493,0.123383,1.39774,-2.09415,0.262854,1.16859,-1.76483,0.168646,1.07229,-1.79033,0.227924,1.01298,-1.81207,0.34447,0.976194,-1.79525,0.220609,0.860429,-1.78556,0.155818,0.819401,-1.79581,0.158336,0.953882,-1.79164,0.098813,0.914187,-1.79827,-0.066121,0.759063,-1.81125,-0.185891,0.785182,-1.89077,-0.000884,0.611014,-1.83711,-0.056839,0.602409,-1.76696,0.068083,1.08992,-2.1448,0.072208,1.00512,-2.12825,-0.071111,1.08357,-2.1046,-0.064758,1.00151,-2.09142,-0.014165,0.857601,-2.08825,-0.062064,0.674814,-2.06586,-0.159071,0.732194,-2.08217,-0.193262,0.671449,-2.0674,-0.284813,0.461989,-2.02174,-0.389226,0.401881,-1.96505,-0.115126,0.375241,-2.00582,-0.170488,0.34018,-2.0673,0.048759,1.28936,-1.8502,0.042113,1.30626,-2.06467},
/*232*/{0.135515,1.87676,-1.73962,0.22631,1.81372,-1.88334,-0.001953,1.76868,-1.66083,-0.111784,1.68986,-1.62053,0.019192,1.60784,-1.66609,0.088169,1.55256,-1.67539,0.165886,1.88994,-2.13304,0.237693,1.81508,-1.96104,0.025292,1.85165,-2.05109,0.020735,1.66216,-2.22012,0.069057,1.58222,-2.27238,0.242256,1.572,-2.1809,0.304094,1.55614,-2.18153,0.125969,1.38068,-1.82565,-0.066544,1.44066,-1.89432,-0.062709,1.4699,-1.94706,-0.064961,1.45044,-2.00582,0.125343,1.39729,-2.09411,0.267261,1.17604,-1.76454,0.173699,1.07548,-1.78968,0.233618,1.02056,-1.81199,0.350572,0.983829,-1.79606,0.229859,0.861409,-1.78493,0.167394,0.818173,-1.79536,0.164303,0.951652,-1.79126,0.105396,0.909859,-1.79933,-0.050668,0.746428,-1.81332,-0.171047,0.765582,-1.89243,0.02355,0.602609,-1.83712,-0.032888,0.590302,-1.7672,0.062724,1.09041,-2.14147,0.064531,1.00601,-2.12478,-0.077012,1.08863,-2.10457,-0.074044,1.00684,-2.09112,-0.027564,0.860934,-2.08604,-0.079298,0.678899,-2.0648,-0.17561,0.736909,-2.0812,-0.209287,0.67763,-2.06721,-0.304007,0.46624,-2.02207,-0.408037,0.409723,-1.96559,-0.136297,0.375753,-2.00532,-0.192868,0.341349,-2.06795,0.049725,1.29244,-1.84962,0.043276,1.30698,-2.06426},
/*233*/{0.133213,1.88069,-1.73941,0.22694,1.81931,-1.88145,-0.005614,1.7737,-1.66143,-0.116796,1.69603,-1.62283,0.01521,1.61395,-1.66719,0.083198,1.55857,-1.67602,0.167144,1.89544,-2.13162,0.237847,1.81967,-1.95857,0.026927,1.85401,-2.05204,0.025431,1.66716,-2.22353,0.076149,1.5869,-2.27294,0.247453,1.58029,-2.17578,0.308933,1.56687,-2.1769,0.127585,1.3849,-1.82614,-0.064558,1.4452,-1.89467,-0.060428,1.47328,-1.94714,-0.061816,1.45303,-2.00658,0.127166,1.39741,-2.09439,0.269163,1.18308,-1.76443,0.179401,1.0835,-1.79003,0.237781,1.02616,-1.81282,0.355564,0.993362,-1.79532,0.239852,0.862828,-1.78526,0.179863,0.816867,-1.79513,0.169231,0.950997,-1.79596,0.113334,0.905161,-1.80024,-0.035197,0.734956,-1.81504,-0.155412,0.746112,-1.8936,0.047768,0.594201,-1.83661,-0.007934,0.57945,-1.76732,0.057483,1.09165,-2.13885,0.05595,1.00733,-2.12128,-0.082887,1.09423,-2.10428,-0.082701,1.01246,-2.09077,-0.040323,0.865017,-2.08378,-0.095357,0.684045,-2.06368,-0.191004,0.742237,-2.08014,-0.225349,0.682555,-2.06644,-0.31778,0.473611,-2.02282,-0.427424,0.418482,-1.96528,-0.158514,0.375561,-2.00551,-0.213972,0.340663,-2.06707,0.051149,1.29662,-1.84817,0.044451,1.30819,-2.06299},
/*234*/{0.130985,1.88486,-1.73919,0.22618,1.82319,-1.88018,-0.009852,1.77913,-1.66297,-0.12109,1.70198,-1.6249,0.011125,1.61976,-1.66822,0.079198,1.56463,-1.67598,0.168724,1.90023,-2.1303,0.23799,1.82464,-1.95726,0.02831,1.85751,-2.05307,0.029766,1.67142,-2.22584,0.08334,1.59173,-2.27359,0.252339,1.58966,-2.17177,0.313214,1.57756,-2.17191,0.130001,1.3883,-1.82664,-0.062761,1.44937,-1.89441,-0.058354,1.47677,-1.94971,-0.058517,1.4559,-2.00726,0.129074,1.39742,-2.09429,0.271443,1.18966,-1.76451,0.182353,1.08989,-1.78989,0.242002,1.03296,-1.81303,0.359115,1.00103,-1.79562,0.249332,0.864304,-1.78499,0.191875,0.816047,-1.79525,0.173899,0.949148,-1.7957,0.120872,0.900392,-1.80166,-0.019012,0.721579,-1.81538,-0.1386,0.725366,-1.89496,0.072782,0.587404,-1.83694,0.016729,0.56922,-1.76699,0.052875,1.09295,-2.13608,0.048195,1.00869,-2.1179,-0.088588,1.09996,-2.10396,-0.090985,1.01774,-2.09008,-0.054448,0.87016,-2.08223,-0.110726,0.689396,-2.06343,-0.206124,0.748957,-2.07946,-0.241195,0.690474,-2.06634,-0.338957,0.478005,-2.02268,-0.445058,0.426418,-1.96354,-0.178734,0.375941,-2.00479,-0.23629,0.341515,-2.06583,0.052388,1.3005,-1.84712,0.045762,1.30933,-2.06207},
/*235*/{0.129085,1.88847,-1.73934,0.22586,1.82898,-1.87847,-0.012785,1.78455,-1.66392,-0.125472,1.70909,-1.62778,0.006839,1.62569,-1.66952,0.075957,1.57055,-1.67591,0.171426,1.90542,-2.12871,0.238201,1.82895,-1.95513,0.029261,1.86072,-2.0537,0.034416,1.67806,-2.22885,0.09097,1.59581,-2.27345,0.255454,1.5976,-2.16756,0.318088,1.5874,-2.16725,0.131493,1.39163,-1.82728,-0.059412,1.45337,-1.8947,-0.055535,1.48025,-1.95051,-0.055848,1.45983,-2.00775,0.131588,1.39739,-2.09422,0.273488,1.19675,-1.76425,0.184278,1.0932,-1.79053,0.246076,1.0398,-1.8126,0.362419,1.00886,-1.7955,0.258253,0.86599,-1.78456,0.204352,0.814064,-1.79517,0.179746,0.946132,-1.79821,0.128491,0.895652,-1.80368,-0.000798,0.71071,-1.81593,-0.122157,0.70545,-1.89578,0.09746,0.579851,-1.83659,0.042988,0.558908,-1.76694,0.047207,1.09425,-2.13343,0.040276,1.01029,-2.11461,-0.094089,1.10584,-2.10326,-0.098955,1.02374,-2.089,-0.068403,0.875871,-2.08145,-0.127198,0.694835,-2.06263,-0.22099,0.756153,-2.07882,-0.258116,0.694567,-2.06483,-0.361004,0.483766,-2.02262,-0.461924,0.435968,-1.96336,-0.201285,0.375775,-2.00287,-0.254188,0.341533,-2.06436,0.053503,1.3041,-1.84626,0.046913,1.3109,-2.06129},
/*236*/{0.126923,1.89273,-1.73937,0.225744,1.83347,-1.8769,-0.015903,1.78948,-1.66569,-0.128394,1.7149,-1.62993,0.0038,1.63138,-1.66973,0.07221,1.57639,-1.67657,0.172294,1.91118,-2.12718,0.238809,1.83414,-1.95353,0.0306,1.86469,-2.05453,0.039469,1.68236,-2.23073,0.09141,1.60104,-2.27567,0.260159,1.60754,-2.16351,0.321909,1.59758,-2.16188,0.133596,1.39538,-1.82853,-0.05731,1.45826,-1.89453,-0.053751,1.48402,-1.95293,-0.052404,1.46248,-2.00855,0.133601,1.39728,-2.0939,0.275341,1.20286,-1.76445,0.187345,1.09929,-1.79089,0.250251,1.04599,-1.81258,0.364032,1.01534,-1.79593,0.267064,0.866551,-1.78476,0.214778,0.811788,-1.79464,0.184305,0.942908,-1.79996,0.136813,0.890348,-1.80497,0.015447,0.69555,-1.81684,-0.10291,0.685167,-1.89776,0.122148,0.573677,-1.8375,0.069658,0.549257,-1.76736,0.041996,1.09588,-2.13045,0.032442,1.01275,-2.1115,-0.099299,1.11174,-2.10295,-0.106565,1.03024,-2.08853,-0.082209,0.88171,-2.08095,-0.142264,0.701245,-2.06248,-0.235333,0.763166,-2.0779,-0.272833,0.703139,-2.06586,-0.377259,0.489633,-2.02315,-0.479557,0.448978,-1.96381,-0.224228,0.376279,-2.00301,-0.27955,0.343111,-2.06521,0.054716,1.30843,-1.84511,0.048034,1.31207,-2.06021},
/*237*/{0.125661,1.89602,-1.73911,0.226048,1.83664,-1.87542,-0.017656,1.7946,-1.66661,-0.128579,1.72169,-1.6326,0.000844,1.63686,-1.67123,0.069437,1.58192,-1.67666,0.174095,1.91558,-2.12516,0.239511,1.83927,-1.95116,0.031779,1.86778,-2.0547,0.045479,1.68762,-2.23336,0.103537,1.60643,-2.27442,0.262775,1.61582,-2.15955,0.324488,1.6076,-2.15686,0.135677,1.40002,-1.8286,-0.054681,1.46361,-1.89528,-0.050407,1.48738,-1.95401,-0.049681,1.46686,-2.00896,0.135697,1.39754,-2.09375,0.27753,1.20875,-1.76481,0.189712,1.1062,-1.78964,0.251775,1.05157,-1.81173,0.365267,1.02069,-1.79652,0.275063,0.86708,-1.78402,0.226621,0.809839,-1.79445,0.189742,0.939114,-1.80092,0.143561,0.883391,-1.8061,0.034038,0.682906,-1.81757,-0.084449,0.665146,-1.89774,0.147893,0.567721,-1.83753,0.096355,0.540215,-1.76833,0.03789,1.09754,-2.12792,0.025672,1.01491,-2.10853,-0.103213,1.11937,-2.10218,-0.113783,1.03773,-2.08822,-0.095525,0.887528,-2.08032,-0.156495,0.708303,-2.06289,-0.249732,0.771269,-2.07749,-0.286543,0.710934,-2.06595,-0.38494,0.499175,-2.02467,-0.493082,0.459051,-1.96292,-0.245519,0.3761,-2.00306,-0.30132,0.343952,-2.065,0.056093,1.31336,-1.84363,0.049269,1.31387,-2.05875},
/*238*/{0.1245,1.89987,-1.73894,0.224982,1.84118,-1.87411,-0.020214,1.80033,-1.66835,-0.133943,1.72607,-1.63554,-0.002299,1.64215,-1.67223,0.066703,1.587,-1.67645,0.176093,1.92087,-2.12389,0.238953,1.84307,-1.95018,0.034401,1.87084,-2.05477,0.051425,1.69265,-2.23582,0.110007,1.61139,-2.2755,0.265031,1.623,-2.15504,0.327275,1.61722,-2.15274,0.137574,1.40391,-1.82913,-0.052891,1.46885,-1.89512,-0.048073,1.49204,-1.95578,-0.04638,1.47002,-2.00949,0.138639,1.39757,-2.09341,0.279989,1.2146,-1.76448,0.191914,1.11256,-1.78759,0.252867,1.0568,-1.81125,0.365666,1.02619,-1.7968,0.283252,0.867463,-1.78392,0.238041,0.807093,-1.79402,0.194983,0.933943,-1.8039,0.151302,0.876871,-1.80828,0.052875,0.670666,-1.81735,-0.064565,0.645372,-1.89802,0.173404,0.560816,-1.83804,0.12331,0.531532,-1.76897,0.033603,1.09956,-2.12573,0.017941,1.01769,-2.10609,-0.107498,1.12553,-2.10135,-0.120204,1.04529,-2.08698,-0.107159,0.894227,-2.07971,-0.170036,0.715999,-2.06327,-0.263955,0.779263,-2.07732,-0.300971,0.719472,-2.06431,-0.39799,0.505038,-2.02562,-0.509361,0.472804,-1.96391,-0.26745,0.377345,-2.00304,-0.32359,0.344754,-2.06431,0.057012,1.318,-1.84224,0.050535,1.31559,-2.05737},
/*239*/{0.124135,1.90332,-1.73867,0.225812,1.84602,-1.87267,-0.022352,1.80497,-1.67021,-0.136985,1.731,-1.6381,-0.004806,1.64664,-1.67274,0.064472,1.59163,-1.6763,0.178255,1.92518,-2.12239,0.23986,1.8475,-1.9481,0.035679,1.87379,-2.05525,0.057348,1.6976,-2.23844,0.115864,1.61668,-2.27623,0.266909,1.63061,-2.15168,0.329866,1.62611,-2.14863,0.139512,1.40761,-1.8304,-0.049845,1.47381,-1.89611,-0.045062,1.49529,-1.95722,-0.043289,1.47326,-2.00947,0.1405,1.39765,-2.09265,0.281477,1.22005,-1.76449,0.195409,1.11773,-1.78577,0.254504,1.06284,-1.80995,0.366586,1.03116,-1.79699,0.291501,0.866876,-1.78396,0.248586,0.804771,-1.79421,0.199303,0.929876,-1.80531,0.159187,0.870033,-1.80963,0.073972,0.658459,-1.81853,-0.043807,0.625839,-1.89957,0.198393,0.556375,-1.83907,0.150127,0.522868,-1.76949,0.028776,1.1017,-2.1234,0.010776,1.02062,-2.10358,-0.11062,1.13304,-2.1011,-0.126828,1.05301,-2.08682,-0.118637,0.901568,-2.07883,-0.182709,0.723985,-2.06412,-0.276741,0.787635,-2.07678,-0.312807,0.726801,-2.06439,-0.415626,0.513347,-2.0276,-0.520762,0.486032,-1.96203,-0.289785,0.377316,-2.00272,-0.346165,0.345956,-2.06437,0.058434,1.3223,-1.84112,0.051625,1.31702,-2.05619},
/*240*/{0.123004,1.90654,-1.73843,0.22534,1.84933,-1.87183,-0.023814,1.80992,-1.67152,-0.139956,1.73474,-1.64058,-0.006318,1.65193,-1.67439,0.062482,1.59587,-1.67563,0.179861,1.92931,-2.12077,0.239723,1.85151,-1.94696,0.037568,1.8776,-2.05632,0.062646,1.70226,-2.24023,0.120942,1.62202,-2.27644,0.268638,1.63788,-2.1485,0.331478,1.63402,-2.14513,0.140064,1.4112,-1.82979,-0.047326,1.4788,-1.89586,-0.042279,1.49921,-1.95819,-0.039811,1.47692,-2.01037,0.142967,1.39828,-2.09182,0.283777,1.22461,-1.76422,0.194144,1.12221,-1.78601,0.254363,1.06667,-1.8093,0.365406,1.0351,-1.79745,0.298783,0.866558,-1.78358,0.25964,0.802556,-1.79405,0.20418,0.924283,-1.80646,0.166521,0.862172,-1.81035,0.092211,0.645308,-1.81845,-0.02268,0.606643,-1.89889,0.223903,0.551383,-1.83833,0.177663,0.514101,-1.7699,0.025387,1.10419,-2.12192,0.004242,1.02384,-2.10132,-0.11342,1.13976,-2.10078,-0.132641,1.06081,-2.08548,-0.129115,0.909471,-2.07918,-0.194996,0.732246,-2.06543,-0.289215,0.794771,-2.07698,-0.325786,0.734997,-2.06492,-0.425777,0.520833,-2.02964,-0.532364,0.500869,-1.96138,-0.310753,0.378266,-2.00413,-0.367967,0.347701,-2.06414,0.058689,1.32649,-1.83973,0.052921,1.31912,-2.05477},
/*241*/{0.122473,1.90913,-1.7383,0.218492,1.8563,-1.87242,-0.025951,1.81408,-1.67332,-0.140928,1.73932,-1.64345,-0.008124,1.65544,-1.67422,0.062088,1.59948,-1.67527,0.181247,1.93321,-2.11916,0.239856,1.85619,-1.94532,0.039041,1.88083,-2.0571,0.068071,1.70706,-2.24172,0.126597,1.62689,-2.27783,0.270865,1.64442,-2.14569,0.333762,1.64089,-2.13635,0.14181,1.41549,-1.8302,-0.04433,1.4838,-1.89573,-0.038931,1.5029,-1.9591,-0.037774,1.48068,-2.01141,0.145707,1.3986,-2.09104,0.28528,1.22929,-1.76455,0.195488,1.12742,-1.78338,0.254578,1.07096,-1.8075,0.363784,1.03837,-1.79792,0.30591,0.865161,-1.78367,0.269625,0.799285,-1.7934,0.208226,0.918077,-1.80765,0.174982,0.854502,-1.81154,0.110821,0.631126,-1.81876,-0.001248,0.588194,-1.8979,0.248454,0.545821,-1.84016,0.205119,0.506622,-1.77072,0.02193,1.10637,-2.12057,-0.001954,1.02613,-2.09978,-0.115501,1.14713,-2.09956,-0.1379,1.06814,-2.0842,-0.138775,0.917533,-2.07934,-0.20494,0.741222,-2.06664,-0.30005,0.803002,-2.07662,-0.335711,0.743203,-2.06508,-0.436543,0.528422,-2.03096,-0.541742,0.515975,-1.96172,-0.33184,0.378031,-2.00489,-0.39004,0.350068,-2.06365,0.060056,1.33124,-1.83832,0.054282,1.32103,-2.05324},
/*242*/{0.121862,1.91199,-1.73837,0.21885,1.85926,-1.8712,-0.026931,1.81774,-1.67458,-0.144259,1.743,-1.64564,-0.009449,1.65903,-1.67507,0.06,1.60265,-1.67418,0.183929,1.93715,-2.11778,0.240459,1.85941,-1.94433,0.040939,1.88348,-2.05766,0.072683,1.71156,-2.24295,0.131608,1.63174,-2.27865,0.271612,1.65036,-2.1439,0.335291,1.64738,-2.13462,0.144102,1.41894,-1.83014,-0.041732,1.4885,-1.89608,-0.036292,1.50696,-1.95977,-0.033661,1.48388,-2.01143,0.147678,1.3993,-2.08979,0.285457,1.23237,-1.76492,0.196594,1.13175,-1.78203,0.254149,1.0746,-1.80553,0.361915,1.04078,-1.79803,0.312587,0.863972,-1.78349,0.279012,0.794983,-1.7934,0.21269,0.911679,-1.8089,0.181801,0.846437,-1.81383,0.131348,0.619455,-1.81894,0.021101,0.569969,-1.89738,0.272783,0.541667,-1.84147,0.231771,0.499495,-1.77272,0.018229,1.10869,-2.11938,-0.008948,1.0321,-2.09975,-0.117737,1.15345,-2.09919,-0.141674,1.0756,-2.08421,-0.147989,0.925349,-2.07964,-0.215195,0.749376,-2.06804,-0.309541,0.811544,-2.07741,-0.345698,0.750449,-2.06512,-0.444764,0.535082,-2.03161,-0.550464,0.532337,-1.96298,-0.349298,0.378595,-2.0061,-0.411109,0.353899,-2.06385,0.061381,1.33548,-1.8369,0.055741,1.32302,-2.0517},
/*243*/{0.121992,1.91406,-1.73817,0.22544,1.86042,-1.86864,-0.027482,1.82136,-1.67623,-0.144957,1.74568,-1.64793,-0.011087,1.66181,-1.67542,0.059827,1.60583,-1.67382,0.185711,1.94036,-2.11604,0.241977,1.86185,-1.94257,0.043661,1.88638,-2.05794,0.076977,1.71646,-2.24461,0.13576,1.63598,-2.27952,0.273795,1.65576,-2.14103,0.336469,1.65418,-2.13011,0.14436,1.42193,-1.83084,-0.039346,1.49266,-1.89604,-0.033992,1.51074,-1.96168,-0.03066,1.48684,-2.01159,0.14987,1.40011,-2.0884,0.287205,1.23572,-1.76515,0.195317,1.13574,-1.77951,0.252638,1.0781,-1.80359,0.360169,1.04191,-1.7979,0.318401,0.86143,-1.78353,0.289482,0.791796,-1.79273,0.217161,0.904105,-1.80941,0.188685,0.837601,-1.81139,0.150348,0.607738,-1.81882,0.043492,0.553032,-1.89776,0.296903,0.538643,-1.84109,0.259173,0.492622,-1.7729,0.015052,1.11177,-2.11889,-0.01386,1.03441,-2.09867,-0.119489,1.15997,-2.09882,-0.144715,1.08233,-2.08315,-0.156529,0.933294,-2.08026,-0.223839,0.757799,-2.06964,-0.318211,0.819897,-2.07749,-0.354172,0.759064,-2.06595,-0.456176,0.54341,-2.0343,-0.556249,0.548307,-1.96166,-0.367237,0.377911,-2.0069,-0.433442,0.358055,-2.06311,0.061555,1.33915,-1.83606,0.056832,1.32502,-2.05077},
/*244*/{0.121541,1.91635,-1.738,0.226907,1.86082,-1.86758,-0.028557,1.82383,-1.67755,-0.145952,1.74793,-1.64941,-0.011402,1.66441,-1.67541,0.058881,1.60801,-1.67265,0.187875,1.94344,-2.115,0.243436,1.86447,-1.94109,0.044642,1.88912,-2.05869,0.081286,1.72024,-2.24583,0.140179,1.63967,-2.2802,0.27445,1.66056,-2.13946,0.337093,1.65974,-2.12784,0.145026,1.42482,-1.83155,-0.037341,1.49665,-1.89715,-0.032576,1.51439,-1.96229,-0.028697,1.49015,-2.01238,0.151163,1.40101,-2.08759,0.287361,1.23814,-1.76606,0.192949,1.13937,-1.77842,0.250578,1.08027,-1.8023,0.357717,1.0418,-1.79787,0.325097,0.858825,-1.78248,0.298385,0.787388,-1.79203,0.221546,0.896703,-1.80991,0.197859,0.828984,-1.812,0.170626,0.595479,-1.8188,0.066626,0.53519,-1.89697,0.319656,0.534821,-1.84277,0.285005,0.485879,-1.77368,0.012531,1.11479,-2.11914,-0.018059,1.03739,-2.09924,-0.121246,1.16621,-2.09773,-0.148004,1.08937,-2.08258,-0.163985,0.940841,-2.08011,-0.231823,0.76488,-2.07076,-0.325926,0.827737,-2.07771,-0.361787,0.7674,-2.06672,-0.464233,0.552142,-2.03582,-0.562363,0.564701,-1.96169,-0.385881,0.379424,-2.00858,-0.454755,0.364493,-2.06176,0.061618,1.34274,-1.83563,0.057221,1.32715,-2.05025},
/*245*/{0.122332,1.91849,-1.73755,0.221145,1.86747,-1.86831,-0.028703,1.82647,-1.67818,-0.146981,1.74981,-1.65134,-0.011519,1.66639,-1.67549,0.058209,1.60947,-1.67212,0.18934,1.94623,-2.11337,0.243457,1.86843,-1.94074,0.046967,1.89112,-2.05921,0.085321,1.72536,-2.24661,0.144505,1.64321,-2.28145,0.276131,1.66548,-2.13812,0.339512,1.66336,-2.1241,0.145429,1.42826,-1.83171,-0.034834,1.50132,-1.8972,-0.031189,1.5185,-1.96369,-0.026182,1.49405,-2.01273,0.153519,1.40277,-2.08694,0.287904,1.23958,-1.76725,0.19199,1.1415,-1.77693,0.24715,1.08131,-1.80122,0.354798,1.04093,-1.79761,0.331287,0.856033,-1.78138,0.308056,0.783076,-1.79147,0.225915,0.887903,-1.81045,0.204259,0.819389,-1.81454,0.19115,0.584071,-1.81881,0.088514,0.520086,-1.89715,0.343608,0.531219,-1.84329,0.310765,0.481266,-1.77536,0.009907,1.11771,-2.11953,-0.021488,1.04181,-2.1,-0.122147,1.17123,-2.09587,-0.150871,1.09469,-2.08141,-0.169526,0.94773,-2.0798,-0.238519,0.771315,-2.07194,-0.331956,0.835399,-2.07708,-0.36886,0.775072,-2.06754,-0.472107,0.560455,-2.03711,-0.566526,0.581775,-1.96192,-0.40344,0.379028,-2.00985,-0.473951,0.371776,-2.05986,0.061865,1.34681,-1.83511,0.058317,1.33007,-2.04967},
/*246*/{0.122272,1.91992,-1.73768,0.22836,1.86508,-1.86577,-0.0288,1.82799,-1.67934,-0.148858,1.7503,-1.65318,-0.011626,1.66835,-1.67585,0.059547,1.61113,-1.6703,0.192076,1.94879,-2.11236,0.245417,1.86918,-1.93896,0.049314,1.89469,-2.05944,0.089198,1.72904,-2.2481,0.147356,1.6472,-2.28282,0.277222,1.66918,-2.13725,0.34034,1.66737,-2.12241,0.146128,1.43143,-1.83148,-0.033279,1.50387,-1.89778,-0.027904,1.52041,-1.96375,-0.024515,1.49694,-2.01376,0.154645,1.40432,-2.08645,0.287058,1.24067,-1.76808,0.188708,1.14433,-1.77687,0.245475,1.08254,-1.79988,0.3521,1.03911,-1.79729,0.33608,0.852312,-1.78099,0.317513,0.778908,-1.79083,0.22973,0.879041,-1.8123,0.211116,0.810226,-1.81552,0.210216,0.573107,-1.81804,0.112278,0.503973,-1.89676,0.365546,0.527977,-1.84351,0.334982,0.475037,-1.77629,0.007863,1.12107,-2.11994,-0.024637,1.04485,-2.1012,-0.122303,1.17572,-2.09512,-0.152597,1.09956,-2.08044,-0.172115,0.95326,-2.07918,-0.244264,0.777815,-2.07302,-0.336613,0.843785,-2.07773,-0.374384,0.783573,-2.06872,-0.483122,0.569459,-2.03784,-0.570565,0.598316,-1.96256,-0.421292,0.378892,-2.00974,-0.495193,0.380445,-2.05846,0.062782,1.34972,-1.83469,0.059692,1.33201,-2.04918},
/*247*/{0.122873,1.92159,-1.73715,0.229196,1.86633,-1.86436,-0.029213,1.82964,-1.68044,-0.148124,1.75091,-1.65499,-0.011654,1.66911,-1.67544,0.059527,1.6124,-1.66949,0.193891,1.95098,-2.11182,0.245561,1.87132,-1.93829,0.051451,1.89633,-2.05947,0.092594,1.73237,-2.2486,0.150804,1.65012,-2.28334,0.278871,1.6721,-2.13688,0.339108,1.67093,-2.12333,0.147675,1.43487,-1.83089,-0.033559,1.50788,-1.89837,-0.027206,1.52424,-1.96465,-0.022265,1.49939,-2.01407,0.156003,1.4058,-2.08608,0.286973,1.24082,-1.76876,0.194057,1.14599,-1.77534,0.242796,1.08296,-1.79995,0.34868,1.03664,-1.79722,0.34052,0.848354,-1.77993,0.32658,0.774247,-1.78983,0.233912,0.869846,-1.81203,0.21998,0.798883,-1.81488,0.229354,0.56269,-1.81774,0.135206,0.489814,-1.89737,0.386766,0.523916,-1.84323,0.359042,0.470148,-1.77588,0.006504,1.12442,-2.121,-0.026779,1.04834,-2.10255,-0.123358,1.17942,-2.0928,-0.15378,1.10328,-2.0786,-0.173834,0.956556,-2.07823,-0.248774,0.783583,-2.07434,-0.340805,0.85046,-2.07729,-0.378661,0.791237,-2.06892,-0.489143,0.579765,-2.03962,-0.574154,0.614862,-1.96402,-0.439484,0.37878,-2.0089,-0.513411,0.389848,-2.05625,0.063234,1.35372,-1.83383,0.060638,1.33427,-2.04816},
/*248*/{0.123064,1.9232,-1.73682,0.231876,1.86739,-1.86328,-0.029097,1.83075,-1.68124,-0.147911,1.75104,-1.6554,-0.010565,1.66957,-1.67514,0.061165,1.61274,-1.66746,0.195814,1.95278,-2.11021,0.247955,1.87315,-1.93671,0.053423,1.89909,-2.05963,0.096572,1.73571,-2.24946,0.153603,1.65278,-2.28492,0.279026,1.67321,-2.13603,0.339863,1.67197,-2.11932,0.15018,1.43738,-1.83104,-0.032017,1.5104,-1.89807,-0.02575,1.52769,-1.96472,-0.021398,1.50289,-2.01425,0.15675,1.40805,-2.08576,0.284195,1.24059,-1.76959,0.189299,1.14706,-1.77471,0.240298,1.08317,-1.79819,0.345787,1.03341,-1.7958,0.344754,0.844258,-1.779,0.334651,0.769578,-1.78917,0.237216,0.859999,-1.81139,0.227133,0.789046,-1.81467,0.247194,0.553221,-1.81802,0.157155,0.477067,-1.89758,0.406208,0.520867,-1.84416,0.382835,0.465914,-1.77759,0.005687,1.12721,-2.12161,-0.02745,1.05153,-2.10352,-0.124203,1.18267,-2.09148,-0.153475,1.10665,-2.07708,-0.172691,0.959719,-2.07799,-0.253541,0.788102,-2.07442,-0.342845,0.856564,-2.07722,-0.383186,0.798577,-2.06911,-0.498267,0.589934,-2.04021,-0.578469,0.631286,-1.96595,-0.458231,0.377434,-2.00656,-0.529844,0.399915,-2.05489,0.064719,1.35664,-1.83372,0.061346,1.33698,-2.04804},
/*249*/{0.123811,1.92455,-1.73628,0.231839,1.86807,-1.8627,-0.028073,1.83099,-1.68093,-0.147738,1.75085,-1.65637,-0.009596,1.66938,-1.6748,0.062011,1.61282,-1.66633,0.198105,1.9542,-2.10929,0.249567,1.87475,-1.93548,0.05567,1.90104,-2.05951,0.098695,1.73871,-2.25032,0.15568,1.65515,-2.28586,0.280024,1.6742,-2.13567,0.342014,1.67258,-2.11496,0.151012,1.44029,-1.83088,-0.030396,1.51254,-1.89919,-0.025867,1.53071,-1.96535,-0.019356,1.50597,-2.01401,0.157455,1.40967,-2.08521,0.28222,1.23896,-1.7699,0.187451,1.1467,-1.77492,0.237291,1.08206,-1.79678,0.341236,1.03027,-1.79459,0.347714,0.839884,-1.77773,0.342545,0.764786,-1.78818,0.239692,0.849662,-1.81047,0.233354,0.77809,-1.81409,0.265814,0.543435,-1.81744,0.178323,0.465238,-1.8976,0.426274,0.518208,-1.84423,0.40346,0.460216,-1.77764,0.005064,1.12966,-2.12183,-0.027434,1.05345,-2.10364,-0.123618,1.18498,-2.09001,-0.153164,1.10825,-2.07608,-0.1716,0.961134,-2.07789,-0.256214,0.791371,-2.07462,-0.344101,0.862002,-2.07736,-0.385581,0.804893,-2.06959,-0.509475,0.59787,-2.04034,-0.583807,0.64668,-1.96846,-0.477731,0.388165,-2.00352,-0.548966,0.411655,-2.05222,0.065219,1.35961,-1.83341,0.062153,1.33916,-2.04765},
/*250*/{0.124222,1.92525,-1.73576,0.234446,1.86922,-1.86121,-0.027727,1.83106,-1.6811,-0.147241,1.75015,-1.65716,-0.008522,1.66954,-1.67487,0.063506,1.61216,-1.66481,0.199779,1.95549,-2.10874,0.25038,1.87577,-1.93521,0.057915,1.90244,-2.05944,0.101408,1.7412,-2.25078,0.15725,1.65705,-2.28673,0.280925,1.67497,-2.13519,0.3411,1.67354,-2.11759,0.150153,1.44269,-1.83093,-0.031064,1.51558,-1.90009,-0.024978,1.53306,-1.96498,-0.018473,1.50796,-2.01509,0.158272,1.41246,-2.08498,0.280543,1.23586,-1.77018,0.183297,1.14473,-1.77421,0.231436,1.07925,-1.79763,0.336805,1.02577,-1.79368,0.350861,0.835206,-1.77712,0.347798,0.759949,-1.78773,0.242349,0.839075,-1.80858,0.240556,0.767462,-1.8125,0.284808,0.535053,-1.81666,0.199196,0.454105,-1.89818,0.44562,0.515568,-1.84414,0.425273,0.456117,-1.77879,0.006327,1.13206,-2.12186,-0.026057,1.05558,-2.10505,-0.122388,1.18583,-2.08913,-0.152315,1.10974,-2.07528,-0.169713,0.962105,-2.07783,-0.258652,0.793377,-2.07395,-0.344669,0.866777,-2.07748,-0.386906,0.810538,-2.0691,-0.511411,0.611364,-2.04519,-0.589424,0.662115,-1.97032,-0.496585,0.399419,-1.99972,-0.565762,0.424993,-2.05172,0.064641,1.36197,-1.83372,0.062853,1.34177,-2.048},
/*251*/{0.124772,1.92621,-1.73504,0.234707,1.87015,-1.86068,-0.027117,1.8309,-1.68082,-0.145975,1.74835,-1.65765,-0.007075,1.66851,-1.674,0.065075,1.6115,-1.66277,0.202002,1.9564,-2.10767,0.251921,1.87804,-1.93359,0.05939,1.90511,-2.05875,0.103557,1.7435,-2.25124,0.158542,1.65856,-2.28717,0.281442,1.67535,-2.13485,0.341813,1.6725,-2.11714,0.151457,1.44335,-1.83108,-0.030209,1.51672,-1.89956,-0.024128,1.53538,-1.9653,-0.018459,1.51018,-2.01421,0.15876,1.41462,-2.08491,0.279032,1.23166,-1.76983,0.179917,1.14281,-1.77377,0.226267,1.07646,-1.79641,0.33228,1.02089,-1.79292,0.353389,0.829803,-1.77648,0.356672,0.75581,-1.78783,0.244517,0.828967,-1.80655,0.246289,0.756854,-1.81083,0.300278,0.526369,-1.81634,0.219554,0.442887,-1.89871,0.461955,0.514623,-1.84387,0.444558,0.45309,-1.77802,0.00848,1.13316,-2.12237,-0.025666,1.05618,-2.10507,-0.121755,1.18629,-2.08887,-0.150034,1.10939,-2.0746,-0.166802,0.961729,-2.07761,-0.260024,0.794251,-2.07356,-0.343475,0.87123,-2.07803,-0.388617,0.816903,-2.06943,-0.519852,0.621421,-2.04313,-0.596748,0.677762,-1.97313,-0.511702,0.409843,-1.99662,-0.58071,0.438368,-2.04989,0.065371,1.36303,-1.83415,0.063171,1.34389,-2.04852},
/*252*/{0.126261,1.92676,-1.73416,0.235126,1.87312,-1.85996,-0.025555,1.82951,-1.68043,-0.144646,1.74619,-1.65775,-0.004416,1.66749,-1.67327,0.067935,1.60998,-1.66063,0.204331,1.95699,-2.10683,0.253067,1.87856,-1.93306,0.061497,1.90669,-2.05878,0.104879,1.74516,-2.25142,0.159126,1.65989,-2.28802,0.283629,1.67531,-2.13534,0.342405,1.67063,-2.11589,0.153595,1.44748,-1.8323,-0.029744,1.51874,-1.89958,-0.024409,1.53771,-1.96549,-0.017933,1.51208,-2.01511,0.15956,1.41654,-2.08471,0.275036,1.2281,-1.77022,0.169884,1.13953,-1.77614,0.220683,1.07315,-1.79674,0.32813,1.01503,-1.79188,0.358253,0.825203,-1.77602,0.362478,0.749757,-1.78752,0.247283,0.819167,-1.80282,0.251592,0.747299,-1.80826,0.317362,0.521015,-1.81672,0.238506,0.433016,-1.89847,0.479879,0.514348,-1.84392,0.46385,0.452053,-1.77977,0.010511,1.13388,-2.12252,-0.020069,1.05697,-2.10523,-0.11888,1.18651,-2.08865,-0.146675,1.10926,-2.07469,-0.162897,0.961271,-2.07748,-0.261605,0.794659,-2.07205,-0.340743,0.875691,-2.07884,-0.389147,0.822036,-2.07001,-0.526063,0.633098,-2.04274,-0.604743,0.692738,-1.97652,-0.527134,0.423178,-1.99287,-0.593395,0.451501,-2.04776,0.067563,1.36659,-1.83373,0.064443,1.34577,-2.04793},
/*253*/{0.126906,1.92723,-1.7334,0.236328,1.87274,-1.85875,-0.024645,1.82849,-1.6802,-0.141924,1.74475,-1.65705,-0.002744,1.66499,-1.67187,0.069157,1.60763,-1.65787,0.20552,1.95721,-2.10618,0.254456,1.87919,-1.93252,0.063078,1.90786,-2.05875,0.106828,1.74621,-2.25133,0.159304,1.66035,-2.28792,0.282731,1.67276,-2.13439,0.343126,1.66887,-2.1183,0.153343,1.44805,-1.83118,-0.029713,1.51957,-1.90004,-0.023856,1.53892,-1.96507,-0.017502,1.51324,-2.01437,0.16053,1.41841,-2.08461,0.270895,1.22318,-1.76989,0.166528,1.13405,-1.77757,0.213788,1.06881,-1.79703,0.322702,1.00927,-1.79184,0.360889,0.820593,-1.7761,0.368346,0.746016,-1.78813,0.250494,0.809534,-1.79909,0.257573,0.738602,-1.80541,0.330675,0.51398,-1.81619,0.255967,0.424463,-1.89825,0.493783,0.514225,-1.84348,0.480249,0.449699,-1.77931,0.01446,1.13394,-2.1224,-0.015913,1.05573,-2.10516,-0.116989,1.18446,-2.08847,-0.143939,1.10712,-2.07427,-0.158648,0.959135,-2.07705,-0.262908,0.795454,-2.07144,-0.339596,0.878687,-2.07933,-0.388489,0.828797,-2.07133,-0.537565,0.645003,-2.04253,-0.612155,0.707843,-1.9795,-0.540053,0.436103,-1.98872,-0.604127,0.465315,-2.04621,0.067426,1.36712,-1.83384,0.065288,1.34734,-2.04816},
/*254*/{0.127647,1.92744,-1.73255,0.2369,1.87423,-1.85847,-0.023275,1.82658,-1.67916,-0.140703,1.74186,-1.65656,-0.00022,1.66298,-1.67038,0.072606,1.60569,-1.65646,0.208411,1.95745,-2.1056,0.255646,1.87935,-1.93169,0.064339,1.90921,-2.05807,0.107964,1.74721,-2.25146,0.158624,1.66106,-2.28812,0.28329,1.67127,-2.13478,0.343807,1.66703,-2.1185,0.151858,1.44812,-1.832,-0.028931,1.52008,-1.89971,-0.024382,1.54037,-1.96445,-0.017796,1.5148,-2.01493,0.161067,1.42034,-2.08453,0.26805,1.21654,-1.76903,0.159679,1.1314,-1.77625,0.206499,1.0654,-1.7976,0.317749,1.00247,-1.79132,0.364292,0.816461,-1.77681,0.37468,0.741927,-1.78837,0.253342,0.801489,-1.79623,0.263067,0.729599,-1.80278,0.344212,0.506259,-1.81535,0.271501,0.415811,-1.89825,0.507008,0.514523,-1.84382,0.496222,0.449878,-1.77996,0.017697,1.13341,-2.12183,-0.011315,1.05538,-2.1051,-0.113424,1.18226,-2.08883,-0.139893,1.10556,-2.07486,-0.153315,0.956644,-2.07634,-0.263118,0.795974,-2.06947,-0.335846,0.883588,-2.08093,-0.387648,0.833971,-2.07171,-0.542331,0.656922,-2.04286,-0.619365,0.723254,-1.98271,-0.553342,0.449581,-1.98523,-0.61487,0.479463,-2.04375,0.066624,1.36712,-1.8349,0.06521,1.3492,-2.04938},
/*255*/{0.129084,1.92741,-1.73152,0.238863,1.87384,-1.85788,-0.021659,1.82475,-1.67866,-0.139432,1.7386,-1.65668,0.002192,1.66035,-1.66875,0.074785,1.60308,-1.65397,0.210489,1.95679,-2.1049,0.256143,1.87979,-1.93102,0.06555,1.91061,-2.05828,0.108216,1.74759,-2.2509,0.158138,1.66081,-2.28776,0.282919,1.6682,-2.13499,0.343816,1.66251,-2.11833,0.15071,1.44825,-1.83233,-0.028939,1.51988,-1.89993,-0.02403,1.54075,-1.96439,-0.017348,1.5155,-2.01492,0.162081,1.42117,-2.08448,0.264678,1.21022,-1.76877,0.152839,1.1272,-1.77718,0.200281,1.05971,-1.7967,0.311915,0.996219,-1.7907,0.367653,0.812468,-1.77756,0.379856,0.737864,-1.78986,0.2568,0.792897,-1.79198,0.26849,0.722544,-1.79932,0.356087,0.502255,-1.81465,0.28577,0.408328,-1.89728,0.518819,0.514799,-1.84379,0.511277,0.450742,-1.78123,0.021725,1.1325,-2.12125,-0.006365,1.05382,-2.10451,-0.111325,1.17947,-2.08932,-0.135189,1.10244,-2.07505,-0.147378,0.953709,-2.07557,-0.26374,0.796698,-2.06786,-0.330194,0.886756,-2.08275,-0.3864,0.841078,-2.07242,-0.547995,0.671454,-2.04276,-0.625025,0.739519,-1.98501,-0.565861,0.46352,-1.98113,-0.623532,0.493969,-2.04191,0.066173,1.36689,-1.83549,0.065819,1.35001,-2.05006},
/*256*/{0.130213,1.92685,-1.73074,0.239207,1.87406,-1.85733,-0.020361,1.82243,-1.67759,-0.135762,1.73534,-1.65552,0.005266,1.6569,-1.66667,0.077238,1.59929,-1.65136,0.211567,1.95595,-2.10456,0.257194,1.87969,-1.93049,0.067221,1.91144,-2.05743,0.107176,1.74792,-2.25015,0.15664,1.66031,-2.28724,0.283417,1.6657,-2.13558,0.344283,1.65801,-2.11818,0.15098,1.44862,-1.8324,-0.028932,1.5198,-1.90001,-0.02403,1.54075,-1.96439,-0.016782,1.51551,-2.01447,0.162611,1.42342,-2.0843,0.260022,1.2034,-1.76872,0.149949,1.12495,-1.77676,0.191931,1.05446,-1.79827,0.305767,0.989857,-1.79074,0.369679,0.808998,-1.7789,0.382314,0.735398,-1.79095,0.259005,0.78595,-1.78938,0.273017,0.716,-1.79664,0.365657,0.498502,-1.81385,0.297832,0.403007,-1.89604,0.526991,0.514216,-1.84599,0.522906,0.449032,-1.78248,0.026712,1.13113,-2.12136,-1.1e-005,1.0522,-2.10311,-0.106643,1.17625,-2.09045,-0.130898,1.09821,-2.0749,-0.140991,0.950781,-2.07467,-0.265094,0.796715,-2.06652,-0.326735,0.888761,-2.08085,-0.384331,0.847404,-2.07368,-0.554429,0.684451,-2.04125,-0.628794,0.755792,-1.98655,-0.576444,0.479221,-1.97867,-0.63274,0.509655,-2.04137,0.067024,1.36685,-1.83603,0.067153,1.35113,-2.05069},
/*257*/{0.131852,1.92579,-1.72945,0.240104,1.87504,-1.85734,-0.018302,1.81974,-1.6764,-0.133802,1.7313,-1.65423,0.008441,1.65324,-1.66487,0.080698,1.59629,-1.64871,0.21334,1.95501,-2.10378,0.258116,1.87887,-1.929,0.068168,1.91157,-2.05648,0.105283,1.74781,-2.24872,0.15533,1.66012,-2.28692,0.282837,1.66206,-2.13582,0.344234,1.65266,-2.11872,0.153704,1.44881,-1.83252,-0.029764,1.51918,-1.9,-0.024109,1.5405,-1.9644,-0.016914,1.51481,-2.01438,0.163966,1.42369,-2.08449,0.254456,1.19674,-1.76821,0.140099,1.11924,-1.77841,0.18466,1.04919,-1.79864,0.300144,0.983729,-1.79062,0.371119,0.805412,-1.77969,0.386244,0.732008,-1.79146,0.260829,0.779692,-1.78783,0.27618,0.709772,-1.79483,0.374009,0.494969,-1.81261,0.307328,0.398207,-1.89279,0.535396,0.514307,-1.84648,0.532836,0.448429,-1.78404,0.031821,1.12876,-2.12,0.006177,1.0492,-2.10199,-0.102493,1.17255,-2.09098,-0.125523,1.09366,-2.07499,-0.134973,0.946972,-2.07296,-0.263104,0.798765,-2.06484,-0.322348,0.893797,-2.08131,-0.380301,0.85425,-2.07352,-0.5579,0.698515,-2.04099,-0.631271,0.772222,-1.98824,-0.587419,0.494947,-1.97608,-0.642996,0.526398,-2.04082,0.069028,1.36689,-1.83602,0.068637,1.35098,-2.05066},
/*258*/{0.133104,1.92491,-1.72913,0.240744,1.87379,-1.85707,-0.016207,1.81676,-1.67491,-0.129521,1.72779,-1.65321,0.011569,1.64982,-1.6625,0.084682,1.5926,-1.64575,0.214808,1.95342,-2.10278,0.258438,1.87832,-1.92881,0.069085,1.9118,-2.0555,0.104083,1.74739,-2.24739,0.152998,1.65854,-2.28601,0.28452,1.65707,-2.13667,0.34353,1.64688,-2.12007,0.154824,1.44894,-1.83258,-0.030059,1.51723,-1.90067,-0.024238,1.53965,-1.96546,-0.017063,1.51362,-2.01425,0.164382,1.42414,-2.0845,0.251274,1.18967,-1.76709,0.137394,1.11684,-1.77738,0.177062,1.04466,-1.79927,0.292836,0.977333,-1.79048,0.369688,0.802692,-1.78069,0.387302,0.729626,-1.79157,0.260714,0.774282,-1.78744,0.279053,0.704629,-1.793,0.379744,0.491456,-1.81223,0.314861,0.393589,-1.89145,0.541395,0.514019,-1.84784,0.541742,0.446909,-1.7842,0.03717,1.12656,-2.11862,0.013083,1.04736,-2.10122,-0.099115,1.1671,-2.09144,-0.119394,1.08806,-2.07508,-0.127747,0.943682,-2.07258,-0.260328,0.800966,-2.0636,-0.316765,0.898095,-2.08099,-0.37672,0.860255,-2.07344,-0.561795,0.712501,-2.04027,-0.631932,0.790215,-1.9895,-0.596983,0.511217,-1.975,-0.650807,0.543845,-2.04035,0.070332,1.3664,-1.83635,0.070064,1.35047,-2.05099},
/*259*/{0.134855,1.92327,-1.72788,0.241701,1.87318,-1.85666,-0.01422,1.81414,-1.67436,-0.125469,1.72383,-1.65117,0.015682,1.64551,-1.66017,0.088535,1.58887,-1.64365,0.214832,1.95082,-2.10202,0.258706,1.87721,-1.92863,0.070147,1.91123,-2.05448,0.101153,1.74699,-2.24537,0.149888,1.65777,-2.28464,0.283593,1.65189,-2.13845,0.343609,1.64034,-2.12162,0.152908,1.44804,-1.8327,-0.030019,1.51537,-1.90121,-0.023852,1.53876,-1.96532,-0.016438,1.51233,-2.01414,0.164549,1.42413,-2.08446,0.245269,1.18304,-1.7674,0.130075,1.11199,-1.78065,0.17037,1.03982,-1.80074,0.285731,0.97122,-1.79048,0.368055,0.800121,-1.7812,0.38743,0.726929,-1.79181,0.259081,0.768965,-1.78802,0.279063,0.700215,-1.7937,0.386043,0.488274,-1.81115,0.321108,0.389659,-1.89042,0.547311,0.512208,-1.84816,0.548456,0.446348,-1.78537,0.042682,1.12395,-2.11767,0.019714,1.04346,-2.10005,-0.093998,1.16257,-2.09179,-0.11372,1.08328,-2.07561,-0.119983,0.93956,-2.0715,-0.25726,0.803391,-2.06289,-0.311088,0.902071,-2.08072,-0.371374,0.86639,-2.07194,-0.563805,0.727778,-2.04097,-0.631026,0.807898,-1.98965,-0.60574,0.527918,-1.97424,-0.658209,0.56222,-2.03904,0.069741,1.36486,-1.83689,0.070626,1.34996,-2.05161},
/*260*/{0.136348,1.92159,-1.72691,0.2422,1.87156,-1.85688,-0.011545,1.81007,-1.67236,-0.12127,1.7193,-1.64925,0.019331,1.64135,-1.6574,0.092076,1.58491,-1.64096,0.21628,1.94923,-2.10112,0.259343,1.87577,-1.92844,0.070196,1.91075,-2.05389,0.098324,1.74671,-2.24354,0.146771,1.65699,-2.28369,0.282839,1.64672,-2.13958,0.343472,1.6325,-2.12236,0.153795,1.44628,-1.83212,-0.029437,1.5132,-1.90028,-0.023842,1.53592,-1.9656,-0.016652,1.51019,-2.01429,0.165579,1.42351,-2.08451,0.242,1.17671,-1.76676,0.124564,1.1069,-1.78048,0.163506,1.0348,-1.80185,0.278786,0.965035,-1.79027,0.36384,0.79727,-1.78107,0.384636,0.725057,-1.79123,0.256397,0.765057,-1.78903,0.277069,0.695965,-1.79514,0.390084,0.485607,-1.81098,0.324863,0.386141,-1.88842,0.549642,0.510291,-1.84937,0.552436,0.445268,-1.78668,0.049121,1.12074,-2.11668,0.026508,1.03994,-2.09872,-0.088655,1.15719,-2.09294,-0.107393,1.07757,-2.07595,-0.11213,0.934206,-2.0709,-0.253748,0.805453,-2.06169,-0.304704,0.905562,-2.07978,-0.367694,0.876942,-2.06742,-0.556099,0.740407,-2.03953,-0.627744,0.825693,-1.98972,-0.61321,0.544547,-1.97345,-0.665162,0.581402,-2.03953,0.071036,1.36277,-1.83701,0.07207,1.34845,-2.05177},
/*261*/{0.138115,1.91947,-1.72591,0.241631,1.86985,-1.85651,-0.009328,1.80614,-1.67037,-0.117562,1.71411,-1.64729,0.023141,1.63586,-1.65453,0.09633,1.57987,-1.63744,0.216544,1.94687,-2.10089,0.259248,1.87378,-1.92819,0.070669,1.90978,-2.05329,0.09551,1.74371,-2.2412,0.143341,1.65561,-2.2826,0.282477,1.64207,-2.13932,0.342566,1.62556,-2.12511,0.154166,1.44466,-1.83168,-0.030037,1.51033,-1.90098,-0.024092,1.53475,-1.96545,-0.016994,1.5081,-2.01506,0.166498,1.42213,-2.08468,0.238899,1.16937,-1.76501,0.118585,1.1003,-1.77952,0.157889,1.0301,-1.80354,0.272208,0.95831,-1.79075,0.360542,0.794095,-1.78022,0.381384,0.721187,-1.79037,0.253262,0.760028,-1.79027,0.274168,0.692031,-1.7961,0.38922,0.481297,-1.81029,0.326166,0.382329,-1.88768,0.551269,0.508262,-1.84985,0.5545,0.442855,-1.78683,0.054454,1.11755,-2.11602,0.033376,1.03662,-2.098,-0.084549,1.15341,-2.09378,-0.100993,1.07127,-2.07491,-0.104443,0.929746,-2.07055,-0.253514,0.806219,-2.06129,-0.296299,0.909294,-2.079,-0.359652,0.877443,-2.06599,-0.560379,0.759211,-2.04249,-0.62369,0.843705,-1.98836,-0.620673,0.561735,-1.97499,-0.66931,0.601369,-2.03933,0.07127,1.36084,-1.83737,0.072958,1.34687,-2.05215},
/*262*/{0.139348,1.91676,-1.725,0.242635,1.86823,-1.85628,-0.006252,1.80212,-1.66887,-0.114349,1.70839,-1.64467,0.027622,1.63102,-1.65127,0.1001,1.57607,-1.63566,0.216411,1.94418,-2.10011,0.260071,1.87164,-1.92749,0.070826,1.90891,-2.05236,0.09205,1.74243,-2.23949,0.139606,1.65363,-2.28086,0.281243,1.63539,-2.14026,0.340706,1.61746,-2.12728,0.155454,1.44222,-1.8314,-0.029544,1.50696,-1.9009,-0.023072,1.53172,-1.96548,-0.016635,1.50493,-2.01434,0.166893,1.42132,-2.08421,0.235757,1.16286,-1.76301,0.11624,1.09645,-1.77919,0.153524,1.02565,-1.80377,0.266487,0.953179,-1.79022,0.355332,0.790373,-1.77843,0.37769,0.717428,-1.78935,0.249336,0.754847,-1.79075,0.271338,0.686309,-1.79659,0.38957,0.477095,-1.80992,0.326191,0.377788,-1.88823,0.550827,0.505727,-1.84945,0.55384,0.438806,-1.78632,0.059949,1.11336,-2.11542,0.040559,1.03189,-2.09646,-0.079037,1.14763,-2.09407,-0.094192,1.06529,-2.07486,-0.09611,0.924787,-2.06928,-0.2491,0.80763,-2.06085,-0.288752,0.913038,-2.07777,-0.352628,0.885221,-2.06884,-0.558107,0.774107,-2.04254,-0.617141,0.860372,-1.98696,-0.626005,0.578482,-1.97628,-0.674935,0.62139,-2.04044,0.072939,1.35799,-1.83751,0.074598,1.34481,-2.05234},
/*263*/{0.141152,1.91356,-1.72427,0.242657,1.86538,-1.85577,-0.003689,1.79795,-1.66694,-0.109827,1.70308,-1.64182,0.031857,1.6264,-1.64843,0.10485,1.57133,-1.63226,0.217257,1.94156,-2.0996,0.259252,1.86904,-1.92779,0.071005,1.9068,-2.05086,0.087945,1.74151,-2.23746,0.135479,1.65136,-2.27919,0.279544,1.62906,-2.14409,0.339674,1.609,-2.12956,0.155117,1.43921,-1.83117,-0.029609,1.50426,-1.90069,-0.023257,1.52835,-1.96555,-0.015888,1.50237,-2.01559,0.167987,1.41992,-2.08354,0.232744,1.15768,-1.76163,0.112249,1.09616,-1.78051,0.150132,1.0224,-1.80454,0.263683,0.949312,-1.78912,0.352325,0.786005,-1.77938,0.37462,0.712825,-1.78952,0.244804,0.749412,-1.79227,0.268463,0.681306,-1.79695,0.387519,0.473068,-1.81068,0.324146,0.373421,-1.88971,0.54762,0.501517,-1.85038,0.551311,0.434238,-1.78729,0.065562,1.11051,-2.11527,0.048428,1.02875,-2.09587,-0.074151,1.13909,-2.0925,-0.087948,1.05833,-2.07422,-0.087848,0.919459,-2.06831,-0.24412,0.80903,-2.06068,-0.279242,0.916179,-2.0775,-0.345945,0.890452,-2.0675,-0.550683,0.785989,-2.0409,-0.609535,0.876714,-1.98553,-0.630177,0.595853,-1.97733,-0.67881,0.640947,-2.04093,0.072892,1.35483,-1.83807,0.075934,1.34278,-2.05295},
/*264*/{0.142669,1.91026,-1.72334,0.243748,1.86227,-1.85581,-0.000557,1.7929,-1.66402,-0.105296,1.69786,-1.63857,0.036337,1.62094,-1.64463,0.110033,1.5669,-1.6301,0.217001,1.93827,-2.09992,0.25979,1.86624,-1.92762,0.071111,1.90443,-2.05,0.084507,1.73935,-2.23509,0.131175,1.64934,-2.27802,0.277417,1.62289,-2.14545,0.337701,1.60104,-2.13218,0.154139,1.43592,-1.83062,-0.02933,1.50092,-1.90029,-0.023185,1.52496,-1.96552,-0.016642,1.49962,-2.01553,0.169408,1.41749,-2.08358,0.230895,1.1534,-1.75981,0.110654,1.09164,-1.78133,0.148224,1.01821,-1.80637,0.262251,0.946708,-1.78946,0.347131,0.78035,-1.77889,0.368924,0.707975,-1.78955,0.241108,0.744116,-1.7936,0.263282,0.676521,-1.79933,0.38409,0.470258,-1.81327,0.320012,0.368989,-1.89074,0.543857,0.495771,-1.85129,0.547462,0.428613,-1.78852,0.070985,1.10614,-2.11489,0.055361,1.02496,-2.09526,-0.069119,1.13252,-2.09214,-0.081156,1.05234,-2.07349,-0.079325,0.913575,-2.06795,-0.23882,0.810347,-2.06071,-0.270341,0.919197,-2.07659,-0.336823,0.896246,-2.06728,-0.550409,0.802911,-2.04254,-0.599891,0.892787,-1.98332,-0.636572,0.613205,-1.98053,-0.67988,0.661495,-2.04094,0.072638,1.3513,-1.83833,0.076624,1.34021,-2.05324},
/*265*/{0.1444,1.90662,-1.72224,0.24461,1.85772,-1.85566,0.002329,1.78716,-1.66154,-0.100473,1.6914,-1.63486,0.041496,1.61552,-1.64095,0.115328,1.56226,-1.62672,0.215818,1.93467,-2.09985,0.260207,1.86342,-1.92766,0.070228,1.90144,-2.04982,0.07983,1.7372,-2.23324,0.126674,1.64598,-2.27631,0.273962,1.61486,-2.14696,0.333852,1.5926,-2.13577,0.156252,1.43262,-1.82968,-0.029389,1.49713,-1.89967,-0.023032,1.52111,-1.96535,-0.015749,1.49565,-2.01541,0.170214,1.41559,-2.08305,0.228247,1.15051,-1.75886,0.107754,1.08698,-1.78191,0.146181,1.01516,-1.80671,0.261439,0.944836,-1.78903,0.342955,0.775052,-1.77839,0.365836,0.702567,-1.78963,0.235756,0.740167,-1.79397,0.25894,0.671722,-1.80058,0.379208,0.464322,-1.8142,0.314105,0.364687,-1.89341,0.538636,0.490167,-1.85176,0.539854,0.422446,-1.78929,0.07641,1.10222,-2.1143,0.062056,1.02011,-2.09431,-0.064998,1.12631,-2.0922,-0.075507,1.04563,-2.07238,-0.070981,0.908253,-2.06737,-0.232874,0.811417,-2.06018,-0.260383,0.920985,-2.07602,-0.32857,0.899168,-2.06636,-0.543607,0.816122,-2.0423,-0.589589,0.907684,-1.9816,-0.638304,0.629499,-1.98284,-0.681609,0.680674,-2.04246,0.074425,1.34783,-1.83815,0.078485,1.33728,-2.05309},
/*266*/{0.145838,1.9027,-1.72139,0.245236,1.85459,-1.85556,0.005194,1.78208,-1.65907,-0.096819,1.68513,-1.63072,0.046098,1.61016,-1.63808,0.120196,1.55686,-1.62379,0.21488,1.93108,-2.10019,0.259896,1.85949,-1.92747,0.069938,1.89908,-2.04742,0.076737,1.73443,-2.23162,0.121885,1.64324,-2.27489,0.271729,1.60696,-2.14854,0.330615,1.58287,-2.13842,0.153304,1.42789,-1.82946,-0.030536,1.49334,-1.90009,-0.022582,1.51807,-1.96507,-0.015984,1.49118,-2.01549,0.170294,1.41244,-2.08182,0.227233,1.14652,-1.7568,0.106088,1.08191,-1.78085,0.143157,1.01215,-1.80714,0.260136,0.942333,-1.78907,0.339201,0.76912,-1.77826,0.360314,0.69619,-1.78985,0.23214,0.73458,-1.79486,0.253849,0.66709,-1.80167,0.371351,0.458054,-1.81551,0.30596,0.359756,-1.89648,0.532359,0.481354,-1.85235,0.533131,0.413552,-1.78977,0.081819,1.09854,-2.11396,0.069197,1.01611,-2.09398,-0.060087,1.11875,-2.09136,-0.069059,1.0388,-2.07264,-0.061776,0.902827,-2.06711,-0.226543,0.812381,-2.06108,-0.249507,0.923416,-2.07561,-0.317727,0.903195,-2.06601,-0.537373,0.829748,-2.04224,-0.578308,0.92199,-1.98043,-0.637695,0.646123,-1.98519,-0.680526,0.700973,-2.04435,0.072168,1.34327,-1.83838,0.078178,1.33388,-2.05333},
/*267*/{0.147584,1.89855,-1.72044,0.246551,1.85088,-1.85592,0.008333,1.77605,-1.65657,-0.09268,1.67851,-1.6269,0.050077,1.604,-1.6347,0.126064,1.55256,-1.62046,0.214798,1.92735,-2.10081,0.260293,1.85589,-1.92765,0.069681,1.89506,-2.04665,0.071915,1.73172,-2.22932,0.117043,1.63954,-2.2737,0.268017,1.59924,-2.1505,0.327816,1.57285,-2.14185,0.15406,1.42447,-1.8278,-0.030196,1.48932,-1.90033,-0.023104,1.51449,-1.96485,-0.016502,1.48724,-2.01561,0.1709,1.40949,-2.08127,0.2249,1.14361,-1.75648,0.104628,1.08382,-1.78334,0.143898,1.00915,-1.80613,0.25923,0.938842,-1.78925,0.333557,0.762607,-1.77898,0.354991,0.689815,-1.79044,0.226485,0.729859,-1.79545,0.247707,0.661008,-1.80208,0.362067,0.451397,-1.81787,0.296815,0.35551,-1.9,0.524669,0.472025,-1.85145,0.523314,0.404003,-1.79131,0.086918,1.09437,-2.11345,0.076285,1.01227,-2.09366,-0.054686,1.11221,-2.09101,-0.062518,1.03184,-2.07193,-0.053792,0.896676,-2.06659,-0.219891,0.8128,-2.06079,-0.238494,0.923296,-2.07362,-0.307745,0.907558,-2.06614,-0.528973,0.841508,-2.04215,-0.565191,0.935423,-1.97963,-0.635389,0.661926,-1.98739,-0.67676,0.718721,-2.04577,0.072665,1.33981,-1.8379,0.079146,1.33041,-2.05283},
/*268*/{0.148603,1.89407,-1.7197,0.24521,1.84832,-1.85612,0.011867,1.7701,-1.65329,-0.087219,1.67165,-1.62281,0.056292,1.59842,-1.63064,0.132038,1.54771,-1.61874,0.21299,1.92283,-2.10126,0.260299,1.85216,-1.92776,0.069059,1.89028,-2.04596,0.068544,1.72791,-2.22788,0.11218,1.63589,-2.27224,0.265666,1.59187,-2.15255,0.323946,1.56287,-2.14466,0.153759,1.42083,-1.82694,-0.030369,1.48497,-1.89995,-0.02329,1.51043,-1.9648,-0.01561,1.48194,-2.0163,0.171334,1.40627,-2.08054,0.223951,1.14098,-1.75609,0.102774,1.08092,-1.78427,0.139939,1.00632,-1.80596,0.257973,0.93446,-1.78884,0.329274,0.756,-1.7794,0.349207,0.683268,-1.79149,0.220554,0.725187,-1.79679,0.241231,0.655611,-1.80279,0.353473,0.444833,-1.81933,0.286489,0.350707,-1.90363,0.515412,0.463522,-1.8523,0.513856,0.395524,-1.79315,0.092679,1.09098,-2.1133,0.082978,1.00734,-2.09375,-0.049056,1.10527,-2.09045,-0.055591,1.02502,-2.07155,-0.044737,0.891206,-2.06642,-0.212431,0.812654,-2.05984,-0.227489,0.925211,-2.07246,-0.29709,0.910227,-2.06525,-0.519651,0.852893,-2.04256,-0.553173,0.947092,-1.97847,-0.632343,0.676523,-1.98924,-0.671351,0.734153,-2.04697,0.072945,1.33586,-1.83749,0.080361,1.3264,-2.05239},
/*269*/{0.150102,1.88894,-1.71918,0.246152,1.84273,-1.85638,0.014845,1.76341,-1.65088,-0.083295,1.66443,-1.61811,0.062327,1.59254,-1.62694,0.137639,1.54282,-1.6147,0.212248,1.91835,-2.10252,0.260897,1.84845,-1.92789,0.067987,1.88576,-2.04479,0.064202,1.72445,-2.22658,0.106484,1.63145,-2.27133,0.261137,1.58182,-2.15447,0.319579,1.55187,-2.14846,0.15314,1.41676,-1.82603,-0.030747,1.48071,-1.90024,-0.022596,1.5059,-1.9642,-0.015453,1.47738,-2.01627,0.17204,1.40313,-2.07996,0.222335,1.13653,-1.75486,0.100704,1.07617,-1.78559,0.138139,1.00315,-1.80655,0.254532,0.928598,-1.78879,0.322245,0.749177,-1.77974,0.342868,0.676112,-1.79286,0.213921,0.719427,-1.79674,0.233135,0.650659,-1.80414,0.342204,0.437954,-1.82053,0.273629,0.348286,-1.9065,0.504567,0.453452,-1.8528,0.502224,0.383147,-1.7943,0.097654,1.08638,-2.1137,0.090339,1.00337,-2.09351,-0.042849,1.09825,-2.08948,-0.047795,1.017,-2.07064,-0.035568,0.885063,-2.06634,-0.204786,0.812524,-2.05964,-0.216326,0.925033,-2.07277,-0.285984,0.912968,-2.06544,-0.505641,0.859551,-2.04058,-0.540289,0.957645,-1.97792,-0.626887,0.689873,-1.99199,-0.656945,0.740533,-2.04334,0.072927,1.33151,-1.83735,0.081396,1.32265,-2.05224},
/*270*/{0.151125,1.88362,-1.71837,0.246101,1.83916,-1.8564,0.018295,1.75628,-1.64773,-0.078578,1.65642,-1.61346,0.066386,1.58633,-1.62276,0.143911,1.5385,-1.61196,0.210251,1.91361,-2.10318,0.260645,1.84402,-1.92881,0.066631,1.88092,-2.04386,0.059385,1.72,-2.22525,0.101525,1.62715,-2.27006,0.257347,1.57398,-2.15721,0.314861,1.54081,-2.15239,0.154952,1.41315,-1.82438,-0.030812,1.47602,-1.9008,-0.023471,1.50165,-1.96358,-0.015723,1.47248,-2.01618,0.172016,1.39956,-2.08025,0.220156,1.13328,-1.75527,0.099721,1.07435,-1.78655,0.136046,0.999296,-1.80539,0.251517,0.922663,-1.78831,0.31622,0.741456,-1.7808,0.333291,0.668169,-1.79257,0.206995,0.71418,-1.79806,0.224613,0.644233,-1.80376,0.327679,0.432169,-1.82135,0.255302,0.353874,-1.9076,0.493236,0.441844,-1.85396,0.484993,0.371147,-1.79474,0.104431,1.08212,-2.11357,0.098417,0.998542,-2.09362,-0.038102,1.09072,-2.08845,-0.040614,1.01018,-2.06952,-0.026806,0.879514,-2.06639,-0.196895,0.811778,-2.06016,-0.204702,0.924084,-2.07253,-0.274837,0.915314,-2.06505,-0.50007,0.872855,-2.04297,-0.527846,0.967012,-1.97623,-0.622758,0.700228,-1.99502,-0.657477,0.762565,-2.05079,0.07421,1.32773,-1.83682,0.082254,1.31845,-2.05171},
/*271*/{0.151802,1.87843,-1.71819,0.246038,1.83402,-1.85633,0.022241,1.74912,-1.64517,-0.073151,1.64923,-1.6081,0.072551,1.58048,-1.61918,0.150677,1.53414,-1.60984,0.208972,1.90873,-2.10416,0.260478,1.83951,-1.92939,0.06576,1.87609,-2.04327,0.054935,1.71632,-2.22426,0.096527,1.62245,-2.26886,0.252657,1.56333,-2.15954,0.309512,1.5291,-2.15649,0.154973,1.40953,-1.82376,-0.030903,1.47023,-1.9007,-0.024229,1.4976,-1.96352,-0.016075,1.46714,-2.01682,0.172109,1.39525,-2.0788,0.22021,1.12849,-1.75481,0.098544,1.07139,-1.78756,0.134973,0.995327,-1.80551,0.248432,0.916301,-1.78797,0.308151,0.734404,-1.78,0.323769,0.661557,-1.79471,0.199048,0.708582,-1.79938,0.215436,0.63937,-1.80778,0.3153,0.429994,-1.82404,0.237461,0.350806,-1.91122,0.47853,0.428846,-1.85615,0.46407,0.360532,-1.79623,0.109967,1.07734,-2.11357,0.105793,0.994033,-2.09445,-0.03205,1.08368,-2.08723,-0.033787,1.00333,-2.06886,-0.016266,0.873807,-2.06672,-0.188019,0.811254,-2.06079,-0.191248,0.923518,-2.07263,-0.262916,0.916629,-2.06473,-0.488767,0.881772,-2.04297,-0.514996,0.976494,-1.97736,-0.613792,0.711497,-1.99667,-0.647773,0.774498,-2.05207,0.07442,1.32361,-1.83607,0.083042,1.31372,-2.0509},
/*272*/{0.153368,1.87291,-1.71765,0.247348,1.82836,-1.85668,0.026761,1.74184,-1.64131,-0.068646,1.64175,-1.60305,0.078347,1.57436,-1.61464,0.157081,1.52962,-1.60681,0.207862,1.90367,-2.10469,0.261649,1.8347,-1.92991,0.064925,1.86965,-2.04237,0.051781,1.71153,-2.22354,0.090509,1.6175,-2.26798,0.247414,1.55384,-2.1628,0.304065,1.51739,-2.16009,0.153792,1.40565,-1.82214,-0.031599,1.46518,-1.90088,-0.023928,1.49154,-1.96226,-0.015606,1.46178,-2.01566,0.172233,1.39196,-2.07843,0.218003,1.12377,-1.75373,0.096788,1.06571,-1.78652,0.133032,0.990078,-1.80572,0.243645,0.910316,-1.78811,0.299755,0.727058,-1.78104,0.314473,0.653204,-1.79461,0.19067,0.703275,-1.80078,0.20694,0.633872,-1.80859,0.300505,0.423006,-1.82708,0.218907,0.355937,-1.9124,0.464716,0.414024,-1.85818,0.446032,0.348232,-1.79662,0.11588,1.0733,-2.11451,0.113656,0.989909,-2.09515,-0.02541,1.07715,-2.08628,-0.025,0.997152,-2.06859,-0.00694,0.868062,-2.06773,-0.178928,0.810584,-2.06111,-0.179796,0.924097,-2.07152,-0.250899,0.918516,-2.0647,-0.477261,0.888786,-2.04326,-0.502141,0.9838,-1.97841,-0.604024,0.720583,-1.9975,-0.636678,0.783534,-2.05462,0.074728,1.31885,-1.83535,0.084251,1.30941,-2.05017},
/*273*/{0.154682,1.86766,-1.71668,0.247525,1.82476,-1.85729,0.030985,1.73442,-1.63846,-0.062539,1.6342,-1.59829,0.084784,1.56883,-1.61098,0.164019,1.52582,-1.60418,0.205774,1.89909,-2.10585,0.260801,1.83002,-1.93101,0.063706,1.86453,-2.04197,0.04608,1.70688,-2.22239,0.084855,1.61275,-2.26701,0.242273,1.54349,-2.16522,0.29789,1.50571,-2.16427,0.15321,1.40096,-1.82072,-0.031692,1.45966,-1.90093,-0.024892,1.48629,-1.96177,-0.016355,1.4558,-2.01629,0.173641,1.38734,-2.0757,0.216072,1.1184,-1.75321,0.095573,1.06289,-1.78724,0.130057,0.985619,-1.80553,0.238296,0.904212,-1.78766,0.291717,0.719618,-1.78211,0.308658,0.648193,-1.79641,0.182736,0.698655,-1.80134,0.196047,0.628779,-1.81074,0.283486,0.417042,-1.8279,0.197562,0.354352,-1.9122,0.449907,0.400528,-1.85983,0.428295,0.337197,-1.79636,0.121476,1.06905,-2.11429,0.121061,0.985641,-2.0957,-0.019659,1.07017,-2.0854,-0.017996,0.989956,-2.06808,0.003851,0.862091,-2.06817,-0.169081,0.809842,-2.06217,-0.167211,0.92393,-2.07198,-0.237077,0.919755,-2.06419,-0.464907,0.895589,-2.04296,-0.489623,0.991524,-1.97856,-0.594603,0.728497,-1.9997,-0.62491,0.791874,-2.05662,0.07433,1.31399,-1.83415,0.085639,1.30425,-2.04887},
/*274*/{0.156371,1.8625,-1.71571,0.247628,1.81748,-1.85713,0.035338,1.72665,-1.63551,-0.057618,1.6261,-1.59274,0.091545,1.56396,-1.60726,0.171216,1.5225,-1.60163,0.20411,1.89454,-2.10639,0.261621,1.82464,-1.93173,0.062149,1.85849,-2.04133,0.042685,1.70206,-2.22155,0.079736,1.60813,-2.26661,0.236516,1.53279,-2.16791,0.290724,1.49297,-2.16826,0.152677,1.39686,-1.82002,-0.033587,1.45495,-1.90088,-0.025501,1.48041,-1.9611,-0.017335,1.45019,-2.01624,0.173596,1.38282,-2.07516,0.213127,1.11272,-1.75184,0.091778,1.05807,-1.78738,0.128473,0.981175,-1.80606,0.232131,0.897816,-1.78603,0.28459,0.713371,-1.78348,0.295351,0.639243,-1.79775,0.174472,0.695931,-1.80313,0.186786,0.62631,-1.81237,0.267339,0.416724,-1.83073,0.1764,0.356813,-1.91001,0.432781,0.3936,-1.86574,0.407434,0.339044,-1.79803,0.126831,1.0653,-2.11511,0.127486,0.981375,-2.09639,-0.01432,1.06347,-2.0851,-0.010614,0.983036,-2.06804,0.014804,0.853723,-2.06841,-0.158583,0.808887,-2.06331,-0.153723,0.922884,-2.07296,-0.224294,0.919441,-2.06423,-0.451799,0.900971,-2.04357,-0.477709,0.99821,-1.97931,-0.581714,0.736527,-2.00129,-0.612878,0.798299,-2.05822,0.074095,1.30949,-1.83339,0.08581,1.29926,-2.04806},
/*275*/{0.157782,1.85742,-1.71529,0.249516,1.81245,-1.85763,0.03981,1.71929,-1.63236,-0.050042,1.61842,-1.58706,0.09806,1.55947,-1.60491,0.179223,1.51953,-1.59888,0.203106,1.88959,-2.10703,0.261809,1.81976,-1.93275,0.060456,1.85303,-2.03984,0.039427,1.69757,-2.22109,0.073989,1.60355,-2.26603,0.230779,1.52209,-2.17133,0.283326,1.48058,-2.17284,0.151252,1.39273,-1.81831,-0.035861,1.45039,-1.90158,-0.026742,1.47505,-1.96154,-0.018061,1.44508,-2.0169,0.171084,1.3781,-2.07535,0.210806,1.10863,-1.74851,0.088745,1.05446,-1.78651,0.124842,0.97771,-1.80746,0.224183,0.889898,-1.78562,0.277107,0.709763,-1.78506,0.287481,0.636021,-1.79932,0.166621,0.697257,-1.80404,0.176413,0.626012,-1.81456,0.2507,0.418964,-1.83508,0.154606,0.355811,-1.91183,0.409573,0.391824,-1.87024,0.385865,0.339812,-1.79897,0.132077,1.06102,-2.11566,0.134966,0.97712,-2.0972,-0.009052,1.05678,-2.08441,-0.003282,0.97583,-2.06714,0.025486,0.85073,-2.07142,-0.148123,0.80932,-2.06432,-0.139804,0.921588,-2.07269,-0.209561,0.919713,-2.06475,-0.434357,0.903255,-2.04274,-0.46415,1.0031,-1.9801,-0.569291,0.740802,-2.00266,-0.597115,0.804164,-2.06154,0.072379,1.30524,-1.8329,0.084567,1.29416,-2.0475},
/*276*/{0.159555,1.85278,-1.71419,0.250881,1.80677,-1.85801,0.045155,1.71156,-1.62901,-0.044154,1.61117,-1.58213,0.105994,1.5551,-1.60189,0.187257,1.51671,-1.59726,0.20072,1.88563,-2.10804,0.263074,1.81451,-1.93348,0.059324,1.84859,-2.03869,0.033948,1.6928,-2.2206,0.067521,1.59917,-2.2657,0.224315,1.51092,-2.17519,0.275514,1.46804,-2.17683,0.14863,1.39011,-1.81923,-0.038116,1.44612,-1.90186,-0.028431,1.46904,-1.96308,-0.020548,1.44,-2.01744,0.17406,1.37401,-2.07252,0.205519,1.10668,-1.74519,0.086007,1.05231,-1.78577,0.121353,0.977751,-1.80837,0.216231,0.883002,-1.78778,0.271195,0.710983,-1.78563,0.278369,0.637921,-1.8014,0.160155,0.702038,-1.80533,0.165983,0.630928,-1.81454,0.229554,0.421237,-1.83776,0.131703,0.35765,-1.91365,0.387849,0.39087,-1.87214,0.361847,0.340325,-1.80107,0.138387,1.0561,-2.11523,0.143257,0.973796,-2.09812,-0.003222,1.04986,-2.084,0.004339,0.968683,-2.06679,0.03599,0.844844,-2.07298,-0.135492,0.806067,-2.06522,-0.126159,0.919445,-2.07323,-0.196231,0.91947,-2.06462,-0.424416,0.910362,-2.04454,-0.450847,1.00708,-1.98078,-0.556754,0.743499,-2.00455,-0.582946,0.808436,-2.06398,0.071155,1.30181,-1.832,0.086068,1.28967,-2.04638},
/*277*/{0.161818,1.84867,-1.71347,0.251712,1.80324,-1.85903,0.051043,1.70432,-1.62648,-0.035946,1.60413,-1.57639,0.113885,1.55107,-1.59915,0.195149,1.51449,-1.5953,0.199641,1.88238,-2.10979,0.264234,1.80977,-1.93494,0.058238,1.84589,-2.0369,0.030498,1.68847,-2.21994,0.061718,1.59489,-2.26517,0.217874,1.50064,-2.17953,0.267692,1.4562,-2.18086,0.145448,1.38818,-1.81879,-0.041516,1.44219,-1.90342,-0.031076,1.46405,-1.96374,-0.022982,1.43478,-2.01886,0.17256,1.36966,-2.07102,0.202388,1.10524,-1.74247,0.083718,1.05349,-1.78586,0.118918,0.978096,-1.80892,0.212473,0.883193,-1.78786,0.267492,0.712207,-1.78611,0.271933,0.639145,-1.8022,0.155784,0.709639,-1.80405,0.158561,0.638398,-1.81362,0.207762,0.424234,-1.83908,0.110766,0.357507,-1.91519,0.365841,0.390058,-1.87258,0.339391,0.338609,-1.80202,0.142829,1.05396,-2.11573,0.149465,0.971202,-2.09846,0.00244,1.04271,-2.08302,0.012121,0.96196,-2.06561,0.047383,0.838392,-2.07272,-0.12113,0.802481,-2.06558,-0.111548,0.917559,-2.07275,-0.180956,0.918041,-2.06477,-0.409845,0.912265,-2.04554,-0.437188,1.00961,-1.9815,-0.540958,0.746736,-2.00828,-0.56846,0.810845,-2.06559,0.068536,1.29922,-1.83089,0.085071,1.28493,-2.04501},
/*278*/{0.16398,1.84478,-1.71221,0.252823,1.79898,-1.8598,0.057062,1.6985,-1.62418,-0.027904,1.59718,-1.5717,0.121912,1.54793,-1.5966,0.203511,1.51274,-1.59407,0.198046,1.87969,-2.11175,0.265159,1.80554,-1.93638,0.057234,1.84404,-2.03393,0.027524,1.68489,-2.21936,0.056094,1.59102,-2.2634,0.210585,1.49115,-2.18326,0.258155,1.44492,-2.18486,0.142924,1.38458,-1.81744,-0.044619,1.43878,-1.90396,-0.035076,1.45987,-1.96538,-0.025523,1.43034,-2.01895,0.171891,1.36564,-2.06895,0.20149,1.10618,-1.73896,0.083523,1.05558,-1.78874,0.117863,0.97907,-1.80877,0.216895,0.89142,-1.78549,0.262334,0.712475,-1.78665,0.26038,0.637697,-1.80254,0.149835,0.714921,-1.80132,0.149465,0.642885,-1.81268,0.18887,0.424711,-1.83922,0.08842,0.359403,-1.91477,0.344283,0.388673,-1.87219,0.317639,0.339061,-1.80087,0.147225,1.05268,-2.11558,0.156591,0.970329,-2.09875,0.007527,1.03614,-2.08267,0.019862,0.956851,-2.06577,0.058686,0.832936,-2.07137,-0.107062,0.79944,-2.06482,-0.096462,0.914973,-2.07201,-0.166633,0.916945,-2.06547,-0.394776,0.914072,-2.04653,-0.422755,1.01061,-1.98314,-0.526681,0.747732,-2.00941,-0.553178,0.811852,-2.06805,0.065334,1.29594,-1.8299,0.083795,1.28075,-2.04381},
/*279*/{0.165277,1.84156,-1.71156,0.253331,1.7955,-1.86039,0.063364,1.69367,-1.62278,-0.019857,1.59228,-1.56686,0.131163,1.54631,-1.59556,0.213094,1.51239,-1.59293,0.197397,1.87635,-2.11309,0.265226,1.80218,-1.93752,0.056423,1.84299,-2.0314,0.023902,1.68218,-2.21824,0.051542,1.58815,-2.2615,0.202791,1.48214,-2.18532,0.24885,1.43524,-2.18792,0.140163,1.38319,-1.81511,-0.048104,1.43562,-1.90714,-0.036762,1.45574,-1.96559,-0.028968,1.42416,-2.0207,0.16966,1.36167,-2.06768,0.198024,1.10693,-1.73764,0.080453,1.05461,-1.78853,0.119074,0.978462,-1.8086,0.222306,0.897821,-1.78304,0.255289,0.711721,-1.78723,0.250001,0.638135,-1.80224,0.142344,0.71919,-1.79977,0.139228,0.648282,-1.80969,0.171151,0.42681,-1.83956,0.067443,0.360279,-1.91509,0.324334,0.387966,-1.87217,0.296858,0.338156,-1.80055,0.1513,1.05315,-2.11553,0.164172,0.970274,-2.09918,0.012588,1.03163,-2.08251,0.027941,0.952501,-2.06541,0.071287,0.829074,-2.07185,-0.093096,0.796365,-2.06464,-0.081851,0.912972,-2.07456,-0.150887,0.915165,-2.06608,-0.379825,0.913976,-2.04737,-0.409606,1.01061,-1.9832,-0.511283,0.747408,-2.01103,-0.536906,0.810571,-2.07034,0.062519,1.29422,-1.82827,0.082636,1.27596,-2.04178},
/*280*/{0.166467,1.83901,-1.7113,0.253811,1.79177,-1.86175,0.069544,1.69089,-1.62182,-0.012011,1.58736,-1.56282,0.139437,1.54459,-1.59488,0.222228,1.51186,-1.59221,0.198102,1.87456,-2.11392,0.266061,1.79953,-1.93896,0.056899,1.8427,-2.03111,0.020526,1.68105,-2.21579,0.045876,1.58646,-2.25972,0.195001,1.47582,-2.18641,0.238905,1.42644,-2.19076,0.137257,1.3832,-1.81246,-0.051123,1.43416,-1.90849,-0.037932,1.45426,-1.9653,-0.031013,1.41948,-2.02224,0.168403,1.3586,-2.06621,0.196066,1.10785,-1.73802,0.078153,1.05165,-1.78731,0.119061,0.978384,-1.80868,0.229763,0.903274,-1.78241,0.246202,0.712039,-1.78692,0.239521,0.638027,-1.80263,0.134095,0.721948,-1.79729,0.128327,0.650286,-1.80701,0.151285,0.425716,-1.83933,0.046324,0.361565,-1.91521,0.303208,0.38715,-1.8719,0.274099,0.338155,-1.80014,0.156836,1.05438,-2.11541,0.172271,0.972196,-2.09926,0.018004,1.02866,-2.08295,0.035214,0.94902,-2.06528,0.085002,0.827558,-2.07098,-0.078262,0.794295,-2.06371,-0.066331,0.910353,-2.07416,-0.136668,0.914279,-2.06724,-0.366793,0.913289,-2.04792,-0.395386,1.00982,-1.98471,-0.493687,0.744441,-2.01282,-0.519927,0.807611,-2.07082,0.059722,1.29402,-1.82606,0.081617,1.27269,-2.03912},
/*281*/{0.16814,1.83812,-1.71138,0.254317,1.79035,-1.86281,0.074476,1.68858,-1.6207,-0.000893,1.58466,-1.55942,0.148559,1.54357,-1.59421,0.231731,1.51268,-1.59173,0.198112,1.87267,-2.11357,0.265724,1.7986,-1.94019,0.057029,1.84265,-2.03101,0.018029,1.68192,-2.2132,0.039983,1.58726,-2.25795,0.187097,1.47177,-2.18595,0.22901,1.41983,-2.19339,0.134322,1.38309,-1.80922,-0.051674,1.43275,-1.90988,-0.038832,1.45399,-1.96601,-0.033328,1.41651,-2.02434,0.166165,1.35647,-2.06567,0.192285,1.1074,-1.73749,0.076601,1.05146,-1.7869,0.116316,0.976705,-1.80693,0.233759,0.904327,-1.78361,0.236273,0.710289,-1.78486,0.226842,0.635439,-1.80032,0.124157,0.724201,-1.79544,0.116632,0.652674,-1.8056,0.130601,0.425936,-1.83885,0.024958,0.362766,-1.91445,0.281589,0.385922,-1.87042,0.253964,0.337574,-1.79956,0.162539,1.05542,-2.11482,0.180713,0.973956,-2.09859,0.023685,1.02591,-2.08298,0.044308,0.946706,-2.0661,0.099672,0.827321,-2.07036,-0.063463,0.79286,-2.06277,-0.051516,0.907026,-2.07546,-0.120548,0.911452,-2.06743,-0.344698,0.906795,-2.0464,-0.383218,1.00753,-1.9866,-0.476888,0.740601,-2.01458,-0.503798,0.803101,-2.07221,0.056834,1.29388,-1.82486,0.080149,1.27041,-2.03753},
/*282*/{0.170509,1.83697,-1.7123,0.253995,1.79032,-1.86329,0.079778,1.68749,-1.62036,0.007387,1.58285,-1.55658,0.157714,1.54372,-1.59381,0.241968,1.51422,-1.59177,0.199144,1.87093,-2.11388,0.265246,1.79685,-1.94052,0.057379,1.84265,-2.03131,0.012663,1.68415,-2.20902,0.034334,1.58925,-2.25547,0.177889,1.46739,-2.18551,0.218726,1.41491,-2.19534,0.131692,1.38252,-1.80707,-0.052493,1.43342,-1.91034,-0.040778,1.45472,-1.96618,-0.035408,1.41668,-2.02463,0.163844,1.35476,-2.06507,0.188264,1.10542,-1.73643,0.072154,1.04966,-1.78601,0.110392,0.974687,-1.80481,0.232277,0.900619,-1.78377,0.224846,0.707471,-1.7834,0.21394,0.633436,-1.79841,0.112942,0.723797,-1.79455,0.103688,0.653342,-1.80425,0.110565,0.427126,-1.83777,0.004262,0.363164,-1.91379,0.261238,0.385529,-1.86906,0.231954,0.336975,-1.79865,0.168796,1.05777,-2.11477,0.189664,0.976189,-2.09783,0.030726,1.02588,-2.08494,0.053351,0.945414,-2.06653,0.115392,0.828459,-2.06975,-0.048155,0.792222,-2.06245,-0.035188,0.903901,-2.07649,-0.105176,0.908941,-2.06792,-0.336146,0.908271,-2.05118,-0.371419,1.00437,-1.98889,-0.457787,0.735748,-2.01491,-0.486516,0.796754,-2.07381,0.053289,1.29405,-1.82396,0.077165,1.26952,-2.03646},
/*283*/{0.172733,1.83656,-1.71311,0.25375,1.78891,-1.86439,0.085133,1.68699,-1.61911,0.015864,1.58123,-1.55436,0.167181,1.54459,-1.59332,0.251957,1.51689,-1.59225,0.199538,1.86986,-2.1136,0.264825,1.79579,-1.9412,0.057749,1.84293,-2.03238,0.00939,1.68667,-2.205,0.028407,1.59212,-2.25346,0.16958,1.46568,-2.18575,0.208523,1.41107,-2.19613,0.130019,1.38258,-1.80433,-0.053338,1.43344,-1.91048,-0.041199,1.4547,-1.96535,-0.035694,1.417,-2.02433,0.161574,1.35373,-2.06469,0.184212,1.10316,-1.73575,0.067602,1.04863,-1.78534,0.104785,0.972715,-1.80461,0.224803,0.896292,-1.7822,0.211602,0.702958,-1.78213,0.198514,0.62968,-1.79753,0.101241,0.72303,-1.7937,0.09065,0.652201,-1.80515,0.08957,0.427433,-1.83639,-0.01756,0.364235,-1.91278,0.240222,0.385081,-1.86904,0.21116,0.336376,-1.7978,0.176065,1.06038,-2.11534,0.198709,0.979984,-2.09755,0.039279,1.02405,-2.08536,0.06502,0.944486,-2.06704,0.131527,0.829576,-2.0684,-0.033458,0.79167,-2.06136,-0.020093,0.903163,-2.07713,-0.090298,0.907271,-2.06905,-0.316036,0.900833,-2.04872,-0.360944,1.00033,-1.99177,-0.439366,0.7282,-2.01437,-0.469238,0.788296,-2.07537,0.051213,1.29417,-1.82278,0.075483,1.26892,-2.03514},
/*284*/{0.174186,1.83704,-1.71445,0.252782,1.7876,-1.8653,0.088865,1.68686,-1.6188,0.025128,1.58165,-1.55223,0.176027,1.54616,-1.59265,0.261816,1.52026,-1.59298,0.199602,1.869,-2.11418,0.263967,1.79552,-1.94229,0.058212,1.84337,-2.03337,0.004465,1.69074,-2.20099,0.02179,1.59532,-2.25208,0.160754,1.46579,-2.18688,0.198137,1.40923,-2.19832,0.128603,1.38329,-1.80248,-0.054099,1.43342,-1.91036,-0.042037,1.45513,-1.96521,-0.036981,1.41863,-2.02426,0.160247,1.35439,-2.06434,0.177617,1.0986,-1.73612,0.059535,1.0461,-1.78696,0.098863,0.970694,-1.80395,0.215518,0.89111,-1.78178,0.198656,0.699161,-1.78178,0.183129,0.626238,-1.79733,0.088131,0.721873,-1.79302,0.074929,0.651474,-1.80366,0.070077,0.428541,-1.83571,-0.038594,0.364616,-1.91175,0.218889,0.384114,-1.86826,0.188893,0.336629,-1.79634,0.185108,1.06341,-2.1145,0.2095,0.984137,-2.09718,0.047981,1.02322,-2.086,0.075586,0.943871,-2.06879,0.148013,0.832306,-2.068,-0.018285,0.791869,-2.06033,-0.005266,0.902038,-2.07766,-0.074579,0.905838,-2.06962,-0.301487,0.895076,-2.04966,-0.350824,0.993862,-1.99439,-0.4197,0.719982,-2.01448,-0.450232,0.777977,-2.07678,0.049691,1.29466,-1.82239,0.074494,1.26969,-2.03473},
/*285*/{0.175921,1.83789,-1.71524,0.254012,1.78708,-1.86591,0.093933,1.68802,-1.61742,0.034395,1.58148,-1.54965,0.185687,1.54849,-1.59287,0.271109,1.52397,-1.59453,0.199134,1.86895,-2.1145,0.264406,1.79564,-1.94245,0.057953,1.8441,-2.03392,0.000522,1.69671,-2.19716,0.014626,1.59948,-2.25079,0.152715,1.46642,-2.18701,0.188182,1.40907,-2.1984,0.126274,1.38329,-1.8007,-0.054783,1.43407,-1.9095,-0.042601,1.45625,-1.96364,-0.037894,1.42003,-2.02291,0.159296,1.35539,-2.06401,0.17429,1.09547,-1.73473,0.055007,1.04529,-1.78554,0.090033,0.969452,-1.8052,0.203682,0.885499,-1.78117,0.184238,0.695033,-1.78136,0.167749,0.622308,-1.79713,0.074354,0.720352,-1.79258,0.05926,0.650901,-1.804,0.049291,0.428511,-1.83488,-0.059892,0.364982,-1.91064,0.197345,0.384398,-1.86718,0.167937,0.33623,-1.7958,0.19322,1.0671,-2.11389,0.220286,0.988911,-2.0966,0.058013,1.02259,-2.08734,0.087692,0.944659,-2.06914,0.164446,0.836802,-2.06755,-0.001636,0.789158,-2.05837,0.009832,0.901453,-2.0779,-0.06039,0.903774,-2.07065,-0.292478,0.89277,-2.05366,-0.340602,0.986944,-1.99645,-0.397443,0.71018,-2.01284,-0.430825,0.765778,-2.07744,0.04789,1.2947,-1.82181,0.073175,1.27085,-2.03422},
/*286*/{0.177766,1.83822,-1.71552,0.253652,1.78758,-1.86671,0.097991,1.68977,-1.61665,0.041784,1.58213,-1.54763,0.194604,1.55167,-1.59305,0.28094,1.52945,-1.59607,0.198307,1.86908,-2.1151,0.264075,1.79497,-1.94341,0.057567,1.84551,-2.03431,-0.0041,1.702,-2.1938,0.007535,1.60401,-2.24923,0.14443,1.46809,-2.18746,0.178822,1.41052,-2.19926,0.124897,1.38416,-1.79996,-0.055962,1.43444,-1.90818,-0.043807,1.45651,-1.96356,-0.038554,1.42203,-2.02114,0.157655,1.35728,-2.0644,0.16931,1.09175,-1.73596,0.049862,1.04638,-1.78469,0.081599,0.968198,-1.80537,0.192068,0.881059,-1.78036,0.169517,0.690624,-1.78134,0.151274,0.618252,-1.79661,0.06089,0.718796,-1.79282,0.043922,0.649328,-1.80397,0.028754,0.428005,-1.83299,-0.080823,0.366204,-1.90974,0.176361,0.384759,-1.86659,0.146713,0.336092,-1.79497,0.200849,1.07336,-2.11481,0.231156,0.99491,-2.09691,0.068121,1.02295,-2.08788,0.099755,0.945949,-2.06976,0.180252,0.840028,-2.06706,0.014826,0.788629,-2.05789,0.024236,0.900934,-2.07738,-0.047793,0.902271,-2.07103,-0.275218,0.883714,-2.05216,-0.332281,0.979363,-1.99932,-0.375615,0.700224,-2.01308,-0.410911,0.753535,-2.0788,0.047153,1.29516,-1.82172,0.072187,1.27245,-2.03428},
/*287*/{0.179499,1.84074,-1.71633,0.253867,1.78883,-1.86799,0.101679,1.69232,-1.61627,0.048695,1.5832,-1.54632,0.203073,1.55561,-1.59284,0.290246,1.53453,-1.59855,0.197237,1.86975,-2.11552,0.26312,1.7952,-1.94406,0.057133,1.84705,-2.03445,-0.007385,1.70792,-2.19069,0.000663,1.60988,-2.24826,0.135624,1.47082,-2.18848,0.169141,1.4135,-2.19961,0.12433,1.38494,-1.79885,-0.056048,1.43466,-1.90783,-0.044706,1.45755,-1.962,-0.040133,1.42336,-2.01969,0.157685,1.35867,-2.06497,0.165206,1.0887,-1.73644,0.042413,1.04672,-1.78495,0.073446,0.967081,-1.80528,0.179049,0.875545,-1.78066,0.153959,0.686682,-1.7816,0.134614,0.61408,-1.79783,0.04597,0.716234,-1.79378,0.027632,0.648709,-1.80455,0.009215,0.428521,-1.8327,-0.101226,0.366749,-1.90965,0.156343,0.38458,-1.8657,0.126358,0.335795,-1.79299,0.209001,1.07962,-2.1148,0.242388,1.00214,-2.0968,0.07775,1.02368,-2.08838,0.113885,0.948348,-2.07037,0.195919,0.844595,-2.06664,0.03137,0.788612,-2.05709,0.038647,0.901653,-2.07781,-0.032914,0.900281,-2.07312,-0.260975,0.874991,-2.05233,-0.322093,0.969516,-2.0018,-0.353828,0.688437,-2.01334,-0.389978,0.739353,-2.07952,0.047099,1.29562,-1.82145,0.071731,1.27386,-2.03416},
/*288*/{0.182057,1.84296,-1.71689,0.254006,1.78951,-1.86932,0.105333,1.69495,-1.61566,0.057819,1.58543,-1.54513,0.210971,1.55955,-1.59316,0.298972,1.54102,-1.60108,0.196617,1.87145,-2.11616,0.262676,1.79598,-1.94502,0.056182,1.84944,-2.03399,-0.010903,1.71224,-2.1875,-0.006817,1.61581,-2.247,0.127427,1.47487,-2.18836,0.160228,1.41757,-2.19952,0.123408,1.38624,-1.79828,-0.057097,1.43584,-1.90789,-0.044984,1.45809,-1.96088,-0.042138,1.42523,-2.01759,0.157508,1.36139,-2.06572,0.158675,1.0862,-1.73662,0.033814,1.04567,-1.78505,0.062894,0.967897,-1.80525,0.16597,0.870821,-1.78061,0.138975,0.683695,-1.78204,0.117835,0.612015,-1.79772,0.030667,0.714946,-1.79403,0.012206,0.64614,-1.80468,-0.010336,0.42845,-1.83256,-0.121709,0.367471,-1.90896,0.135632,0.383567,-1.8654,0.105475,0.335898,-1.79338,0.216889,1.08643,-2.11457,0.252709,1.01016,-2.09644,0.087686,1.02728,-2.08914,0.124138,0.954675,-2.07329,0.211562,0.849824,-2.06705,0.047626,0.789509,-2.05706,0.051174,0.901683,-2.07898,-0.01908,0.900269,-2.07356,-0.250784,0.870102,-2.05453,-0.315396,0.959336,-2.00286,-0.330555,0.676865,-2.01349,-0.368057,0.725235,-2.08081,0.047067,1.29654,-1.82154,0.071399,1.27607,-2.03441},
/*289*/{0.184073,1.84598,-1.71831,0.254226,1.79146,-1.87042,0.108925,1.69813,-1.61605,0.064856,1.58732,-1.543,0.218318,1.56411,-1.59437,0.306911,1.5473,-1.60309,0.194522,1.87363,-2.11719,0.262527,1.79805,-1.94731,0.055689,1.85083,-2.03418,-0.017347,1.72052,-2.18686,-0.01414,1.62213,-2.24626,0.120111,1.47977,-2.18922,0.152229,1.42269,-2.19886,0.123951,1.38735,-1.79814,-0.056667,1.43744,-1.90656,-0.0455,1.45957,-1.96027,-0.042883,1.42639,-2.0168,0.155243,1.36449,-2.0662,0.151949,1.08441,-1.73769,0.026598,1.04698,-1.78481,0.052797,0.968822,-1.80539,0.150557,0.866244,-1.78087,0.122973,0.681418,-1.78293,0.103204,0.611494,-1.79944,0.01542,0.713841,-1.79459,-0.003529,0.646177,-1.80464,-0.031111,0.429179,-1.83287,-0.142175,0.368158,-1.90947,0.114155,0.383679,-1.86556,0.084556,0.336397,-1.79372,0.22458,1.09391,-2.11527,0.262674,1.01935,-2.09647,0.097265,1.03029,-2.08979,0.13599,0.959346,-2.07285,0.22607,0.855484,-2.06752,0.064522,0.790956,-2.05741,0.064819,0.903745,-2.07935,-0.005828,0.899989,-2.07432,-0.236706,0.861331,-2.05641,-0.30623,0.947071,-2.00484,-0.307083,0.664295,-2.01268,-0.345739,0.710451,-2.08153,0.047767,1.29776,-1.82167,0.070621,1.27821,-2.0348},
/*290*/{0.186391,1.84918,-1.71885,0.254257,1.79398,-1.8717,0.113199,1.70151,-1.61574,0.071652,1.58993,-1.54202,0.22648,1.5697,-1.59454,0.314383,1.55435,-1.60696,0.19288,1.87598,-2.11789,0.261267,1.79975,-1.9485,0.054555,1.85362,-2.03257,-0.022375,1.7254,-2.1855,-0.021294,1.62857,-2.24573,0.111959,1.48587,-2.18833,0.143316,1.42882,-2.19867,0.125189,1.38808,-1.79883,-0.056343,1.43917,-1.90499,-0.045191,1.46119,-1.95923,-0.043151,1.42837,-2.01566,0.154533,1.36698,-2.06682,0.149259,1.0836,-1.73794,0.01906,1.04867,-1.78467,0.044275,0.968466,-1.80559,0.133963,0.863854,-1.78202,0.107478,0.680472,-1.78428,0.084186,0.609222,-1.8005,-1e-006,0.714204,-1.79455,-0.020648,0.646371,-1.8049,-0.052538,0.430053,-1.83342,-0.162765,0.368586,-1.90998,0.093983,0.38369,-1.86618,0.06411,0.336623,-1.79382,0.230361,1.10215,-2.11567,0.2711,1.02843,-2.09704,0.106242,1.0349,-2.08975,0.146609,0.965,-2.07366,0.2407,0.861786,-2.0678,0.080869,0.792304,-2.05745,0.077106,0.905296,-2.07968,0.007229,0.898115,-2.07431,-0.222678,0.8517,-2.0563,-0.297215,0.934002,-2.00586,-0.28241,0.652137,-2.0135,-0.323135,0.695575,-2.0824,0.048878,1.29872,-1.82204,0.070142,1.28042,-2.03544},
/*291*/{0.188919,1.85269,-1.72005,0.255636,1.79589,-1.8732,0.117832,1.70534,-1.61573,0.078834,1.59293,-1.54113,0.233098,1.57568,-1.59668,0.321926,1.5616,-1.6098,0.189121,1.87901,-2.11835,0.261026,1.80218,-1.94992,0.052649,1.85584,-2.03172,-0.028649,1.73141,-2.18494,-0.028314,1.63534,-2.24517,0.103948,1.49217,-2.18753,0.135388,1.43502,-2.1977,0.126499,1.38908,-1.79908,-0.055718,1.44093,-1.90454,-0.045847,1.46313,-1.95851,-0.043176,1.42957,-2.0145,0.15368,1.37042,-2.06808,0.137349,1.08238,-1.7396,0.012605,1.05219,-1.78416,0.032629,0.970167,-1.80495,0.116962,0.861688,-1.78287,0.091792,0.67865,-1.78624,0.068338,0.60877,-1.80202,-0.014571,0.714535,-1.79589,-0.037262,0.647562,-1.80661,-0.071852,0.43012,-1.83383,-0.183062,0.370458,-1.90995,0.073978,0.383476,-1.86586,0.043737,0.336691,-1.79297,0.236918,1.10991,-2.11552,0.279421,1.03837,-2.09736,0.113854,1.03945,-2.08964,0.157286,0.971162,-2.07329,0.254691,0.869475,-2.0686,0.096793,0.794968,-2.05861,0.088218,0.908277,-2.07881,0.019195,0.898299,-2.07584,-0.20963,0.841275,-2.05668,-0.28826,0.919426,-2.00731,-0.258416,0.638911,-2.01439,-0.300825,0.680876,-2.08373,0.050302,1.2999,-1.82276,0.07014,1.28298,-2.03641},
/*292*/{0.191765,1.85645,-1.72112,0.254408,1.79938,-1.87443,0.122954,1.70893,-1.61556,0.085934,1.59654,-1.54004,0.238928,1.58176,-1.59886,0.327871,1.56936,-1.61347,0.187266,1.88273,-2.11909,0.260811,1.80455,-1.95191,0.051452,1.85854,-2.03043,-0.034938,1.7395,-2.18595,-0.035847,1.64225,-2.24474,0.096229,1.49942,-2.18683,0.127571,1.44189,-2.19669,0.127065,1.3903,-1.79982,-0.055346,1.44373,-1.90281,-0.045057,1.4656,-1.95699,-0.043522,1.43192,-2.01385,0.153671,1.37392,-2.06762,0.135993,1.0823,-1.74033,0.003404,1.05504,-1.78506,0.022698,0.972788,-1.80549,0.10028,0.860215,-1.78477,0.075527,0.678052,-1.78785,0.051215,0.609289,-1.80378,-0.029654,0.715885,-1.79588,-0.053562,0.648627,-1.80786,-0.089862,0.433191,-1.83336,-0.203125,0.371651,-1.90943,0.053416,0.382932,-1.86623,0.022861,0.336848,-1.79333,0.242008,1.12004,-2.11546,0.286776,1.04885,-2.09783,0.121627,1.04378,-2.08911,0.166546,0.977453,-2.07319,0.268149,0.878589,-2.06893,0.113388,0.797074,-2.05964,0.100584,0.909643,-2.08127,0.031715,0.895765,-2.07664,-0.191835,0.829521,-2.05562,-0.28004,0.904812,-2.0061,-0.232647,0.625819,-2.01509,-0.278458,0.665301,-2.08452,0.05101,1.30148,-1.82295,0.07002,1.28604,-2.03679},
/*293*/{0.19448,1.8604,-1.72225,0.257356,1.80342,-1.87706,0.127625,1.71245,-1.61561,0.093576,1.60027,-1.53922,0.245669,1.5886,-1.60051,0.333628,1.57719,-1.61697,0.18274,1.88629,-2.11976,0.260152,1.80768,-1.95372,0.049614,1.86045,-2.02843,-0.041281,1.74598,-2.18498,-0.042665,1.64856,-2.24406,0.089181,1.50667,-2.18602,0.120672,1.45011,-2.19597,0.128035,1.39114,-1.80037,-0.054589,1.44642,-1.90167,-0.044509,1.46827,-1.95501,-0.04287,1.43433,-2.01237,0.153001,1.37725,-2.06819,0.126265,1.08063,-1.74294,-0.004617,1.05768,-1.78485,0.01096,0.974905,-1.80618,0.083019,0.860163,-1.78702,0.059776,0.677636,-1.78971,0.032397,0.608911,-1.80621,-0.046041,0.716543,-1.79714,-0.070031,0.65124,-1.80776,-0.111866,0.434615,-1.83483,-0.223481,0.373118,-1.9092,0.032721,0.382913,-1.86686,0.001778,0.336746,-1.79389,0.247448,1.12793,-2.11509,0.293721,1.05878,-2.09832,0.128678,1.04885,-2.08851,0.176098,0.983369,-2.0725,0.280782,0.889547,-2.06958,0.129046,0.800391,-2.0604,0.111426,0.912146,-2.08244,0.042616,0.896039,-2.07804,-0.182903,0.818902,-2.05615,-0.270552,0.887402,-2.00567,-0.206925,0.612829,-2.01702,-0.253253,0.650059,-2.08516,0.051982,1.30277,-1.82342,0.069558,1.28907,-2.03749},
/*294*/{0.196834,1.86488,-1.72369,0.256664,1.80608,-1.87891,0.132796,1.71654,-1.61546,0.099263,1.60447,-1.53854,0.251487,1.59488,-1.60291,0.339977,1.58533,-1.62138,0.179317,1.8907,-2.12023,0.25975,1.81141,-1.95579,0.048021,1.86385,-2.02707,-0.046281,1.75252,-2.18457,-0.049434,1.65565,-2.24339,0.082571,1.51462,-2.18518,0.113566,1.45772,-2.19503,0.129931,1.39165,-1.80037,-0.05228,1.44938,-1.89995,-0.043854,1.47058,-1.95352,-0.042551,1.43694,-2.01123,0.153826,1.38128,-2.06827,0.117926,1.07951,-1.74511,-0.013992,1.05942,-1.78592,0.00102,0.978259,-1.80624,0.06866,0.861863,-1.789,0.042327,0.678935,-1.79178,0.016492,0.610129,-1.80702,-0.062176,0.718254,-1.79916,-0.087461,0.653135,-1.80713,-0.12987,0.434343,-1.83352,-0.24383,0.376705,-1.90878,0.01291,0.383037,-1.86725,-0.018281,0.337327,-1.79391,0.251518,1.13653,-2.11554,0.30043,1.06877,-2.09863,0.135219,1.05442,-2.08854,0.184297,0.990608,-2.07226,0.292469,0.899725,-2.06995,0.144501,0.803599,-2.06136,0.121527,0.91417,-2.08241,0.053166,0.896023,-2.07838,-0.168253,0.808134,-2.05703,-0.261153,0.870287,-2.00576,-0.179586,0.600138,-2.02018,-0.228322,0.634289,-2.08728,0.053798,1.30397,-1.82394,0.070249,1.29248,-2.03824},
/*295*/{0.199853,1.86958,-1.72492,0.256852,1.81038,-1.88084,0.138135,1.7211,-1.61551,0.106871,1.60858,-1.53813,0.256277,1.60162,-1.60563,0.344231,1.59346,-1.62545,0.17498,1.89449,-2.12011,0.259247,1.81492,-1.95794,0.046381,1.867,-2.02569,-0.051697,1.75953,-2.18396,-0.055494,1.6624,-2.24264,0.075628,1.5223,-2.18391,0.107005,1.46565,-2.19413,0.131227,1.39286,-1.80036,-0.052023,1.45238,-1.89792,-0.042829,1.47344,-1.95215,-0.041603,1.44094,-2.01015,0.153856,1.38481,-2.06797,0.112051,1.07956,-1.74721,-0.020803,1.06193,-1.78348,-0.010079,0.981089,-1.80661,0.055459,0.863694,-1.79146,0.025317,0.68026,-1.79356,-0.001501,0.610997,-1.80821,-0.079067,0.72074,-1.80007,-0.10468,0.654086,-1.80975,-0.149147,0.437626,-1.83389,-0.263567,0.380601,-1.9083,-0.007022,0.382816,-1.86762,-0.039045,0.337,-1.79502,0.25581,1.14471,-2.11605,0.306664,1.07861,-2.09864,0.14211,1.06002,-2.0877,0.192493,0.997241,-2.07181,0.304232,0.911316,-2.07106,0.159623,0.807102,-2.06327,0.130815,0.916493,-2.08257,0.062771,0.89627,-2.07898,-0.152829,0.796651,-2.059,-0.248276,0.85163,-2.00521,-0.151982,0.587842,-2.02262,-0.205421,0.618812,-2.08943,0.054467,1.30569,-1.82419,0.070151,1.29609,-2.03864},
/*296*/{0.202122,1.87428,-1.72646,0.258858,1.81515,-1.88352,0.144299,1.72505,-1.61555,0.113771,1.61294,-1.53696,0.261153,1.60803,-1.60799,0.349833,1.60152,-1.62925,0.171291,1.89917,-2.12052,0.25959,1.81954,-1.95992,0.045193,1.86944,-2.02297,-0.056912,1.76639,-2.18283,-0.062085,1.66862,-2.24158,0.069294,1.53053,-2.18289,0.101253,1.47419,-2.19322,0.132462,1.39432,-1.8004,-0.050267,1.45553,-1.89601,-0.042196,1.47701,-1.95002,-0.040626,1.44395,-2.00885,0.154147,1.38928,-2.06741,0.105237,1.08019,-1.74977,-0.029467,1.06997,-1.78554,-0.020138,0.984941,-1.80814,0.044701,0.866659,-1.79354,0.008412,0.681916,-1.79516,-0.019958,0.612906,-1.81032,-0.096367,0.723066,-1.80188,-0.120649,0.656968,-1.81192,-0.167149,0.440077,-1.83369,-0.283071,0.385775,-1.908,-0.026976,0.381925,-1.86725,-0.058496,0.338116,-1.79448,0.259519,1.15301,-2.1165,0.31201,1.08749,-2.09907,0.147689,1.06653,-2.08764,0.199622,1.0046,-2.07178,0.313948,0.922755,-2.07151,0.173392,0.810808,-2.06442,0.139411,0.918488,-2.08293,0.073278,0.89255,-2.07887,-0.137905,0.784553,-2.05878,-0.239141,0.833222,-2.00345,-0.124467,0.575444,-2.02531,-0.181034,0.604388,-2.09104,0.055826,1.30763,-1.82431,0.070598,1.30008,-2.0389},
/*297*/{0.204888,1.87906,-1.72797,0.25968,1.81916,-1.88518,0.150951,1.72938,-1.6164,0.12027,1.61833,-1.53706,0.266537,1.61591,-1.61083,0.353856,1.60975,-1.63352,0.167914,1.90407,-2.1206,0.259181,1.82358,-1.96204,0.04329,1.87271,-2.02153,-0.060677,1.773,-2.1821,-0.068281,1.67572,-2.23981,0.062472,1.53896,-2.18174,0.095507,1.4826,-2.19251,0.134724,1.39536,-1.80023,-0.048724,1.45838,-1.89435,-0.040992,1.47985,-1.94875,-0.040744,1.44866,-2.00766,0.154833,1.39365,-2.06712,0.103342,1.08219,-1.75113,-0.034233,1.07311,-1.78474,-0.030583,0.989728,-1.8087,0.033563,0.869864,-1.79616,-0.007694,0.684592,-1.79655,-0.036925,0.615685,-1.81116,-0.112768,0.7264,-1.80228,-0.13894,0.6606,-1.81161,-0.186762,0.444411,-1.83388,-0.302088,0.391143,-1.90796,-0.047168,0.381552,-1.8684,-0.080275,0.338063,-1.79518,0.262859,1.16143,-2.11662,0.316674,1.09799,-2.09977,0.153358,1.07109,-2.08653,0.206965,1.0112,-2.07098,0.323183,0.933557,-2.07197,0.187316,0.814252,-2.06649,0.147219,0.920501,-2.083,0.083034,0.89084,-2.0785,-0.121992,0.770963,-2.05902,-0.226013,0.81342,-2.0024,-0.095728,0.565363,-2.02918,-0.154878,0.589191,-2.09279,0.057255,1.3093,-1.82502,0.071046,1.30433,-2.03976},
/*298*/{0.207574,1.88424,-1.72954,0.259779,1.82377,-1.88712,0.156352,1.73459,-1.61611,0.125661,1.62275,-1.53714,0.270437,1.62196,-1.61298,0.35743,1.61766,-1.63771,0.165088,1.90895,-2.12026,0.258333,1.82852,-1.96432,0.041745,1.87621,-2.01901,-0.065647,1.77928,-2.18131,-0.073793,1.68222,-2.23834,0.056897,1.54717,-2.18003,0.090238,1.49099,-2.19142,0.136095,1.3962,-1.79946,-0.046874,1.46281,-1.89332,-0.039917,1.48348,-1.94615,-0.039707,1.4521,-2.00641,0.155418,1.39813,-2.06633,0.092604,1.0816,-1.75479,-0.042149,1.0768,-1.78494,-0.039954,0.995088,-1.80853,0.021813,0.871481,-1.79881,-0.024857,0.688208,-1.7977,-0.053741,0.619508,-1.81246,-0.128634,0.730839,-1.80337,-0.155162,0.664728,-1.81241,-0.204061,0.449088,-1.83456,-0.321114,0.398702,-1.90785,-0.06649,0.381072,-1.86895,-0.100562,0.338232,-1.7957,0.266496,1.16969,-2.11709,0.320782,1.10767,-2.09996,0.158397,1.07751,-2.08626,0.213437,1.01864,-2.07091,0.331378,0.944927,-2.07233,0.200791,0.81904,-2.06783,0.15458,0.92206,-2.08326,0.091707,0.88946,-2.07885,-0.104346,0.757389,-2.05858,-0.211822,0.792264,-2.00079,-0.067382,0.553736,-2.03257,-0.128477,0.575471,-2.0958,0.058023,1.31131,-1.8251,0.07134,1.30849,-2.03991},
/*299*/{0.209462,1.88945,-1.73082,0.260483,1.82844,-1.88948,0.162716,1.73917,-1.61731,0.132756,1.6281,-1.5361,0.274388,1.62953,-1.61629,0.36083,1.62563,-1.64212,0.161696,1.91355,-2.12032,0.258429,1.83316,-1.96619,0.040493,1.87968,-2.0172,-0.069735,1.78516,-2.18005,-0.079672,1.68949,-2.23719,0.051063,1.55459,-2.17832,0.085435,1.4991,-2.19078,0.138201,1.39801,-1.79929,-0.045261,1.46599,-1.89158,-0.038228,1.48731,-1.94435,-0.038263,1.45737,-2.00594,0.156399,1.40282,-2.06531,0.088197,1.08327,-1.75765,-0.048131,1.08203,-1.785,-0.048625,1.00032,-1.8093,0.009715,0.874294,-1.80005,-0.041372,0.692302,-1.79856,-0.070599,0.623382,-1.81237,-0.144721,0.735782,-1.80444,-0.171957,0.670037,-1.81338,-0.221967,0.45115,-1.8319,-0.338867,0.405626,-1.90859,-0.08601,0.38012,-1.86888,-0.121026,0.338851,-1.79644,0.269914,1.17787,-2.11731,0.325957,1.11673,-2.09954,0.16307,1.08425,-2.08614,0.219058,1.02632,-2.07137,0.338971,0.95651,-2.07292,0.214034,0.820778,-2.06875,0.161065,0.923463,-2.0834,0.101002,0.886738,-2.07858,-0.087265,0.7437,-2.05767,-0.198702,0.771611,-1.99806,-0.038587,0.542835,-2.03592,-0.10137,0.561744,-2.09815,0.059376,1.31363,-1.8256,0.072331,1.31328,-2.04044},
/*300*/{0.211821,1.89428,-1.73259,0.261272,1.8337,-1.89124,0.16784,1.74425,-1.61825,0.138105,1.63325,-1.53589,0.278014,1.63655,-1.61868,0.364233,1.63351,-1.64665,0.158382,1.91804,-2.12065,0.257657,1.83855,-1.96829,0.038943,1.88407,-2.01551,-0.073793,1.79197,-2.17955,-0.084689,1.696,-2.23583,0.047164,1.56251,-2.17604,0.080455,1.50721,-2.19044,0.139764,1.39916,-1.79923,-0.043819,1.46912,-1.89059,-0.037218,1.49084,-1.94274,-0.03746,1.46215,-2.00508,0.157091,1.40788,-2.06446,0.083123,1.08438,-1.76171,-0.053657,1.08835,-1.78485,-0.058036,1.00602,-1.8096,-0.004908,0.879081,-1.80084,-0.057133,0.696929,-1.79916,-0.087548,0.628807,-1.81345,-0.159961,0.741495,-1.80567,-0.188429,0.675948,-1.8144,-0.239243,0.457114,-1.83378,-0.356397,0.413766,-1.90798,-0.104275,0.380055,-1.86966,-0.141319,0.340252,-1.79617,0.272749,1.18592,-2.11755,0.329485,1.12568,-2.09957,0.167532,1.09089,-2.08623,0.224769,1.03365,-2.07116,0.345173,0.9671,-2.07297,0.225383,0.826107,-2.07081,0.168298,0.923963,-2.08285,0.109706,0.883882,-2.07749,-0.073563,0.731455,-2.05699,-0.183389,0.749757,-1.99646,-0.008095,0.532483,-2.03909,-0.074021,0.549499,-2.10084,0.060307,1.31549,-1.82656,0.073057,1.31813,-2.0414},
/*301*/{0.213071,1.90003,-1.73477,0.261837,1.83817,-1.89326,0.173174,1.74937,-1.61898,0.143688,1.63899,-1.53592,0.281108,1.64357,-1.6213,0.367048,1.64091,-1.6508,0.156584,1.9226,-2.12051,0.2573,1.84286,-1.97004,0.037629,1.88801,-2.01433,-0.077259,1.79812,-2.17734,-0.089481,1.70318,-2.23347,0.041314,1.57014,-2.17515,0.076099,1.51504,-2.18979,0.142143,1.40119,-1.79871,-0.041667,1.47228,-1.88923,-0.035503,1.49499,-1.94006,-0.035554,1.46772,-2.00435,0.15874,1.41307,-2.06372,0.07754,1.08733,-1.76317,-0.059496,1.0946,-1.78491,-0.064301,1.01195,-1.80697,-0.01976,0.884336,-1.80134,-0.072072,0.702006,-1.79983,-0.103704,0.633498,-1.81344,-0.175121,0.747375,-1.80621,-0.203988,0.68202,-1.81504,-0.256222,0.46268,-1.83367,-0.373222,0.422786,-1.90856,-0.122197,0.379535,-1.86943,-0.161683,0.341111,-1.79668,0.275548,1.19329,-2.11708,0.332694,1.13385,-2.099,0.171987,1.09774,-2.08711,0.229037,1.04102,-2.07092,0.350427,0.977012,-2.07279,0.237334,0.829867,-2.0729,0.17346,0.924321,-2.08275,0.116566,0.881021,-2.07836,-0.055657,0.718855,-2.05684,-0.166268,0.72886,-1.99611,0.021509,0.524071,-2.04334,-0.045008,0.536987,-2.10355,0.062157,1.31794,-1.82716,0.07461,1.32344,-2.04196},
/*302*/{0.214992,1.90515,-1.73686,0.262014,1.84346,-1.89519,0.177891,1.75521,-1.62003,0.14901,1.6443,-1.5357,0.284072,1.65028,-1.62338,0.369511,1.64832,-1.65529,0.153661,1.927,-2.1205,0.256854,1.84774,-1.97184,0.036728,1.89157,-2.01311,-0.080645,1.80359,-2.17508,-0.094492,1.7094,-2.23186,0.03764,1.57731,-2.17339,0.072122,1.52297,-2.18928,0.14405,1.40214,-1.79894,-0.039191,1.47587,-1.88827,-0.034003,1.4991,-1.93881,-0.033867,1.47278,-2.0036,0.159324,1.41775,-2.06295,0.071179,1.09006,-1.76639,-0.064957,1.1006,-1.7843,-0.072949,1.01963,-1.80915,-0.033944,0.890585,-1.80032,-0.086899,0.708253,-1.79949,-0.119562,0.639607,-1.81176,-0.189519,0.754261,-1.80642,-0.219487,0.688617,-1.81603,-0.27182,0.468708,-1.83311,-0.389881,0.433064,-1.90924,-0.141736,0.378199,-1.86992,-0.181884,0.3417,-1.79711,0.278917,1.20129,-2.11729,0.336964,1.14255,-2.09799,0.175732,1.10439,-2.08741,0.23305,1.04869,-2.07151,0.354172,0.986328,-2.07268,0.248037,0.833053,-2.07426,0.178469,0.923694,-2.08235,0.12515,0.877325,-2.07739,-0.038548,0.705018,-2.05696,-0.150325,0.708248,-1.99569,0.052236,0.516331,-2.0472,-0.015627,0.525566,-2.10722,0.06312,1.32,-1.82825,0.075194,1.32824,-2.04299},
/*303*/{0.21659,1.9107,-1.73842,0.263322,1.84813,-1.89718,0.182518,1.76044,-1.62105,0.154353,1.64983,-1.53571,0.286164,1.65711,-1.62709,0.370859,1.65488,-1.65844,0.15168,1.93103,-2.12073,0.256687,1.85266,-1.97347,0.035833,1.89556,-2.01275,-0.084655,1.80934,-2.17507,-0.098486,1.71594,-2.22912,0.03279,1.58472,-2.17228,0.068631,1.52973,-2.18898,0.146069,1.40364,-1.7997,-0.037272,1.47954,-1.88675,-0.032897,1.5033,-1.93692,-0.032247,1.47791,-2.00294,0.160348,1.42314,-2.06258,0.066972,1.09177,-1.76814,-0.066994,1.10925,-1.7828,-0.080178,1.02668,-1.80702,-0.04658,0.896908,-1.80042,-0.101806,0.714781,-1.79866,-0.133135,0.645534,-1.8115,-0.203687,0.761237,-1.80684,-0.234055,0.696163,-1.81614,-0.288849,0.475715,-1.83406,-0.405505,0.443058,-1.90992,-0.160387,0.377407,-1.87053,-0.202575,0.342176,-1.79787,0.281858,1.20894,-2.11731,0.340214,1.15046,-2.09759,0.17845,1.1113,-2.08814,0.237115,1.0566,-2.07219,0.356765,0.995206,-2.07254,0.258304,0.836651,-2.07546,0.183997,0.921473,-2.08146,0.133657,0.872272,-2.07701,-0.020809,0.693077,-2.05939,-0.131939,0.686464,-1.99398,0.08267,0.509121,-2.05154,0.012676,0.515159,-2.11013,0.064569,1.32229,-1.82956,0.076014,1.33365,-2.04419},
/*304*/{0.218954,1.91549,-1.73964,0.262555,1.85186,-1.89945,0.186263,1.76572,-1.62151,0.15885,1.65597,-1.5355,0.288723,1.66321,-1.62907,0.372988,1.66203,-1.66359,0.149612,1.93465,-2.12077,0.25612,1.85717,-1.97551,0.036143,1.89773,-2.01086,-0.087432,1.81478,-2.17273,-0.102756,1.72186,-2.22764,0.029136,1.5915,-2.17115,0.066568,1.53622,-2.18788,0.148399,1.40503,-1.80046,-0.034558,1.48256,-1.88669,-0.030392,1.50737,-1.93545,-0.030425,1.48263,-2.00287,0.16111,1.42821,-2.06243,0.062322,1.09432,-1.76941,-0.073258,1.11407,-1.78314,-0.087212,1.03401,-1.8068,-0.058962,0.903227,-1.79992,-0.115247,0.72165,-1.79748,-0.148145,0.653329,-1.81108,-0.217311,0.768292,-1.80788,-0.247127,0.703569,-1.81636,-0.306292,0.482064,-1.83394,-0.420876,0.45381,-1.91007,-0.179697,0.377143,-1.87064,-0.223392,0.34306,-1.79863,0.283822,1.21658,-2.11703,0.342967,1.15827,-2.0968,0.18223,1.11802,-2.08925,0.240407,1.06306,-2.07198,0.358588,1.00288,-2.07255,0.268026,0.839318,-2.07664,0.188929,0.919715,-2.08054,0.141767,0.867353,-2.07618,0.001425,0.678107,-2.05569,-0.111657,0.663835,-1.99084,0.112902,0.502997,-2.05619,0.042202,0.505751,-2.1136,0.066352,1.32442,-1.83124,0.077266,1.3386,-2.04574},
/*305*/{0.220353,1.92121,-1.74141,0.262797,1.85654,-1.90123,0.189618,1.77096,-1.6227,0.162407,1.66183,-1.53611,0.291065,1.6694,-1.63273,0.374949,1.66856,-1.66706,0.147663,1.93834,-2.12116,0.255947,1.86174,-1.97754,0.036551,1.90123,-2.00921,-0.089874,1.82059,-2.17173,-0.106175,1.72793,-2.22537,0.026415,1.59794,-2.16978,0.063421,1.54272,-2.18751,0.150756,1.40683,-1.80164,-0.032664,1.48594,-1.88497,-0.029134,1.51141,-1.93323,-0.028716,1.48774,-2.00219,0.161818,1.43298,-2.06236,0.062087,1.09926,-1.77029,-0.076218,1.1211,-1.78202,-0.093587,1.04173,-1.80661,-0.069527,0.910047,-1.79994,-0.12888,0.727833,-1.79654,-0.161688,0.66013,-1.80946,-0.229913,0.776379,-1.80809,-0.260055,0.712258,-1.81642,-0.317997,0.488285,-1.83207,-0.43497,0.466058,-1.91114,-0.198904,0.377038,-1.87076,-0.243958,0.344719,-1.79859,0.286502,1.22259,-2.11677,0.345269,1.1652,-2.09582,0.184835,1.12447,-2.09027,0.243242,1.06879,-2.07251,0.358795,1.0101,-2.07311,0.277614,0.841135,-2.07753,0.194099,0.916695,-2.08032,0.150152,0.861774,-2.07423,0.019502,0.664698,-2.0559,-0.092095,0.643498,-1.99127,0.143641,0.49787,-2.05961,0.071953,0.496792,-2.11649,0.06806,1.32682,-1.83242,0.077758,1.34368,-2.04678},
/*306*/{0.221245,1.92553,-1.74316,0.264725,1.862,-1.9035,0.193499,1.77616,-1.62345,0.166949,1.66688,-1.53569,0.292563,1.67506,-1.6345,0.376737,1.67391,-1.67059,0.146401,1.94187,-2.12113,0.2551,1.86566,-1.97915,0.036054,1.90359,-2.00964,-0.091802,1.82421,-2.16887,-0.110172,1.73317,-2.22301,0.02336,1.60338,-2.16833,0.059232,1.5495,-2.18817,0.153346,1.40825,-1.80301,-0.030532,1.49048,-1.88442,-0.027342,1.51527,-1.93175,-0.026612,1.49282,-2.00146,0.16258,1.43822,-2.06232,0.05524,1.1006,-1.77125,-0.07784,1.13013,-1.78149,-0.09933,1.04946,-1.80524,-0.078603,0.916795,-1.79918,-0.139802,0.735539,-1.7953,-0.17382,0.668413,-1.80695,-0.24189,0.78422,-1.80839,-0.272091,0.719503,-1.8173,-0.333369,0.49404,-1.83154,-0.448745,0.478966,-1.91149,-0.21697,0.37712,-1.87111,-0.263786,0.346232,-1.79959,0.288299,1.22969,-2.11603,0.347323,1.17216,-2.09515,0.186507,1.13098,-2.09099,0.246117,1.07429,-2.07181,0.358471,1.01615,-2.07297,0.285991,0.842407,-2.07885,0.198823,0.913324,-2.07941,0.158121,0.854993,-2.0733,0.039202,0.651049,-2.0551,-0.069219,0.620103,-1.98946,0.173245,0.493402,-2.06306,0.102409,0.488676,-2.11884,0.069685,1.32936,-1.83407,0.078484,1.349,-2.04823},
/*307*/{0.22309,1.9294,-1.74473,0.264741,1.86509,-1.90497,0.196149,1.78104,-1.62396,0.170144,1.67119,-1.5362,0.294827,1.68054,-1.63645,0.377492,1.67977,-1.67521,0.145037,1.94522,-2.12143,0.254632,1.86974,-1.98099,0.036302,1.90742,-2.00873,-0.093377,1.83013,-2.16651,-0.113438,1.73855,-2.22088,0.021502,1.60852,-2.16729,0.056504,1.55519,-2.18802,0.155389,1.41007,-1.80393,-0.027972,1.49388,-1.88388,-0.025719,1.51912,-1.92967,-0.024512,1.49773,-2.00149,0.16294,1.44242,-2.063,0.051315,1.10362,-1.77146,-0.080541,1.13768,-1.78148,-0.105022,1.05783,-1.80486,-0.08775,0.924011,-1.79918,-0.152588,0.743817,-1.79314,-0.184312,0.676702,-1.80508,-0.253222,0.791603,-1.8104,-0.283094,0.727793,-1.81677,-0.346362,0.501236,-1.82938,-0.460152,0.491797,-1.91221,-0.236432,0.377522,-1.87058,-0.285435,0.347355,-1.79944,0.290402,1.2354,-2.11545,0.34872,1.17777,-2.09373,0.188318,1.13568,-2.09371,0.245954,1.08181,-2.07536,0.358357,1.02149,-2.07278,0.295586,0.842974,-2.07959,0.203956,0.908779,-2.07891,0.166777,0.848813,-2.07339,0.059739,0.638458,-2.05597,-0.046565,0.599883,-1.98898,0.202574,0.490058,-2.06552,0.131887,0.481268,-2.12102,0.071172,1.33184,-1.83542,0.078867,1.35357,-2.04942},
/*308*/{0.224016,1.93356,-1.74631,0.264991,1.86977,-1.90741,0.198513,1.78571,-1.62494,0.17353,1.6772,-1.53668,0.296181,1.6857,-1.63856,0.378748,1.68549,-1.67907,0.143658,1.94822,-2.12196,0.254422,1.87376,-1.9816,0.035578,1.91045,-2.00764,-0.095121,1.83447,-2.16453,-0.116861,1.7434,-2.21789,0.019103,1.61378,-2.16679,0.054538,1.55999,-2.18758,0.157834,1.41191,-1.80511,-0.025895,1.49745,-1.88304,-0.023216,1.52252,-1.93007,-0.022628,1.50284,-2.0004,0.163448,1.44653,-2.06311,0.046594,1.10763,-1.77128,-0.0822,1.14335,-1.77939,-0.109205,1.06434,-1.80407,-0.09607,0.931574,-1.79849,-0.161879,0.751093,-1.79159,-0.19418,0.683853,-1.80322,-0.26238,0.800358,-1.80813,-0.293696,0.735386,-1.81704,-0.357907,0.508866,-1.82788,-0.469869,0.50588,-1.91078,-0.254674,0.37808,-1.86991,-0.305993,0.349625,-1.80018,0.292046,1.24128,-2.11437,0.349889,1.1823,-2.09241,0.189057,1.14202,-2.09431,0.246235,1.08619,-2.07714,0.357957,1.02548,-2.07366,0.304107,0.843086,-2.08032,0.2101,0.904131,-2.07863,0.174984,0.841601,-2.07315,0.079431,0.625586,-2.05652,-0.023201,0.580619,-1.9886,0.232467,0.487292,-2.06749,0.162015,0.474437,-2.12312,0.072716,1.33445,-1.83669,0.079516,1.35798,-2.05053},
/*309*/{0.226079,1.93748,-1.7478,0.26585,1.87272,-1.90861,0.201144,1.78988,-1.62552,0.177614,1.68146,-1.53673,0.298172,1.69013,-1.6406,0.379762,1.69035,-1.68194,0.143177,1.95113,-2.12202,0.254423,1.87703,-1.98321,0.035644,1.9132,-2.00684,-0.095687,1.83842,-2.16199,-0.119347,1.74806,-2.21555,0.017426,1.61838,-2.16618,0.05312,1.56514,-2.18749,0.159282,1.41387,-1.80596,-0.023526,1.50061,-1.88241,-0.021857,1.52618,-1.9288,-0.020706,1.5074,-2.00034,0.164364,1.45119,-2.06348,0.045053,1.10986,-1.77064,-0.085583,1.15029,-1.77947,-0.113283,1.07196,-1.80414,-0.104021,0.938433,-1.79809,-0.170664,0.758507,-1.79024,-0.204074,0.691524,-1.80078,-0.271,0.808315,-1.80824,-0.301965,0.743014,-1.81513,-0.368356,0.516273,-1.82612,-0.479536,0.521061,-1.91076,-0.273218,0.378701,-1.86962,-0.32652,0.351902,-1.80007,0.293004,1.24549,-2.11306,0.350908,1.18699,-2.09109,0.190312,1.14715,-2.09606,0.24683,1.09069,-2.07911,0.356967,1.02819,-2.07366,0.312837,0.842823,-2.08074,0.215548,0.898667,-2.07865,0.18411,0.834828,-2.07291,0.097179,0.612885,-2.05686,1.1e-005,0.560229,-1.98821,0.260803,0.485165,-2.06845,0.19169,0.468976,-2.12405,0.074115,1.3369,-1.83815,0.080456,1.36274,-2.05174},
/*310*/{0.227243,1.94192,-1.74926,0.266585,1.87748,-1.90971,0.202891,1.79409,-1.62623,0.179607,1.68513,-1.53621,0.299316,1.69445,-1.64264,0.38084,1.69438,-1.6852,0.141772,1.95409,-2.12197,0.254206,1.88027,-1.98458,0.035761,1.9152,-2.00691,-0.09719,1.84243,-2.15967,-0.12223,1.75198,-2.21303,0.016311,1.6229,-2.16551,0.051528,1.56919,-2.18761,0.16194,1.41595,-1.80663,-0.021404,1.50476,-1.88203,-0.020664,1.52964,-1.92836,-0.019454,1.51161,-2.00004,0.164701,1.45523,-2.06404,0.042011,1.1146,-1.7713,-0.086059,1.15564,-1.77834,-0.117329,1.07857,-1.80294,-0.110351,0.945199,-1.79799,-0.179897,0.766338,-1.78831,-0.212837,0.699088,-1.7985,-0.278832,0.815748,-1.80747,-0.309219,0.750799,-1.81389,-0.380328,0.523834,-1.82367,-0.488259,0.537519,-1.91057,-0.291092,0.380372,-1.86844,-0.347621,0.356229,-1.80173,0.294407,1.24931,-2.11164,0.350788,1.19033,-2.08988,0.190182,1.15134,-2.09693,0.246785,1.09414,-2.0807,0.356289,1.02974,-2.07414,0.321014,0.841775,-2.08128,0.22026,0.891637,-2.07911,0.192775,0.827347,-2.07311,0.117934,0.600671,-2.05725,0.023985,0.541779,-1.98944,0.28911,0.48369,-2.06836,0.221039,0.463469,-2.12442,0.075721,1.33991,-1.83905,0.080851,1.36682,-2.05253},
/*311*/{0.228504,1.94424,-1.75079,0.266691,1.8807,-1.91101,0.205075,1.79835,-1.62719,0.182738,1.68885,-1.53616,0.299837,1.69872,-1.64468,0.381328,1.69865,-1.68899,0.141288,1.95663,-2.12207,0.25453,1.88366,-1.98532,0.035953,1.91798,-2.00625,-0.097827,1.84662,-2.15813,-0.124103,1.75572,-2.21043,0.014932,1.62673,-2.16494,0.049933,1.57342,-2.18752,0.163405,1.41798,-1.80819,-0.020205,1.50826,-1.88082,-0.019185,1.53329,-1.92649,-0.017475,1.51646,-1.99932,0.165693,1.45837,-2.06451,0.036206,1.11798,-1.76892,-0.088445,1.16217,-1.77926,-0.120031,1.08444,-1.80247,-0.115575,0.951168,-1.79829,-0.186807,0.772923,-1.78685,-0.221504,0.706092,-1.79676,-0.285691,0.823307,-1.80701,-0.317177,0.759241,-1.81226,-0.39072,0.531621,-1.82186,-0.494626,0.552258,-1.90953,-0.307572,0.382423,-1.86785,-0.368383,0.360709,-1.80237,0.294887,1.25312,-2.11043,0.351,1.19242,-2.08882,0.189434,1.15467,-2.09765,0.245865,1.0968,-2.08143,0.354947,1.03085,-2.07537,0.329477,0.840826,-2.08158,0.225593,0.88515,-2.07928,0.201307,0.818446,-2.07295,0.137625,0.589553,-2.05703,0.046907,0.525593,-1.98978,0.316382,0.482879,-2.06825,0.250281,0.45914,-2.12465,0.076577,1.34242,-1.83994,0.080803,1.37097,-2.05323},
/*312*/{0.230068,1.94732,-1.75171,0.266909,1.8836,-1.91198,0.206577,1.80185,-1.62768,0.184018,1.69245,-1.53722,0.300841,1.70185,-1.64652,0.38159,1.70196,-1.69075,0.140348,1.95903,-2.12269,0.254309,1.88643,-1.98661,0.036676,1.91964,-2.00568,-0.09866,1.84951,-2.15501,-0.126151,1.75908,-2.20838,0.013761,1.63009,-2.16479,0.04881,1.57692,-2.18755,0.165016,1.42032,-1.80863,-0.017812,1.51144,-1.88044,-0.017976,1.53758,-1.92617,-0.016186,1.52048,-1.99863,0.165125,1.46136,-2.06465,0.036454,1.12027,-1.76665,-0.090249,1.16636,-1.77912,-0.122804,1.08994,-1.80362,-0.118491,0.956534,-1.7983,-0.193017,0.77937,-1.78602,-0.227958,0.713454,-1.79529,-0.291168,0.830367,-1.80613,-0.323269,0.767336,-1.81223,-0.400168,0.539203,-1.81901,-0.500611,0.568553,-1.90736,-0.327274,0.384906,-1.86726,-0.388131,0.366521,-1.80355,0.294696,1.25562,-2.10925,0.350401,1.19432,-2.08787,0.188826,1.15743,-2.09837,0.24427,1.09958,-2.08253,0.353454,1.03084,-2.07671,0.33709,0.838831,-2.08322,0.230857,0.877506,-2.07865,0.209935,0.810912,-2.07382,0.159799,0.579438,-2.05801,0.071039,0.508425,-1.99085,0.343537,0.482838,-2.06714,0.278656,0.455117,-2.12426,0.077379,1.34545,-1.8402,0.080433,1.37439,-2.05346},
/*313*/{0.23106,1.95021,-1.75337,0.268379,1.88663,-1.91324,0.208287,1.80562,-1.62844,0.186383,1.6958,-1.53704,0.30248,1.70481,-1.64836,0.381619,1.70489,-1.69406,0.14058,1.96141,-2.12331,0.255004,1.8888,-1.98724,0.036534,1.9218,-2.0059,-0.098804,1.85319,-2.15271,-0.127925,1.76259,-2.20524,0.01244,1.63335,-2.16449,0.047851,1.58049,-2.18826,0.166285,1.42296,-1.80908,-0.01647,1.51397,-1.88007,-0.017076,1.54058,-1.92528,-0.013452,1.52301,-1.99698,0.16636,1.46451,-2.06482,0.034498,1.1238,-1.76495,-0.092217,1.17035,-1.78227,-0.124245,1.09411,-1.80472,-0.120603,0.960733,-1.79928,-0.197497,0.785225,-1.78563,-0.23361,0.719333,-1.79353,-0.295651,0.837795,-1.80523,-0.328392,0.775207,-1.81025,-0.409552,0.547468,-1.8172,-0.506052,0.585306,-1.90432,-0.343829,0.389442,-1.86743,-0.408187,0.37335,-1.80469,0.294284,1.25597,-2.10842,0.349211,1.19465,-2.08731,0.187228,1.15937,-2.09859,0.242155,1.10063,-2.08329,0.351321,1.02978,-2.07773,0.343965,0.837113,-2.08389,0.236388,0.870413,-2.07846,0.218394,0.803235,-2.07458,0.178533,0.568136,-2.05845,0.094575,0.493384,-1.99241,0.369173,0.483329,-2.06525,0.306486,0.451439,-2.12312,0.079047,1.34788,-1.84029,0.081723,1.37757,-2.05345},
/*314*/{0.232809,1.95251,-1.75407,0.268557,1.88998,-1.9153,0.210012,1.80877,-1.62924,0.187834,1.69726,-1.53695,0.302553,1.70789,-1.64967,0.381539,1.70783,-1.69726,0.140034,1.96345,-2.12317,0.255789,1.89115,-1.98898,0.037365,1.92361,-2.00496,-0.099806,1.85503,-2.14963,-0.129297,1.76506,-2.20247,0.012251,1.63551,-2.164,0.047113,1.5836,-2.18839,0.167153,1.42535,-1.80896,-0.015795,1.5177,-1.88022,-0.0146,1.54349,-1.92471,-0.012873,1.52599,-1.99598,0.166877,1.46733,-2.0649,0.033508,1.12727,-1.76417,-0.093562,1.1733,-1.78271,-0.124528,1.09832,-1.80533,-0.121786,0.964537,-1.79957,-0.201495,0.790602,-1.78506,-0.238285,0.725038,-1.79319,-0.298319,0.844936,-1.80486,-0.333935,0.781355,-1.8086,-0.416999,0.55739,-1.81421,-0.511085,0.602313,-1.89932,-0.360763,0.395563,-1.86799,-0.425626,0.3814,-1.8068,0.293167,1.25639,-2.10773,0.348419,1.19321,-2.08677,0.185152,1.16012,-2.09892,0.239001,1.10095,-2.08368,0.349287,1.02866,-2.07864,0.349511,0.834783,-2.08529,0.240853,0.863824,-2.08026,0.226558,0.795288,-2.07514,0.199295,0.55906,-2.06017,0.117853,0.478642,-1.99435,0.393587,0.484601,-2.06316,0.334368,0.448312,-2.12129,0.079634,1.3507,-1.84013,0.081984,1.3805,-2.05328},
/*315*/{0.234035,1.95519,-1.75567,0.26838,1.89139,-1.9156,0.210789,1.81126,-1.6295,0.189488,1.70033,-1.53664,0.30326,1.70999,-1.65144,0.381439,1.70962,-1.69965,0.1398,1.96511,-2.12359,0.255865,1.89266,-1.98976,0.038023,1.92574,-2.00458,-0.100298,1.85729,-2.14817,-0.130665,1.76714,-2.20041,0.011462,1.63847,-2.16421,0.046729,1.58601,-2.1892,0.169008,1.42798,-1.81024,-0.01464,1.52137,-1.87913,-0.014426,1.54659,-1.92385,-0.011983,1.52937,-1.9954,0.167139,1.46918,-2.06464,0.032744,1.13049,-1.7641,-0.093796,1.17633,-1.78501,-0.124865,1.10132,-1.80746,-0.121961,0.967356,-1.80043,-0.205312,0.794386,-1.78566,-0.243797,0.729617,-1.79225,-0.300613,0.85054,-1.80363,-0.33674,0.789277,-1.80759,-0.424992,0.566975,-1.81281,-0.517177,0.61851,-1.89442,-0.376177,0.403267,-1.86971,-0.442896,0.389111,-1.8093,0.291446,1.2553,-2.10734,0.344764,1.19256,-2.08674,0.181946,1.16063,-2.09984,0.23627,1.10042,-2.08433,0.346263,1.02674,-2.07996,0.355287,0.832296,-2.08578,0.245299,0.856899,-2.08141,0.234407,0.7867,-2.07592,0.21972,0.549713,-2.06101,0.141725,0.467365,-1.99605,0.416709,0.486634,-2.06114,0.359963,0.445624,-2.11934,0.080552,1.3537,-1.83972,0.081527,1.38311,-2.05293},
/*316*/{0.234822,1.95688,-1.75654,0.269878,1.89416,-1.91715,0.211479,1.81418,-1.63039,0.190454,1.7023,-1.53718,0.303587,1.71168,-1.65367,0.381982,1.71092,-1.70177,0.139748,1.96682,-2.12357,0.256513,1.89448,-1.99067,0.038165,1.92684,-2.00471,-0.101039,1.85897,-2.14535,-0.131502,1.76891,-2.19839,0.010776,1.64059,-2.16443,0.046012,1.588,-2.18957,0.169661,1.43067,-1.81016,-0.013453,1.52387,-1.87809,-0.013706,1.54982,-1.92307,-0.011698,1.53244,-1.99416,0.167206,1.47116,-2.06445,0.032363,1.13218,-1.76392,-0.093803,1.17797,-1.78554,-0.124646,1.10291,-1.80781,-0.120946,0.969008,-1.80109,-0.206493,0.797747,-1.7848,-0.247497,0.73434,-1.79185,-0.301262,0.856665,-1.80185,-0.338884,0.796275,-1.80521,-0.431227,0.575782,-1.80827,-0.522923,0.633874,-1.887,-0.39258,0.412182,-1.87307,-0.45832,0.399296,-1.81179,0.289358,1.25391,-2.10759,0.34192,1.19006,-2.08701,0.179351,1.15981,-2.1002,0.232441,1.09947,-2.0854,0.343802,1.02454,-2.08136,0.36046,0.829777,-2.08678,0.249703,0.848796,-2.08317,0.241599,0.779315,-2.07727,0.238425,0.541293,-2.06216,0.162795,0.455147,-1.99861,0.439579,0.488368,-2.05787,0.38604,0.444378,-2.11667,0.081062,1.35643,-1.83899,0.081166,1.3856,-2.05224},
/*317*/{0.236751,1.95847,-1.75768,0.269446,1.89625,-1.91766,0.212943,1.81621,-1.63124,0.191689,1.70441,-1.53783,0.302916,1.71249,-1.65494,0.38123,1.71179,-1.70414,0.139639,1.96805,-2.12453,0.256915,1.89552,-1.99182,0.038948,1.92869,-2.00507,-0.101431,1.8594,-2.14275,-0.132315,1.77011,-2.19633,0.010911,1.64193,-2.16459,0.046473,1.5899,-2.19021,0.169955,1.4332,-1.8097,-0.01337,1.52637,-1.87812,-0.013014,1.55229,-1.92358,-0.011289,1.53452,-1.99397,0.167144,1.47319,-2.0637,0.032557,1.13506,-1.76318,-0.093626,1.17881,-1.78651,-0.123587,1.10388,-1.8092,-0.118382,0.970607,-1.80111,-0.207641,0.800358,-1.78525,-0.251104,0.73844,-1.79142,-0.299809,0.862787,-1.79935,-0.339381,0.80334,-1.80107,-0.437946,0.58588,-1.80766,-0.529783,0.649431,-1.88006,-0.409269,0.421731,-1.87717,-0.472066,0.40997,-1.81329,0.286436,1.2515,-2.10799,0.338689,1.18679,-2.08737,0.175697,1.15837,-2.10049,0.227253,1.09719,-2.08583,0.341912,1.02139,-2.08222,0.365995,0.827107,-2.08747,0.252845,0.842036,-2.08497,0.247173,0.772024,-2.07928,0.255584,0.532891,-2.06313,0.184649,0.44262,-1.99797,0.458919,0.49017,-2.05577,0.409617,0.441883,-2.11371,0.081151,1.35902,-1.83836,0.081462,1.38755,-2.0517},
/*318*/{0.237642,1.95977,-1.75841,0.270213,1.89761,-1.91908,0.213781,1.81795,-1.63179,0.192185,1.70553,-1.53826,0.303465,1.71387,-1.65699,0.38072,1.71227,-1.70672,0.140405,1.96925,-2.12511,0.25749,1.89687,-1.9928,0.040394,1.93018,-2.00509,-0.100642,1.86068,-2.14098,-0.132893,1.77079,-2.19411,0.011875,1.64405,-2.16525,0.046079,1.59107,-2.191,0.170068,1.43518,-1.80949,-0.012969,1.52805,-1.87708,-0.012649,1.55467,-1.92338,-0.010863,1.53629,-1.99319,0.168768,1.47501,-2.06318,0.034613,1.13638,-1.76385,-0.092271,1.17913,-1.78738,-0.120937,1.1039,-1.80955,-0.115041,0.970433,-1.80153,-0.207704,0.802094,-1.78563,-0.252471,0.741339,-1.79331,-0.298338,0.866748,-1.79814,-0.338396,0.809133,-1.80008,-0.445058,0.594826,-1.80561,-0.53837,0.663958,-1.87194,-0.423836,0.433334,-1.88156,-0.484633,0.421337,-1.81573,0.283751,1.24848,-2.10817,0.335585,1.18258,-2.08753,0.172169,1.15774,-2.10141,0.222563,1.09495,-2.08562,0.338951,1.018,-2.08352,0.369307,0.825045,-2.08828,0.256398,0.834986,-2.0878,0.253036,0.76446,-2.08122,0.274479,0.526586,-2.06377,0.20466,0.43403,-1.9993,0.477983,0.492315,-2.05193,0.431766,0.440938,-2.11067,0.081606,1.36088,-1.83789,0.082321,1.38959,-2.0512},
/*319*/{0.238221,1.96056,-1.75949,0.269751,1.89889,-1.91976,0.213422,1.81917,-1.63299,0.191044,1.70717,-1.53928,0.303189,1.71377,-1.65847,0.380709,1.71163,-1.70877,0.141019,1.96995,-2.12584,0.257473,1.89709,-1.99371,0.041257,1.931,-2.00545,-0.101125,1.86109,-2.13865,-0.133342,1.77144,-2.19221,0.01288,1.6447,-2.16528,0.046923,1.59199,-2.19166,0.170758,1.43753,-1.80896,-0.012394,1.52987,-1.87666,-0.013783,1.5567,-1.92322,-0.010785,1.5379,-1.99241,0.168497,1.47568,-2.06213,0.038054,1.1364,-1.76465,-0.089654,1.17913,-1.78795,-0.117487,1.10365,-1.81045,-0.109995,0.970085,-1.80272,-0.207054,0.803421,-1.78651,-0.254357,0.744754,-1.7941,-0.295396,0.871796,-1.79546,-0.338769,0.81617,-1.79653,-0.451474,0.605363,-1.80541,-0.546565,0.678073,-1.86377,-0.437849,0.445227,-1.88648,-0.495079,0.431877,-1.81798,0.281361,1.24435,-2.10824,0.331644,1.17806,-2.08812,0.167832,1.15538,-2.10147,0.217634,1.09333,-2.08639,0.335973,1.01427,-2.08434,0.373168,0.823682,-2.08818,0.258522,0.829017,-2.0917,0.260393,0.757915,-2.08549,0.291208,0.520554,-2.06432,0.223444,0.425171,-2.00053,0.495281,0.494209,-2.04853,0.452709,0.440007,-2.10698,0.081832,1.36317,-1.83645,0.082051,1.39055,-2.04994},
/*320*/{0.239811,1.96077,-1.7603,0.271421,1.8997,-1.92162,0.213875,1.8197,-1.634,0.191285,1.70774,-1.53971,0.302923,1.71257,-1.65774,0.378838,1.70935,-1.71005,0.141901,1.97061,-2.12662,0.257493,1.89749,-1.99491,0.041583,1.93153,-2.00616,-0.101203,1.86103,-2.13603,-0.13351,1.77167,-2.19075,0.013522,1.64533,-2.16574,0.047491,1.59251,-2.19253,0.170876,1.43981,-1.80911,-0.011903,1.53127,-1.87654,-0.014049,1.5587,-1.92245,-0.010404,1.53893,-1.99244,0.169307,1.47727,-2.06148,0.042511,1.1365,-1.7648,-0.085909,1.17941,-1.78812,-0.113591,1.10254,-1.81057,-0.104766,0.968327,-1.8036,-0.206063,0.803494,-1.78734,-0.257244,0.74715,-1.79506,-0.291605,0.876242,-1.79338,-0.337324,0.821572,-1.79448,-0.457439,0.61598,-1.80402,-0.554273,0.692183,-1.85526,-0.450836,0.458929,-1.89121,-0.504616,0.443905,-1.81961,0.277559,1.24011,-2.1085,0.327301,1.17426,-2.08888,0.163386,1.1527,-2.10161,0.211764,1.08971,-2.08639,0.331591,1.00937,-2.08502,0.37555,0.821943,-2.08836,0.261472,0.822533,-2.09402,0.266298,0.752413,-2.08762,0.306162,0.514836,-2.06453,0.241152,0.418904,-2.00195,0.510895,0.496504,-2.04647,0.472122,0.439746,-2.10446,0.082435,1.36502,-1.83596,0.082765,1.3921,-2.04948},
/*321*/{0.240498,1.96067,-1.76067,0.270877,1.89982,-1.92189,0.213793,1.82017,-1.63511,0.190856,1.70761,-1.54004,0.301876,1.71128,-1.659,0.377939,1.7081,-1.7123,0.142502,1.97036,-2.12759,0.258604,1.89829,-1.99544,0.042369,1.93289,-2.00639,-0.100713,1.86054,-2.13446,-0.133406,1.77154,-2.18892,0.013777,1.64532,-2.16584,0.048192,1.59261,-2.19309,0.171523,1.44135,-1.80868,-0.01203,1.53189,-1.87632,-0.013175,1.56001,-1.92246,-0.010192,1.53917,-1.9926,0.170432,1.47791,-2.06069,0.047199,1.13566,-1.76725,-0.080495,1.17862,-1.78747,-0.108927,1.09994,-1.81158,-0.09844,0.967055,-1.80392,-0.204752,0.803995,-1.78882,-0.257528,0.749358,-1.79704,-0.287248,0.880401,-1.79149,-0.335718,0.828885,-1.79361,-0.463329,0.62636,-1.80398,-0.561829,0.70594,-1.84744,-0.462505,0.473042,-1.89591,-0.513935,0.456124,-1.82267,0.274899,1.23633,-2.10911,0.32286,1.16837,-2.08955,0.15875,1.15052,-2.10197,0.207403,1.08644,-2.08659,0.328141,1.00505,-2.0856,0.378189,0.819529,-2.08717,0.265366,0.815401,-2.09656,0.271515,0.745644,-2.08955,0.319697,0.510654,-2.06514,0.258176,0.411457,-2.00166,0.525047,0.498342,-2.04343,0.489145,0.439883,-2.10076,0.083143,1.36626,-1.83519,0.083854,1.39264,-2.0488},
/*322*/{0.241234,1.96007,-1.76153,0.270413,1.89937,-1.92245,0.213221,1.82003,-1.63592,0.189432,1.70714,-1.54043,0.300821,1.70921,-1.66048,0.37688,1.70585,-1.71387,0.142972,1.97018,-2.1285,0.259275,1.89827,-1.99571,0.043878,1.933,-2.00752,-0.10099,1.86,-2.13238,-0.133383,1.7706,-2.18805,0.014912,1.64449,-2.16574,0.049331,1.59188,-2.19372,0.170632,1.44246,-1.80754,-0.011983,1.53192,-1.87636,-0.013744,1.56,-1.92303,-0.010305,1.53895,-1.99255,0.171259,1.47845,-2.05966,0.052355,1.13401,-1.76953,-0.077144,1.17594,-1.78714,-0.103345,1.09692,-1.81146,-0.091867,0.964041,-1.80522,-0.203017,0.804561,-1.78996,-0.258527,0.752914,-1.79809,-0.281862,0.88488,-1.78948,-0.333363,0.834937,-1.79137,-0.470199,0.638193,-1.80369,-0.56732,0.720292,-1.84021,-0.474666,0.48756,-1.89974,-0.52216,0.469194,-1.82516,0.271351,1.23137,-2.10974,0.319229,1.16337,-2.09042,0.153977,1.14827,-2.10093,0.201824,1.08253,-2.08638,0.324111,1.00019,-2.08605,0.381553,0.8177,-2.08613,0.268578,0.809312,-2.09957,0.278233,0.739819,-2.09163,0.332706,0.506153,-2.06547,0.271547,0.407634,-2.00361,0.538112,0.500018,-2.04029,0.504493,0.439874,-2.09833,0.083073,1.36688,-1.83439,0.084933,1.39276,-2.04806},
/*323*/{0.242297,1.95981,-1.76287,0.269789,1.89937,-1.92315,0.212565,1.81959,-1.63691,0.188357,1.7065,-1.54077,0.300205,1.7079,-1.66194,0.375826,1.70329,-1.71543,0.144109,1.96946,-2.12943,0.259355,1.89778,-1.99629,0.044629,1.93332,-2.00816,-0.099175,1.8589,-2.13047,-0.132553,1.76945,-2.18679,0.017214,1.64354,-2.16594,0.050223,1.59069,-2.19442,0.170254,1.44343,-1.80722,-0.01203,1.53189,-1.87632,-0.013744,1.56,-1.92303,-0.009764,1.53775,-1.99218,0.172033,1.4785,-2.05866,0.058135,1.13253,-1.77233,-0.072111,1.17336,-1.7875,-0.09725,1.09361,-1.81196,-0.08566,0.961167,-1.8067,-0.201741,0.804869,-1.79082,-0.259423,0.755851,-1.79715,-0.276838,0.889007,-1.78611,-0.329703,0.841012,-1.78973,-0.47448,0.649573,-1.80221,-0.571054,0.735367,-1.83348,-0.485076,0.503065,-1.90216,-0.531304,0.483323,-1.82728,0.268151,1.22662,-2.10959,0.314853,1.15791,-2.09159,0.149631,1.14524,-2.10026,0.196376,1.07831,-2.08646,0.319402,0.995712,-2.08655,0.383878,0.814969,-2.0837,0.272535,0.804053,-2.10255,0.28177,0.734528,-2.09469,0.343769,0.502068,-2.06517,0.284556,0.401317,-2.00325,0.548055,0.501118,-2.03853,0.516337,0.438819,-2.09539,0.083522,1.36728,-1.83347,0.085962,1.39241,-2.04722},
/*324*/{0.242842,1.959,-1.76335,0.270301,1.89966,-1.92375,0.211113,1.81921,-1.63731,0.186383,1.70574,-1.54206,0.29868,1.7053,-1.66314,0.374618,1.69965,-1.71676,0.144646,1.96863,-2.13019,0.259239,1.89731,-1.99661,0.045044,1.93291,-2.00853,-0.09797,1.8569,-2.12868,-0.131545,1.76772,-2.18633,0.018412,1.64205,-2.16609,0.051901,1.58914,-2.19473,0.170107,1.44371,-1.80694,-0.012101,1.53161,-1.87674,-0.013823,1.55979,-1.9236,-0.009545,1.53613,-1.99271,0.173123,1.47867,-2.05722,0.064396,1.13217,-1.77498,-0.065681,1.16932,-1.78671,-0.091483,1.08941,-1.8113,-0.077449,0.957547,-1.80815,-0.199466,0.805699,-1.79228,-0.259399,0.759493,-1.7993,-0.270855,0.89324,-1.78517,-0.326358,0.847498,-1.788,-0.478082,0.662248,-1.79977,-0.57364,0.751758,-1.82831,-0.493584,0.518352,-1.90424,-0.539928,0.497695,-1.82948,0.265449,1.22181,-2.11018,0.311862,1.15243,-2.0922,0.145598,1.14155,-2.10009,0.191851,1.0749,-2.08637,0.314561,0.990649,-2.08709,0.385755,0.812945,-2.08151,0.275467,0.798813,-2.10428,0.286938,0.729699,-2.0966,0.352236,0.498506,-2.06548,0.294206,0.397469,-2.00226,0.557002,0.501835,-2.03647,0.527563,0.438638,-2.09334,0.083879,1.36727,-1.83298,0.087454,1.39195,-2.04677},
/*325*/{0.242571,1.95758,-1.76389,0.269594,1.89869,-1.9241,0.209865,1.81811,-1.63866,0.183372,1.70467,-1.54367,0.297264,1.70277,-1.66393,0.372018,1.69582,-1.71745,0.145895,1.9675,-2.13079,0.259222,1.89649,-1.99716,0.04528,1.93191,-2.00931,-0.09683,1.8544,-2.12752,-0.130494,1.76552,-2.18594,0.019727,1.63981,-2.16653,0.053934,1.58692,-2.1952,0.170198,1.44393,-1.80554,-0.012646,1.53046,-1.87681,-0.014208,1.5582,-1.9233,-0.009864,1.53461,-1.99304,0.173951,1.47845,-2.05616,0.071618,1.12838,-1.77687,-0.061272,1.16274,-1.78619,-0.085424,1.08469,-1.81116,-0.069312,0.95325,-1.80955,-0.197261,0.807432,-1.79266,-0.258358,0.764123,-1.79896,-0.264568,0.89735,-1.784,-0.322257,0.854208,-1.78675,-0.481869,0.675378,-1.79862,-0.573929,0.767756,-1.82447,-0.501937,0.533928,-1.9045,-0.549839,0.512659,-1.83003,0.262587,1.21669,-2.11108,0.308098,1.14657,-2.09313,0.141751,1.13788,-2.09995,0.186719,1.07085,-2.08641,0.310369,0.986104,-2.08717,0.386694,0.810333,-2.07901,0.278095,0.794069,-2.10637,0.290856,0.725825,-2.0981,0.358923,0.495213,-2.06575,0.303963,0.394926,-2.00361,0.564005,0.50178,-2.03417,0.536639,0.43838,-2.09094,0.084517,1.36686,-1.83204,0.088913,1.39103,-2.04587},
/*326*/{0.2425,1.95606,-1.76488,0.26948,1.89666,-1.92416,0.208773,1.81722,-1.63967,0.182295,1.70331,-1.54457,0.29469,1.69871,-1.66491,0.370057,1.69107,-1.71843,0.145751,1.96621,-2.13199,0.259444,1.89562,-1.99753,0.046922,1.93108,-2.01058,-0.096472,1.85189,-2.12524,-0.128946,1.763,-2.18606,0.021247,1.63717,-2.16674,0.055754,1.58434,-2.19614,0.169786,1.44304,-1.80527,-0.012918,1.52862,-1.8775,-0.01367,1.55667,-1.9251,-0.009548,1.53306,-1.99448,0.175167,1.47797,-2.05537,0.077857,1.12599,-1.77939,-0.05612,1.15781,-1.78543,-0.078183,1.07944,-1.81181,-0.060902,0.948854,-1.81103,-0.193749,0.808926,-1.79351,-0.257831,0.767897,-1.79991,-0.258308,0.901406,-1.78376,-0.317007,0.861033,-1.78648,-0.485858,0.688214,-1.79637,-0.573046,0.785281,-1.82175,-0.509329,0.549611,-1.90449,-0.558289,0.529355,-1.83092,0.260415,1.21191,-2.11136,0.304623,1.14118,-2.09419,0.138457,1.13518,-2.09977,0.182784,1.06717,-2.08619,0.306268,0.981178,-2.08716,0.387146,0.808301,-2.07767,0.27892,0.789864,-2.10648,0.293642,0.721234,-2.09819,0.364878,0.492113,-2.0658,0.309169,0.390685,-2.00435,0.569318,0.500754,-2.03343,0.541401,0.437068,-2.09005,0.084624,1.36564,-1.83253,0.09074,1.38999,-2.0463},
/*327*/{0.241558,1.95452,-1.76577,0.270231,1.89551,-1.92454,0.206566,1.81571,-1.64054,0.178597,1.70158,-1.54617,0.293409,1.69531,-1.66559,0.368548,1.68607,-1.71887,0.14637,1.96419,-2.13257,0.259034,1.89392,-1.99767,0.046988,1.93015,-2.01267,-0.095572,1.85231,-2.12585,-0.127745,1.76018,-2.1863,0.024255,1.63438,-2.16716,0.057847,1.58153,-2.19677,0.169846,1.44239,-1.80487,-0.013147,1.52686,-1.87791,-0.013523,1.55471,-1.92585,-0.009364,1.5303,-1.9945,0.175068,1.47621,-2.05468,0.083596,1.12313,-1.78053,-0.050206,1.15216,-1.78487,-0.070817,1.07347,-1.81168,-0.051788,0.944355,-1.81246,-0.190678,0.811572,-1.79345,-0.255886,0.772124,-1.79957,-0.251524,0.905944,-1.7834,-0.311411,0.868107,-1.78537,-0.48664,0.702238,-1.79532,-0.570581,0.802331,-1.81986,-0.515727,0.564956,-1.90311,-0.56698,0.546409,-1.83058,0.258606,1.20713,-2.11235,0.302213,1.13522,-2.09482,0.135381,1.13197,-2.09983,0.179092,1.06373,-2.08569,0.301409,0.976759,-2.08729,0.386806,0.80622,-2.07618,0.278641,0.78586,-2.1056,0.293583,0.718279,-2.09801,0.368733,0.490286,-2.06487,0.314856,0.385803,-2.00546,0.573061,0.501204,-2.03179,0.546829,0.436896,-2.08959,0.08507,1.36451,-1.83171,0.091448,1.3877,-2.0456},
/*328*/{0.241722,1.95223,-1.76608,0.269396,1.89385,-1.92491,0.204019,1.81366,-1.64128,0.175713,1.69901,-1.54734,0.290216,1.69142,-1.66649,0.365077,1.68126,-1.7197,0.146428,1.96202,-2.13299,0.259296,1.8926,-1.99807,0.046581,1.92832,-2.0132,-0.093066,1.84629,-2.1237,-0.125676,1.75653,-2.18697,0.026682,1.63049,-2.16731,0.060234,1.57823,-2.19751,0.169896,1.44171,-1.80448,-0.013374,1.52474,-1.87853,-0.013092,1.55295,-1.92559,-0.009303,1.52786,-1.99527,0.176251,1.47496,-2.05447,0.088551,1.12164,-1.78243,-0.044721,1.14643,-1.78403,-0.06409,1.06792,-1.81193,-0.043318,0.939866,-1.81331,-0.186467,0.813589,-1.79312,-0.253815,0.777342,-1.79878,-0.243557,0.911011,-1.78343,-0.303311,0.874992,-1.78528,-0.487167,0.717494,-1.79322,-0.567005,0.819231,-1.81939,-0.52044,0.580045,-1.90121,-0.573551,0.563511,-1.82899,0.257023,1.20302,-2.1131,0.298628,1.13179,-2.0964,0.133627,1.12879,-2.09945,0.176513,1.06073,-2.08577,0.297293,0.972491,-2.08764,0.385023,0.80341,-2.07555,0.276805,0.782445,-2.10453,0.294484,0.715553,-2.09635,0.369706,0.487404,-2.0647,0.317572,0.386757,-2.00307,0.575471,0.500703,-2.03126,0.549789,0.436523,-2.08941,0.085825,1.36318,-1.83147,0.092885,1.38602,-2.04537},
/*329*/{0.240487,1.94994,-1.76654,0.26951,1.89188,-1.92498,0.202054,1.81107,-1.64187,0.172831,1.69734,-1.54898,0.287541,1.68717,-1.6671,0.362585,1.67573,-1.71957,0.147858,1.96013,-2.13339,0.258763,1.88999,-1.99814,0.047036,1.9267,-2.01415,-0.09054,1.84267,-2.12332,-0.124031,1.75287,-2.18814,0.028505,1.62618,-2.16781,0.062925,1.57438,-2.1981,0.170298,1.44057,-1.8046,-0.013329,1.52205,-1.87945,-0.012308,1.54941,-1.92713,-0.008601,1.52505,-1.99621,0.176601,1.47235,-2.05443,0.096038,1.1178,-1.78285,-0.039513,1.14141,-1.78348,-0.057464,1.06223,-1.81181,-0.035566,0.935584,-1.81462,-0.182502,0.816026,-1.79259,-0.249596,0.781879,-1.7989,-0.235013,0.915178,-1.78361,-0.29767,0.881796,-1.78392,-0.487237,0.730901,-1.78998,-0.56252,0.836746,-1.81978,-0.524294,0.594869,-1.89902,-0.579702,0.581733,-1.82724,0.255731,1.19824,-2.11449,0.296143,1.12624,-2.0981,0.131989,1.12657,-2.09971,0.173474,1.05716,-2.08552,0.293286,0.967986,-2.08757,0.38232,0.800764,-2.07597,0.273997,0.778515,-2.10311,0.291242,0.711216,-2.09464,0.370232,0.484377,-2.06352,0.319282,0.379644,-2.00224,0.575366,0.499551,-2.03179,0.549939,0.434298,-2.08929,0.086725,1.36131,-1.83131,0.09421,1.38298,-2.04532},
/*330*/{0.240104,1.94707,-1.76674,0.269982,1.88891,-1.92551,0.200119,1.80928,-1.643,0.169122,1.6951,-1.55126,0.284116,1.68269,-1.66769,0.359853,1.67002,-1.71989,0.148153,1.95749,-2.13438,0.258092,1.8872,-1.99765,0.046201,1.92524,-2.01613,-0.089328,1.83915,-2.12369,-0.121369,1.74842,-2.18893,0.030307,1.62262,-2.16881,0.065531,1.57029,-2.19898,0.170985,1.43952,-1.80459,-0.01331,1.519,-1.88016,-0.012682,1.54709,-1.92711,-0.008734,1.52225,-1.99685,0.176883,1.46994,-2.05491,0.10223,1.11584,-1.78389,-0.034607,1.13561,-1.78396,-0.050638,1.05651,-1.81275,-0.026991,0.931195,-1.8152,-0.176789,0.818869,-1.79181,-0.246726,0.787769,-1.79671,-0.226586,0.919579,-1.78417,-0.289827,0.889158,-1.78382,-0.485613,0.743998,-1.78683,-0.555856,0.853683,-1.82033,-0.527288,0.609108,-1.89596,-0.584582,0.599452,-1.82584,0.255432,1.19377,-2.11579,0.295826,1.12185,-2.09845,0.130292,1.12378,-2.09982,0.171433,1.05417,-2.08542,0.289881,0.963551,-2.08797,0.37812,0.797195,-2.07641,0.270323,0.774667,-2.10161,0.288063,0.70718,-2.09301,0.36845,0.48115,-2.06254,0.318607,0.375533,-2.0009,0.573973,0.496093,-2.03146,0.548605,0.432155,-2.08915,0.087711,1.35956,-1.83109,0.094902,1.38035,-2.0452},
/*331*/{0.239366,1.94578,-1.76683,0.268673,1.88694,-1.92558,0.196349,1.80631,-1.64325,0.164687,1.69154,-1.55159,0.280579,1.67763,-1.668,0.356278,1.66368,-1.71952,0.148988,1.9546,-2.13462,0.258461,1.88516,-1.9978,0.04769,1.92261,-2.01677,-0.087896,1.83454,-2.12413,-0.11893,1.74345,-2.19033,0.032697,1.6178,-2.16958,0.068862,1.56581,-2.19975,0.171393,1.43728,-1.80457,-0.013008,1.51617,-1.88133,-0.012824,1.5442,-1.92821,-0.008172,1.51893,-1.99739,0.17765,1.46717,-2.0559,0.107658,1.11185,-1.78371,-0.028286,1.13152,-1.78315,-0.044011,1.05054,-1.81207,-0.018471,0.926912,-1.81593,-0.171322,0.821014,-1.79107,-0.242208,0.792455,-1.79567,-0.21671,0.924251,-1.78517,-0.281586,0.896087,-1.78355,-0.483748,0.759181,-1.78923,-0.548483,0.870024,-1.82218,-0.528746,0.623364,-1.89239,-0.587571,0.61764,-1.82333,0.254925,1.18977,-2.11621,0.295405,1.11634,-2.09906,0.129447,1.12155,-2.09978,0.169406,1.05134,-2.08569,0.287666,0.959713,-2.08806,0.3743,0.793798,-2.07698,0.26608,0.770489,-2.1005,0.284328,0.702355,-2.09147,0.366755,0.477653,-2.06064,0.316639,0.373022,-1.99748,0.571618,0.4926,-2.03138,0.546069,0.428712,-2.08924,0.088361,1.35711,-1.83142,0.09582,1.37734,-2.04558},
/*332*/{0.237994,1.94262,-1.76682,0.268099,1.88409,-1.92545,0.194371,1.80319,-1.64345,0.160146,1.6886,-1.55296,0.276416,1.67271,-1.66757,0.352942,1.65681,-1.71889,0.14878,1.95157,-2.13505,0.258347,1.88233,-1.99746,0.046783,1.9196,-2.0176,-0.085733,1.8293,-2.12727,-0.116783,1.73814,-2.19197,0.036348,1.61372,-2.17101,0.071379,1.56071,-2.20044,0.171615,1.4348,-1.80451,-0.013238,1.51309,-1.88184,-0.01245,1.54092,-1.92845,-0.008453,1.51541,-1.99805,0.177142,1.46402,-2.05637,0.112369,1.10875,-1.78367,-0.024966,1.12439,-1.7848,-0.037348,1.04446,-1.81246,-0.009816,0.922747,-1.81565,-0.165316,0.823252,-1.79086,-0.23743,0.795669,-1.79479,-0.206463,0.92783,-1.7847,-0.273651,0.901907,-1.78462,-0.479709,0.771841,-1.78821,-0.539038,0.886132,-1.82394,-0.52945,0.636828,-1.889,-0.589194,0.634799,-1.82051,0.254556,1.18628,-2.11721,0.293261,1.11292,-2.10073,0.128304,1.11921,-2.09926,0.167733,1.04908,-2.08593,0.285814,0.955955,-2.08797,0.369927,0.789389,-2.07773,0.26116,0.765532,-2.09919,0.2796,0.69852,-2.09012,0.362508,0.473821,-2.05887,0.312866,0.36942,-1.99538,0.568182,0.488849,-2.03221,0.541493,0.424123,-2.08846,0.088653,1.35441,-1.83134,0.09583,1.37391,-2.04557},
/*333*/{0.236114,1.93893,-1.76654,0.268108,1.8809,-1.92546,0.191278,1.79995,-1.64397,0.15526,1.68518,-1.55481,0.272358,1.66669,-1.6682,0.348445,1.64974,-1.71828,0.149084,1.94819,-2.13543,0.258119,1.87911,-1.99766,0.046255,1.91739,-2.01965,-0.085801,1.82283,-2.12807,-0.114627,1.73236,-2.19355,0.039236,1.60828,-2.17241,0.074325,1.55552,-2.20155,0.171675,1.43226,-1.80473,-0.013128,1.50981,-1.88187,-0.0127,1.53704,-1.92885,-0.008652,1.51195,-1.99878,0.177331,1.46131,-2.0568,0.117374,1.10583,-1.78327,-0.020138,1.11913,-1.7848,-0.031465,1.03876,-1.81381,-0.002266,0.918857,-1.81538,-0.159151,0.825614,-1.78966,-0.231191,0.802039,-1.79277,-0.196242,0.932028,-1.7859,-0.263446,0.907555,-1.78519,-0.474786,0.784941,-1.78634,-0.529235,0.900344,-1.82629,-0.529334,0.649849,-1.88565,-0.589192,0.65228,-1.81727,0.253996,1.18286,-2.11836,0.291986,1.10849,-2.10218,0.127343,1.11713,-2.10014,0.166035,1.04652,-2.08603,0.285138,0.952511,-2.08738,0.365109,0.784635,-2.07901,0.256375,0.761847,-2.09809,0.274448,0.694395,-2.0884,0.355978,0.467466,-2.057,0.305962,0.364931,-1.9923,0.562897,0.482669,-2.03163,0.535402,0.417156,-2.08808,0.08927,1.35145,-1.83157,0.096388,1.37079,-2.04582},
/*334*/{0.235658,1.9357,-1.76587,0.268567,1.87732,-1.92549,0.187809,1.79596,-1.64396,0.149524,1.68141,-1.55634,0.267571,1.66117,-1.66809,0.344431,1.64234,-1.71721,0.148774,1.94448,-2.1355,0.258171,1.87559,-1.99797,0.045936,1.91329,-2.02041,-0.083997,1.81787,-2.12869,-0.111729,1.72633,-2.19569,0.041157,1.6024,-2.17392,0.07758,1.54961,-2.20262,0.171852,1.4295,-1.80511,-0.013907,1.50567,-1.88275,-0.013179,1.53328,-1.9295,-0.00856,1.50793,-1.99894,0.177306,1.45874,-2.05762,0.122553,1.10274,-1.78279,-0.014373,1.11264,-1.7843,-0.024391,1.03306,-1.81365,0.006408,0.914939,-1.81491,-0.151739,0.827427,-1.78861,-0.224955,0.80586,-1.79103,-0.186906,0.934279,-1.78788,-0.254228,0.912821,-1.78512,-0.468177,0.798232,-1.78425,-0.518842,0.914532,-1.82814,-0.527886,0.662896,-1.88148,-0.58895,0.66898,-1.81399,0.253649,1.17963,-2.1189,0.291157,1.10491,-2.10236,0.126322,1.11489,-2.09944,0.164749,1.04347,-2.08622,0.284902,0.949973,-2.08712,0.360969,0.779154,-2.07949,0.251411,0.757486,-2.09627,0.268815,0.689812,-2.08689,0.350172,0.463476,-2.05571,0.29929,0.361598,-1.98785,0.555633,0.474496,-2.03319,0.527894,0.409514,-2.08624,0.089965,1.34811,-1.83223,0.097086,1.36765,-2.04645},
/*335*/{0.233833,1.93171,-1.76574,0.267044,1.87347,-1.92451,0.183903,1.79217,-1.64414,0.144493,1.67775,-1.55796,0.262754,1.65496,-1.66834,0.340225,1.63449,-1.71624,0.149312,1.94069,-2.13623,0.258143,1.87184,-1.99829,0.045173,1.90994,-2.02207,-0.083078,1.81249,-2.12882,-0.109199,1.71939,-2.19811,0.044281,1.59676,-2.17567,0.080609,1.54334,-2.20387,0.171971,1.42649,-1.80556,-0.013119,1.50116,-1.88274,-0.011957,1.52944,-1.92999,-0.009309,1.50341,-1.99868,0.176968,1.45581,-2.05841,0.127262,1.10017,-1.78194,-0.008644,1.10867,-1.78545,-0.018029,1.0267,-1.81313,0.014485,0.910953,-1.81385,-0.144659,0.828908,-1.78849,-0.218063,0.809585,-1.79145,-0.17626,0.936805,-1.78868,-0.244728,0.917405,-1.78586,-0.461495,0.810973,-1.78232,-0.507591,0.927565,-1.8309,-0.524884,0.674898,-1.87764,-0.584706,0.684149,-1.81034,0.253232,1.17623,-2.11953,0.290175,1.10195,-2.10369,0.125121,1.11227,-2.09947,0.163129,1.04005,-2.08624,0.284481,0.946561,-2.08631,0.356886,0.773858,-2.07984,0.246091,0.753198,-2.09476,0.263174,0.685515,-2.08538,0.341257,0.457106,-2.05376,0.290488,0.358008,-1.98425,0.548289,0.467347,-2.03208,0.518939,0.400993,-2.08508,0.091163,1.34451,-1.83257,0.097515,1.36402,-2.04682},
/*336*/{0.23179,1.92785,-1.76517,0.267153,1.86952,-1.92473,0.18093,1.78777,-1.64489,0.138914,1.67396,-1.55981,0.258259,1.64879,-1.66826,0.335328,1.62606,-1.71483,0.149437,1.93646,-2.13646,0.257573,1.86786,-1.99757,0.044703,1.90533,-2.0236,-0.081753,1.80393,-2.13335,-0.107313,1.71244,-2.20051,0.046988,1.58996,-2.17742,0.083709,1.53668,-2.20512,0.173219,1.42371,-1.80641,-0.012802,1.49672,-1.88305,-0.012612,1.52536,-1.92994,-0.009966,1.49881,-1.9998,0.176351,1.4524,-2.05919,0.131137,1.09697,-1.7809,-0.006429,1.10443,-1.7874,-0.011425,1.02159,-1.81435,0.023064,0.906826,-1.8124,-0.137023,0.830371,-1.787,-0.211047,0.813163,-1.79065,-0.165298,0.939702,-1.78853,-0.23408,0.922028,-1.78664,-0.453633,0.822969,-1.78009,-0.496957,0.939366,-1.83383,-0.521859,0.686331,-1.87293,-0.580664,0.699341,-1.80612,0.252563,1.1724,-2.12014,0.288913,1.09867,-2.10394,0.124186,1.10912,-2.0999,0.162228,1.03732,-2.0868,0.282956,0.943254,-2.08599,0.352573,0.768285,-2.08033,0.241,0.749046,-2.09413,0.257006,0.681054,-2.08408,0.332613,0.452155,-2.05198,0.279651,0.354109,-1.98075,0.539604,0.457323,-2.03172,0.508043,0.390388,-2.08306,0.092601,1.34116,-1.83291,0.097766,1.36009,-2.04725},
/*337*/{0.231363,1.92391,-1.76445,0.267481,1.86504,-1.92451,0.177138,1.78329,-1.64455,0.132707,1.66936,-1.56086,0.252473,1.64243,-1.66825,0.330582,1.61772,-1.71344,0.149418,1.93177,-2.13709,0.258312,1.86316,-1.99727,0.045266,1.90077,-2.02486,-0.081999,1.79691,-2.13674,-0.104648,1.70463,-2.20319,0.050196,1.58302,-2.17911,0.086928,1.53,-2.20644,0.173563,1.42043,-1.80678,-0.012576,1.49165,-1.88249,-0.012788,1.52079,-1.92968,-0.010786,1.49418,-1.99956,0.176452,1.4491,-2.06051,0.136309,1.09201,-1.77969,-0.000749,1.09622,-1.78805,-0.005025,1.01575,-1.8134,0.031455,0.902686,-1.81155,-0.129804,0.83167,-1.78547,-0.203696,0.817298,-1.78797,-0.153466,0.941635,-1.78924,-0.223155,0.926272,-1.78766,-0.44535,0.834709,-1.78509,-0.485907,0.950352,-1.83696,-0.516254,0.695953,-1.86942,-0.57487,0.7133,-1.80201,0.250983,1.16871,-2.12089,0.288038,1.09526,-2.10503,0.123318,1.10594,-2.09996,0.161396,1.03392,-2.08668,0.280751,0.938899,-2.08561,0.346568,0.761425,-2.07957,0.236245,0.744689,-2.09269,0.250857,0.676635,-2.08299,0.322063,0.44626,-2.05085,0.268201,0.350497,-1.97882,0.531372,0.447649,-2.02924,0.497561,0.381237,-2.08087,0.093969,1.33712,-1.83328,0.098138,1.35628,-2.04762},
/*338*/{0.229465,1.91913,-1.76407,0.267357,1.86013,-1.92387,0.173642,1.77898,-1.64496,0.127019,1.66551,-1.56255,0.246788,1.63548,-1.66815,0.325433,1.60917,-1.71246,0.149466,1.92677,-2.13772,0.258076,1.85915,-1.99719,0.044181,1.89516,-2.02673,-0.079658,1.78876,-2.1399,-0.102192,1.69679,-2.20567,0.053382,1.57568,-2.18168,0.089837,1.52249,-2.20706,0.173244,1.41676,-1.80759,-0.013763,1.48749,-1.88357,-0.012557,1.51538,-1.92973,-0.011686,1.48885,-1.9993,0.175996,1.44569,-2.0616,0.140689,1.08958,-1.77851,0.003054,1.09026,-1.78921,0.00143,1.00933,-1.81417,0.039275,0.898208,-1.8101,-0.120866,0.832938,-1.78439,-0.195498,0.819897,-1.78687,-0.142411,0.942776,-1.79213,-0.21288,0.929133,-1.78858,-0.43643,0.845003,-1.78292,-0.473558,0.960311,-1.8405,-0.51035,0.706001,-1.86526,-0.569088,0.72598,-1.79868,0.251201,1.16543,-2.12188,0.287524,1.09126,-2.10533,0.122554,1.10217,-2.09962,0.160779,1.02978,-2.08646,0.278675,0.93377,-2.08602,0.342943,0.755548,-2.07993,0.23065,0.740425,-2.09266,0.244011,0.671886,-2.08256,0.308884,0.439266,-2.04857,0.255201,0.34893,-1.97653,0.519051,0.437177,-2.02805,0.484834,0.371491,-2.0785,0.094511,1.33293,-1.83389,0.098218,1.35212,-2.04824},
/*339*/{0.22749,1.91459,-1.76325,0.267548,1.85485,-1.92356,0.169652,1.77355,-1.64503,0.121528,1.66147,-1.56454,0.24172,1.62861,-1.66778,0.319493,1.60032,-1.71056,0.149827,1.92199,-2.13824,0.257573,1.85389,-1.99716,0.044179,1.88935,-2.02716,-0.079294,1.78038,-2.1432,-0.098996,1.68845,-2.20879,0.056335,1.5682,-2.18355,0.094121,1.51551,-2.2081,0.174851,1.41301,-1.80909,-0.013865,1.48187,-1.88358,-0.013003,1.51063,-1.93052,-0.012143,1.48371,-1.99974,0.175458,1.44185,-2.06292,0.144455,1.08628,-1.7768,0.007308,1.08488,-1.7902,0.00778,1.00424,-1.81639,0.047227,0.893265,-1.80759,-0.112116,0.833577,-1.78263,-0.186752,0.822382,-1.7854,-0.130896,0.943418,-1.79333,-0.201819,0.932125,-1.79159,-0.42617,0.854253,-1.78498,-0.461321,0.969453,-1.84365,-0.50285,0.714409,-1.86192,-0.56122,0.738398,-1.79462,0.249493,1.16195,-2.12337,0.286227,1.08765,-2.10643,0.121571,1.09772,-2.09961,0.159527,1.02614,-2.08709,0.276105,0.928038,-2.08678,0.337331,0.749319,-2.07955,0.22567,0.735628,-2.09221,0.236948,0.666877,-2.08215,0.300565,0.437463,-2.04739,0.237078,0.353978,-1.97703,0.507059,0.426328,-2.02555,0.469027,0.361201,-2.07635,0.09624,1.32859,-1.83489,0.098504,1.34778,-2.04925},
/*340*/{0.225944,1.90861,-1.76266,0.266463,1.84946,-1.92245,0.165587,1.7688,-1.64542,0.113927,1.65745,-1.56638,0.234971,1.62071,-1.6675,0.314357,1.59131,-1.70906,0.149809,1.91649,-2.1385,0.257599,1.84868,-1.99641,0.042993,1.88404,-2.02941,-0.077784,1.77284,-2.14652,-0.096135,1.67999,-2.21212,0.059728,1.55986,-2.18617,0.098143,1.50688,-2.20883,0.174594,1.40918,-1.81038,-0.014291,1.47634,-1.88333,-0.013027,1.50521,-1.93084,-0.012185,1.47747,-1.99857,0.175374,1.43827,-2.06454,0.146679,1.08318,-1.77542,0.012446,1.08012,-1.79157,0.012919,0.997001,-1.81624,0.056577,0.890607,-1.8057,-0.103506,0.834033,-1.78162,-0.178357,0.824913,-1.7853,-0.118647,0.943914,-1.79474,-0.191067,0.934655,-1.79331,-0.415056,0.862099,-1.78358,-0.450174,0.976811,-1.84667,-0.494474,0.721973,-1.85714,-0.550814,0.748512,-1.79141,0.247275,1.15745,-2.12367,0.286255,1.08268,-2.10654,0.120251,1.09218,-2.09948,0.159097,1.02165,-2.08707,0.27375,0.92161,-2.08685,0.332482,0.742204,-2.07878,0.219111,0.730778,-2.09191,0.229683,0.662096,-2.08181,0.287648,0.432658,-2.04632,0.218923,0.353552,-1.97693,0.492683,0.411426,-2.02337,0.450372,0.350178,-2.07349,0.097711,1.32385,-1.83556,0.098974,1.34334,-2.04991},
/*341*/{0.224509,1.90351,-1.76173,0.265967,1.84329,-1.92208,0.161285,1.76335,-1.64533,0.106359,1.65269,-1.56739,0.229334,1.61402,-1.66741,0.30729,1.58167,-1.70741,0.150626,1.91093,-2.13918,0.257436,1.84381,-1.99611,0.043181,1.87734,-2.02988,-0.07607,1.76338,-2.1513,-0.092955,1.67138,-2.21542,0.063563,1.55173,-2.18769,0.102337,1.49915,-2.20994,0.174681,1.40467,-1.81103,-0.014311,1.47052,-1.88399,-0.013915,1.4999,-1.93074,-0.013399,1.47177,-1.99806,0.174953,1.43398,-2.06625,0.149073,1.07912,-1.7736,0.016385,1.07431,-1.79277,0.018748,0.990829,-1.8166,0.06684,0.886501,-1.80364,-0.093214,0.834043,-1.77973,-0.168831,0.826906,-1.78378,-0.107247,0.944637,-1.79621,-0.177363,0.936902,-1.79355,-0.405563,0.871776,-1.78526,-0.437841,0.983924,-1.85036,-0.484538,0.729035,-1.853,-0.541365,0.757764,-1.78697,0.24612,1.1533,-2.12457,0.285119,1.07884,-2.10791,0.119412,1.08754,-2.09972,0.159125,1.01666,-2.08719,0.271553,0.916135,-2.08734,0.325865,0.735217,-2.07824,0.213413,0.726388,-2.09178,0.222521,0.656753,-2.08159,0.278118,0.429384,-2.04418,0.199888,0.356182,-1.97444,0.478321,0.395527,-2.01997,0.431834,0.339691,-2.0722,0.098556,1.31884,-1.83636,0.098757,1.33858,-2.05069},
/*342*/{0.223639,1.89789,-1.76039,0.266536,1.83927,-1.9208,0.157387,1.75763,-1.64552,0.100676,1.64868,-1.56834,0.223,1.60707,-1.66614,0.302319,1.57304,-1.70482,0.151448,1.90514,-2.13995,0.258467,1.83842,-1.99517,0.041948,1.87174,-2.03233,-0.075989,1.75448,-2.15543,-0.089384,1.66195,-2.21901,0.06869,1.54322,-2.18919,0.106745,1.49093,-2.21035,0.175561,1.4003,-1.81224,-0.014511,1.46459,-1.88399,-0.014178,1.49357,-1.93169,-0.014629,1.46633,-1.99815,0.174762,1.43001,-2.06801,0.153922,1.07529,-1.77042,0.021118,1.06763,-1.79349,0.025382,0.984547,-1.81759,0.075292,0.883218,-1.802,-0.083291,0.834824,-1.77709,-0.158802,0.829563,-1.78332,-0.093907,0.944556,-1.79769,-0.165636,0.939034,-1.79548,-0.392863,0.878615,-1.78483,-0.426046,0.989809,-1.85372,-0.473624,0.735615,-1.84966,-0.530316,0.765722,-1.78421,0.244453,1.14865,-2.12571,0.283762,1.07447,-2.1096,0.117998,1.08259,-2.10075,0.157023,1.01156,-2.0872,0.267569,0.91038,-2.08765,0.320139,0.727857,-2.07679,0.207359,0.721451,-2.09128,0.215094,0.651891,-2.08077,0.258341,0.424761,-2.03913,0.176936,0.354826,-1.97492,0.462178,0.385481,-2.00869,0.411004,0.342769,-2.07212,0.100137,1.31382,-1.83758,0.099131,1.33393,-2.05187},
/*343*/{0.221863,1.89248,-1.75979,0.266759,1.83237,-1.92013,0.152455,1.75161,-1.64593,0.093189,1.64447,-1.56984,0.216523,1.59963,-1.66541,0.294678,1.56354,-1.70317,0.152545,1.89978,-2.14073,0.258705,1.83294,-1.99511,0.041804,1.86475,-2.03249,-0.072829,1.74541,-2.15924,-0.085425,1.65319,-2.22252,0.072549,1.5344,-2.19145,0.111268,1.48181,-2.21106,0.175989,1.39546,-1.81388,-0.015507,1.45805,-1.88342,-0.014177,1.48794,-1.93128,-0.016372,1.46101,-1.99811,0.173636,1.42567,-2.07014,0.159955,1.07113,-1.76682,0.025306,1.05892,-1.79458,0.032011,0.977266,-1.81719,0.085714,0.880134,-1.79894,-0.072545,0.835098,-1.77629,-0.148018,0.829294,-1.78166,-0.081543,0.944719,-1.79884,-0.15316,0.939698,-1.79629,-0.382495,0.88424,-1.78425,-0.41427,0.994633,-1.85688,-0.463133,0.740407,-1.84628,-0.518601,0.772885,-1.78168,0.241565,1.14424,-2.12822,0.281146,1.06979,-2.11228,0.115797,1.07855,-2.10155,0.155273,1.00755,-2.08725,0.264437,0.905427,-2.08857,0.312946,0.720308,-2.07312,0.20113,0.71747,-2.09076,0.20687,0.647269,-2.07936,0.240344,0.424656,-2.03468,0.153786,0.355271,-1.97491,0.435075,0.385909,-2.01215,0.387362,0.341846,-2.07254,0.101112,1.30833,-1.83899,0.098227,1.32926,-2.05319},
/*344*/{0.220459,1.88653,-1.75894,0.266413,1.82643,-1.9191,0.148347,1.74622,-1.64624,0.085714,1.63982,-1.57076,0.209353,1.59214,-1.66554,0.287927,1.55454,-1.70055,0.153151,1.894,-2.14153,0.259239,1.82745,-1.99376,0.041783,1.85801,-2.03431,-0.071765,1.73578,-2.16307,-0.081056,1.64336,-2.22586,0.077439,1.52683,-2.19337,0.116302,1.47327,-2.21173,0.175622,1.39075,-1.81501,-0.015711,1.45209,-1.88356,-0.015894,1.48189,-1.93189,-0.018801,1.45632,-1.99783,0.17188,1.42035,-2.07193,0.164556,1.06617,-1.76544,0.029309,1.05423,-1.7957,0.039856,0.970418,-1.81866,0.094765,0.876363,-1.79704,-0.061419,0.835139,-1.7739,-0.135042,0.83105,-1.78032,-0.066981,0.944515,-1.79842,-0.139494,0.94121,-1.79853,-0.369192,0.889428,-1.78488,-0.401845,0.998334,-1.85963,-0.450784,0.744398,-1.84211,-0.506757,0.778706,-1.77986,0.237793,1.14034,-2.1328,0.277015,1.06616,-2.11675,0.112339,1.07531,-2.10151,0.152612,1.00459,-2.08695,0.259181,0.899167,-2.08967,0.308355,0.713664,-2.06838,0.197348,0.715051,-2.08994,0.197439,0.645683,-2.07679,0.215305,0.426026,-2.03034,0.129792,0.354826,-1.97168,0.409725,0.386381,-2.00814,0.36351,0.342655,-2.07209,0.100998,1.30317,-1.83989,0.096519,1.32398,-2.05407},
/*345*/{0.218918,1.88081,-1.75771,0.265831,1.82003,-1.91707,0.143874,1.74055,-1.64642,0.078636,1.63643,-1.57294,0.202307,1.58463,-1.66443,0.280109,1.54558,-1.69807,0.154956,1.88842,-2.14285,0.259301,1.82144,-1.99361,0.041146,1.8524,-2.03597,-0.068043,1.7267,-2.16832,-0.075841,1.63361,-2.2298,0.082664,1.51808,-2.19511,0.121995,1.46488,-2.21233,0.176087,1.38534,-1.8164,-0.018248,1.44686,-1.8832,-0.017789,1.47559,-1.93159,-0.021047,1.45092,-1.99766,0.16936,1.41561,-2.07354,0.167698,1.06206,-1.76538,0.034188,1.04487,-1.79606,0.047113,0.963072,-1.81875,0.104431,0.872056,-1.79551,-0.05013,0.835282,-1.77539,-0.124589,0.830384,-1.77642,-0.054764,0.943811,-1.80018,-0.126364,0.941486,-1.7984,-0.355149,0.893332,-1.78497,-0.389602,1.00105,-1.86243,-0.437082,0.74821,-1.8388,-0.493452,0.783769,-1.77689,0.23433,1.13671,-2.13885,0.273119,1.06274,-2.122,0.109131,1.07334,-2.10041,0.149549,1.00279,-2.08597,0.253671,0.893944,-2.0903,0.302942,0.710344,-2.06389,0.192519,0.717369,-2.08751,0.188848,0.648733,-2.07299,0.189291,0.427034,-2.02662,0.10714,0.357338,-1.97213,0.389591,0.382275,-2.00839,0.340384,0.342349,-2.07121,0.100723,1.29776,-1.84095,0.094295,1.31894,-2.05504},
/*346*/{0.217873,1.87509,-1.75643,0.26726,1.81413,-1.9159,0.139276,1.73509,-1.64688,0.071549,1.63314,-1.57495,0.195211,1.57792,-1.6631,0.273236,1.53837,-1.69571,0.156525,1.88279,-2.14408,0.261174,1.81582,-1.99262,0.040805,1.84827,-2.03745,-0.066066,1.71664,-2.1727,-0.070682,1.62399,-2.23327,0.088602,1.50891,-2.19731,0.128147,1.45658,-2.21261,0.17545,1.38036,-1.81829,-0.019652,1.44037,-1.88297,-0.02005,1.46986,-1.9306,-0.024504,1.4467,-1.99774,0.167085,1.41268,-2.07505,0.170923,1.05866,-1.76408,0.040417,1.03959,-1.79677,0.053582,0.956745,-1.81913,0.115676,0.86887,-1.79227,-0.037341,0.834155,-1.77442,-0.11218,0.832836,-1.77709,-0.040606,0.942467,-1.80147,-0.111464,0.942176,-1.79875,-0.343751,0.897331,-1.785,-0.376733,1.00321,-1.86446,-0.422901,0.750234,-1.83517,-0.479594,0.786346,-1.77401,0.23068,1.13327,-2.1437,0.270303,1.0592,-2.12609,0.106761,1.07269,-2.09888,0.146673,1.00151,-2.08577,0.24906,0.890712,-2.09138,0.295142,0.708861,-2.06094,0.185366,0.721664,-2.08639,0.178834,0.653342,-2.07227,0.17545,0.430433,-2.02597,0.085751,0.357835,-1.97061,0.367123,0.38252,-2.00597,0.318006,0.342514,-2.07017,0.100576,1.29222,-1.84316,0.092359,1.31558,-2.05697},
/*347*/{0.216782,1.86995,-1.75493,0.267484,1.80692,-1.91453,0.134905,1.72999,-1.64745,0.063737,1.62988,-1.57604,0.18789,1.57147,-1.66183,0.265047,1.53023,-1.69334,0.158244,1.87811,-2.14531,0.261221,1.80991,-1.99236,0.042545,1.84577,-2.0371,-0.062077,1.70739,-2.17854,-0.064405,1.61402,-2.23646,0.094766,1.50026,-2.19914,0.13448,1.44816,-2.21299,0.174397,1.37523,-1.82062,-0.02173,1.43546,-1.88255,-0.022255,1.46374,-1.92954,-0.027302,1.44229,-1.99691,0.164921,1.40982,-2.07701,0.178091,1.05722,-1.76268,0.046601,1.03275,-1.79636,0.061593,0.95021,-1.81909,0.126892,0.864387,-1.79204,-0.024068,0.832824,-1.7737,-0.098293,0.833138,-1.77531,-0.026063,0.941391,-1.80202,-0.09869,0.940946,-1.79916,-0.329123,0.899308,-1.78572,-0.364228,1.00368,-1.86586,-0.407983,0.751419,-1.83293,-0.464237,0.788075,-1.77199,0.227496,1.12992,-2.14634,0.267603,1.05651,-2.1285,0.104732,1.0713,-2.09852,0.144503,0.999929,-2.0841,0.249119,0.889987,-2.09219,0.28585,0.707603,-2.06032,0.176436,0.726445,-2.0855,0.166345,0.658141,-2.07174,0.156394,0.430924,-2.02473,0.062474,0.35852,-1.96894,0.346344,0.380976,-2.00601,0.295491,0.342417,-2.06933,0.100113,1.28685,-1.84528,0.089985,1.31224,-2.05878},
/*348*/{0.215105,1.8645,-1.75346,0.267689,1.80227,-1.91355,0.130472,1.72563,-1.6475,0.054995,1.62719,-1.57828,0.181592,1.56579,-1.66111,0.25672,1.52333,-1.69127,0.159715,1.87299,-2.14689,0.262785,1.80504,-1.99089,0.043568,1.84309,-2.03731,-0.054835,1.69885,-2.18504,-0.057779,1.60447,-2.24002,0.101156,1.49172,-2.20024,0.14228,1.44085,-2.21313,0.173603,1.3708,-1.82189,-0.024002,1.43083,-1.88108,-0.025216,1.46003,-1.93018,-0.030192,1.43881,-1.99573,0.16277,1.4064,-2.07927,0.184081,1.05557,-1.76156,0.050667,1.02643,-1.7978,0.071117,0.945057,-1.81894,0.139083,0.861889,-1.78952,-0.010603,0.831506,-1.77315,-0.086152,0.832011,-1.77554,-0.01237,0.940759,-1.80222,-0.083386,0.94029,-1.79919,-0.315091,0.90044,-1.78464,-0.351908,1.00367,-1.86705,-0.392963,0.750727,-1.83106,-0.448438,0.788165,-1.7702,0.223301,1.12804,-2.14677,0.263942,1.05422,-2.12953,0.101168,1.06826,-2.09777,0.141629,0.998064,-2.08353,0.250646,0.889602,-2.09182,0.274295,0.706749,-2.06196,0.165085,0.729529,-2.08445,0.153591,0.662155,-2.07189,0.13638,0.431776,-2.02312,0.040795,0.359766,-1.96699,0.324683,0.380287,-2.00542,0.273612,0.342334,-2.06927,0.098854,1.28254,-1.8466,0.08699,1.30889,-2.05989},
/*349*/{0.215183,1.86017,-1.75177,0.268124,1.79737,-1.91181,0.125132,1.72175,-1.64799,0.048039,1.6247,-1.57959,0.174594,1.56107,-1.6596,0.247754,1.51684,-1.68891,0.161102,1.86828,-2.14829,0.263476,1.79963,-1.98966,0.044645,1.84032,-2.03753,-0.04937,1.68926,-2.19227,-0.049881,1.59426,-2.24294,0.109429,1.48464,-2.20109,0.150456,1.43283,-2.21249,0.172829,1.36706,-1.82459,-0.025251,1.42565,-1.87997,-0.02613,1.45702,-1.92942,-0.031915,1.43498,-1.99345,0.160831,1.40477,-2.08107,0.187902,1.055,-1.76117,0.058029,1.02254,-1.79669,0.080114,0.941329,-1.81754,0.151942,0.859508,-1.78848,0.002852,0.830079,-1.77297,-0.071496,0.830693,-1.77716,0.002006,0.939161,-1.80236,-0.06901,0.939331,-1.79921,-0.30154,0.899666,-1.78619,-0.340117,1.00195,-1.86796,-0.377126,0.749145,-1.82963,-0.432825,0.786262,-1.76779,0.219186,1.12601,-2.14718,0.258973,1.05167,-2.13058,0.097377,1.06578,-2.09676,0.137722,0.99585,-2.08284,0.252444,0.889808,-2.09032,0.263723,0.70508,-2.06584,0.154392,0.731683,-2.0845,0.140224,0.663276,-2.07145,0.112437,0.430391,-2.02259,0.019635,0.361455,-1.96773,0.302557,0.379336,-2.00576,0.251389,0.341739,-2.06944,0.099154,1.27829,-1.84865,0.084981,1.30685,-2.06151},
/*350*/{0.214461,1.85584,-1.7497,0.269268,1.79248,-1.91026,0.119504,1.71894,-1.64842,0.037893,1.62345,-1.58174,0.166498,1.55682,-1.65864,0.240225,1.51217,-1.68655,0.163825,1.86422,-2.14839,0.263729,1.79547,-1.98826,0.045327,1.83916,-2.0379,-0.043329,1.68189,-2.19847,-0.040707,1.58512,-2.24585,0.118085,1.47829,-2.20054,0.158902,1.42693,-2.21199,0.171229,1.36258,-1.82552,-0.027839,1.42275,-1.87798,-0.027753,1.4549,-1.92828,-0.034072,1.43291,-1.99163,0.158361,1.40256,-2.08306,0.194808,1.05687,-1.76163,0.064014,1.01915,-1.79665,0.08974,0.938707,-1.81665,0.16505,0.85761,-1.78792,0.017207,0.828672,-1.77263,-0.058699,0.829594,-1.77781,0.01596,0.938543,-1.80094,-0.055089,0.938861,-1.7996,-0.286603,0.897204,-1.78584,-0.329144,1.00004,-1.8684,-0.360962,0.745581,-1.82853,-0.415947,0.782486,-1.76605,0.213927,1.12277,-2.14751,0.253265,1.04848,-2.13246,0.091958,1.06414,-2.09577,0.132197,0.993556,-2.08201,0.252897,0.890383,-2.08858,0.251195,0.702269,-2.06989,0.141715,0.731334,-2.08529,0.126938,0.66407,-2.07186,0.098095,0.43432,-2.0225,-0.003147,0.362327,-1.96676,0.280855,0.378577,-2.0075,0.229117,0.341472,-2.06975,0.097005,1.27443,-1.84988,0.081232,1.30495,-2.06236},
/*351*/{0.213689,1.85143,-1.74839,0.268274,1.78878,-1.90862,0.114668,1.71783,-1.64939,0.029931,1.62379,-1.58405,0.158261,1.55379,-1.65812,0.232563,1.50739,-1.68331,0.166153,1.86095,-2.14763,0.264095,1.79195,-1.98687,0.045905,1.83633,-2.0378,-0.038098,1.67538,-2.20522,-0.030745,1.57712,-2.248,0.126841,1.47331,-2.20004,0.169304,1.42277,-2.21136,0.169214,1.35819,-1.82614,-0.028632,1.42042,-1.87614,-0.027992,1.45386,-1.92789,-0.035736,1.43139,-1.98921,0.156449,1.4016,-2.08471,0.202495,1.05917,-1.76186,0.073845,1.01754,-1.79332,0.10011,0.936991,-1.81431,0.179548,0.857244,-1.78877,0.030845,0.827237,-1.77325,-0.044055,0.827829,-1.77891,0.030256,0.937183,-1.80067,-0.041604,0.938089,-1.79933,-0.272685,0.893333,-1.78666,-0.318576,0.996485,-1.8678,-0.343613,0.742136,-1.82793,-0.399769,0.776862,-1.76627,0.208645,1.119,-2.14845,0.248395,1.04439,-2.13363,0.087007,1.05977,-2.09395,0.126022,0.991328,-2.08148,0.247748,0.890205,-2.08827,0.236661,0.699458,-2.07287,0.128949,0.729819,-2.08665,0.110385,0.664235,-2.07113,0.074771,0.433204,-2.02406,-0.024595,0.362669,-1.96836,0.258936,0.377274,-2.00664,0.206951,0.341134,-2.07018,0.095089,1.27091,-1.85139,0.078187,1.30407,-2.06339},
/*352*/{0.21309,1.84848,-1.74695,0.267891,1.78613,-1.90652,0.108142,1.71724,-1.65006,0.022025,1.62494,-1.58602,0.150339,1.55212,-1.65741,0.223396,1.50372,-1.68107,0.168465,1.85817,-2.14729,0.264242,1.78866,-1.98532,0.04672,1.83542,-2.03826,-0.031238,1.66838,-2.20956,-0.020619,1.56981,-2.24898,0.137402,1.46942,-2.19894,0.17979,1.41896,-2.20977,0.168414,1.35529,-1.82781,-0.029331,1.41894,-1.87564,-0.030728,1.45277,-1.92781,-0.036606,1.43011,-1.98694,0.155005,1.40037,-2.08608,0.209404,1.06114,-1.76238,0.082341,1.0158,-1.79116,0.110474,0.936053,-1.81158,0.194221,0.858654,-1.78812,0.044298,0.826705,-1.77342,-0.029868,0.82727,-1.77905,0.043332,0.936598,-1.79907,-0.027781,0.937061,-1.7993,-0.258129,0.891603,-1.78725,-0.309674,0.992045,-1.86731,-0.324404,0.736731,-1.8277,-0.38121,0.769817,-1.76498,0.203674,1.11538,-2.14946,0.240616,1.04012,-2.13487,0.081546,1.05783,-2.0938,0.11935,0.989283,-2.08122,0.238553,0.88561,-2.08969,0.222648,0.693819,-2.07416,0.115301,0.727987,-2.08775,0.094413,0.662176,-2.07182,0.056453,0.435575,-2.02714,-0.049362,0.366425,-1.97029,0.237973,0.37742,-2.00828,0.185472,0.34097,-2.07068,0.093865,1.26856,-1.85268,0.075635,1.30315,-2.06434},
/*353*/{0.212166,1.84573,-1.74671,0.266643,1.78333,-1.90592,0.10336,1.71776,-1.65097,0.013683,1.62699,-1.58959,0.14251,1.55062,-1.65712,0.215009,1.50027,-1.67875,0.170998,1.85558,-2.14618,0.264337,1.78661,-1.9835,0.048013,1.83305,-2.0384,-0.024102,1.66187,-2.2127,-0.011699,1.56496,-2.25056,0.146693,1.46677,-2.19726,0.190725,1.41723,-2.20795,0.166548,1.35211,-1.82687,-0.02986,1.41761,-1.87446,-0.030919,1.45234,-1.92807,-0.037154,1.42965,-1.98599,0.153912,1.39966,-2.08735,0.216656,1.06307,-1.76258,0.091162,1.01489,-1.78998,0.120927,0.936333,-1.81039,0.208595,0.861164,-1.78796,0.05813,0.826249,-1.77356,-0.017171,0.825672,-1.77817,0.055881,0.936426,-1.79861,-0.015479,0.93627,-1.79867,-0.245028,0.88684,-1.7879,-0.301149,0.986158,-1.86704,-0.305964,0.730077,-1.82809,-0.361753,0.761207,-1.76346,0.196842,1.11183,-2.1517,0.234182,1.03524,-2.136,0.075111,1.05657,-2.09377,0.111263,0.98622,-2.08064,0.228001,0.880475,-2.09192,0.209275,0.687639,-2.07384,0.102601,0.72577,-2.08888,0.082054,0.658402,-2.07139,0.035799,0.435034,-2.02515,-0.068689,0.364149,-1.9692,0.215756,0.377058,-2.00816,0.163254,0.340717,-2.07151,0.091835,1.26629,-1.85345,0.07382,1.30259,-2.06483},
/*354*/{0.211479,1.84412,-1.74577,0.265776,1.78075,-1.90398,0.096827,1.71825,-1.65148,0.006827,1.6301,-1.59261,0.134246,1.55068,-1.65697,0.206212,1.4988,-1.67723,0.173511,1.85383,-2.14565,0.264866,1.78447,-1.98235,0.048841,1.83205,-2.0391,-0.017584,1.65658,-2.21501,-0.002479,1.56041,-2.25141,0.157447,1.46559,-2.19562,0.202,1.41673,-2.20596,0.165761,1.3502,-1.82745,-0.030381,1.41764,-1.87375,-0.031325,1.45116,-1.92802,-0.037154,1.42965,-1.98599,0.153593,1.39877,-2.08839,0.223669,1.06688,-1.76243,0.100949,1.01438,-1.78896,0.132475,0.936619,-1.80932,0.222924,0.862932,-1.78785,0.071987,0.826185,-1.774,-0.003379,0.824765,-1.77982,0.068016,0.936374,-1.79774,-0.00306,0.935453,-1.79728,-0.230439,0.88061,-1.79097,-0.293034,0.97934,-1.86574,-0.287021,0.72306,-1.82966,-0.340531,0.751303,-1.76265,0.191414,1.10736,-2.15249,0.226648,1.03025,-2.13714,0.068343,1.05538,-2.09385,0.10511,0.982628,-2.08101,0.215583,0.874289,-2.09319,0.193177,0.683084,-2.07516,0.089002,0.723373,-2.0897,0.066328,0.654818,-2.07248,0.012992,0.434471,-2.02731,-0.090454,0.364988,-1.97023,0.194451,0.376456,-2.00963,0.141108,0.33979,-2.07229,0.09073,1.26493,-1.85418,0.072586,1.30205,-2.06542},
/*355*/{0.210325,1.84337,-1.74441,0.265868,1.77954,-1.90297,0.092504,1.72007,-1.6522,-0.001379,1.63388,-1.59583,0.126085,1.55129,-1.65761,0.198019,1.49732,-1.67518,0.177259,1.8519,-2.14456,0.264489,1.78261,-1.98091,0.049883,1.83128,-2.04036,-0.008517,1.65303,-2.21635,0.006047,1.55653,-2.25206,0.166968,1.46331,-2.19311,0.213176,1.41747,-2.20313,0.16487,1.34867,-1.82716,-0.030662,1.418,-1.87358,-0.032098,1.45032,-1.92769,-0.037154,1.42965,-1.98599,0.152907,1.39772,-2.08939,0.229893,1.07073,-1.76277,0.108965,1.01374,-1.78676,0.144242,0.938387,-1.80803,0.235808,0.866804,-1.78809,0.085965,0.825447,-1.7735,0.010316,0.823729,-1.78113,0.080133,0.936224,-1.79696,0.008458,0.933294,-1.79593,-0.21691,0.874253,-1.78994,-0.285485,0.971288,-1.86444,-0.265969,0.715387,-1.83097,-0.320722,0.741188,-1.76139,0.185824,1.10399,-2.15313,0.219051,1.02583,-2.13827,0.061741,1.05467,-2.09476,0.094985,0.979843,-2.08108,0.202983,0.86932,-2.09477,0.178455,0.677767,-2.07504,0.07498,0.720351,-2.08995,0.050897,0.656176,-2.07483,-0.00533,0.435853,-2.0273,-0.110447,0.364992,-1.96995,0.171988,0.375652,-2.00978,0.120154,0.339776,-2.0735,0.089447,1.264,-1.85436,0.071275,1.30134,-2.06555},
/*356*/{0.20762,1.84301,-1.74451,0.264999,1.77892,-1.9017,0.086328,1.72202,-1.65293,-0.009281,1.63797,-1.59868,0.118275,1.55156,-1.65603,0.188785,1.49748,-1.67291,0.179477,1.85099,-2.14408,0.265457,1.78142,-1.9793,0.051062,1.83115,-2.04122,-0.001782,1.65036,-2.21785,0.014777,1.55311,-2.25327,0.176843,1.4644,-2.19092,0.223564,1.41895,-2.19996,0.163167,1.34891,-1.82619,-0.032025,1.41807,-1.87491,-0.031882,1.45,-1.92903,-0.037797,1.42996,-1.98628,0.152274,1.397,-2.08986,0.240117,1.07547,-1.76212,0.118955,1.01655,-1.78603,0.154894,0.940723,-1.80617,0.24972,0.870438,-1.7889,0.098823,0.826065,-1.77388,0.024301,0.822372,-1.78113,0.090729,0.936925,-1.7959,0.020283,0.932611,-1.79495,-0.203763,0.868343,-1.79199,-0.277956,0.96185,-1.86359,-0.245733,0.707483,-1.83117,-0.298628,0.729723,-1.76117,0.179201,1.10073,-2.15359,0.210994,1.02175,-2.13874,0.054535,1.05443,-2.09657,0.087036,0.978664,-2.08349,0.189444,0.86421,-2.09516,0.163736,0.671757,-2.07372,0.060493,0.717448,-2.09056,0.034491,0.652153,-2.07538,-0.028927,0.435347,-2.02884,-0.133481,0.367089,-1.97251,0.151324,0.37503,-2.01105,0.097364,0.339155,-2.07404,0.087922,1.26413,-1.85413,0.070792,1.30076,-2.06554},
/*357*/{0.206223,1.84317,-1.74283,0.264444,1.77793,-1.89967,0.080113,1.72509,-1.65374,-0.017849,1.64153,-1.60065,0.110791,1.55381,-1.65556,0.179618,1.49782,-1.67209,0.18351,1.85031,-2.14353,0.265089,1.78066,-1.97765,0.052057,1.83093,-2.04164,0.005348,1.64833,-2.21987,0.023676,1.55063,-2.25413,0.187219,1.46709,-2.18822,0.234884,1.42232,-2.19565,0.161948,1.34888,-1.82584,-0.032024,1.41799,-1.8756,-0.033304,1.44971,-1.92951,-0.03757,1.42994,-1.98748,0.152494,1.39541,-2.08972,0.246584,1.08147,-1.76178,0.127329,1.01811,-1.78536,0.165523,0.943594,-1.80593,0.261835,0.875003,-1.78902,0.112578,0.826048,-1.77551,0.038207,0.820223,-1.78261,0.102253,0.937802,-1.79425,0.029961,0.931224,-1.79509,-0.188299,0.858786,-1.79495,-0.270124,0.951162,-1.86379,-0.224879,0.697732,-1.83266,-0.276919,0.718207,-1.76027,0.173497,1.09722,-2.1534,0.20261,1.01783,-2.13908,0.046765,1.05432,-2.09807,0.076455,0.97826,-2.08546,0.175825,0.859215,-2.09623,0.147824,0.667847,-2.07318,0.045246,0.714042,-2.09092,0.019241,0.650302,-2.07613,-0.05356,0.434621,-2.02824,-0.154174,0.367894,-1.97201,0.129193,0.374626,-2.01087,0.076081,0.3396,-2.07475,0.086754,1.26403,-1.85363,0.070608,1.2997,-2.06528},
/*358*/{0.202867,1.84407,-1.74191,0.264017,1.77806,-1.8978,0.074999,1.72841,-1.65454,-0.025967,1.64582,-1.60386,0.10197,1.55632,-1.65563,0.171166,1.4999,-1.67147,0.186487,1.8506,-2.14229,0.265688,1.78092,-1.97616,0.054019,1.83067,-2.04271,0.010861,1.64667,-2.22038,0.031587,1.54891,-2.25476,0.197097,1.47016,-2.18525,0.245413,1.42701,-2.19116,0.161654,1.35019,-1.82538,-0.031989,1.41795,-1.87573,-0.033199,1.44965,-1.92968,-0.036911,1.43035,-1.98826,0.152521,1.3948,-2.08978,0.25298,1.08751,-1.76212,0.134624,1.02099,-1.78495,0.176098,0.947932,-1.80487,0.274669,0.880682,-1.7881,0.126798,0.827672,-1.77616,0.050815,0.818697,-1.7832,0.112593,0.938265,-1.79383,0.041755,0.93053,-1.79383,-0.175445,0.851781,-1.79585,-0.262682,0.938924,-1.86397,-0.202721,0.689791,-1.83278,-0.255185,0.70626,-1.76049,0.168157,1.09454,-2.15318,0.194343,1.01377,-2.13905,0.039076,1.05466,-2.09909,0.067766,0.977504,-2.08627,0.161828,0.854186,-2.09652,0.130155,0.664197,-2.07254,0.02954,0.711925,-2.09106,0.002077,0.64795,-2.07623,-0.072248,0.436275,-2.03048,-0.176048,0.367934,-1.97464,0.106786,0.375021,-2.01222,0.053516,0.339416,-2.07512,0.086901,1.26476,-1.85294,0.071032,1.29928,-2.06479},
/*359*/{0.200582,1.84601,-1.74099,0.263386,1.77861,-1.89662,0.069391,1.73153,-1.65528,-0.033066,1.65047,-1.60548,0.094204,1.55966,-1.65588,0.161934,1.50213,-1.66995,0.188541,1.85122,-2.14092,0.266183,1.78137,-1.97407,0.054689,1.83123,-2.04406,0.016561,1.645,-2.22135,0.040147,1.54853,-2.25485,0.205978,1.47422,-2.18105,0.256008,1.43319,-2.18609,0.160325,1.35046,-1.82486,-0.03261,1.41897,-1.87722,-0.032776,1.44958,-1.93114,-0.037464,1.43087,-1.98978,0.151308,1.39369,-2.08999,0.25695,1.09524,-1.76338,0.141786,1.02403,-1.78508,0.186511,0.952225,-1.80473,0.286626,0.885925,-1.78813,0.13965,0.828587,-1.77744,0.066071,0.817803,-1.78443,0.122203,0.939232,-1.79315,0.050026,0.927901,-1.79287,-0.163331,0.842594,-1.79559,-0.254932,0.926186,-1.86437,-0.180825,0.68042,-1.83372,-0.232677,0.694518,-1.76044,0.161892,1.09188,-2.15318,0.185785,1.01075,-2.13865,0.031327,1.0551,-2.10024,0.056819,0.977302,-2.08786,0.146604,0.848918,-2.0968,0.115194,0.662412,-2.07186,0.013844,0.71098,-2.09175,-0.014237,0.647372,-2.07663,-0.089339,0.439195,-2.02892,-0.196731,0.369132,-1.97387,0.085564,0.374771,-2.01238,0.033749,0.340323,-2.07477,0.085248,1.26523,-1.85271,0.070184,1.29847,-2.06483},
/*360*/{0.197072,1.84756,-1.74027,0.261894,1.77951,-1.89363,0.063479,1.73552,-1.65552,-0.040255,1.6554,-1.60824,0.086325,1.56315,-1.65552,0.154303,1.50561,-1.66926,0.190873,1.8527,-2.13942,0.266813,1.78261,-1.97191,0.055717,1.8316,-2.04444,0.022189,1.64427,-2.22217,0.048198,1.54803,-2.25499,0.214153,1.4795,-2.17741,0.265964,1.44027,-2.18132,0.159265,1.35236,-1.82392,-0.032964,1.41913,-1.87876,-0.03297,1.45075,-1.93228,-0.036852,1.43105,-1.99092,0.153281,1.39366,-2.09001,0.26321,1.10221,-1.76357,0.151166,1.02713,-1.78366,0.196618,0.956816,-1.80443,0.298176,0.893235,-1.78843,0.153525,0.830305,-1.77762,0.079049,0.816117,-1.78558,0.131175,0.940073,-1.79184,0.060426,0.926465,-1.7919,-0.149439,0.832891,-1.79706,-0.246457,0.91216,-1.8657,-0.15962,0.669953,-1.83406,-0.211751,0.682404,-1.76044,0.155448,1.08925,-2.15313,0.17759,1.0077,-2.13829,0.023004,1.05633,-2.10099,0.047647,0.977717,-2.0891,0.131421,0.845537,-2.09645,0.097674,0.660778,-2.07125,-0.002344,0.711047,-2.09151,-0.030969,0.648305,-2.07608,-0.109087,0.440449,-2.02877,-0.218989,0.370753,-1.97516,0.06438,0.375049,-2.01238,0.0106,0.339538,-2.07596,0.084994,1.26653,-1.8521,0.071824,1.29856,-2.06453},
/*361*/{0.194266,1.8498,-1.73893,0.262304,1.78125,-1.89164,0.058093,1.73991,-1.6566,-0.048352,1.66019,-1.61022,0.079054,1.56775,-1.65647,0.1456,1.50937,-1.66865,0.193629,1.85487,-2.13773,0.266952,1.78386,-1.96976,0.05674,1.83178,-2.04506,0.027964,1.64403,-2.22237,0.056114,1.54842,-2.25469,0.222175,1.48495,-2.17333,0.275318,1.44807,-2.17609,0.159959,1.35309,-1.82238,-0.032406,1.41995,-1.87945,-0.032563,1.45081,-1.93331,-0.036132,1.4321,-1.99252,0.154086,1.39282,-2.08992,0.270118,1.10763,-1.7613,0.158159,1.03139,-1.78378,0.20593,0.961853,-1.80306,0.30974,0.900146,-1.7886,0.166308,0.831598,-1.77914,0.09218,0.814745,-1.78764,0.139474,0.940786,-1.79082,0.06922,0.924035,-1.79161,-0.136655,0.82389,-1.79854,-0.237727,0.896793,-1.86691,-0.13746,0.660807,-1.8345,-0.188883,0.669634,-1.76015,0.149364,1.08813,-2.15227,0.16889,1.00526,-2.13693,0.014856,1.05806,-2.10268,0.037311,0.978142,-2.09055,0.115351,0.844216,-2.09597,0.080613,0.658759,-2.0705,-0.018415,0.711882,-2.0911,-0.048442,0.649533,-2.07644,-0.129525,0.442233,-2.02922,-0.240082,0.37339,-1.97448,0.042687,0.375112,-2.01295,-0.010592,0.339573,-2.07593,0.084955,1.26742,-1.85131,0.072784,1.29807,-2.064},
/*362*/{0.190971,1.85238,-1.73801,0.261481,1.7834,-1.88902,0.053191,1.7434,-1.65651,-0.055844,1.66508,-1.61285,0.070986,1.57258,-1.65709,0.137998,1.51377,-1.66891,0.195364,1.85742,-2.13596,0.267387,1.78555,-1.96792,0.058188,1.83282,-2.04544,0.032796,1.6446,-2.22226,0.064055,1.54937,-2.25469,0.230183,1.49171,-2.16951,0.285493,1.45678,-2.1709,0.160033,1.35549,-1.82214,-0.032748,1.42109,-1.88161,-0.031179,1.45224,-1.93445,-0.035436,1.43304,-1.9936,0.155703,1.39221,-2.09013,0.275299,1.11557,-1.76166,0.168112,1.03634,-1.7832,0.214158,0.967014,-1.8044,0.320472,0.909177,-1.78919,0.178639,0.833283,-1.77947,0.105726,0.81353,-1.78817,0.147574,0.940824,-1.79037,0.078249,0.920972,-1.7915,-0.122533,0.811836,-1.79763,-0.228314,0.880737,-1.86905,-0.114534,0.650339,-1.83449,-0.167114,0.657304,-1.76008,0.142684,1.08649,-2.15016,0.159842,1.00309,-2.13524,0.007767,1.05977,-2.10309,0.027209,0.979202,-2.09109,0.100126,0.844132,-2.09548,0.062808,0.659582,-2.0702,-0.035232,0.71336,-2.09007,-0.06683,0.650593,-2.07545,-0.15298,0.444583,-2.03053,-0.260615,0.37646,-1.97505,0.021309,0.374764,-2.01369,-0.03192,0.340119,-2.07727,0.085047,1.2693,-1.85065,0.074054,1.29801,-2.06368},
/*363*/{0.187813,1.85497,-1.73691,0.261732,1.78633,-1.88697,0.047902,1.74833,-1.65784,-0.062135,1.67163,-1.61621,0.064518,1.57745,-1.65804,0.130875,1.5181,-1.66764,0.198346,1.86065,-2.13465,0.267545,1.78823,-1.96563,0.058588,1.83368,-2.04554,0.036713,1.64512,-2.2219,0.071835,1.55115,-2.2548,0.238591,1.49945,-2.16536,0.294531,1.46613,-2.16567,0.159568,1.35712,-1.8216,-0.032207,1.42227,-1.88326,-0.030587,1.45397,-1.93548,-0.034725,1.43483,-1.99564,0.156961,1.3923,-2.0892,0.277477,1.12267,-1.76254,0.173098,1.03928,-1.7837,0.222151,0.972702,-1.80439,0.33056,0.917033,-1.78955,0.191566,0.835049,-1.7804,0.119153,0.812211,-1.78835,0.155055,0.941121,-1.78996,0.086197,0.918094,-1.79094,-0.109538,0.801561,-1.79997,-0.218,0.863385,-1.8712,-0.092518,0.640103,-1.8345,-0.145741,0.645017,-1.76056,0.13604,1.0846,-2.14894,0.150569,1.00154,-2.13364,0.000342,1.06243,-2.10387,0.016799,0.981653,-2.09167,0.084513,0.845103,-2.0945,0.045485,0.659161,-2.0693,-0.052733,0.714958,-2.08945,-0.084474,0.65408,-2.07449,-0.171559,0.447146,-2.03074,-0.280806,0.380068,-1.97626,0.000206,0.374774,-2.0132,-0.054437,0.339718,-2.07547,0.084367,1.27087,-1.85034,0.075161,1.29866,-2.06357},
/*364*/{0.184264,1.85791,-1.73631,0.26034,1.78882,-1.88514,0.042974,1.75323,-1.65836,-0.068611,1.67714,-1.61785,0.05802,1.58304,-1.65931,0.123556,1.52294,-1.66751,0.200259,1.86433,-2.13333,0.268255,1.79145,-1.96278,0.059593,1.83566,-2.04535,0.04185,1.64524,-2.22121,0.079884,1.55281,-2.25451,0.246119,1.50708,-2.16138,0.303,1.47642,-2.16006,0.160315,1.35971,-1.82164,-0.03106,1.42456,-1.88494,-0.029665,1.45568,-1.93717,-0.032673,1.43606,-1.99726,0.156032,1.39164,-2.09189,0.283258,1.12895,-1.7614,0.179368,1.04357,-1.78483,0.229465,0.977962,-1.80582,0.340303,0.925925,-1.78997,0.203101,0.836706,-1.78087,0.133204,0.811057,-1.78885,0.16267,0.941289,-1.78983,0.093862,0.915976,-1.79199,-0.09579,0.791227,-1.80232,-0.207112,0.845528,-1.87339,-0.069201,0.63057,-1.83406,-0.122962,0.632368,-1.76066,0.129189,1.0845,-2.14757,0.141853,1.00024,-2.1317,-0.007923,1.065,-2.10393,0.005344,0.984034,-2.09166,0.068844,0.846261,-2.09374,0.026366,0.661683,-2.06914,-0.069693,0.717273,-2.08827,-0.102643,0.656753,-2.07484,-0.191353,0.450906,-2.02973,-0.30175,0.384383,-1.97691,-0.022307,0.375258,-2.01307,-0.076102,0.339998,-2.07627,0.084881,1.27335,-1.85023,0.074993,1.29844,-2.06377},
/*365*/{0.181708,1.86104,-1.73542,0.259791,1.79346,-1.88243,0.038295,1.75753,-1.65919,-0.075077,1.68379,-1.62114,0.051367,1.58928,-1.66069,0.116428,1.52827,-1.66754,0.201194,1.86809,-2.13173,0.268123,1.79431,-1.96068,0.061119,1.83742,-2.04596,0.046911,1.64676,-2.22044,0.087588,1.55495,-2.25403,0.252625,1.51522,-2.1573,0.311078,1.48646,-2.15457,0.161867,1.3634,-1.82163,-0.030293,1.4268,-1.88584,-0.027925,1.45761,-1.93835,-0.031098,1.43757,-1.99903,0.155529,1.39167,-2.09291,0.28828,1.13592,-1.76137,0.187565,1.04756,-1.78542,0.237228,0.983671,-1.80608,0.349103,0.935146,-1.79045,0.214877,0.838628,-1.78068,0.147428,0.809279,-1.7889,0.168588,0.941314,-1.79003,0.099639,0.913651,-1.79444,-0.082549,0.779952,-1.80332,-0.195491,0.82702,-1.87578,-0.046415,0.620559,-1.83361,-0.100368,0.620099,-1.76133,0.123174,1.08333,-2.14599,0.132175,0.999551,-2.12984,-0.015854,1.06871,-2.10456,-0.002386,0.986082,-2.09196,0.054187,0.847218,-2.09238,0.00987,0.663034,-2.06788,-0.086514,0.720514,-2.08732,-0.119799,0.659714,-2.07409,-0.215668,0.453739,-2.02977,-0.322257,0.389218,-1.97678,-0.043839,0.375355,-2.01308,-0.097654,0.340319,-2.07517,0.086158,1.27652,-1.84946,0.075644,1.29876,-2.06328},
/*366*/{0.179302,1.86426,-1.73507,0.260045,1.79614,-1.88083,0.033437,1.76214,-1.66026,-0.081595,1.69004,-1.62332,0.044959,1.59518,-1.66163,0.109912,1.53459,-1.66753,0.202356,1.87263,-2.13001,0.268855,1.79773,-1.95848,0.06216,1.83969,-2.04615,0.051766,1.64817,-2.22031,0.094665,1.55757,-2.25355,0.260082,1.52421,-2.15263,0.319005,1.49756,-2.14911,0.16147,1.36588,-1.82166,-0.029366,1.42905,-1.88735,-0.026247,1.45973,-1.94001,-0.029357,1.44037,-1.99939,0.15942,1.39132,-2.09153,0.290794,1.14245,-1.76133,0.194373,1.052,-1.78504,0.243944,0.989763,-1.80854,0.357518,0.943764,-1.79074,0.226645,0.84092,-1.78091,0.159207,0.807255,-1.78956,0.175052,0.940543,-1.7894,0.111706,0.907885,-1.79189,-0.067773,0.767039,-1.80534,-0.183787,0.808553,-1.87939,-0.022704,0.611296,-1.8334,-0.077648,0.607419,-1.76204,0.116925,1.08305,-2.14331,0.123278,0.999093,-2.12703,-0.022793,1.07292,-2.10487,-0.012583,0.990531,-2.09236,0.040198,0.849045,-2.08995,-0.008194,0.666029,-2.06708,-0.103645,0.724352,-2.08632,-0.13767,0.664016,-2.07333,-0.230966,0.457377,-2.02968,-0.341944,0.396788,-1.97704,-0.064818,0.376101,-2.01284,-0.119689,0.340347,-2.07487,0.085843,1.27879,-1.84855,0.077755,1.29967,-2.06262},
/*367*/{0.176014,1.86823,-1.73391,0.259477,1.79994,-1.87865,0.030018,1.76772,-1.66039,-0.086763,1.69585,-1.62624,0.039987,1.60127,-1.66318,0.103385,1.53968,-1.66809,0.203474,1.8773,-2.12872,0.269567,1.80155,-1.95673,0.063302,1.84189,-2.04551,0.055257,1.65178,-2.22047,0.102733,1.56092,-2.25375,0.265966,1.53318,-2.14812,0.325912,1.50832,-2.14346,0.162843,1.36979,-1.82117,-0.027922,1.43207,-1.88901,-0.02453,1.46207,-1.94061,-0.027881,1.44192,-2.00084,0.162061,1.39115,-2.09109,0.295115,1.15015,-1.76128,0.19892,1.05709,-1.7834,0.250142,0.996132,-1.80796,0.365298,0.952595,-1.79151,0.237934,0.843035,-1.78092,0.171096,0.806033,-1.79084,0.181159,0.93962,-1.79007,0.118563,0.902644,-1.79355,-0.052836,0.754175,-1.80566,-0.170904,0.789213,-1.88127,0.001482,0.601107,-1.8331,-0.054236,0.595394,-1.762,0.110477,1.08408,-2.14141,0.114305,0.999011,-2.12397,-0.029321,1.07703,-2.10481,-0.021388,0.993471,-2.0915,0.026856,0.850977,-2.08801,-0.026183,0.669328,-2.06642,-0.120299,0.728774,-2.08536,-0.155449,0.668729,-2.07284,-0.251962,0.46315,-2.03185,-0.362505,0.402336,-1.97454,-0.086393,0.376076,-2.01264,-0.141434,0.340408,-2.07412,0.087085,1.28234,-1.84698,0.079879,1.30016,-2.06136},
/*368*/{0.173729,1.8714,-1.73341,0.259873,1.80376,-1.87662,0.025978,1.77275,-1.66146,-0.092072,1.70272,-1.62937,0.033838,1.60725,-1.66435,0.097948,1.54505,-1.66845,0.205309,1.88184,-2.12723,0.270514,1.80515,-1.95466,0.064032,1.84499,-2.04622,0.060717,1.65452,-2.22016,0.109772,1.56432,-2.25337,0.271586,1.54298,-2.14413,0.333038,1.51917,-2.13772,0.16436,1.37417,-1.82249,-0.02635,1.4359,-1.88955,-0.023045,1.46505,-1.94336,-0.024565,1.44446,-2.00204,0.165363,1.39064,-2.09097,0.29786,1.15615,-1.76094,0.202352,1.06223,-1.78594,0.256591,1.00266,-1.80869,0.372319,0.96168,-1.79122,0.248662,0.844677,-1.78105,0.183566,0.804415,-1.79122,0.187284,0.937668,-1.79086,0.126268,0.89937,-1.79438,-0.0382,0.743753,-1.80772,-0.156709,0.769703,-1.8841,0.025818,0.592811,-1.83322,-0.029724,0.584013,-1.76249,0.104599,1.08424,-2.13847,0.106342,0.999616,-2.12108,-0.037051,1.08175,-2.10524,-0.031205,0.999007,-2.09221,0.013295,0.854226,-2.08554,-0.041794,0.673318,-2.06579,-0.13632,0.733728,-2.08489,-0.172121,0.674789,-2.07293,-0.271288,0.470891,-2.03536,-0.381183,0.410257,-1.9753,-0.107478,0.376509,-2.01238,-0.162228,0.341536,-2.07468,0.088398,1.28645,-1.84584,0.082017,1.30092,-2.06049},
/*369*/{0.171812,1.87528,-1.73276,0.260168,1.80734,-1.87487,0.022272,1.77793,-1.66292,-0.096338,1.70956,-1.63215,0.029689,1.61368,-1.6657,0.092999,1.5516,-1.66851,0.206597,1.88711,-2.1262,0.272733,1.8085,-1.95167,0.065989,1.84696,-2.04565,0.064995,1.65752,-2.22027,0.117097,1.56829,-2.25263,0.277446,1.55222,-2.14024,0.338747,1.53095,-2.13246,0.16618,1.37795,-1.82289,-0.024369,1.43901,-1.89074,-0.01992,1.46789,-1.94399,-0.021799,1.44787,-2.00267,0.165867,1.39112,-2.09091,0.300071,1.16305,-1.76086,0.206653,1.06915,-1.78577,0.262141,1.0096,-1.80827,0.377865,0.96948,-1.79122,0.258236,0.845606,-1.78132,0.196139,0.801719,-1.79113,0.193015,0.936518,-1.79248,0.134444,0.893977,-1.79571,-0.020607,0.730493,-1.80852,-0.141544,0.749435,-1.88669,0.050384,0.583811,-1.83295,-0.005004,0.572697,-1.7628,0.099061,1.08458,-2.13599,0.098232,1.00044,-2.11837,-0.04217,1.08662,-2.1054,-0.04042,1.00462,-2.09163,0.00087,0.858224,-2.08363,-0.058343,0.677748,-2.06496,-0.15172,0.738946,-2.08432,-0.187602,0.679851,-2.07183,-0.289507,0.475416,-2.03337,-0.399178,0.419194,-1.97609,-0.128623,0.377279,-2.01183,-0.184361,0.341368,-2.07391,0.089754,1.28998,-1.84509,0.083045,1.30232,-2.05987},
/*370*/{0.169635,1.87843,-1.73237,0.2597,1.81199,-1.87321,0.018477,1.78352,-1.66386,-0.101174,1.71613,-1.6349,0.02465,1.61941,-1.66691,0.087522,1.55713,-1.66947,0.208426,1.89174,-2.1242,0.27324,1.8127,-1.95003,0.067161,1.85086,-2.04622,0.06996,1.66095,-2.22033,0.123938,1.5729,-2.25274,0.282451,1.56056,-2.1343,0.343686,1.54201,-2.12701,0.168164,1.3819,-1.82312,-0.02236,1.44363,-1.89142,-0.018674,1.47047,-1.94584,-0.019716,1.4501,-2.00416,0.169931,1.39106,-2.09101,0.302991,1.17072,-1.7616,0.210635,1.0741,-1.78587,0.267029,1.01503,-1.80937,0.383349,0.977631,-1.79189,0.26853,0.846488,-1.78174,0.209067,0.800728,-1.79174,0.197665,0.934338,-1.7933,0.142222,0.889122,-1.79725,-0.003906,0.717867,-1.80952,-0.126176,0.729424,-1.88859,0.075775,0.575674,-1.83352,0.020368,0.561344,-1.76291,0.094315,1.08587,-2.13397,0.090201,1.00219,-2.11553,-0.04842,1.09171,-2.10507,-0.048738,1.00935,-2.09044,-0.013191,0.863458,-2.08245,-0.074543,0.683115,-2.06444,-0.168261,0.744631,-2.0833,-0.204438,0.685816,-2.07161,-0.308185,0.480505,-2.03149,-0.415908,0.427629,-1.97499,-0.151781,0.376255,-2.01087,-0.206428,0.34226,-2.07359,0.091261,1.29415,-1.84381,0.085405,1.30327,-2.05878},
/*371*/{0.168204,1.88186,-1.73175,0.260605,1.81421,-1.87039,0.015154,1.78881,-1.6655,-0.105776,1.72263,-1.63825,0.021365,1.62503,-1.66797,0.082858,1.56265,-1.66933,0.209402,1.89711,-2.12255,0.272841,1.81662,-1.94817,0.068184,1.8537,-2.046,0.074772,1.66481,-2.22064,0.130832,1.57708,-2.25249,0.287987,1.57103,-2.13009,0.348047,1.55269,-2.12177,0.169198,1.38563,-1.82419,-0.021049,1.44762,-1.89139,-0.016301,1.47391,-1.94791,-0.016239,1.45387,-2.00461,0.171082,1.39084,-2.09111,0.306553,1.17647,-1.76092,0.209612,1.08038,-1.78652,0.270511,1.02111,-1.81073,0.387389,0.985121,-1.79267,0.277733,0.847731,-1.78189,0.221253,0.798993,-1.79196,0.20251,0.93159,-1.79479,0.149671,0.883862,-1.79847,0.010421,0.704426,-1.81191,-0.108671,0.707778,-1.89074,0.100778,0.568755,-1.83439,0.046055,0.550784,-1.76329,0.08806,1.08779,-2.13164,0.081661,1.00325,-2.11219,-0.053802,1.09792,-2.10473,-0.056351,1.01562,-2.09027,-0.027572,0.868179,-2.08168,-0.090111,0.68832,-2.06415,-0.183013,0.752031,-2.08351,-0.219578,0.693316,-2.07224,-0.320406,0.486064,-2.03169,-0.434491,0.438037,-1.97522,-0.173204,0.376051,-2.00965,-0.228214,0.342611,-2.07332,0.091702,1.29799,-1.84297,0.085907,1.30463,-2.05803},
/*372*/{0.166696,1.88535,-1.73141,0.259788,1.81998,-1.87006,0.012591,1.7939,-1.66711,-0.108031,1.729,-1.64077,0.016026,1.63057,-1.66949,0.07852,1.56764,-1.67011,0.211522,1.90155,-2.12055,0.272988,1.82043,-1.94645,0.069829,1.85619,-2.0462,0.079427,1.66876,-2.22174,0.13808,1.58173,-2.25185,0.290708,1.57977,-2.12598,0.352653,1.56321,-2.11739,0.171477,1.38939,-1.82464,-0.017748,1.45121,-1.89263,-0.013745,1.47714,-1.94896,-0.013293,1.45681,-2.00611,0.173846,1.39085,-2.09065,0.309107,1.18276,-1.76043,0.213343,1.08542,-1.78558,0.274596,1.02715,-1.80976,0.389931,0.990993,-1.79287,0.286993,0.84837,-1.78232,0.233109,0.796463,-1.79188,0.207942,0.928524,-1.79584,0.157533,0.877523,-1.80041,0.029216,0.690871,-1.81253,-0.091823,0.687446,-1.89254,0.12612,0.561359,-1.83433,0.072518,0.540944,-1.76377,0.083493,1.08909,-2.12834,0.073998,1.0053,-2.10949,-0.057853,1.10402,-2.1039,-0.064931,1.02222,-2.08969,-0.041457,0.873683,-2.08143,-0.105327,0.69493,-2.06416,-0.19729,0.758626,-2.08314,-0.234697,0.69954,-2.07172,-0.338747,0.492683,-2.0328,-0.451647,0.450461,-1.97494,-0.195398,0.376881,-2.01002,-0.250581,0.342747,-2.07252,0.093465,1.30187,-1.84202,0.088023,1.30582,-2.05715},
/*373*/{0.1652,1.88798,-1.73105,0.259267,1.82357,-1.86786,0.009698,1.79878,-1.66845,-0.112399,1.73475,-1.64414,0.012405,1.63586,-1.67024,0.074865,1.57297,-1.6704,0.212842,1.90659,-2.1191,0.273659,1.82453,-1.94473,0.0712,1.85948,-2.04638,0.084787,1.67313,-2.22181,0.14339,1.58645,-2.25175,0.295643,1.58889,-2.12215,0.356481,1.574,-2.11277,0.172644,1.39378,-1.82548,-0.015914,1.45564,-1.8927,-0.01029,1.48003,-1.94993,-0.010059,1.45967,-2.00649,0.176324,1.39034,-2.09002,0.310515,1.18885,-1.76042,0.21655,1.09087,-1.78753,0.277167,1.0335,-1.80844,0.39259,0.997817,-1.79391,0.296353,0.848906,-1.78179,0.244418,0.793943,-1.79228,0.213136,0.924809,-1.79768,0.165468,0.872074,-1.80188,0.047077,0.677215,-1.81394,-0.072812,0.66734,-1.8941,0.151997,0.554206,-1.8348,0.099617,0.530883,-1.76458,0.078074,1.08998,-2.12586,0.065674,1.00854,-2.10743,-0.063239,1.11125,-2.1035,-0.072694,1.02884,-2.08922,-0.054603,0.879364,-2.08092,-0.11973,0.700941,-2.06451,-0.211103,0.765636,-2.08327,-0.249584,0.70772,-2.07211,-0.357231,0.500021,-2.03478,-0.467258,0.461452,-1.97541,-0.218271,0.376865,-2.00939,-0.271447,0.343645,-2.07197,0.094727,1.30615,-1.84028,0.089494,1.3068,-2.05545},
/*374*/{0.163849,1.89094,-1.73081,0.25932,1.82574,-1.86624,0.007721,1.8043,-1.66989,-0.115631,1.74086,-1.64716,0.009357,1.64109,-1.67176,0.071678,1.57791,-1.6711,0.215215,1.9112,-2.11716,0.27408,1.8282,-1.94296,0.07276,1.86247,-2.04696,0.090288,1.67723,-2.2218,0.150643,1.59124,-2.25166,0.297402,1.59653,-2.11919,0.360043,1.58414,-2.10865,0.17479,1.39715,-1.82596,-0.013206,1.46076,-1.89339,-0.008863,1.4838,-1.95182,-0.006302,1.46276,-2.00672,0.178187,1.39097,-2.08929,0.313107,1.19475,-1.76063,0.219907,1.09573,-1.78492,0.279996,1.03868,-1.80871,0.393919,1.00391,-1.79402,0.305486,0.848572,-1.78228,0.256771,0.791296,-1.79322,0.218804,0.920448,-1.79857,0.172835,0.864995,-1.80389,0.066655,0.664009,-1.81539,-0.053696,0.64668,-1.89569,0.17761,0.547481,-1.83569,0.126115,0.520859,-1.76514,0.073417,1.09251,-2.12382,0.058367,1.01041,-2.10477,-0.066854,1.118,-2.10333,-0.079959,1.03699,-2.08846,-0.066791,0.885278,-2.08044,-0.133392,0.708645,-2.06537,-0.225243,0.773372,-2.08299,-0.263168,0.715796,-2.07277,-0.372578,0.505965,-2.03521,-0.481974,0.473306,-1.9739,-0.239482,0.377181,-2.00988,-0.294857,0.344643,-2.0724,0.095805,1.3104,-1.83922,0.090754,1.30854,-2.05439},
/*375*/{0.162919,1.89386,-1.73033,0.261256,1.83017,-1.86519,0.005562,1.80872,-1.67211,-0.118175,1.74588,-1.64984,0.006393,1.64627,-1.67338,0.068057,1.58235,-1.67112,0.216975,1.91529,-2.11545,0.274642,1.83231,-1.94128,0.074381,1.86535,-2.04719,0.094495,1.68156,-2.22177,0.156679,1.59597,-2.2517,0.300231,1.60475,-2.11591,0.36329,1.59398,-2.10466,0.176622,1.40148,-1.82596,-0.010612,1.46476,-1.89312,-0.006409,1.48658,-1.95324,-0.003907,1.46599,-2.00781,0.181058,1.39076,-2.08893,0.31526,1.20093,-1.76087,0.223885,1.10151,-1.78305,0.281806,1.0434,-1.80803,0.394771,1.00873,-1.79401,0.313457,0.848417,-1.78221,0.269773,0.789831,-1.79318,0.224625,0.914831,-1.7989,0.180682,0.857562,-1.80544,0.084407,0.650043,-1.81676,-0.033214,0.626132,-1.89757,0.203671,0.540899,-1.8357,0.153065,0.511323,-1.76659,0.06877,1.09437,-2.12215,0.050649,1.01286,-2.10265,-0.070911,1.12514,-2.103,-0.08691,1.04472,-2.08778,-0.077778,0.892905,-2.08084,-0.146779,0.716242,-2.06673,-0.23751,0.782048,-2.08328,-0.276543,0.721882,-2.07278,-0.385759,0.513274,-2.0366,-0.494838,0.486553,-1.97623,-0.262724,0.376676,-2.00933,-0.316937,0.345488,-2.07184,0.097387,1.31475,-1.83768,0.09255,1.30974,-2.0528},
/*376*/{0.162163,1.89658,-1.73038,0.259599,1.83323,-1.86355,0.004609,1.81321,-1.67355,-0.121156,1.7517,-1.65313,0.002802,1.65093,-1.67438,0.065277,1.58643,-1.67184,0.218485,1.91938,-2.11375,0.274674,1.83524,-1.93969,0.075862,1.86748,-2.0478,0.099934,1.68579,-2.22214,0.162161,1.5999,-2.25168,0.303106,1.61309,-2.11314,0.366259,1.6032,-2.10051,0.177296,1.40513,-1.82705,-0.0083,1.46922,-1.89325,-0.003295,1.49067,-1.95444,-0.000922,1.46882,-2.00807,0.182353,1.39067,-2.08831,0.316505,1.20572,-1.76058,0.224681,1.10573,-1.7832,0.28351,1.04856,-1.80622,0.394923,1.01343,-1.79462,0.321626,0.847857,-1.78247,0.279024,0.785568,-1.7928,0.228798,0.909891,-1.80151,0.188128,0.850621,-1.8079,0.10401,0.636815,-1.81697,-0.011981,0.606263,-1.89847,0.229797,0.535763,-1.83728,0.1815,0.503019,-1.76745,0.064572,1.09654,-2.12028,0.042196,1.01571,-2.10104,-0.074103,1.13178,-2.10179,-0.092873,1.05248,-2.08744,-0.0889,0.900479,-2.0809,-0.158845,0.724264,-2.06801,-0.250781,0.789521,-2.08353,-0.288544,0.731852,-2.07362,-0.395563,0.519317,-2.03756,-0.50669,0.500745,-1.9752,-0.283711,0.377775,-2.01021,-0.339128,0.347109,-2.07202,0.097919,1.31888,-1.83648,0.092957,1.31117,-2.05152},
/*377*/{0.161893,1.89911,-1.72965,0.259918,1.83813,-1.86281,0.003039,1.8177,-1.67485,-0.123693,1.75628,-1.6563,0.001271,1.65472,-1.67496,0.062501,1.58999,-1.67192,0.219743,1.92295,-2.11184,0.275804,1.83896,-1.93819,0.078406,1.86968,-2.04819,0.104377,1.68947,-2.22289,0.168065,1.60459,-2.25184,0.30506,1.61924,-2.11037,0.368419,1.6117,-2.09728,0.17919,1.40994,-1.82761,-0.005874,1.47374,-1.89417,-0.001821,1.49412,-1.95516,0.002864,1.47181,-2.00847,0.184685,1.39091,-2.08719,0.318848,1.20984,-1.76011,0.227544,1.11102,-1.7812,0.286589,1.05332,-1.80572,0.394392,1.01736,-1.7947,0.329201,0.846772,-1.78242,0.29192,0.782389,-1.79296,0.233951,0.903619,-1.80275,0.197779,0.842018,-1.80805,0.123644,0.625248,-1.81805,0.009575,0.587442,-1.89944,0.255475,0.530756,-1.8379,0.208508,0.493779,-1.76914,0.060867,1.09862,-2.11911,0.035605,1.019,-2.09954,-0.076508,1.13949,-2.10135,-0.098203,1.0599,-2.08607,-0.099763,0.908341,-2.08127,-0.170622,0.732363,-2.06957,-0.262553,0.797221,-2.08364,-0.301391,0.737515,-2.07242,-0.406049,0.526114,-2.03899,-0.515766,0.514579,-1.97468,-0.304712,0.378522,-2.01071,-0.361236,0.349325,-2.07168,0.099549,1.32381,-1.83477,0.094761,1.31275,-2.04967},
/*378*/{0.161172,1.90088,-1.7294,0.260794,1.84007,-1.86087,0.001941,1.82122,-1.67631,-0.124567,1.7601,-1.65961,-0.001418,1.65815,-1.67618,0.060875,1.59373,-1.67204,0.221523,1.92636,-2.11055,0.277058,1.84218,-1.93638,0.080017,1.87236,-2.04814,0.109204,1.69371,-2.2229,0.173672,1.60903,-2.25234,0.307005,1.62565,-2.1083,0.37087,1.61909,-2.09366,0.180936,1.41277,-1.82779,-0.003541,1.47738,-1.89369,0.001515,1.49779,-1.95711,0.005411,1.47494,-2.00945,0.186569,1.39088,-2.08615,0.319518,1.21356,-1.76027,0.22889,1.11465,-1.77917,0.284691,1.0572,-1.80524,0.392765,1.02015,-1.7949,0.336877,0.845811,-1.78209,0.302816,0.779741,-1.79338,0.23883,0.897599,-1.80463,0.204733,0.833432,-1.80974,0.143077,0.612205,-1.81874,0.031948,0.568747,-1.89977,0.280828,0.525681,-1.83852,0.235841,0.485299,-1.77105,0.056865,1.10114,-2.11834,0.029515,1.02223,-2.09845,-0.079193,1.14602,-2.10074,-0.102457,1.06707,-2.08613,-0.109672,0.915972,-2.08201,-0.18045,0.740981,-2.07161,-0.274277,0.80494,-2.08366,-0.311276,0.745362,-2.0724,-0.420363,0.533662,-2.04083,-0.524624,0.530365,-1.97543,-0.323933,0.378454,-2.01179,-0.383408,0.352235,-2.07166,0.100272,1.32739,-1.83376,0.09576,1.31416,-2.04854},
/*379*/{0.160925,1.90306,-1.72945,0.254119,1.84611,-1.86186,0.001458,1.82469,-1.67739,-0.127606,1.76303,-1.6617,-0.002981,1.66182,-1.67746,0.058818,1.59622,-1.67226,0.22408,1.9294,-2.1083,0.276855,1.84559,-1.93572,0.081396,1.87431,-2.04857,0.113897,1.69713,-2.22416,0.177952,1.61241,-2.25258,0.308623,1.6323,-2.10607,0.372329,1.62675,-2.09081,0.181292,1.41606,-1.82858,-0.00036,1.48127,-1.89362,0.004702,1.50083,-1.95774,0.008038,1.47785,-2.00965,0.188283,1.39106,-2.08535,0.321006,1.21693,-1.76014,0.228801,1.1187,-1.7782,0.284344,1.05993,-1.8036,0.391936,1.02229,-1.79498,0.34411,0.843423,-1.78199,0.310883,0.774965,-1.79225,0.243348,0.890968,-1.80549,0.213277,0.825042,-1.81081,0.163758,0.599953,-1.81981,0.055224,0.550351,-1.90016,0.304774,0.521005,-1.84054,0.26266,0.477774,-1.77227,0.052869,1.10348,-2.1178,0.024255,1.02554,-2.09819,-0.081092,1.15184,-2.10048,-0.108524,1.0748,-2.08615,-0.11944,0.923429,-2.08327,-0.191383,0.748615,-2.0735,-0.284697,0.812961,-2.08414,-0.321562,0.753459,-2.07308,-0.429938,0.540771,-2.04205,-0.53153,0.545943,-1.97398,-0.342141,0.378292,-2.01286,-0.404257,0.35601,-2.07089,0.101063,1.33097,-1.83269,0.096565,1.31569,-2.04734},
/*380*/{0.16102,1.90488,-1.72898,0.255279,1.84856,-1.86095,0.000741,1.82676,-1.67989,-0.12888,1.76715,-1.66474,-0.004294,1.66468,-1.67864,0.057459,1.59904,-1.67213,0.22551,1.93203,-2.10722,0.277816,1.84846,-1.93422,0.083979,1.87656,-2.04886,0.118586,1.7006,-2.22471,0.183126,1.61587,-2.25315,0.311621,1.63873,-2.10467,0.373318,1.63228,-2.08712,0.1818,1.41935,-1.82881,0.001178,1.48515,-1.89369,0.007435,1.50396,-1.95815,0.011648,1.48013,-2.00944,0.189373,1.39166,-2.08444,0.321137,1.22002,-1.76078,0.228539,1.12192,-1.77627,0.283986,1.06334,-1.80156,0.389661,1.02328,-1.79524,0.35033,0.841669,-1.7814,0.323197,0.772732,-1.79261,0.248916,0.883526,-1.8065,0.222116,0.816733,-1.80958,0.183646,0.588154,-1.81943,0.077836,0.533216,-1.90046,0.329064,0.516737,-1.8409,0.290436,0.470331,-1.7737,0.050136,1.10568,-2.11756,0.018963,1.02813,-2.09824,-0.082906,1.15863,-2.10005,-0.11155,1.0813,-2.08555,-0.128486,0.931412,-2.08396,-0.200231,0.756875,-2.07521,-0.292589,0.82164,-2.08473,-0.330377,0.761616,-2.074,-0.436658,0.54848,-2.04474,-0.537782,0.561303,-1.97502,-0.360976,0.378276,-2.01465,-0.425761,0.361657,-2.06974,0.101658,1.33454,-1.83142,0.097433,1.3173,-2.04593},
/*381*/{0.161488,1.90649,-1.72887,0.261517,1.84696,-1.85847,0.000909,1.82969,-1.68073,-0.12849,1.7694,-1.6671,-0.00525,1.66679,-1.67949,0.056633,1.60106,-1.67236,0.228052,1.93421,-2.10565,0.279294,1.84991,-1.93294,0.085315,1.8775,-2.04883,0.123344,1.70396,-2.22593,0.187332,1.61885,-2.25366,0.313112,1.64331,-2.10323,0.374965,1.63766,-2.08462,0.182122,1.42287,-1.82998,0.003765,1.48835,-1.89422,0.009449,1.50651,-1.95896,0.013255,1.48275,-2.00969,0.191142,1.39214,-2.08368,0.323257,1.22179,-1.76158,0.226004,1.12411,-1.7763,0.282326,1.06504,-1.80013,0.388835,1.02318,-1.79511,0.357243,0.838683,-1.78168,0.333387,0.767495,-1.79157,0.253265,0.875558,-1.80789,0.230273,0.805916,-1.8111,0.205345,0.576064,-1.81997,0.101012,0.516347,-1.89979,0.353271,0.513363,-1.84245,0.317364,0.464935,-1.77496,0.047787,1.10867,-2.11822,0.01452,1.0327,-2.09983,-0.084741,1.16347,-2.0988,-0.114605,1.08723,-2.08497,-0.135848,0.938974,-2.08411,-0.208141,0.764451,-2.07712,-0.299786,0.829955,-2.08517,-0.338168,0.76994,-2.07494,-0.441814,0.556272,-2.04579,-0.54156,0.57795,-1.97619,-0.377324,0.379154,-2.01559,-0.444836,0.367874,-2.0682,0.102573,1.33808,-1.83065,0.09839,1.31881,-2.04498},
/*382*/{0.162207,1.90793,-1.72832,0.262795,1.84948,-1.85687,0.001016,1.83137,-1.6815,-0.129209,1.77133,-1.66902,-0.005279,1.66848,-1.67992,0.056515,1.60233,-1.67226,0.229923,1.93632,-2.10477,0.280584,1.85258,-1.9317,0.087613,1.87959,-2.04944,0.127665,1.70653,-2.22666,0.191501,1.62137,-2.25411,0.314515,1.6468,-2.10234,0.376274,1.64256,-2.08244,0.183611,1.42569,-1.82992,0.005379,1.49185,-1.89459,0.010645,1.50971,-1.9594,0.015449,1.48645,-2.00983,0.192475,1.39354,-2.08304,0.323656,1.22296,-1.76197,0.225276,1.12537,-1.7738,0.279579,1.06625,-1.79857,0.387145,1.02212,-1.79482,0.363514,0.835456,-1.78115,0.342431,0.763013,-1.79085,0.25753,0.865714,-1.81003,0.23843,0.797849,-1.8128,0.225685,0.564399,-1.81851,0.124394,0.500095,-1.89983,0.377903,0.510607,-1.84313,0.344063,0.45877,-1.77656,0.044469,1.11177,-2.1192,0.010294,1.03631,-2.10091,-0.086174,1.16785,-2.09739,-0.11684,1.09306,-2.08402,-0.140324,0.945651,-2.08448,-0.214123,0.771099,-2.07898,-0.305736,0.838347,-2.08561,-0.343809,0.77747,-2.07624,-0.452451,0.565891,-2.0485,-0.545711,0.593868,-1.97583,-0.39355,0.377529,-2.01549,-0.466356,0.376713,-2.0683,0.103199,1.34142,-1.83014,0.099165,1.32122,-2.04439},
/*383*/{0.162235,1.90881,-1.72819,0.262975,1.85156,-1.85685,0.001374,1.83207,-1.68247,-0.129121,1.7724,-1.67101,-0.005723,1.67017,-1.68065,0.056832,1.60369,-1.67179,0.231027,1.93792,-2.10336,0.281318,1.85382,-1.93033,0.088833,1.88134,-2.04971,0.132126,1.70957,-2.22884,0.19555,1.62369,-2.25486,0.315456,1.65006,-2.10121,0.377306,1.6462,-2.08075,0.184815,1.4286,-1.82996,0.005429,1.49585,-1.89504,0.012233,1.51284,-1.95924,0.017249,1.48821,-2.00993,0.192979,1.39474,-2.08248,0.324068,1.22342,-1.76303,0.224763,1.1268,-1.77319,0.278879,1.06676,-1.7969,0.38547,1.02065,-1.7947,0.369278,0.832151,-1.77967,0.352364,0.758857,-1.79054,0.263148,0.857192,-1.80925,0.246215,0.787531,-1.81281,0.246702,0.552471,-1.8194,0.147418,0.485226,-1.899,0.400316,0.506209,-1.84337,0.370899,0.454562,-1.77649,0.042293,1.11488,-2.12002,0.007259,1.03921,-2.10213,-0.087806,1.17279,-2.09577,-0.119024,1.09735,-2.08245,-0.143384,0.95059,-2.08402,-0.219999,0.777592,-2.08067,-0.310852,0.845986,-2.08585,-0.350529,0.786358,-2.07743,-0.460464,0.575531,-2.05051,-0.548528,0.609536,-1.9769,-0.411926,0.377892,-2.01609,-0.484588,0.38556,-2.06618,0.103721,1.34492,-1.82916,0.099488,1.32303,-2.04324},
/*384*/{0.162895,1.90994,-1.72752,0.263872,1.8529,-1.85562,0.000667,1.83316,-1.6839,-0.130732,1.77278,-1.67249,-0.00579,1.67054,-1.68128,0.057017,1.60477,-1.67133,0.233136,1.93925,-2.10256,0.282703,1.8559,-1.92948,0.090982,1.88273,-2.04989,0.136512,1.71159,-2.22977,0.19903,1.62532,-2.25547,0.316388,1.65252,-2.09969,0.378417,1.64819,-2.07874,0.185336,1.43139,-1.82978,0.007279,1.49834,-1.89439,0.013147,1.51556,-1.95945,0.018302,1.4912,-2.01009,0.194181,1.39655,-2.08211,0.324006,1.22335,-1.7631,0.222692,1.12805,-1.77212,0.275054,1.06647,-1.7962,0.382066,1.01789,-1.79438,0.374649,0.828183,-1.77931,0.360433,0.754968,-1.79022,0.266737,0.848395,-1.81077,0.253789,0.777762,-1.81349,0.26549,0.543786,-1.81872,0.170503,0.470679,-1.89886,0.422298,0.504223,-1.8449,0.39417,0.448761,-1.7774,0.040357,1.11848,-2.12098,0.00535,1.04281,-2.10406,-0.089007,1.17607,-2.09391,-0.120606,1.10164,-2.08157,-0.144318,0.954321,-2.08378,-0.225408,0.782856,-2.08068,-0.31516,0.852188,-2.08611,-0.355222,0.793119,-2.07735,-0.467852,0.585413,-2.05214,-0.553016,0.625078,-1.97771,-0.430203,0.376039,-2.01509,-0.503761,0.395674,-2.06575,0.104417,1.34768,-1.82874,0.100285,1.32536,-2.04278},
/*385*/{0.163853,1.91068,-1.72677,0.264638,1.85381,-1.85469,0.000885,1.83361,-1.68419,-0.1306,1.77293,-1.6741,-0.004741,1.67121,-1.6816,0.058253,1.60477,-1.6705,0.234517,1.94016,-2.10147,0.283448,1.85682,-1.92908,0.093194,1.88415,-2.04999,0.141315,1.71351,-2.23117,0.201957,1.62664,-2.25673,0.317395,1.65471,-2.0994,0.380004,1.64993,-2.07773,0.185949,1.434,-1.83018,0.007624,1.50073,-1.89418,0.01525,1.51772,-1.95882,0.019411,1.49373,-2.00984,0.194506,1.3983,-2.08164,0.320116,1.22222,-1.76488,0.219599,1.12855,-1.77408,0.271852,1.0659,-1.79614,0.37867,1.01476,-1.79327,0.378567,0.824096,-1.77809,0.369022,0.74961,-1.78947,0.270987,0.839115,-1.8095,0.261617,0.768467,-1.81378,0.284857,0.535255,-1.81955,0.193455,0.457631,-1.89874,0.443198,0.502141,-1.84505,0.418127,0.444907,-1.7792,0.039649,1.12097,-2.12216,0.004582,1.04582,-2.10562,-0.08941,1.17942,-2.09186,-0.120926,1.10399,-2.07961,-0.143651,0.956745,-2.08359,-0.228153,0.787235,-2.08179,-0.317166,0.857578,-2.08574,-0.358207,0.800987,-2.07976,-0.476057,0.595398,-2.05356,-0.557441,0.641531,-1.98146,-0.450525,0.380295,-2.014,-0.5225,0.40638,-2.06392,0.105137,1.35016,-1.8283,0.100714,1.32744,-2.04229},
/*386*/{0.164442,1.9117,-1.72626,0.266474,1.85389,-1.85379,0.001064,1.83323,-1.68456,-0.130468,1.77224,-1.67507,-0.003111,1.67148,-1.6817,0.059366,1.60443,-1.67017,0.23662,1.94121,-2.10145,0.285018,1.85836,-1.92725,0.094927,1.88636,-2.05024,0.145561,1.71472,-2.23198,0.20422,1.62715,-2.25696,0.319468,1.65481,-2.09933,0.380541,1.65064,-2.07685,0.186737,1.43618,-1.83076,0.008815,1.50263,-1.89456,0.014922,1.52033,-1.95932,0.020423,1.49638,-2.00876,0.195113,1.40032,-2.08162,0.319358,1.21988,-1.76455,0.216867,1.12956,-1.77502,0.268422,1.06392,-1.7958,0.375675,1.01099,-1.79257,0.382533,0.820336,-1.77744,0.378007,0.745024,-1.78868,0.274646,0.829959,-1.80909,0.268863,0.758396,-1.81381,0.303456,0.525417,-1.81927,0.215952,0.445042,-1.89947,0.463867,0.500267,-1.84538,0.441275,0.441006,-1.77903,0.039383,1.12389,-2.12326,0.002685,1.04768,-2.10593,-0.088865,1.18183,-2.09093,-0.120968,1.10565,-2.07824,-0.142658,0.958186,-2.08336,-0.231574,0.789861,-2.08214,-0.318091,0.862894,-2.08642,-0.360226,0.806683,-2.07906,-0.483892,0.604593,-2.0551,-0.562429,0.656702,-1.98413,-0.46899,0.39314,-2.0114,-0.53874,0.419287,-2.06263,0.105888,1.35241,-1.82841,0.101157,1.3297,-2.04239},
/*387*/{0.164922,1.91211,-1.72592,0.267301,1.85475,-1.85301,0.002597,1.83279,-1.68441,-0.128397,1.77098,-1.67542,-0.001972,1.67026,-1.68181,0.061461,1.60359,-1.66931,0.238676,1.94201,-2.10085,0.286391,1.85926,-1.92711,0.096838,1.88784,-2.04984,0.148118,1.71613,-2.23339,0.206436,1.62817,-2.25752,0.319678,1.65495,-2.09856,0.381181,1.65057,-2.076,0.186756,1.43784,-1.83125,0.009817,1.50467,-1.8939,0.015743,1.52296,-1.95831,0.020424,1.49753,-2.00837,0.195913,1.4022,-2.08164,0.315954,1.21658,-1.76528,0.213313,1.1256,-1.7741,0.264712,1.06195,-1.7947,0.37134,1.0063,-1.79219,0.385758,0.816025,-1.77693,0.383956,0.740387,-1.78811,0.276556,0.819303,-1.80861,0.2756,0.74754,-1.81219,0.321106,0.515997,-1.81816,0.237512,0.433318,-1.89979,0.482179,0.498846,-1.84539,0.463024,0.438029,-1.77963,0.038824,1.12627,-2.12368,0.003189,1.04883,-2.10787,-0.088633,1.18286,-2.08916,-0.119876,1.10706,-2.07711,-0.14106,0.958946,-2.08338,-0.234227,0.790942,-2.08177,-0.31651,0.868417,-2.08702,-0.361856,0.812509,-2.08081,-0.491795,0.61526,-2.05606,-0.568962,0.671773,-1.98484,-0.485076,0.4041,-2.00994,-0.553207,0.432174,-2.06227,0.106503,1.35413,-1.82826,0.101381,1.33165,-2.04226},
/*388*/{0.166535,1.91235,-1.72518,0.269561,1.85526,-1.85279,0.003671,1.83185,-1.68455,-0.126185,1.76876,-1.67565,7.7e-005,1.66932,-1.68181,0.063586,1.60188,-1.66848,0.240495,1.94179,-2.10023,0.287704,1.85971,-1.92639,0.098387,1.88894,-2.04964,0.151011,1.71707,-2.23376,0.207293,1.62805,-2.25772,0.321464,1.65575,-2.09889,0.381558,1.64938,-2.07532,0.187007,1.44008,-1.83131,0.009727,1.50536,-1.89338,0.016034,1.52421,-1.95818,0.021072,1.49957,-2.00795,0.197055,1.40464,-2.08145,0.315682,1.21177,-1.7644,0.209621,1.12261,-1.77414,0.260323,1.05885,-1.79472,0.366921,1.00128,-1.79171,0.389289,0.811466,-1.77736,0.391434,0.736536,-1.78916,0.279876,0.809422,-1.80526,0.282289,0.738154,-1.81024,0.33901,0.509697,-1.81865,0.257365,0.424601,-1.90044,0.500699,0.498418,-1.84458,0.483357,0.436731,-1.78022,0.041133,1.12724,-2.12416,0.007707,1.05008,-2.1088,-0.087035,1.18318,-2.08814,-0.117947,1.1073,-2.07677,-0.13813,0.958682,-2.08318,-0.235656,0.79161,-2.0811,-0.316467,0.871622,-2.0877,-0.363294,0.818233,-2.08047,-0.500524,0.627141,-2.05635,-0.575685,0.686111,-1.98787,-0.500356,0.415645,-2.00779,-0.568191,0.445619,-2.06191,0.107417,1.3556,-1.82835,0.102764,1.33374,-2.04242},
/*389*/{0.16724,1.91241,-1.72463,0.270286,1.85573,-1.85238,0.004223,1.8303,-1.68456,-0.12492,1.76577,-1.67589,0.002708,1.66702,-1.68109,0.066139,1.60035,-1.66645,0.242319,1.94165,-2.09997,0.288594,1.85999,-1.9255,0.1,1.88981,-2.04942,0.152724,1.71701,-2.23372,0.208382,1.62759,-2.25804,0.32259,1.65328,-2.09885,0.382829,1.64684,-2.07473,0.187339,1.44152,-1.83154,0.010303,1.50743,-1.89206,0.016791,1.52539,-1.95747,0.021509,1.50104,-2.00696,0.197005,1.40619,-2.08129,0.312792,1.20692,-1.7644,0.205717,1.12086,-1.77384,0.253697,1.05455,-1.79491,0.361793,0.996109,-1.78994,0.393207,0.807251,-1.77617,0.398594,0.731617,-1.78795,0.282784,0.799432,-1.80248,0.288515,0.727828,-1.8082,0.354763,0.502782,-1.81829,0.277097,0.414202,-1.90033,0.517293,0.498409,-1.84412,0.501553,0.434835,-1.78095,0.042493,1.12807,-2.12433,0.010147,1.05104,-2.10919,-0.08536,1.18302,-2.08785,-0.115522,1.10619,-2.07622,-0.134198,0.957455,-2.08311,-0.236782,0.792488,-2.08083,-0.314227,0.874859,-2.08826,-0.363412,0.823794,-2.08259,-0.507983,0.639311,-2.05733,-0.582836,0.700896,-1.9901,-0.515427,0.428361,-2.00611,-0.581047,0.458824,-2.06159,0.108124,1.35707,-1.82787,0.102699,1.33529,-2.04193},
/*390*/{0.168301,1.91206,-1.72397,0.271837,1.85486,-1.8516,0.006001,1.82838,-1.68338,-0.123527,1.76252,-1.67562,0.005429,1.66456,-1.68056,0.068911,1.59749,-1.66563,0.243462,1.9414,-2.0998,0.289733,1.85998,-1.92518,0.10089,1.89154,-2.04925,0.154064,1.71698,-2.23373,0.208258,1.62737,-2.25813,0.323039,1.65072,-2.09804,0.383689,1.64391,-2.0748,0.187117,1.44211,-1.83179,0.010387,1.50758,-1.89203,0.016118,1.52693,-1.95718,0.021348,1.50241,-2.00647,0.197812,1.40808,-2.08125,0.307871,1.2017,-1.76464,0.199754,1.11659,-1.77476,0.24755,1.05086,-1.79597,0.357043,0.989857,-1.79047,0.397045,0.802827,-1.77731,0.404468,0.727044,-1.78856,0.286434,0.791293,-1.79946,0.29438,0.719835,-1.80497,0.368769,0.49629,-1.81757,0.294899,0.40591,-1.90086,0.53269,0.498352,-1.84374,0.520011,0.43399,-1.77991,0.045956,1.12815,-2.12466,0.014554,1.05055,-2.10943,-0.083595,1.18099,-2.08759,-0.112943,1.10418,-2.07509,-0.129558,0.955521,-2.08278,-0.237479,0.792864,-2.07958,-0.310936,0.879517,-2.09021,-0.362158,0.830439,-2.0838,-0.514607,0.650892,-2.05653,-0.589635,0.715144,-1.99331,-0.528117,0.441663,-2.00439,-0.591599,0.473206,-2.06146,0.108134,1.35745,-1.82845,0.10315,1.33699,-2.04265},
/*391*/{0.16981,1.91161,-1.72306,0.272582,1.85597,-1.85172,0.007219,1.82542,-1.68302,-0.122129,1.75897,-1.67437,0.008334,1.66169,-1.67954,0.072615,1.5953,-1.66398,0.245494,1.94058,-2.09928,0.290919,1.86021,-1.9249,0.102574,1.89214,-2.04858,0.154696,1.71692,-2.23351,0.207857,1.62694,-2.25811,0.323925,1.64849,-2.09799,0.38389,1.64014,-2.07475,0.189959,1.44382,-1.83265,0.01065,1.50806,-1.89196,0.016067,1.52786,-1.95706,0.021251,1.50296,-2.00583,0.198002,1.40949,-2.08135,0.303158,1.19573,-1.76461,0.195274,1.11563,-1.77391,0.240792,1.04651,-1.79537,0.352331,0.983843,-1.79013,0.400311,0.798625,-1.77814,0.410779,0.723893,-1.78963,0.289635,0.782197,-1.795,0.300261,0.712211,-1.80298,0.381903,0.490078,-1.81567,0.311573,0.39804,-1.9004,0.545358,0.49936,-1.84294,0.535229,0.43392,-1.78061,0.049283,1.12754,-2.12402,0.017793,1.04978,-2.10914,-0.080474,1.17957,-2.08855,-0.107914,1.1014,-2.07541,-0.124338,0.952711,-2.08212,-0.238614,0.79372,-2.07851,-0.307863,0.882737,-2.09091,-0.361393,0.836203,-2.08405,-0.522182,0.662832,-2.0577,-0.596098,0.730105,-1.99519,-0.542379,0.45486,-2.00313,-0.600976,0.487241,-2.06064,0.110651,1.35897,-1.82833,0.104098,1.33788,-2.04243},
/*392*/{0.17136,1.91063,-1.72241,0.273591,1.85608,-1.85121,0.009163,1.82339,-1.68148,-0.118708,1.75472,-1.67346,0.011697,1.65876,-1.67825,0.07601,1.59195,-1.6623,0.246784,1.9396,-2.09815,0.291574,1.86006,-1.92448,0.103407,1.89229,-2.04831,0.153886,1.71695,-2.23296,0.206516,1.6262,-2.25763,0.325072,1.64486,-2.09824,0.385073,1.63531,-2.07527,0.191373,1.44355,-1.83134,0.010528,1.50796,-1.89137,0.016417,1.52832,-1.95597,0.021149,1.50312,-2.00497,0.198818,1.41099,-2.08145,0.300432,1.18933,-1.76411,0.191999,1.11095,-1.77341,0.233999,1.04119,-1.79543,0.347214,0.97784,-1.79019,0.403077,0.795436,-1.77857,0.415667,0.720467,-1.79052,0.29249,0.775525,-1.79258,0.304534,0.705416,-1.80015,0.393574,0.484576,-1.81635,0.324757,0.391645,-1.89953,0.555933,0.498894,-1.84462,0.549047,0.433357,-1.7809,0.053666,1.126,-2.1236,0.023013,1.04824,-2.10931,-0.077434,1.17612,-2.08835,-0.103942,1.09835,-2.07562,-0.118282,0.949938,-2.08114,-0.239235,0.794779,-2.07715,-0.304929,0.886687,-2.09102,-0.360723,0.841935,-2.08418,-0.527024,0.677124,-2.05833,-0.60219,0.746958,-1.99783,-0.551898,0.469311,-2.001,-0.611487,0.502717,-2.06159,0.111659,1.35871,-1.82827,0.105072,1.3388,-2.04248},
/*393*/{0.172218,1.90985,-1.7218,0.275582,1.8563,-1.85133,0.011507,1.81975,-1.68043,-0.115192,1.75022,-1.67202,0.015284,1.6543,-1.67614,0.080122,1.58792,-1.65985,0.24774,1.93832,-2.09811,0.292309,1.85937,-1.92447,0.104564,1.89253,-2.0473,0.152508,1.7159,-2.23183,0.204664,1.62512,-2.25723,0.324774,1.6407,-2.09873,0.384957,1.63004,-2.07586,0.192091,1.44335,-1.83152,0.011906,1.50631,-1.89026,0.016317,1.52836,-1.95582,0.021814,1.50305,-2.00424,0.199486,1.41144,-2.08162,0.296901,1.1828,-1.76342,0.181742,1.10601,-1.77533,0.226969,1.03668,-1.79708,0.341044,0.971825,-1.7898,0.405127,0.792334,-1.77903,0.420562,0.717925,-1.79197,0.295343,0.767811,-1.79087,0.310011,0.698117,-1.79793,0.403731,0.482063,-1.81612,0.337477,0.386446,-1.89826,0.565811,0.499489,-1.8447,0.560847,0.4341,-1.78135,0.058475,1.12404,-2.12258,0.029255,1.04511,-2.10804,-0.073615,1.17233,-2.08907,-0.099484,1.09416,-2.07568,-0.112889,0.945766,-2.08003,-0.238892,0.796044,-2.07668,-0.300476,0.890297,-2.09111,-0.357374,0.848691,-2.08397,-0.531859,0.690807,-2.05766,-0.605423,0.762594,-1.99979,-0.563172,0.484285,-2.00068,-0.619049,0.51913,-2.06289,0.112999,1.35797,-1.82851,0.106029,1.33896,-2.04279},
/*394*/{0.174385,1.90807,-1.72082,0.276627,1.85413,-1.85073,0.013678,1.8162,-1.67947,-0.112362,1.74509,-1.67004,0.019235,1.64968,-1.67434,0.084235,1.58357,-1.6574,0.249276,1.93662,-2.0976,0.292977,1.85862,-1.92362,0.104647,1.89298,-2.04592,0.150405,1.71563,-2.23107,0.202984,1.62422,-2.25666,0.324804,1.63589,-2.09962,0.385326,1.62469,-2.07675,0.192485,1.44272,-1.83196,0.011973,1.50499,-1.88992,0.017495,1.52705,-1.95546,0.021828,1.50233,-2.00319,0.20078,1.41181,-2.08156,0.292455,1.17626,-1.76309,0.175316,1.10232,-1.77633,0.218944,1.03096,-1.79816,0.335257,0.966129,-1.78931,0.407007,0.789521,-1.78076,0.422177,0.715415,-1.79334,0.296604,0.762554,-1.78971,0.314196,0.692739,-1.79599,0.411122,0.478518,-1.81506,0.346514,0.382241,-1.89674,0.574282,0.499779,-1.8454,0.569273,0.434628,-1.78288,0.06346,1.12183,-2.12135,0.035636,1.04235,-2.10649,-0.070415,1.16807,-2.09005,-0.094039,1.08946,-2.07581,-0.106331,0.942291,-2.0794,-0.238338,0.79809,-2.07566,-0.29583,0.89486,-2.09055,-0.354701,0.855566,-2.08313,-0.534627,0.705216,-2.05774,-0.607633,0.779697,-2.00226,-0.572826,0.499707,-2.00137,-0.626731,0.536337,-2.06401,0.114186,1.35681,-1.82878,0.107329,1.33874,-2.04315},
/*395*/{0.175981,1.90609,-1.72009,0.276989,1.85265,-1.85126,0.015683,1.81298,-1.67798,-0.107864,1.73975,-1.66719,0.023882,1.6449,-1.67221,0.089545,1.57918,-1.6551,0.249922,1.93506,-2.09687,0.293475,1.85708,-1.92349,0.105511,1.89199,-2.04476,0.147864,1.71484,-2.22921,0.200139,1.62284,-2.25551,0.325264,1.63072,-2.10105,0.385218,1.61781,-2.07808,0.188976,1.43852,-1.83096,0.010811,1.50337,-1.89061,0.01686,1.52566,-1.95559,0.022149,1.50147,-2.0026,0.201138,1.4118,-2.08189,0.28723,1.16964,-1.76278,0.171268,1.09597,-1.77581,0.211849,1.02615,-1.79856,0.32821,0.959283,-1.78933,0.406532,0.786498,-1.78143,0.423489,0.713142,-1.79326,0.296991,0.757271,-1.78934,0.315137,0.687974,-1.79537,0.418056,0.476656,-1.8151,0.354089,0.377807,-1.89547,0.579304,0.498911,-1.84705,0.579621,0.434301,-1.78388,0.068286,1.11892,-2.12003,0.041899,1.03949,-2.10468,-0.066008,1.16288,-2.0905,-0.088828,1.08367,-2.07666,-0.099519,0.93833,-2.07863,-0.236758,0.799649,-2.07554,-0.290841,0.898887,-2.09016,-0.351394,0.861465,-2.08204,-0.53849,0.719596,-2.05716,-0.607556,0.796644,-2.00226,-0.581636,0.515601,-2.00144,-0.635366,0.554536,-2.06549,0.110884,1.353,-1.83041,0.106697,1.33853,-2.04512},
/*396*/{0.177216,1.90377,-1.71926,0.277858,1.8514,-1.85123,0.018123,1.80848,-1.67613,-0.103319,1.73417,-1.66453,0.028176,1.63995,-1.66919,0.094398,1.57415,-1.65315,0.249349,1.93267,-2.0961,0.293976,1.85592,-1.92351,0.105929,1.89163,-2.04415,0.144614,1.71406,-2.2284,0.197037,1.62178,-2.25441,0.325209,1.62615,-2.10217,0.38434,1.61058,-2.07988,0.191687,1.44008,-1.83212,0.012541,1.50197,-1.88945,0.01673,1.52368,-1.95532,0.022268,1.49916,-2.00277,0.201676,1.41166,-2.08202,0.28421,1.16297,-1.76134,0.16433,1.09288,-1.77636,0.205969,1.02171,-1.7992,0.321195,0.953475,-1.7894,0.404532,0.784304,-1.78126,0.4238,0.711195,-1.79277,0.295585,0.752536,-1.78932,0.315147,0.683879,-1.79515,0.422601,0.472617,-1.81411,0.359057,0.374014,-1.89381,0.5834,0.496928,-1.84717,0.583515,0.432719,-1.78442,0.0742,1.11561,-2.11891,0.048832,1.035,-2.10315,-0.060954,1.15718,-2.09035,-0.082916,1.07806,-2.07658,-0.091732,0.93362,-2.0782,-0.234533,0.802334,-2.07736,-0.283795,0.903594,-2.08933,-0.346691,0.867998,-2.08047,-0.537804,0.735006,-2.06254,-0.606077,0.814156,-2.00217,-0.589694,0.53174,-2.00334,-0.640567,0.572973,-2.0667,0.114955,1.3535,-1.82968,0.108772,1.33721,-2.04421},
/*397*/{0.17945,1.90108,-1.71821,0.27833,1.84943,-1.8514,0.020865,1.80399,-1.67356,-0.099312,1.72744,-1.66162,0.032895,1.63414,-1.66657,0.099632,1.56885,-1.65083,0.249592,1.93061,-2.09599,0.293838,1.85387,-1.92359,0.105482,1.89115,-2.04275,0.140963,1.71299,-2.22677,0.193451,1.62052,-2.2532,0.324647,1.62007,-2.10336,0.383191,1.6028,-2.08128,0.190572,1.43742,-1.83208,0.010603,1.49815,-1.89003,0.017069,1.52168,-1.95519,0.02196,1.49789,-2.00281,0.202502,1.41081,-2.08216,0.280733,1.15678,-1.76028,0.159065,1.09055,-1.77822,0.19908,1.01707,-1.80011,0.314529,0.947331,-1.78869,0.401853,0.780982,-1.78149,0.421062,0.708112,-1.79243,0.293482,0.747836,-1.79025,0.313838,0.679441,-1.79593,0.424811,0.46926,-1.81376,0.362097,0.370174,-1.89286,0.586982,0.49541,-1.84853,0.58814,0.430358,-1.78661,0.079754,1.11212,-2.11791,0.056555,1.03141,-2.10206,-0.05591,1.15104,-2.09078,-0.076147,1.07174,-2.07628,-0.084332,0.928528,-2.07738,-0.232499,0.803665,-2.07563,-0.277243,0.907281,-2.08743,-0.340628,0.875083,-2.07589,-0.538132,0.750975,-2.05917,-0.602829,0.830784,-2.00099,-0.596114,0.548316,-2.00553,-0.648584,0.591966,-2.0672,0.114035,1.35019,-1.83088,0.10939,1.33611,-2.04561},
/*398*/{0.181113,1.89828,-1.71714,0.278989,1.84659,-1.8513,0.023709,1.79894,-1.6704,-0.095904,1.72036,-1.65783,0.038107,1.62812,-1.6637,0.104689,1.56322,-1.64797,0.249809,1.9281,-2.09549,0.294245,1.8515,-1.92336,0.105831,1.88922,-2.04169,0.137,1.71158,-2.22491,0.189269,1.61903,-2.25211,0.323377,1.61331,-2.10418,0.382269,1.59466,-2.08357,0.191741,1.43616,-1.83212,0.011651,1.49551,-1.88897,0.018208,1.51881,-1.95496,0.023754,1.49586,-2.00217,0.20313,1.40897,-2.08196,0.275789,1.15119,-1.75924,0.155072,1.08668,-1.77776,0.194982,1.01358,-1.80088,0.309677,0.941447,-1.78826,0.397812,0.777336,-1.78086,0.416886,0.705364,-1.79212,0.290036,0.743195,-1.79062,0.312131,0.675145,-1.79609,0.425316,0.466554,-1.81394,0.363536,0.365908,-1.89273,0.587413,0.493013,-1.84935,0.588832,0.426382,-1.78668,0.085951,1.10813,-2.11691,0.063642,1.02726,-2.10122,-0.051806,1.1447,-2.09149,-0.069661,1.06532,-2.07648,-0.076315,0.923528,-2.0765,-0.228487,0.805636,-2.07543,-0.269309,0.911157,-2.08663,-0.33406,0.880669,-2.07872,-0.536466,0.765908,-2.05932,-0.59727,0.846627,-1.99873,-0.60237,0.565216,-2.00778,-0.651493,0.611821,-2.07033,0.115933,1.34828,-1.83041,0.110851,1.33398,-2.04511},
/*399*/{0.182629,1.89478,-1.71612,0.279482,1.84439,-1.85144,0.026409,1.79406,-1.66922,-0.091195,1.71259,-1.65358,0.043406,1.62151,-1.65991,0.111095,1.55828,-1.6454,0.249017,1.92478,-2.09508,0.293803,1.84959,-1.92314,0.105897,1.88802,-2.04086,0.133167,1.71049,-2.22349,0.185054,1.61717,-2.25096,0.321098,1.60516,-2.10473,0.380856,1.58667,-2.08631,0.191894,1.43308,-1.8323,0.011393,1.49312,-1.8893,0.018594,1.51568,-1.95473,0.023488,1.49154,-2.00238,0.204321,1.40733,-2.08137,0.272936,1.14659,-1.75833,0.15358,1.08276,-1.77761,0.192503,1.01002,-1.80222,0.306224,0.937583,-1.7876,0.393947,0.77338,-1.77957,0.414217,0.700408,-1.79125,0.28629,0.737873,-1.79079,0.308924,0.670393,-1.79677,0.425064,0.461467,-1.81356,0.361894,0.362293,-1.89249,0.586558,0.488254,-1.85013,0.589224,0.422274,-1.78735,0.091983,1.10399,-2.11682,0.071553,1.02268,-2.0997,-0.046104,1.13803,-2.09151,-0.063813,1.05824,-2.07595,-0.068478,0.918101,-2.07614,-0.224124,0.807,-2.07541,-0.261356,0.914703,-2.08588,-0.326338,0.886155,-2.07662,-0.533507,0.78028,-2.05993,-0.591776,0.863863,-1.99824,-0.60918,0.581742,-2.01183,-0.654775,0.630621,-2.07151,0.116506,1.34529,-1.83054,0.112087,1.33135,-2.04528},
/*400*/{0.184516,1.89077,-1.71511,0.278696,1.84224,-1.85155,0.029058,1.78856,-1.66692,-0.085892,1.70534,-1.64885,0.048623,1.61522,-1.65613,0.117344,1.55251,-1.64232,0.248377,1.92199,-2.09515,0.293794,1.84634,-1.92342,0.105173,1.88493,-2.03975,0.128589,1.70853,-2.22136,0.180642,1.6148,-2.25007,0.318822,1.59776,-2.10685,0.37841,1.57659,-2.08903,0.192573,1.42943,-1.83201,0.011885,1.49006,-1.88928,0.018503,1.51196,-1.95511,0.023103,1.48887,-2.00302,0.205319,1.40508,-2.08085,0.272938,1.14183,-1.75598,0.152196,1.07884,-1.77702,0.191968,1.00635,-1.80311,0.305007,0.935504,-1.78761,0.389567,0.768411,-1.77957,0.411207,0.695583,-1.79033,0.282777,0.732429,-1.79208,0.304392,0.664946,-1.79861,0.423597,0.45854,-1.81451,0.35931,0.35777,-1.89341,0.584225,0.483217,-1.85125,0.584521,0.416939,-1.78887,0.096901,1.09962,-2.1163,0.077844,1.0178,-2.09894,-0.041199,1.13168,-2.09171,-0.057458,1.05179,-2.07592,-0.060113,0.912633,-2.07569,-0.218908,0.80818,-2.07552,-0.252557,0.917392,-2.08439,-0.318548,0.891614,-2.07629,-0.529647,0.794362,-2.05976,-0.583864,0.879142,-1.99699,-0.612595,0.598252,-2.0142,-0.657641,0.649873,-2.07258,0.116799,1.34183,-1.83096,0.112989,1.32868,-2.04576},
/*401*/{0.18614,1.88666,-1.71443,0.279907,1.83918,-1.85174,0.032616,1.7825,-1.66416,-0.081703,1.69677,-1.64377,0.054873,1.60875,-1.65235,0.123283,1.54669,-1.63989,0.247306,1.91866,-2.09552,0.294186,1.84332,-1.92317,0.104152,1.88229,-2.03813,0.12404,1.70642,-2.21949,0.176079,1.61196,-2.24907,0.316862,1.59019,-2.10829,0.375833,1.56718,-2.09241,0.191709,1.42598,-1.83086,0.012423,1.48554,-1.88948,0.017781,1.5091,-1.95519,0.024339,1.48522,-2.00335,0.206726,1.40303,-2.08026,0.2703,1.1389,-1.75526,0.150773,1.07565,-1.77678,0.189071,1.00259,-1.80304,0.304343,0.933426,-1.78762,0.386108,0.763147,-1.77902,0.407565,0.690358,-1.79008,0.27896,0.727605,-1.79311,0.300607,0.659496,-1.7994,0.417388,0.453078,-1.81547,0.354424,0.352711,-1.89596,0.578661,0.476921,-1.85237,0.581319,0.410712,-1.79029,0.102124,1.09576,-2.1158,0.08507,1.01342,-2.09806,-0.037292,1.12436,-2.09107,-0.050222,1.0445,-2.07529,-0.051926,0.906692,-2.07551,-0.213371,0.80914,-2.07545,-0.242119,0.919753,-2.08283,-0.309124,0.89551,-2.07542,-0.525313,0.808411,-2.06053,-0.574523,0.894585,-1.99541,-0.613633,0.614846,-2.0168,-0.656941,0.669296,-2.07462,0.116641,1.33794,-1.83123,0.114682,1.32601,-2.04612},
/*402*/{0.187546,1.88182,-1.71314,0.279571,1.83522,-1.85226,0.035914,1.77549,-1.66064,-0.076277,1.68878,-1.63879,0.059982,1.60133,-1.64834,0.129805,1.54121,-1.63773,0.246019,1.91522,-2.09553,0.294277,1.84002,-1.92328,0.103912,1.87881,-2.03688,0.119101,1.70429,-2.21746,0.170895,1.60927,-2.24816,0.313494,1.58211,-2.1101,0.373213,1.55669,-2.09549,0.193188,1.4223,-1.83072,0.011497,1.48249,-1.88958,0.019176,1.50602,-1.95522,0.024008,1.48116,-2.00412,0.207366,1.40045,-2.0796,0.269402,1.13598,-1.7538,0.150399,1.07248,-1.77668,0.188096,1.00075,-1.80281,0.304085,0.931444,-1.78747,0.38137,0.756262,-1.77852,0.402345,0.684106,-1.79049,0.274466,0.722897,-1.79285,0.29521,0.65433,-1.80047,0.411151,0.446515,-1.8164,0.347203,0.349065,-1.89747,0.573322,0.470321,-1.85358,0.574112,0.403403,-1.79189,0.107886,1.09124,-2.11564,0.092783,1.00906,-2.0973,-0.032061,1.11793,-2.09109,-0.044147,1.03652,-2.07463,-0.043606,0.900469,-2.07482,-0.207052,0.809835,-2.07545,-0.231535,0.920082,-2.08192,-0.299933,0.901309,-2.0772,-0.519448,0.820866,-2.05939,-0.564206,0.907806,-1.99422,-0.614662,0.630698,-2.01892,-0.655538,0.687786,-2.07625,0.117272,1.33461,-1.83133,0.11557,1.32286,-2.04623},
/*403*/{0.189264,1.87756,-1.71243,0.280764,1.83112,-1.85182,0.03932,1.76854,-1.65765,-0.071134,1.68058,-1.63342,0.066558,1.59441,-1.64445,0.136927,1.53557,-1.63425,0.245128,1.91162,-2.09624,0.29415,1.83663,-1.92305,0.103054,1.87531,-2.03539,0.114519,1.70148,-2.21622,0.165835,1.60614,-2.24671,0.310442,1.57369,-2.11225,0.369392,1.54645,-2.09915,0.192275,1.41836,-1.82915,0.011892,1.47874,-1.88944,0.01927,1.5048,-1.95528,0.024379,1.47684,-2.00451,0.208412,1.39729,-2.07908,0.267433,1.13307,-1.75361,0.147802,1.06786,-1.77792,0.186205,0.996683,-1.80122,0.303012,0.927726,-1.78752,0.376802,0.750362,-1.77852,0.396334,0.678787,-1.79121,0.269375,0.717944,-1.79335,0.290036,0.649738,-1.80088,0.405615,0.440936,-1.81856,0.338045,0.345783,-1.90066,0.566621,0.461124,-1.8531,0.567293,0.394835,-1.79259,0.113467,1.08662,-2.11522,0.099662,1.00407,-2.0972,-0.025732,1.11009,-2.0906,-0.037388,1.02944,-2.07469,-0.034895,0.894445,-2.07491,-0.200613,0.808906,-2.07547,-0.22079,0.91933,-2.0808,-0.289409,0.904058,-2.077,-0.511627,0.832702,-2.05955,-0.553089,0.921522,-1.99423,-0.612507,0.645924,-2.02088,-0.652816,0.703809,-2.07768,0.116316,1.33102,-1.83105,0.11607,1.31972,-2.04599},
/*404*/{0.190842,1.8726,-1.7119,0.281692,1.8275,-1.85225,0.042652,1.76139,-1.65388,-0.066036,1.67175,-1.62814,0.071845,1.58706,-1.6402,0.144391,1.52987,-1.63185,0.242643,1.90732,-2.09622,0.294256,1.83291,-1.92349,0.10207,1.87076,-2.03353,0.109438,1.69819,-2.21461,0.159932,1.60268,-2.24658,0.306377,1.56416,-2.11492,0.366162,1.53558,-2.10332,0.193178,1.41703,-1.82862,0.011736,1.4742,-1.89007,0.018612,1.49794,-1.95457,0.024531,1.4723,-2.00477,0.20875,1.39404,-2.07873,0.266917,1.13065,-1.75333,0.146788,1.06616,-1.77763,0.184397,0.994108,-1.80167,0.30224,0.923005,-1.78643,0.372091,0.74385,-1.77855,0.391249,0.671301,-1.79169,0.263526,0.713271,-1.79447,0.284079,0.644235,-1.80132,0.3941,0.435635,-1.81923,0.322872,0.350365,-1.90147,0.557744,0.452157,-1.85366,0.553378,0.382603,-1.79291,0.119131,1.08203,-2.1149,0.107006,0.999769,-2.09671,-0.021906,1.10288,-2.09046,-0.031026,1.02239,-2.07497,-0.026117,0.888345,-2.07458,-0.193414,0.808537,-2.075,-0.209471,0.920689,-2.08123,-0.278205,0.905842,-2.07682,-0.501184,0.843479,-2.06052,-0.541888,0.932792,-1.99366,-0.610382,0.659815,-2.02325,-0.647421,0.719878,-2.0791,0.118584,1.32824,-1.83002,0.118206,1.31532,-2.04487},
/*405*/{0.192861,1.86712,-1.71049,0.281143,1.82335,-1.85213,0.046613,1.7535,-1.64991,-0.06142,1.66274,-1.62207,0.078852,1.57975,-1.63537,0.151293,1.52407,-1.62995,0.240929,1.90324,-2.0976,0.294678,1.82925,-1.92376,0.101592,1.86699,-2.03304,0.104723,1.69301,-2.21285,0.154561,1.59885,-2.24564,0.303286,1.55607,-2.11778,0.361089,1.52419,-2.10788,0.191194,1.41022,-1.82772,0.010653,1.47,-1.89061,0.018493,1.49403,-1.95445,0.024808,1.46734,-2.00509,0.210042,1.39123,-2.07671,0.26542,1.12642,-1.75252,0.144279,1.06442,-1.78043,0.183654,0.991042,-1.80069,0.299823,0.916892,-1.78621,0.366089,0.737469,-1.77921,0.384733,0.664207,-1.79224,0.258206,0.707732,-1.79458,0.276504,0.639417,-1.80362,0.382224,0.433049,-1.82124,0.306771,0.350414,-1.90474,0.545248,0.439235,-1.85518,0.535536,0.371642,-1.79319,0.125501,1.07803,-2.11471,0.114411,0.995082,-2.09763,-0.016649,1.09577,-2.09027,-0.023927,1.01512,-2.07463,-0.017265,0.882379,-2.07473,-0.185622,0.807936,-2.07505,-0.19743,0.919855,-2.08033,-0.267443,0.907771,-2.07451,-0.491577,0.851988,-2.06039,-0.529286,0.942722,-1.99317,-0.605229,0.672816,-2.02428,-0.641549,0.734377,-2.081,0.116283,1.32217,-1.83072,0.118839,1.31185,-2.04569},
/*406*/{0.194667,1.86163,-1.70995,0.28256,1.81791,-1.85229,0.050899,1.74516,-1.64602,-0.055871,1.65318,-1.6162,0.085721,1.57257,-1.63168,0.159771,1.5188,-1.62725,0.239585,1.89843,-2.09775,0.294371,1.82514,-1.92418,0.100169,1.86187,-2.03223,0.100793,1.68946,-2.21109,0.149062,1.59456,-2.24493,0.298562,1.54531,-2.12031,0.357017,1.51215,-2.11216,0.192283,1.40699,-1.82656,0.011207,1.46534,-1.89032,0.019125,1.49008,-1.954,0.02507,1.46252,-2.00562,0.210049,1.38729,-2.07721,0.264158,1.12404,-1.75274,0.144943,1.06086,-1.77954,0.182301,0.987342,-1.80083,0.29698,0.911022,-1.78557,0.36045,0.730588,-1.77982,0.377948,0.657121,-1.79297,0.251117,0.702986,-1.79569,0.269585,0.633541,-1.80318,0.368141,0.426838,-1.82304,0.289775,0.354087,-1.90771,0.53273,0.426045,-1.85691,0.518079,0.360138,-1.79418,0.131171,1.07361,-2.11506,0.121871,0.990271,-2.09718,-0.009973,1.08826,-2.08966,-0.016281,1.00715,-2.07382,-0.007764,0.875715,-2.07516,-0.177699,0.806397,-2.07494,-0.185431,0.918547,-2.08021,-0.255996,0.909394,-2.07542,-0.481585,0.862256,-2.06053,-0.517418,0.953839,-1.99424,-0.599776,0.68429,-2.02588,-0.633173,0.747435,-2.08258,0.117571,1.31856,-1.83018,0.1197,1.30753,-2.04513},
/*407*/{0.195491,1.85628,-1.70922,0.282625,1.81331,-1.85224,0.055291,1.73664,-1.64228,-0.049836,1.64349,-1.6101,0.092723,1.56564,-1.62766,0.167936,1.51355,-1.6253,0.238205,1.89398,-2.0984,0.294876,1.82059,-1.92464,0.098568,1.85757,-2.03008,0.095339,1.68509,-2.21005,0.143026,1.59042,-2.24488,0.293712,1.53509,-2.12354,0.35208,1.50002,-2.11671,0.192619,1.40201,-1.82488,0.011466,1.46023,-1.8907,0.017914,1.48574,-1.95373,0.024161,1.45826,-2.00576,0.210582,1.38361,-2.07615,0.264034,1.11918,-1.75101,0.144949,1.05886,-1.77991,0.180888,0.9842,-1.79972,0.293117,0.905358,-1.78482,0.353382,0.723491,-1.78026,0.369259,0.650015,-1.79433,0.244179,0.698941,-1.79712,0.260167,0.629059,-1.80435,0.353277,0.421322,-1.82451,0.269233,0.35456,-1.90782,0.517763,0.410831,-1.85588,0.497505,0.343541,-1.79434,0.137752,1.06925,-2.11494,0.12974,0.984746,-2.09798,-0.004227,1.08144,-2.08943,-0.008449,0.999994,-2.07291,0.002495,0.869406,-2.07548,-0.169478,0.805162,-2.07508,-0.175101,0.918892,-2.08041,-0.244218,0.909531,-2.07536,-0.471809,0.869507,-2.06058,-0.50447,0.962646,-1.99501,-0.591903,0.695264,-2.02851,-0.62402,0.757827,-2.08423,0.117279,1.31377,-1.83,0.120304,1.30346,-2.04496},
/*408*/{0.1977,1.85081,-1.70803,0.282123,1.80944,-1.85293,0.060373,1.72819,-1.63835,-0.042007,1.63434,-1.60349,0.100733,1.5589,-1.62357,0.176232,1.5084,-1.62261,0.235423,1.8892,-2.09865,0.294564,1.81608,-1.92498,0.097663,1.85168,-2.02904,0.090372,1.68121,-2.20879,0.136725,1.58625,-2.24429,0.289024,1.52559,-2.12736,0.344802,1.48892,-2.122,0.19166,1.39772,-1.82327,0.009307,1.45582,-1.89103,0.017802,1.48096,-1.95389,0.023696,1.45274,-2.00641,0.211109,1.37991,-2.07502,0.262158,1.11472,-1.75136,0.142459,1.05371,-1.78029,0.179267,0.980072,-1.79956,0.287604,0.899669,-1.78483,0.34662,0.717083,-1.78197,0.360225,0.643314,-1.79604,0.237003,0.696782,-1.79765,0.250792,0.626113,-1.80739,0.335864,0.418718,-1.82603,0.248051,0.356095,-1.90708,0.502555,0.398099,-1.85896,0.480365,0.335939,-1.79433,0.14332,1.0645,-2.11528,0.13703,0.980791,-2.09781,0.001891,1.0744,-2.08892,-0.002101,0.99302,-2.07241,0.011632,0.863038,-2.07554,-0.160604,0.803763,-2.07518,-0.162707,0.917115,-2.08018,-0.232274,0.910612,-2.07575,-0.459394,0.87748,-2.0616,-0.490545,0.969915,-1.99535,-0.584934,0.703664,-2.02948,-0.613231,0.767537,-2.0857,0.116307,1.3094,-1.82943,0.121138,1.29904,-2.04436},
/*409*/{0.198587,1.84585,-1.70789,0.282402,1.80479,-1.85334,0.065335,1.71913,-1.63412,-0.035297,1.62411,-1.59748,0.107949,1.55203,-1.62112,0.185802,1.50373,-1.62055,0.233908,1.88493,-2.0993,0.294418,1.81218,-1.92628,0.096265,1.84694,-2.02774,0.085114,1.67825,-2.20877,0.130503,1.58188,-2.2435,0.284222,1.51451,-2.13143,0.338975,1.47639,-2.12748,0.190914,1.39375,-1.82127,0.008026,1.45154,-1.8926,0.016113,1.47566,-1.95456,0.02307,1.4476,-2.0072,0.210996,1.37696,-2.07525,0.261691,1.10947,-1.74873,0.141141,1.05102,-1.7804,0.177744,0.976154,-1.80071,0.281666,0.893697,-1.78342,0.339069,0.712817,-1.78279,0.348511,0.638424,-1.79682,0.228972,0.696175,-1.79964,0.240059,0.625481,-1.80885,0.319238,0.418173,-1.82868,0.226339,0.356501,-1.90523,0.482374,0.393087,-1.86539,0.458119,0.339373,-1.79635,0.148869,1.06028,-2.11531,0.144139,0.976175,-2.09815,0.00772,1.06694,-2.08736,0.005285,0.986396,-2.07197,0.021844,0.856843,-2.07624,-0.15035,0.802146,-2.07526,-0.149856,0.915457,-2.07985,-0.220064,0.910593,-2.07599,-0.446952,0.883261,-2.06146,-0.478001,0.975765,-1.99462,-0.57361,0.7116,-2.03065,-0.602917,0.775426,-2.08712,0.115678,1.30526,-1.82955,0.121957,1.295,-2.04444},
/*410*/{0.200693,1.84116,-1.70685,0.284006,1.79779,-1.85183,0.070575,1.71015,-1.63045,-0.028329,1.61464,-1.59109,0.116833,1.54659,-1.61762,0.194325,1.49897,-1.61905,0.232701,1.88106,-2.10009,0.295102,1.80713,-1.92678,0.095255,1.84165,-2.0255,0.080905,1.67253,-2.20711,0.124056,1.57799,-2.24379,0.278423,1.50398,-2.13596,0.331323,1.46416,-2.13286,0.188403,1.39006,-1.82037,0.004986,1.44829,-1.89304,0.013891,1.47087,-1.95536,0.0216,1.44221,-2.00789,0.211142,1.37214,-2.07336,0.259116,1.10781,-1.74686,0.138903,1.0483,-1.77934,0.175887,0.974543,-1.80232,0.275082,0.887547,-1.78462,0.332314,0.711646,-1.78298,0.341471,0.637232,-1.79811,0.221083,0.699853,-1.80101,0.2296,0.629465,-1.80973,0.301097,0.419382,-1.83077,0.204102,0.35706,-1.90716,0.459968,0.392801,-1.86796,0.435466,0.340054,-1.7977,0.154907,1.05579,-2.11462,0.152116,0.972027,-2.09823,0.013219,1.06065,-2.08687,0.013464,0.979453,-2.0713,0.031357,0.846224,-2.07458,-0.140014,0.800314,-2.07625,-0.135435,0.913363,-2.0805,-0.207455,0.910706,-2.07609,-0.434815,0.888338,-2.06189,-0.46666,0.982777,-1.99588,-0.56259,0.718121,-2.03155,-0.588731,0.782075,-2.08924,0.113074,1.30175,-1.82831,0.12142,1.29008,-2.04307},
/*411*/{0.201884,1.83614,-1.70595,0.286157,1.79268,-1.85266,0.076992,1.70108,-1.62694,-0.019242,1.6047,-1.58486,0.125763,1.53925,-1.61376,0.203585,1.49487,-1.61697,0.231231,1.87702,-2.10144,0.295697,1.80182,-1.92707,0.094091,1.83804,-2.02357,0.07629,1.66911,-2.20615,0.11705,1.57395,-2.24354,0.27171,1.49272,-2.14135,0.32437,1.45256,-2.13828,0.186577,1.38678,-1.8194,0.001306,1.4446,-1.89378,0.011573,1.46522,-1.95676,0.019534,1.43785,-2.00915,0.208415,1.36776,-2.073,0.252135,1.10752,-1.74601,0.135038,1.04795,-1.78071,0.173253,0.974348,-1.80323,0.270296,0.882949,-1.78497,0.327,0.713915,-1.78401,0.331752,0.639204,-1.79814,0.214922,0.706413,-1.80044,0.220372,0.634977,-1.80941,0.27931,0.42245,-1.8336,0.181594,0.358264,-1.90777,0.438708,0.391656,-1.86952,0.412851,0.340961,-1.79864,0.160431,1.05238,-2.11428,0.15936,0.968539,-2.09803,0.018849,1.05374,-2.08605,0.020194,0.972792,-2.06997,0.042129,0.841349,-2.07688,-0.128762,0.798836,-2.07608,-0.12374,0.912671,-2.0826,-0.193476,0.910392,-2.07653,-0.417022,0.889537,-2.05975,-0.45227,0.986436,-1.99721,-0.549956,0.722858,-2.03234,-0.575802,0.787371,-2.09055,0.11065,1.29837,-1.82785,0.119705,1.28534,-2.0425},
/*412*/{0.203971,1.83215,-1.7049,0.286585,1.78876,-1.85295,0.084156,1.69214,-1.62346,-0.010568,1.59499,-1.57856,0.134305,1.53429,-1.6123,0.213798,1.49116,-1.61585,0.230554,1.87365,-2.10246,0.29713,1.79829,-1.92837,0.093868,1.83513,-2.02054,0.071914,1.66481,-2.20574,0.110648,1.57017,-2.24301,0.265443,1.48342,-2.14663,0.31628,1.4412,-2.14375,0.183772,1.38412,-1.81809,-0.002591,1.44056,-1.89613,0.008903,1.46119,-1.95793,0.017268,1.43301,-2.01021,0.209851,1.36367,-2.06945,0.253152,1.10627,-1.74085,0.132866,1.04937,-1.78256,0.173645,0.976061,-1.8037,0.270376,0.887266,-1.78413,0.321089,0.715088,-1.78382,0.317611,0.638341,-1.80235,0.2089,0.712743,-1.79922,0.211244,0.641537,-1.80868,0.258838,0.425259,-1.83465,0.160356,0.359956,-1.90926,0.415926,0.390215,-1.86964,0.389885,0.338222,-1.79702,0.165283,1.04958,-2.11403,0.166358,0.965946,-2.09738,0.0228,1.0472,-2.08557,0.026862,0.965617,-2.0695,0.053487,0.836645,-2.07659,-0.116528,0.797029,-2.07566,-0.109739,0.911224,-2.08307,-0.179087,0.908928,-2.07626,-0.410094,0.895829,-2.06116,-0.438911,0.990628,-1.99703,-0.536475,0.727031,-2.03411,-0.559802,0.790272,-2.09159,0.107501,1.29552,-1.8265,0.1203,1.28104,-2.04087},
/*413*/{0.205749,1.8276,-1.7036,0.286217,1.78411,-1.85311,0.091022,1.68441,-1.62052,-0.000471,1.58638,-1.5729,0.144462,1.52925,-1.61005,0.224405,1.48815,-1.61446,0.229445,1.87066,-2.10419,0.297822,1.79473,-1.92992,0.093274,1.83396,-2.01748,0.06762,1.66174,-2.20504,0.103852,1.56673,-2.24183,0.258166,1.47446,-2.15104,0.307536,1.43104,-2.14832,0.181165,1.38176,-1.81566,-0.005451,1.43681,-1.89772,0.006066,1.45753,-1.95878,0.013715,1.4291,-2.01209,0.209226,1.36095,-2.06674,0.248467,1.10652,-1.73773,0.131251,1.05056,-1.78502,0.172642,0.976448,-1.8046,0.273996,0.89374,-1.78195,0.314846,0.715636,-1.78378,0.309036,0.638747,-1.80099,0.202069,0.717519,-1.79779,0.200668,0.646628,-1.80811,0.240086,0.425822,-1.83456,0.137597,0.361126,-1.90912,0.394984,0.388682,-1.86916,0.368417,0.338233,-1.79575,0.169743,1.04852,-2.11349,0.174013,0.965055,-2.09759,0.0277,1.04117,-2.08478,0.035642,0.960114,-2.06847,0.065338,0.832696,-2.07616,-0.10315,0.795143,-2.07526,-0.095116,0.90908,-2.08345,-0.164575,0.908222,-2.07654,-0.393205,0.898041,-2.06404,-0.426174,0.993535,-1.99905,-0.5218,0.728451,-2.03537,-0.546901,0.792266,-2.09321,0.104431,1.29301,-1.82548,0.119955,1.27763,-2.03961},
/*414*/{0.206444,1.82486,-1.70308,0.287047,1.77986,-1.85302,0.097537,1.67761,-1.6196,0.010743,1.5784,-1.5672,0.155226,1.52549,-1.60753,0.235041,1.48595,-1.61395,0.228844,1.86838,-2.10495,0.29854,1.7914,-1.93085,0.092838,1.83388,-2.01505,0.064989,1.66018,-2.20437,0.097447,1.56453,-2.2407,0.250081,1.4668,-2.15424,0.298035,1.42256,-2.15412,0.177616,1.38074,-1.813,-0.007606,1.43376,-1.90071,0.003936,1.45577,-1.95935,0.011108,1.42393,-2.01439,0.20726,1.35813,-2.0663,0.245958,1.10834,-1.7361,0.131773,1.04887,-1.78291,0.170725,0.975672,-1.80445,0.279149,0.899943,-1.7813,0.307564,0.714998,-1.78379,0.303066,0.640909,-1.79873,0.195102,0.720906,-1.79528,0.190446,0.649413,-1.8055,0.220934,0.425665,-1.8336,0.117018,0.362062,-1.9087,0.374924,0.388718,-1.86786,0.347374,0.33829,-1.79701,0.17486,1.04929,-2.11241,0.18222,0.964933,-2.09607,0.032779,1.03575,-2.08423,0.042324,0.955926,-2.0685,0.078673,0.829845,-2.0756,-0.089241,0.792788,-2.07423,-0.080261,0.907015,-2.08415,-0.149894,0.906927,-2.07744,-0.378625,0.899261,-2.0643,-0.412198,0.994091,-1.9996,-0.506568,0.729482,-2.03593,-0.531805,0.792868,-2.09459,0.101333,1.29166,-1.82458,0.118945,1.27413,-2.03837},
/*415*/{0.206362,1.82285,-1.70252,0.286962,1.77851,-1.85441,0.104883,1.67388,-1.61741,0.019782,1.57179,-1.56271,0.165422,1.52271,-1.60626,0.246261,1.48521,-1.61297,0.229695,1.86668,-2.10531,0.298936,1.7882,-1.93139,0.093213,1.83359,-2.01453,0.061978,1.66032,-2.20158,0.091287,1.56459,-2.23961,0.24185,1.4621,-2.15576,0.288202,1.41449,-2.15901,0.17586,1.38118,-1.80901,-0.010199,1.43152,-1.90325,0.002844,1.4534,-1.96019,0.007883,1.41882,-2.01717,0.205791,1.3566,-2.06492,0.242661,1.10774,-1.73539,0.127921,1.04756,-1.78359,0.170174,0.975122,-1.80355,0.284575,0.905237,-1.78166,0.297727,0.713883,-1.7834,0.291108,0.639175,-1.79816,0.185539,0.723583,-1.79379,0.180236,0.652812,-1.803,0.202558,0.428516,-1.83435,0.09579,0.362314,-1.90849,0.353475,0.38706,-1.86727,0.325043,0.337941,-1.7953,0.179665,1.0499,-2.11177,0.189232,0.966837,-2.09684,0.038197,1.03275,-2.08435,0.050572,0.951927,-2.06756,0.09287,0.827983,-2.07472,-0.075292,0.790759,-2.07326,-0.065341,0.904491,-2.08424,-0.135103,0.90572,-2.07812,-0.363107,0.898789,-2.06442,-0.398168,0.993622,-2.00174,-0.490076,0.72793,-2.03701,-0.51586,0.791542,-2.09568,0.099483,1.2916,-1.82282,0.119271,1.27119,-2.03617},
/*416*/{0.206593,1.82165,-1.70256,0.287198,1.77745,-1.85523,0.109587,1.67108,-1.61749,0.031622,1.56727,-1.55936,0.176985,1.52093,-1.60649,0.257398,1.4847,-1.61266,0.230444,1.86463,-2.10533,0.299042,1.78617,-1.93314,0.09381,1.8338,-2.01442,0.056657,1.66184,-2.1983,0.083697,1.56615,-2.23769,0.233064,1.45838,-2.15828,0.277717,1.40847,-2.16329,0.172124,1.38027,-1.80565,-0.012258,1.43001,-1.90493,0.001441,1.45316,-1.96066,0.005962,1.41604,-2.01879,0.203572,1.35437,-2.0638,0.238339,1.10612,-1.73503,0.123991,1.04646,-1.78367,0.163993,0.973617,-1.80485,0.288694,0.906036,-1.78298,0.287194,0.711504,-1.78241,0.278638,0.637233,-1.79761,0.175649,0.72535,-1.79292,0.167724,0.654105,-1.80264,0.181321,0.427691,-1.8337,0.074699,0.362922,-1.90758,0.332611,0.38658,-1.86795,0.304711,0.337192,-1.79465,0.185219,1.05095,-2.11167,0.197355,0.96805,-2.0959,0.043584,1.03018,-2.08414,0.05958,0.949187,-2.06818,0.107167,0.826604,-2.07382,-0.060238,0.788239,-2.07248,-0.050112,0.900993,-2.08329,-0.119358,0.903183,-2.07779,-0.348863,0.897278,-2.06565,-0.384675,0.992589,-2.00319,-0.472214,0.72487,-2.03786,-0.498307,0.787541,-2.09731,0.095476,1.29085,-1.82167,0.117481,1.26897,-2.03465},
/*417*/{0.207055,1.82096,-1.70344,0.286665,1.77671,-1.85622,0.115792,1.66968,-1.61613,0.043236,1.56371,-1.55626,0.18835,1.51975,-1.60573,0.269956,1.4857,-1.61306,0.230861,1.86337,-2.10485,0.298364,1.78481,-1.93317,0.094006,1.83405,-2.01461,0.05173,1.66494,-2.19526,0.076882,1.56932,-2.23634,0.224084,1.45568,-2.16021,0.267506,1.40444,-2.16703,0.169719,1.38007,-1.80252,-0.013301,1.4295,-1.90494,0.000914,1.45299,-1.96014,0.005219,1.41586,-2.0189,0.202845,1.35371,-2.06252,0.233436,1.1036,-1.7344,0.118611,1.04537,-1.78467,0.159008,0.972176,-1.80455,0.283236,0.902126,-1.78279,0.275658,0.707826,-1.78187,0.263712,0.63364,-1.79641,0.164641,0.724852,-1.79172,0.153965,0.654306,-1.80206,0.161218,0.426899,-1.83263,0.052745,0.36356,-1.90755,0.310687,0.386269,-1.86685,0.283173,0.33664,-1.79348,0.192352,1.05238,-2.111,0.206315,0.969662,-2.09417,0.051752,1.02633,-2.08435,0.068449,0.946956,-2.06854,0.1208,0.825322,-2.07203,-0.045412,0.787139,-2.06976,-0.033566,0.898513,-2.08341,-0.10341,0.900996,-2.07776,-0.333844,0.894043,-2.06528,-0.372646,0.989719,-2.00433,-0.455859,0.720258,-2.03764,-0.481058,0.78248,-2.09811,0.093102,1.29059,-1.82043,0.116795,1.26845,-2.03321},
/*418*/{0.20868,1.82071,-1.70399,0.286967,1.77419,-1.85644,0.121876,1.66935,-1.61544,0.05415,1.5612,-1.55298,0.199681,1.51991,-1.6061,0.281291,1.48765,-1.61399,0.231689,1.8626,-2.10461,0.298202,1.78369,-1.93326,0.094324,1.83426,-2.01574,0.046953,1.66936,-2.19119,0.069754,1.57294,-2.23474,0.215366,1.45532,-2.16244,0.25653,1.40199,-2.17092,0.166639,1.38052,-1.79983,-0.014762,1.42982,-1.90649,0.00038,1.45458,-1.96027,0.003077,1.41708,-2.01935,0.201516,1.35389,-2.06155,0.229526,1.09861,-1.73384,0.113828,1.04334,-1.78477,0.153169,0.970169,-1.80591,0.274383,0.89722,-1.78141,0.263274,0.703709,-1.78128,0.249055,0.629654,-1.79628,0.152192,0.724666,-1.79165,0.139682,0.653708,-1.80115,0.140621,0.427299,-1.83192,0.031062,0.364137,-1.9064,0.288553,0.385816,-1.8656,0.261153,0.336843,-1.79324,0.199096,1.05405,-2.11057,0.215095,0.972455,-2.0948,0.058241,1.02448,-2.0849,0.078245,0.945742,-2.06944,0.137131,0.825956,-2.07056,-0.029708,0.784402,-2.06873,-0.018474,0.89668,-2.08384,-0.088742,0.899728,-2.07885,-0.318808,0.891421,-2.06551,-0.362038,0.986575,-2.00723,-0.436491,0.715309,-2.03792,-0.4629,0.775101,-2.09914,0.089621,1.29124,-1.81995,0.115163,1.26899,-2.0325},
/*419*/{0.209904,1.82123,-1.70514,0.286941,1.77339,-1.85667,0.127608,1.66908,-1.61417,0.063923,1.55986,-1.55129,0.210862,1.52151,-1.60612,0.293105,1.49128,-1.61501,0.232766,1.86229,-2.10427,0.298163,1.78279,-1.93345,0.094027,1.83474,-2.01641,0.041741,1.67494,-2.18747,0.062399,1.57744,-2.23349,0.206591,1.45566,-2.1647,0.246403,1.40111,-2.17372,0.16454,1.38101,-1.7972,-0.015753,1.43017,-1.9054,-0.001575,1.45455,-1.95913,0.003014,1.4184,-2.01882,0.200154,1.35433,-2.06103,0.222243,1.09511,-1.73303,0.107269,1.0427,-1.78589,0.145546,0.966948,-1.80626,0.263537,0.891825,-1.78068,0.249706,0.699764,-1.78072,0.233713,0.626308,-1.79638,0.139426,0.722583,-1.79086,0.125286,0.652054,-1.80199,0.119976,0.427752,-1.83153,0.00955,0.365448,-1.90605,0.267377,0.384899,-1.86513,0.238963,0.337212,-1.79331,0.206819,1.05638,-2.1104,0.226013,0.974568,-2.0941,0.067353,1.02255,-2.08548,0.089507,0.943705,-2.06877,0.153484,0.826129,-2.0695,-0.01426,0.782788,-2.06779,-0.003325,0.894733,-2.08416,-0.072748,0.895971,-2.07926,-0.303974,0.887486,-2.06581,-0.35079,0.981299,-2.0086,-0.415448,0.706866,-2.03524,-0.444021,0.766395,-2.09997,0.087772,1.2915,-1.81892,0.114068,1.26963,-2.03142},
/*420*/{0.211162,1.82199,-1.70585,0.286537,1.77301,-1.8573,0.132985,1.66927,-1.61338,0.074052,1.55963,-1.54892,0.221186,1.52371,-1.60597,0.305275,1.4956,-1.61604,0.232497,1.8624,-2.10446,0.296952,1.78234,-1.93371,0.094164,1.83579,-2.017,0.036753,1.68063,-2.1837,0.054724,1.58284,-2.23234,0.197468,1.45578,-2.16675,0.236114,1.40158,-2.17651,0.163639,1.38152,-1.79603,-0.016733,1.43113,-1.90544,-0.003212,1.45507,-1.95912,0.002091,1.41976,-2.0175,0.197725,1.35506,-2.06023,0.220443,1.09283,-1.73301,0.098238,1.04092,-1.78776,0.137139,0.965074,-1.80731,0.251844,0.885754,-1.78008,0.235594,0.694656,-1.78058,0.217517,0.621963,-1.7959,0.125781,0.719717,-1.79083,0.110405,0.650266,-1.80131,0.098079,0.427325,-1.83046,-0.011282,0.365702,-1.90534,0.246684,0.384335,-1.86486,0.217324,0.336782,-1.79208,0.21514,1.0596,-2.11017,0.236311,0.978619,-2.09332,0.076558,1.02371,-2.08736,0.100684,0.943032,-2.06995,0.168622,0.83038,-2.06903,0.001601,0.781083,-2.06619,0.011377,0.893158,-2.08416,-0.058018,0.894348,-2.07917,-0.285685,0.880351,-2.06493,-0.338713,0.975146,-2.00929,-0.395464,0.698752,-2.03599,-0.424892,0.756084,-2.10089,0.0862,1.29229,-1.81826,0.112332,1.27033,-2.03077},
/*421*/{0.212694,1.82436,-1.70633,0.285365,1.7745,-1.85864,0.137437,1.67072,-1.6119,0.083593,1.55941,-1.54693,0.23121,1.52735,-1.60654,0.316077,1.50156,-1.61869,0.231702,1.86314,-2.10455,0.296438,1.78265,-1.93423,0.093959,1.83748,-2.0177,0.03216,1.68722,-2.18063,0.046517,1.58866,-2.23167,0.189376,1.45985,-2.16913,0.225358,1.40361,-2.17913,0.160949,1.38243,-1.79421,-0.016347,1.4342,-1.905,-0.003763,1.45551,-1.9573,0.000958,1.42148,-2.0165,0.196161,1.35737,-2.05997,0.2128,1.0877,-1.73337,0.093244,1.04003,-1.78654,0.128138,0.962834,-1.80777,0.239685,0.879934,-1.77972,0.220107,0.690272,-1.7806,0.201908,0.617752,-1.79626,0.111731,0.717654,-1.79113,0.095053,0.648578,-1.80157,0.077682,0.427656,-1.83074,-0.03224,0.366285,-1.90493,0.224811,0.384368,-1.86461,0.196734,0.337124,-1.79159,0.223143,1.06363,-2.1098,0.247348,0.983061,-2.09321,0.086248,1.02267,-2.08699,0.112404,0.943813,-2.0701,0.184275,0.832832,-2.06876,0.018165,0.780419,-2.06607,0.026965,0.891968,-2.08376,-0.043496,0.892723,-2.0789,-0.276213,0.87645,-2.06567,-0.329422,0.968644,-2.01145,-0.373835,0.689313,-2.03579,-0.404735,0.745094,-2.10156,0.084529,1.29349,-1.81756,0.110961,1.27218,-2.0301},
/*422*/{0.21439,1.8267,-1.70697,0.284902,1.77465,-1.85889,0.141779,1.67267,-1.6109,0.092059,1.56,-1.5451,0.240447,1.53174,-1.60652,0.326708,1.50812,-1.62041,0.231548,1.8641,-2.10508,0.295791,1.78345,-1.93472,0.09366,1.83906,-2.01748,0.027885,1.69436,-2.17806,0.039171,1.5951,-2.23109,0.180308,1.46278,-2.17092,0.215344,1.40636,-2.1814,0.159502,1.38353,-1.7923,-0.017657,1.43269,-1.90352,-0.004727,1.45607,-1.95732,-0.000653,1.42236,-2.01538,0.195438,1.35948,-2.0595,0.206015,1.08412,-1.73485,0.085686,1.03869,-1.786,0.119064,0.961984,-1.80655,0.227251,0.873375,-1.78018,0.204691,0.685798,-1.78163,0.184353,0.613395,-1.79711,0.096396,0.714675,-1.79216,0.078207,0.646335,-1.80287,0.057984,0.427959,-1.82971,-0.053304,0.366263,-1.90459,0.204661,0.384838,-1.8641,0.175602,0.33625,-1.79015,0.231804,1.06798,-2.11007,0.258082,0.988966,-2.09333,0.096186,1.02313,-2.08778,0.124772,0.944503,-2.06997,0.200055,0.835342,-2.06756,0.034152,0.779594,-2.06472,0.040843,0.892335,-2.08428,-0.029414,0.892112,-2.07954,-0.260632,0.869662,-2.06648,-0.319834,0.960135,-2.01329,-0.35203,0.679792,-2.03523,-0.384394,0.733625,-2.10187,0.084071,1.29367,-1.81707,0.111122,1.27358,-2.02966},
/*423*/{0.2164,1.82981,-1.70803,0.286104,1.77622,-1.86068,0.145687,1.67549,-1.61058,0.100855,1.56057,-1.54329,0.249626,1.53665,-1.60749,0.335749,1.51514,-1.62285,0.230084,1.86554,-2.10532,0.29523,1.78427,-1.93572,0.09253,1.84159,-2.01787,0.022051,1.70111,-2.17541,0.031061,1.6019,-2.23097,0.171611,1.46809,-2.17318,0.20573,1.4111,-2.18335,0.158064,1.38398,-1.79142,-0.018236,1.43394,-1.90206,-0.005144,1.45673,-1.9559,2.6e-005,1.42542,-2.01325,0.194179,1.36201,-2.05929,0.202935,1.08328,-1.73527,0.079871,1.04105,-1.78488,0.110113,0.96124,-1.80685,0.213494,0.868391,-1.78038,0.189293,0.681851,-1.7825,0.167565,0.610342,-1.79753,0.081243,0.713292,-1.79104,0.061801,0.645096,-1.8029,0.037376,0.428211,-1.82996,-0.074236,0.366722,-1.90492,0.182825,0.383921,-1.8638,0.153943,0.336023,-1.79072,0.238878,1.07422,-2.11109,0.26922,0.99558,-2.093,0.105346,1.02435,-2.0883,0.137149,0.946898,-2.07123,0.215221,0.83904,-2.06855,0.050578,0.779825,-2.06426,0.054676,0.892558,-2.08368,-0.015291,0.890591,-2.07921,-0.241425,0.859407,-2.06367,-0.309914,0.950184,-2.01392,-0.329693,0.669459,-2.03579,-0.36446,0.72088,-2.10199,0.083298,1.294,-1.81699,0.110403,1.27595,-2.02975},
/*424*/{0.218852,1.83231,-1.70842,0.286406,1.77812,-1.86166,0.151136,1.67868,-1.61064,0.109481,1.56288,-1.54207,0.258497,1.54252,-1.60782,0.345458,1.52268,-1.62586,0.22808,1.86727,-2.10533,0.29462,1.78608,-1.93717,0.091558,1.84407,-2.01748,0.016674,1.70888,-2.17401,0.02266,1.60909,-2.23023,0.163068,1.4734,-2.17472,0.195757,1.41663,-2.18479,0.157898,1.38424,-1.79139,-0.018988,1.43482,-1.90184,-0.005918,1.45847,-1.95518,-0.002804,1.4268,-2.0122,0.193474,1.36378,-2.05884,0.194954,1.08002,-1.73615,0.072345,1.04242,-1.78404,0.099256,0.962194,-1.80542,0.199215,0.864395,-1.78058,0.173534,0.679979,-1.78244,0.152129,0.608451,-1.79817,0.065941,0.712699,-1.79238,0.044865,0.64499,-1.80366,0.017043,0.428644,-1.82989,-0.095345,0.367995,-1.90504,0.161968,0.384042,-1.86407,0.132698,0.336486,-1.79071,0.246557,1.08093,-2.1115,0.279172,1.00315,-2.0932,0.114596,1.02615,-2.08863,0.148891,0.949826,-2.07127,0.229541,0.842819,-2.06873,0.067609,0.780433,-2.06415,0.068684,0.893339,-2.08316,-0.002146,0.889659,-2.07983,-0.231819,0.854527,-2.06755,-0.30167,0.940169,-2.01495,-0.307455,0.658017,-2.0345,-0.341908,0.707706,-2.10244,0.082645,1.29462,-1.8171,0.109168,1.27756,-2.03001},
/*425*/{0.221911,1.83577,-1.70905,0.286569,1.77984,-1.86273,0.156255,1.68166,-1.61013,0.118788,1.56556,-1.54173,0.266272,1.54797,-1.60927,0.353408,1.53095,-1.62833,0.226266,1.86978,-2.10623,0.294063,1.78752,-1.93841,0.09054,1.84655,-2.01569,0.011213,1.71553,-2.17288,0.0148,1.61653,-2.22999,0.154248,1.47939,-2.17572,0.186647,1.42334,-2.18586,0.157804,1.38357,-1.79111,-0.018954,1.43703,-1.9009,-0.006721,1.45972,-1.954,-0.003529,1.42814,-2.01117,0.192601,1.36619,-2.05907,0.189564,1.07892,-1.73754,0.063528,1.04384,-1.78368,0.089435,0.963743,-1.80445,0.182287,0.861242,-1.78153,0.157865,0.67818,-1.78402,0.136585,0.60888,-1.79959,0.050811,0.712431,-1.79239,0.028943,0.645062,-1.80368,-0.004232,0.429185,-1.82981,-0.116301,0.368171,-1.90478,0.141695,0.383724,-1.86415,0.112254,0.336118,-1.79024,0.253606,1.08808,-2.11158,0.288498,1.01158,-2.0932,0.123324,1.02921,-2.08829,0.162906,0.956248,-2.07179,0.24463,0.847855,-2.0687,0.083609,0.781351,-2.06393,0.081441,0.894566,-2.08358,0.011664,0.888518,-2.07987,-0.217844,0.845655,-2.0669,-0.291862,0.927977,-2.01527,-0.284159,0.64631,-2.03435,-0.321539,0.694129,-2.10268,0.08226,1.2948,-1.81755,0.108123,1.27953,-2.03068},
/*426*/{0.225094,1.83932,-1.71016,0.287894,1.78306,-1.86385,0.161073,1.68501,-1.61034,0.12696,1.56837,-1.54075,0.274187,1.55437,-1.61065,0.360621,1.53914,-1.63177,0.223053,1.8726,-2.10679,0.293755,1.79005,-1.94004,0.089252,1.84894,-2.01499,0.00534,1.72257,-2.17164,0.006897,1.62392,-2.22941,0.146303,1.48667,-2.17669,0.178283,1.43007,-2.18683,0.158543,1.3843,-1.79135,-0.01915,1.4386,-1.89985,-0.006976,1.46193,-1.95341,-0.005041,1.43017,-2.01037,0.192143,1.36939,-2.05976,0.181856,1.07752,-1.73827,0.056576,1.04591,-1.7827,0.079251,0.964593,-1.80399,0.16622,0.858779,-1.78263,0.141561,0.676981,-1.785,0.117323,0.606896,-1.80045,0.035553,0.713408,-1.79279,0.012713,0.646424,-1.80348,-0.02373,0.430092,-1.83008,-0.136793,0.368968,-1.90513,0.120716,0.383039,-1.86326,0.091161,0.33643,-1.79012,0.259159,1.09599,-2.11167,0.296309,1.02033,-2.09325,0.131811,1.03343,-2.0887,0.169408,0.961593,-2.07257,0.258966,0.85417,-2.06888,0.099728,0.782805,-2.06434,0.093036,0.897414,-2.08264,0.024286,0.887271,-2.07957,-0.200159,0.834805,-2.0649,-0.282386,0.915365,-2.01395,-0.259453,0.633447,-2.03414,-0.299762,0.680055,-2.10283,0.082823,1.29581,-1.81828,0.107621,1.28225,-2.03165},
/*427*/{0.228214,1.84293,-1.71129,0.287547,1.78559,-1.86541,0.166025,1.6891,-1.61039,0.134073,1.5712,-1.54031,0.28054,1.56099,-1.61238,0.367559,1.54845,-1.63483,0.220242,1.8757,-2.10732,0.293139,1.79316,-1.94195,0.08766,1.85081,-2.01378,-0.001304,1.72884,-2.16899,-0.000109,1.63125,-2.22942,0.136955,1.49362,-2.17673,0.170032,1.4375,-2.18749,0.159544,1.38453,-1.79159,-0.018637,1.44121,-1.89816,-0.007055,1.46392,-1.95173,-0.005072,1.43184,-2.00975,0.190651,1.37098,-2.05965,0.175248,1.07714,-1.73997,0.048565,1.0472,-1.78225,0.068759,0.966153,-1.80389,0.150843,0.857846,-1.78422,0.125329,0.676224,-1.78615,0.100276,0.606746,-1.80092,0.019817,0.715347,-1.79353,-0.003029,0.646813,-1.80474,-0.044515,0.430911,-1.83018,-0.156726,0.370178,-1.90535,0.100285,0.383009,-1.86392,0.070373,0.336688,-1.79004,0.264824,1.10449,-2.11204,0.304608,1.02979,-2.09354,0.139262,1.03661,-2.08782,0.179296,0.966318,-2.07213,0.274083,0.862207,-2.06913,0.116248,0.784964,-2.06539,0.10589,0.898672,-2.08243,0.036766,0.886489,-2.07945,-0.190386,0.826324,-2.06734,-0.272616,0.900328,-2.0143,-0.235586,0.620695,-2.03451,-0.278386,0.664856,-2.10257,0.082965,1.29688,-1.81807,0.106158,1.28392,-2.03166},
/*428*/{0.231088,1.84741,-1.71256,0.287935,1.78946,-1.86684,0.171991,1.69289,-1.61071,0.14243,1.57487,-1.5399,0.287608,1.56785,-1.61415,0.3738,1.55687,-1.63836,0.217318,1.87983,-2.10779,0.292647,1.7961,-1.94365,0.086061,1.85449,-2.01196,-0.00764,1.73608,-2.16853,-0.00834,1.6385,-2.22866,0.12984,1.50157,-2.17746,0.161793,1.44565,-2.18822,0.160827,1.38547,-1.79265,-0.018645,1.44358,-1.89626,-0.006503,1.46623,-1.95054,-0.006206,1.43423,-2.00864,0.189927,1.37382,-2.06012,0.171211,1.07656,-1.74018,0.040282,1.04888,-1.78026,0.059383,0.968365,-1.80372,0.13485,0.857175,-1.78498,0.109337,0.675988,-1.78772,0.081315,0.606929,-1.80355,0.003214,0.715469,-1.79447,-0.021585,0.648564,-1.8038,-0.062963,0.433085,-1.83043,-0.177303,0.372162,-1.90493,0.07962,0.383066,-1.86403,0.049835,0.336827,-1.79101,0.269682,1.11296,-2.11192,0.311866,1.03961,-2.09382,0.146361,1.04172,-2.08797,0.188935,0.972816,-2.07193,0.287201,0.87108,-2.06891,0.132507,0.787836,-2.06567,0.11766,0.89981,-2.08243,0.049391,0.885427,-2.07963,-0.175831,0.815627,-2.06793,-0.263161,0.885272,-2.01359,-0.210182,0.607924,-2.03465,-0.256099,0.650232,-2.10253,0.083859,1.29825,-1.81847,0.105203,1.28661,-2.03233},
/*429*/{0.233639,1.85164,-1.71408,0.289607,1.7924,-1.8683,0.177597,1.69691,-1.61138,0.149728,1.57892,-1.53928,0.294202,1.57549,-1.61651,0.37988,1.56597,-1.64216,0.213472,1.88386,-2.10786,0.292137,1.7998,-1.94547,0.084464,1.85588,-2.01099,-0.01374,1.74272,-2.16742,-0.01572,1.64605,-2.228,0.123314,1.50975,-2.17778,0.154452,1.45371,-2.18905,0.161729,1.38612,-1.79364,-0.017569,1.44746,-1.89479,-0.007108,1.46976,-1.94862,-0.004926,1.43624,-2.00663,0.189353,1.37694,-2.06017,0.162313,1.07466,-1.74185,0.031651,1.04989,-1.78009,0.048227,0.971258,-1.80305,0.118875,0.857622,-1.78607,0.091738,0.676492,-1.78851,0.064321,0.607211,-1.80337,-0.012743,0.716895,-1.79462,-0.038387,0.65044,-1.80446,-0.081905,0.433955,-1.83022,-0.197818,0.374592,-1.9043,0.059137,0.382931,-1.86465,0.029181,0.33739,-1.7914,0.27456,1.12168,-2.11255,0.319363,1.04969,-2.0939,0.153285,1.04716,-2.08781,0.197668,0.978891,-2.07186,0.301248,0.881634,-2.06939,0.147989,0.790351,-2.06676,0.128429,0.901977,-2.08244,0.058631,0.884508,-2.07919,-0.163756,0.804298,-2.06715,-0.252607,0.869308,-2.01285,-0.184213,0.595749,-2.03541,-0.232869,0.634967,-2.10266,0.084416,1.29993,-1.81858,0.10426,1.28965,-2.03265},
/*430*/{0.236459,1.8563,-1.71573,0.290656,1.79612,-1.87027,0.183298,1.70075,-1.61193,0.156392,1.58289,-1.53914,0.299649,1.58286,-1.61825,0.385389,1.57553,-1.64534,0.210045,1.88757,-2.10866,0.291505,1.80311,-1.94752,0.082232,1.85962,-2.00847,-0.019681,1.74941,-2.16632,-0.022956,1.65337,-2.22727,0.114198,1.51797,-2.17802,0.147758,1.46177,-2.18967,0.162763,1.3867,-1.79349,-0.017029,1.44983,-1.89356,-0.006587,1.47228,-1.947,-0.006042,1.43992,-2.0059,0.188669,1.38049,-2.06084,0.156332,1.07484,-1.74469,0.023484,1.0537,-1.77865,0.036633,0.97415,-1.80191,0.106869,0.859218,-1.78818,0.074426,0.67663,-1.79021,0.046206,0.607766,-1.80508,-0.029737,0.718566,-1.79614,-0.05668,0.651648,-1.80596,-0.102266,0.435032,-1.82934,-0.217528,0.378616,-1.90368,0.0392,0.38265,-1.86531,0.009268,0.337926,-1.79063,0.280022,1.13002,-2.11067,0.325309,1.05986,-2.09444,0.16011,1.05196,-2.08691,0.206548,0.986075,-2.07155,0.312335,0.892784,-2.06982,0.164074,0.79368,-2.06847,0.13932,0.90294,-2.08197,0.070875,0.883744,-2.07948,-0.147128,0.792515,-2.06757,-0.243303,0.851309,-2.0134,-0.157457,0.583259,-2.03683,-0.208912,0.619326,-2.10253,0.084849,1.30109,-1.81943,0.103413,1.29309,-2.03372},
/*431*/{0.23954,1.8612,-1.71724,0.290739,1.80017,-1.87219,0.190167,1.70477,-1.61187,0.162405,1.58725,-1.53939,0.304446,1.59115,-1.62108,0.389906,1.5849,-1.64926,0.206539,1.89169,-2.10888,0.291789,1.80664,-1.94983,0.080914,1.86287,-2.00629,-0.02401,1.75651,-2.16534,-0.029917,1.66081,-2.22622,0.108626,1.52603,-2.17724,0.140618,1.4704,-2.19052,0.165197,1.38756,-1.79394,-0.016213,1.4535,-1.89101,-0.006452,1.4761,-1.94565,-0.00555,1.44261,-2.00467,0.188397,1.38433,-2.06072,0.148691,1.07591,-1.74666,0.01444,1.0569,-1.77955,0.027096,0.977174,-1.80372,0.094068,0.860805,-1.78984,0.05726,0.678339,-1.7915,0.0291,0.609018,-1.80589,-0.046662,0.720801,-1.79678,-0.073215,0.653621,-1.80597,-0.120581,0.437602,-1.82902,-0.238044,0.382976,-1.90356,0.018494,0.381603,-1.86527,-0.012944,0.337507,-1.79124,0.2845,1.13805,-2.11079,0.331435,1.06972,-2.09418,0.166326,1.05695,-2.08651,0.21414,0.992454,-2.07117,0.323283,0.904204,-2.07017,0.178742,0.797345,-2.06848,0.149795,0.903871,-2.08185,0.082853,0.882789,-2.0791,-0.128538,0.778751,-2.06431,-0.230473,0.834038,-2.0121,-0.128913,0.57136,-2.03826,-0.185696,0.603401,-2.10237,0.086151,1.30305,-1.81963,0.102959,1.29669,-2.03412},
/*432*/{0.241924,1.86655,-1.71874,0.291087,1.80402,-1.87424,0.195537,1.70935,-1.61263,0.169628,1.59155,-1.53955,0.309434,1.59812,-1.62388,0.394401,1.59368,-1.65303,0.203082,1.89651,-2.10882,0.291682,1.81115,-1.95185,0.079983,1.86582,-2.00531,-0.030011,1.76201,-2.16375,-0.036732,1.66801,-2.22522,0.1009,1.53445,-2.17819,0.133889,1.47836,-2.19128,0.16602,1.38875,-1.79411,-0.014828,1.45671,-1.88961,-0.005467,1.47847,-1.94351,-0.005252,1.44657,-2.00331,0.18763,1.38769,-2.06046,0.142657,1.07485,-1.74991,0.008493,1.06152,-1.7788,0.015784,0.980545,-1.80279,0.081804,0.863479,-1.79197,0.041075,0.680417,-1.79246,0.012282,0.61144,-1.8074,-0.063324,0.722991,-1.79763,-0.090541,0.657118,-1.80639,-0.141107,0.440258,-1.82882,-0.257336,0.388736,-1.90229,-0.000806,0.381728,-1.86455,-0.032882,0.337733,-1.7912,0.288311,1.14706,-2.11184,0.337428,1.07976,-2.09445,0.172308,1.06275,-2.08699,0.221713,0.999925,-2.07116,0.334133,0.914901,-2.07043,0.193281,0.801314,-2.07014,0.156683,0.909225,-2.0829,0.091832,0.882727,-2.07943,-0.117335,0.768341,-2.06645,-0.219926,0.814975,-2.01039,-0.101506,0.559249,-2.03861,-0.159118,0.588614,-2.10256,0.086706,1.30477,-1.8198,0.102272,1.30011,-2.03442},
/*433*/{0.243877,1.87198,-1.72013,0.291636,1.80871,-1.87615,0.20139,1.71464,-1.61449,0.175834,1.59742,-1.54017,0.313746,1.60559,-1.62613,0.398871,1.60334,-1.65693,0.199139,1.9007,-2.10898,0.291026,1.81561,-1.95388,0.07864,1.8687,-2.00275,-0.035034,1.77,-2.16272,-0.042722,1.67539,-2.22422,0.094227,1.54308,-2.1772,0.127502,1.48661,-2.19151,0.168595,1.38987,-1.79407,-0.014151,1.46005,-1.88837,-0.005106,1.48248,-1.94114,-0.004874,1.45084,-2.00196,0.187805,1.39137,-2.06037,0.137188,1.07566,-1.75245,0.003441,1.06754,-1.7779,0.005965,0.984935,-1.8028,0.070402,0.865525,-1.79433,0.024065,0.682992,-1.7939,-0.007135,0.614053,-1.80849,-0.079265,0.726716,-1.7981,-0.107533,0.661306,-1.80791,-0.158636,0.445078,-1.82867,-0.276564,0.394909,-1.90159,-0.021448,0.380937,-1.86597,-0.053442,0.338065,-1.79228,0.291145,1.15556,-2.11174,0.342394,1.08962,-2.0942,0.177512,1.06915,-2.08636,0.228252,1.00673,-2.07107,0.342969,0.926498,-2.07157,0.207154,0.805887,-2.07089,0.165692,0.91161,-2.08239,0.101264,0.881494,-2.07866,-0.100658,0.756027,-2.06684,-0.207479,0.795264,-2.00947,-0.072122,0.548848,-2.03956,-0.133093,0.574042,-2.10281,0.087736,1.30685,-1.82013,0.101874,1.30415,-2.03489},
/*434*/{0.246349,1.87742,-1.72271,0.292887,1.81358,-1.8782,0.206875,1.71997,-1.61559,0.181905,1.60215,-1.53963,0.317412,1.61368,-1.6292,0.401195,1.6121,-1.66092,0.196259,1.90547,-2.10911,0.290609,1.82006,-1.95616,0.077779,1.87224,-2.00167,-0.038402,1.77594,-2.16275,-0.048932,1.68256,-2.22232,0.088549,1.54967,-2.17614,0.12187,1.49477,-2.19206,0.169678,1.39118,-1.79366,-0.011978,1.4637,-1.88667,-0.003524,1.48639,-1.93925,-0.005345,1.45576,-2.00059,0.187554,1.39609,-2.0601,0.130574,1.07689,-1.7543,-0.005505,1.07255,-1.77959,-0.003602,0.990758,-1.80274,0.058729,0.868313,-1.7961,0.007837,0.686762,-1.79445,-0.023639,0.617406,-1.80896,-0.095662,0.731153,-1.79862,-0.124682,0.665211,-1.80737,-0.17632,0.449606,-1.8283,-0.295059,0.401643,-1.90148,-0.040373,0.381238,-1.86539,-0.073661,0.338517,-1.79309,0.294797,1.16471,-2.11226,0.347622,1.0978,-2.09406,0.182161,1.07578,-2.08672,0.235173,1.01462,-2.07136,0.351252,0.937915,-2.07159,0.220972,0.809416,-2.07219,0.173025,0.912837,-2.08182,0.111002,0.878844,-2.0783,-0.082367,0.742261,-2.06478,-0.193821,0.774799,-2.00756,-0.04407,0.53701,-2.03954,-0.106276,0.558881,-2.10255,0.088374,1.30905,-1.82063,0.101418,1.3088,-2.03547},
/*435*/{0.248557,1.88298,-1.7238,0.294388,1.81845,-1.88043,0.212842,1.7257,-1.61603,0.187987,1.60743,-1.53975,0.320797,1.62106,-1.63148,0.403986,1.62121,-1.66489,0.193334,1.90969,-2.10907,0.290349,1.82478,-1.95806,0.076186,1.87559,-1.99996,-0.042759,1.78291,-2.16229,-0.054916,1.68981,-2.22065,0.082463,1.55776,-2.17597,0.11611,1.50271,-2.19224,0.172195,1.39294,-1.79441,-0.010037,1.46661,-1.88506,-0.002946,1.48962,-1.93688,-0.004867,1.46002,-1.99939,0.187475,1.40134,-2.06017,0.124264,1.07911,-1.75693,-0.011995,1.07763,-1.77947,-0.012054,0.99613,-1.80319,0.044584,0.871028,-1.79661,-0.008303,0.690509,-1.79535,-0.03922,0.622206,-1.80826,-0.11144,0.735592,-1.79938,-0.140659,0.670299,-1.80814,-0.19458,0.454623,-1.82882,-0.313354,0.409958,-1.90128,-0.059786,0.380481,-1.86598,-0.094863,0.338789,-1.79305,0.29806,1.1734,-2.11247,0.350725,1.10926,-2.09461,0.187801,1.08235,-2.08716,0.240965,1.0225,-2.0715,0.358296,0.948743,-2.07198,0.233797,0.811649,-2.07325,0.180151,0.914068,-2.08186,0.119728,0.877173,-2.07822,-0.065976,0.728432,-2.06438,-0.179257,0.753334,-2.0063,-0.014078,0.52704,-2.04124,-0.077763,0.544478,-2.10306,0.090594,1.31114,-1.82155,0.101853,1.31358,-2.03648},
/*436*/{0.251,1.88818,-1.72601,0.295511,1.82262,-1.88317,0.217081,1.73069,-1.61736,0.193381,1.61281,-1.54004,0.323966,1.62849,-1.63376,0.406885,1.63026,-1.66879,0.190912,1.91434,-2.10909,0.290188,1.82936,-1.95981,0.0759,1.87938,-1.99917,-0.046484,1.78903,-2.16082,-0.059977,1.69657,-2.21873,0.07765,1.56526,-2.17449,0.111233,1.51055,-2.19262,0.17364,1.39449,-1.79417,-0.008277,1.46985,-1.88384,-0.001335,1.49352,-1.93475,-0.004107,1.46472,-1.99869,0.188846,1.40655,-2.05973,0.118998,1.08055,-1.75986,-0.017866,1.08388,-1.7783,-0.020968,1.00197,-1.80234,0.030065,0.876238,-1.79738,-0.024126,0.695747,-1.79468,-0.055833,0.627842,-1.80889,-0.126991,0.741496,-1.79996,-0.155959,0.677012,-1.80839,-0.212872,0.459544,-1.82856,-0.330556,0.418083,-1.90122,-0.07838,0.379635,-1.86645,-0.115619,0.339767,-1.79336,0.300921,1.18168,-2.11246,0.355005,1.11871,-2.09486,0.191629,1.08969,-2.08725,0.246505,1.02987,-2.0715,0.364581,0.959277,-2.07176,0.245221,0.817092,-2.0744,0.186657,0.91515,-2.08071,0.127931,0.874333,-2.0777,-0.049221,0.714972,-2.06366,-0.162319,0.732773,-2.00505,0.017043,0.516561,-2.04163,-0.049568,0.530802,-2.10367,0.091826,1.31328,-1.82243,0.102915,1.31863,-2.03731},
/*437*/{0.252099,1.89333,-1.72779,0.296015,1.8279,-1.88506,0.22142,1.73635,-1.61816,0.197622,1.61891,-1.54051,0.326454,1.63649,-1.63661,0.408811,1.63862,-1.67262,0.188663,1.91865,-2.10971,0.290084,1.83427,-1.96152,0.074063,1.8835,-1.9979,-0.049412,1.79492,-2.16013,-0.06475,1.70361,-2.21669,0.072245,1.57287,-2.17385,0.106654,1.51769,-2.19296,0.176086,1.3964,-1.79461,-0.007204,1.4734,-1.88258,-0.000607,1.49723,-1.93286,-0.002837,1.47011,-1.99793,0.188807,1.4122,-2.05961,0.114643,1.0828,-1.76123,-0.021351,1.09052,-1.77762,-0.029105,1.00803,-1.80284,0.014978,0.881511,-1.79786,-0.039825,0.700419,-1.79496,-0.071296,0.633103,-1.80816,-0.141842,0.747674,-1.80009,-0.171869,0.682811,-1.80915,-0.228255,0.464688,-1.82696,-0.347575,0.427509,-1.9014,-0.097462,0.378643,-1.86631,-0.136144,0.340025,-1.7936,0.303487,1.18948,-2.11224,0.357859,1.12748,-2.09468,0.195472,1.09668,-2.08723,0.250965,1.03778,-2.07159,0.3705,0.968442,-2.07142,0.256207,0.821171,-2.07511,0.192827,0.915465,-2.08077,0.137473,0.872021,-2.07791,-0.030722,0.701409,-2.06171,-0.14605,0.711217,-2.00297,0.04736,0.507779,-2.04299,-0.018685,0.518333,-2.10389,0.09337,1.31579,-1.82364,0.103403,1.32406,-2.03848},
/*438*/{0.254116,1.89882,-1.73018,0.296883,1.83243,-1.88698,0.224927,1.74182,-1.61906,0.202659,1.62493,-1.54129,0.328792,1.64294,-1.63845,0.410162,1.64688,-1.6762,0.187125,1.92267,-2.10965,0.290065,1.83888,-1.96314,0.075272,1.88613,-1.99615,-0.052086,1.79998,-2.15773,-0.069017,1.70986,-2.2146,0.068962,1.58002,-2.17246,0.101856,1.52456,-2.1933,0.177652,1.39835,-1.79518,-0.00407,1.47723,-1.88161,0.000285,1.50122,-1.93016,-0.001635,1.47496,-1.99675,0.188104,1.41743,-2.05938,0.109538,1.08537,-1.76212,-0.02701,1.09815,-1.7771,-0.037428,1.01503,-1.80171,0.000985,0.887756,-1.79727,-0.054455,0.706101,-1.79455,-0.088133,0.638241,-1.8076,-0.156289,0.753869,-1.80051,-0.186247,0.689118,-1.80835,-0.244405,0.469378,-1.82612,-0.364453,0.437546,-1.90122,-0.117131,0.377241,-1.86648,-0.157594,0.340536,-1.7942,0.30495,1.19743,-2.11248,0.361126,1.13696,-2.09446,0.199012,1.10347,-2.08827,0.255182,1.04525,-2.07181,0.374047,0.978717,-2.071,0.267908,0.82435,-2.07576,0.198467,0.914956,-2.08017,0.146112,0.86882,-2.07748,-0.012736,0.688456,-2.06116,-0.128898,0.69094,-2.00298,0.078527,0.500075,-2.04412,0.010493,0.506577,-2.10451,0.094781,1.3184,-1.82445,0.103284,1.32911,-2.03926},
/*439*/{0.255524,1.90423,-1.73152,0.297149,1.83743,-1.8889,0.22873,1.74707,-1.61976,0.206626,1.63014,-1.54091,0.330348,1.6504,-1.64186,0.411914,1.65404,-1.68022,0.185418,1.92663,-2.10981,0.289686,1.84407,-1.9645,0.07518,1.88988,-1.99576,-0.055231,1.80521,-2.1559,-0.073026,1.71633,-2.21224,0.064714,1.58618,-2.17215,0.098534,1.53127,-2.19295,0.180992,1.39984,-1.79572,-0.001979,1.48045,-1.87976,0.002203,1.50616,-1.92851,-0.000741,1.48017,-1.99603,0.188906,1.42285,-2.05961,0.102689,1.08965,-1.76665,-0.033014,1.10309,-1.7764,-0.044545,1.02253,-1.80083,-0.011889,0.894316,-1.79668,-0.068574,0.712819,-1.79361,-0.102757,0.645751,-1.80715,-0.170483,0.76152,-1.80039,-0.200651,0.696911,-1.80844,-0.26075,0.477222,-1.82584,-0.379382,0.447804,-1.90197,-0.13586,0.376703,-1.86662,-0.177831,0.34158,-1.79444,0.307743,1.20556,-2.11247,0.364082,1.14599,-2.09339,0.202046,1.11016,-2.08793,0.259267,1.05221,-2.07178,0.376379,0.987227,-2.07135,0.278577,0.827892,-2.07642,0.203749,0.911973,-2.07903,0.154938,0.861488,-2.07548,0.008235,0.674926,-2.06048,-0.110328,0.669289,-2.00139,0.110078,0.493388,-2.04549,0.040213,0.495048,-2.10515,0.096894,1.32088,-1.82584,0.103941,1.33458,-2.04052},
/*440*/{0.257721,1.90922,-1.73288,0.297751,1.84229,-1.89076,0.231377,1.75202,-1.62041,0.210093,1.63564,-1.54189,0.332415,1.65716,-1.64347,0.413104,1.66162,-1.68386,0.183663,1.9305,-2.11022,0.289643,1.84799,-1.96606,0.074495,1.89319,-1.9956,-0.056248,1.8112,-2.15403,-0.076913,1.72231,-2.21038,0.061195,1.5922,-2.1708,0.094488,1.53713,-2.1933,0.182393,1.40164,-1.79681,-0.000761,1.48379,-1.87891,0.003608,1.50955,-1.9262,0.001188,1.48476,-1.99529,0.188412,1.42856,-2.05965,0.100259,1.09301,-1.7673,-0.036244,1.11148,-1.77626,-0.052726,1.02964,-1.80147,-0.022457,0.900735,-1.79639,-0.08311,0.719255,-1.79207,-0.116136,0.65204,-1.80551,-0.183386,0.768406,-1.79926,-0.21467,0.703507,-1.80857,-0.277037,0.482396,-1.82568,-0.394453,0.459076,-1.90206,-0.155314,0.376666,-1.86694,-0.197943,0.34286,-1.79435,0.308838,1.21318,-2.11318,0.366676,1.15347,-2.09333,0.204805,1.11667,-2.08872,0.262464,1.05916,-2.07167,0.37834,0.995312,-2.07134,0.288791,0.830702,-2.07732,0.2087,0.909819,-2.07855,0.162191,0.85732,-2.07555,0.025665,0.661541,-2.05994,-0.089832,0.647473,-1.99816,0.140336,0.487625,-2.04701,0.072033,0.484976,-2.10593,0.098234,1.32308,-1.8274,0.104342,1.3399,-2.04189},
/*441*/{0.259092,1.91372,-1.7346,0.298337,1.84642,-1.89255,0.23423,1.75728,-1.62156,0.21362,1.64007,-1.54164,0.333693,1.66323,-1.64497,0.414609,1.66869,-1.68606,0.182363,1.93422,-2.11032,0.288984,1.85242,-1.96789,0.073469,1.89694,-1.99567,-0.058577,1.81678,-2.15236,-0.079897,1.72777,-2.20774,0.058473,1.59818,-2.17007,0.091394,1.54279,-2.19314,0.184773,1.40373,-1.7981,0.001283,1.48688,-1.87738,0.005109,1.51318,-1.92395,0.002356,1.48944,-1.99399,0.189096,1.43365,-2.0599,0.093353,1.0946,-1.76791,-0.040255,1.1186,-1.77559,-0.058451,1.03744,-1.80005,-0.032333,0.907253,-1.79552,-0.095808,0.726481,-1.79039,-0.128871,0.660413,-1.80277,-0.196781,0.775789,-1.80105,-0.228344,0.712109,-1.80852,-0.289906,0.48854,-1.82331,-0.409259,0.470539,-1.90165,-0.174056,0.376228,-1.86709,-0.218347,0.344044,-1.79481,0.31055,1.22042,-2.1131,0.368854,1.1608,-2.09298,0.207098,1.12351,-2.08948,0.264483,1.06596,-2.0711,0.378592,1.00296,-2.07213,0.29815,0.832455,-2.07774,0.21388,0.906833,-2.07791,0.170507,0.850947,-2.07501,0.040864,0.648664,-2.06122,-0.06846,0.627273,-1.99664,0.172061,0.482725,-2.04849,0.102847,0.475915,-2.10658,0.100426,1.32548,-1.8286,0.10497,1.34498,-2.04291},
/*442*/{0.260451,1.9181,-1.73636,0.298334,1.85036,-1.89466,0.237013,1.7623,-1.62176,0.21744,1.6458,-1.54173,0.335307,1.66936,-1.64742,0.415499,1.67515,-1.68978,0.180664,1.93714,-2.11058,0.289164,1.85687,-1.96918,0.073587,1.90006,-1.99543,-0.060282,1.8216,-2.15025,-0.082698,1.73345,-2.20582,0.055595,1.60294,-2.16905,0.088947,1.54789,-2.19305,0.187651,1.4058,-1.79894,0.003945,1.49013,-1.8764,0.006069,1.5171,-1.92229,0.003718,1.49499,-1.99275,0.189481,1.43887,-2.06008,0.090392,1.0977,-1.76823,-0.04437,1.12502,-1.77469,-0.064707,1.04581,-1.79904,-0.041989,0.913122,-1.79522,-0.107908,0.733862,-1.78898,-0.142072,0.667455,-1.80167,-0.208113,0.78458,-1.80052,-0.240114,0.719793,-1.80891,-0.305323,0.495045,-1.82272,-0.421618,0.482796,-1.90247,-0.193081,0.376369,-1.86738,-0.240156,0.345174,-1.79532,0.312691,1.22721,-2.11289,0.370188,1.16781,-2.09194,0.208638,1.12962,-2.09017,0.266163,1.0728,-2.07137,0.377968,1.00921,-2.07223,0.307533,0.833592,-2.07821,0.218904,0.902891,-2.07793,0.179075,0.844932,-2.07307,0.062878,0.634392,-2.05795,-0.044905,0.604617,-1.99363,0.20285,0.478207,-2.04862,0.134099,0.467661,-2.10688,0.102505,1.32818,-1.82995,0.105549,1.35032,-2.04402},
/*443*/{0.262478,1.92215,-1.73773,0.29958,1.85563,-1.89658,0.238915,1.76713,-1.62222,0.221452,1.65052,-1.54164,0.336684,1.67456,-1.64937,0.416483,1.68141,-1.69318,0.18025,1.9405,-2.1111,0.288737,1.86066,-1.97053,0.073706,1.90262,-1.9946,-0.061108,1.82528,-2.14705,-0.08513,1.73815,-2.20313,0.053324,1.60758,-2.16882,0.086495,1.55254,-2.19267,0.190244,1.40741,-1.80016,0.005811,1.49407,-1.87519,0.007776,1.5202,-1.92087,0.00557,1.49966,-1.9919,0.18931,1.44399,-2.06079,0.08697,1.1003,-1.76837,-0.046708,1.13204,-1.7741,-0.0704,1.05304,-1.79883,-0.051001,0.920418,-1.79343,-0.119405,0.741659,-1.78727,-0.152984,0.675166,-1.79773,-0.219776,0.792632,-1.80058,-0.250922,0.727791,-1.80841,-0.317734,0.501783,-1.82046,-0.433761,0.49684,-1.90204,-0.212588,0.376377,-1.86723,-0.260696,0.346879,-1.79603,0.313905,1.23241,-2.11207,0.371026,1.17341,-2.09118,0.209395,1.13395,-2.0912,0.267158,1.07753,-2.07205,0.377637,1.01498,-2.07228,0.316919,0.834236,-2.07854,0.224277,0.899224,-2.07767,0.187831,0.837514,-2.07205,0.083542,0.621658,-2.05677,-0.021997,0.584511,-1.99114,0.232896,0.475325,-2.04957,0.164959,0.461182,-2.1078,0.104386,1.33061,-1.8315,0.105815,1.35527,-2.04532},
/*444*/{0.263583,1.92684,-1.73868,0.300712,1.85926,-1.89828,0.241154,1.77151,-1.62302,0.223042,1.65415,-1.54154,0.337338,1.67995,-1.65104,0.416683,1.68755,-1.69535,0.179086,1.94376,-2.11162,0.288746,1.86399,-1.97202,0.074032,1.90606,-1.9941,-0.060584,1.83064,-2.14389,-0.087316,1.74301,-2.20089,0.050708,1.61193,-2.16821,0.083954,1.55705,-2.1925,0.19236,1.4087,-1.80155,0.008476,1.49737,-1.87349,0.010067,1.52425,-1.91996,0.006953,1.50433,-1.99099,0.190073,1.44865,-2.06127,0.083027,1.10286,-1.76796,-0.04722,1.13987,-1.77186,-0.074482,1.06125,-1.79785,-0.060001,0.928088,-1.79335,-0.129837,0.749832,-1.78563,-0.163545,0.682949,-1.79614,-0.229986,0.7994,-1.80089,-0.261864,0.735578,-1.80882,-0.330483,0.509654,-1.81931,-0.444189,0.511095,-1.90165,-0.230338,0.377498,-1.866,-0.281534,0.349099,-1.79647,0.315104,1.23844,-2.11204,0.37051,1.17852,-2.09086,0.209755,1.14136,-2.09234,0.266294,1.08369,-2.0747,0.376279,1.01913,-2.07281,0.325854,0.834618,-2.07911,0.230247,0.893408,-2.0776,0.196504,0.830929,-2.07182,0.103281,0.608958,-2.05503,0.001941,0.565106,-1.98772,0.263473,0.473075,-2.05049,0.195308,0.454455,-2.10765,0.105983,1.33286,-1.83311,0.106168,1.36015,-2.0466},
/*445*/{0.265301,1.92956,-1.74053,0.300892,1.86347,-1.89984,0.242594,1.77607,-1.62357,0.225965,1.65863,-1.5412,0.338094,1.68479,-1.6524,0.417364,1.69297,-1.69891,0.178098,1.94674,-2.11174,0.288713,1.86756,-1.97341,0.074329,1.909,-1.99418,-0.061987,1.83408,-2.14223,-0.089168,1.74714,-2.19832,0.049336,1.61592,-2.16765,0.082282,1.56103,-2.19191,0.194727,1.41074,-1.80256,0.010338,1.50083,-1.87311,0.011742,1.52734,-1.91837,0.007948,1.50932,-1.99027,0.189898,1.45308,-2.06156,0.080293,1.10732,-1.76748,-0.051528,1.14588,-1.77181,-0.079691,1.06861,-1.79693,-0.068611,0.935571,-1.79274,-0.139158,0.757256,-1.784,-0.173699,0.690436,-1.79446,-0.238458,0.807239,-1.80067,-0.271914,0.742813,-1.80832,-0.340874,0.517016,-1.81713,-0.453933,0.527694,-1.90067,-0.248066,0.378936,-1.86535,-0.301817,0.352338,-1.79632,0.315342,1.24253,-2.11096,0.371436,1.18267,-2.09047,0.209588,1.14569,-2.09275,0.265555,1.08775,-2.07627,0.374565,1.02216,-2.07315,0.334848,0.834232,-2.0784,0.235541,0.887884,-2.07796,0.205475,0.823234,-2.07185,0.127651,0.598122,-2.0532,0.026636,0.546777,-1.98556,0.292717,0.471822,-2.05003,0.225254,0.449081,-2.10744,0.107525,1.3355,-1.83432,0.106273,1.36475,-2.04756},
/*446*/{0.267015,1.93362,-1.74211,0.300913,1.86655,-1.90082,0.244977,1.78022,-1.62428,0.227861,1.66204,-1.54155,0.339759,1.68856,-1.65446,0.417253,1.69695,-1.70073,0.17773,1.94948,-2.11157,0.288499,1.8711,-1.97437,0.074576,1.91115,-1.99376,-0.062644,1.83911,-2.14046,-0.090743,1.75094,-2.19614,0.048083,1.61943,-2.1674,0.081062,1.56456,-2.1915,0.196248,1.41249,-1.80353,0.011656,1.50439,-1.87191,0.012635,1.53111,-1.91718,0.009074,1.51453,-1.98987,0.190008,1.45762,-2.06119,0.076292,1.10957,-1.76661,-0.054417,1.15204,-1.77133,-0.082756,1.07542,-1.79594,-0.076149,0.943032,-1.79206,-0.146954,0.764825,-1.7822,-0.182648,0.697943,-1.79249,-0.247216,0.814993,-1.79949,-0.279228,0.75134,-1.80691,-0.35283,0.524443,-1.81484,-0.460729,0.542563,-1.89969,-0.26647,0.380933,-1.86489,-0.322587,0.356293,-1.79638,0.315507,1.24672,-2.11031,0.370725,1.18572,-2.08974,0.208694,1.15032,-2.09429,0.264567,1.09181,-2.07788,0.373502,1.02418,-2.07393,0.343385,0.833848,-2.07869,0.241434,0.881848,-2.07795,0.215775,0.815435,-2.07133,0.145116,0.586436,-2.05229,0.051355,0.52955,-1.98527,0.321312,0.471522,-2.05053,0.254977,0.444387,-2.10689,0.108117,1.33813,-1.83553,0.106226,1.36967,-2.04844},
/*447*/{0.268114,1.93688,-1.74334,0.302613,1.87108,-1.90304,0.24634,1.78382,-1.62465,0.230728,1.6667,-1.54145,0.339851,1.69307,-1.65613,0.417552,1.70099,-1.70332,0.176698,1.95223,-2.11199,0.288997,1.87405,-1.97561,0.074542,1.91374,-1.9931,-0.062624,1.84207,-2.13669,-0.092626,1.7544,-2.19386,0.04771,1.62287,-2.16669,0.079895,1.56808,-2.19134,0.198878,1.41495,-1.80474,0.013992,1.50834,-1.87114,0.013714,1.53434,-1.91609,0.012501,1.51746,-1.98771,0.189972,1.46118,-2.06163,0.074364,1.11383,-1.76474,-0.056671,1.15869,-1.77148,-0.085907,1.08151,-1.79556,-0.081779,0.949448,-1.79216,-0.155569,0.771635,-1.78074,-0.18991,0.705169,-1.78912,-0.254073,0.823119,-1.79841,-0.286172,0.760539,-1.80509,-0.362815,0.531846,-1.8129,-0.467841,0.558121,-1.89768,-0.282968,0.382411,-1.86355,-0.343249,0.361739,-1.79783,0.314523,1.24935,-2.1095,0.369658,1.18842,-2.08904,0.207677,1.1539,-2.09445,0.263034,1.09498,-2.07897,0.371364,1.02524,-2.07489,0.3511,0.832908,-2.07935,0.246479,0.875543,-2.07841,0.223733,0.807537,-2.07115,0.16733,0.575749,-2.0514,0.075523,0.513405,-1.98299,0.349373,0.47197,-2.05006,0.284937,0.441524,-2.10598,0.110387,1.34099,-1.83573,0.106659,1.3732,-2.04851},
/*448*/{0.269868,1.93978,-1.74471,0.301886,1.87401,-1.9039,0.248078,1.78733,-1.62482,0.231607,1.6694,-1.54182,0.341293,1.69611,-1.65709,0.417678,1.70499,-1.70562,0.176677,1.95452,-2.11262,0.289449,1.87694,-1.97673,0.0746,1.91611,-1.99381,-0.063012,1.84584,-2.13653,-0.093992,1.75733,-2.1914,0.047205,1.62624,-2.16613,0.07896,1.57131,-2.1911,0.199623,1.41735,-1.80624,0.015531,1.51082,-1.87067,0.015134,1.53848,-1.91487,0.01364,1.52152,-1.98684,0.190717,1.46409,-2.06178,0.071412,1.11753,-1.76387,-0.055395,1.16375,-1.7703,-0.088808,1.0873,-1.79563,-0.085409,0.955099,-1.79225,-0.161304,0.779245,-1.77967,-0.196146,0.71204,-1.78758,-0.259567,0.830855,-1.79823,-0.293263,0.767959,-1.80368,-0.370406,0.539913,-1.80886,-0.473037,0.574484,-1.89511,-0.301023,0.386335,-1.86222,-0.362753,0.36763,-1.79859,0.314367,1.25172,-2.10873,0.368788,1.18913,-2.08899,0.206094,1.15622,-2.09506,0.261527,1.09652,-2.07996,0.36967,1.02532,-2.07592,0.358648,0.831737,-2.07951,0.252139,0.868434,-2.07898,0.233547,0.800097,-2.07148,0.190392,0.565621,-2.05004,0.100786,0.497406,-1.98194,0.376161,0.47271,-2.04807,0.31332,0.438131,-2.10489,0.111018,1.34353,-1.83648,0.106598,1.37695,-2.04905},
/*449*/{0.270554,1.94214,-1.74523,0.302655,1.87702,-1.90497,0.250081,1.79064,-1.62597,0.234199,1.67304,-1.54154,0.341496,1.69961,-1.65838,0.417815,1.7088,-1.70848,0.176055,1.95673,-2.11294,0.290283,1.8792,-1.97783,0.075663,1.9177,-1.99287,-0.063329,1.84832,-2.13412,-0.095306,1.75988,-2.18922,0.046571,1.62895,-2.16563,0.078314,1.57408,-2.19067,0.202187,1.41942,-1.80676,0.016912,1.51425,-1.86985,0.015608,1.54129,-1.91369,0.015564,1.52462,-1.98525,0.190857,1.46728,-2.06168,0.067846,1.12196,-1.7628,-0.056994,1.16852,-1.77074,-0.091401,1.09196,-1.79628,-0.087992,0.959738,-1.7927,-0.166426,0.785062,-1.77875,-0.203038,0.720065,-1.78629,-0.264309,0.838518,-1.79733,-0.299579,0.775341,-1.80197,-0.379722,0.550136,-1.80752,-0.47828,0.591367,-1.89173,-0.318441,0.390502,-1.86206,-0.381897,0.374642,-1.79923,0.313074,1.25191,-2.10749,0.366968,1.1899,-2.08798,0.204035,1.15775,-2.09521,0.258055,1.09825,-2.08039,0.367662,1.02469,-2.07745,0.366327,0.830146,-2.08019,0.257489,0.861401,-2.07934,0.241842,0.792428,-2.07118,0.209712,0.556197,-2.04988,0.126505,0.483189,-1.98182,0.401999,0.474302,-2.04651,0.341926,0.436026,-2.10291,0.112709,1.34612,-1.83647,0.106909,1.38023,-2.04891},
/*450*/{0.272975,1.94489,-1.74694,0.303386,1.87981,-1.90586,0.250837,1.79338,-1.62624,0.23507,1.67485,-1.54124,0.341613,1.7023,-1.66096,0.417707,1.71093,-1.71089,0.175724,1.95902,-2.11306,0.290763,1.88144,-1.97914,0.075449,1.92051,-1.99305,-0.063762,1.84983,-2.13066,-0.096191,1.76187,-2.18785,0.045945,1.63168,-2.16502,0.077515,1.57639,-2.19056,0.202594,1.42225,-1.80762,0.017931,1.51799,-1.86861,0.016628,1.54496,-1.91304,0.015047,1.52845,-1.9842,0.191241,1.46958,-2.06175,0.067679,1.12562,-1.76,-0.059794,1.17398,-1.77393,-0.091825,1.09672,-1.79725,-0.090386,0.963561,-1.79352,-0.170952,0.790806,-1.77826,-0.209496,0.724775,-1.78515,-0.268044,0.845358,-1.79604,-0.301946,0.783331,-1.79827,-0.388043,0.559336,-1.80457,-0.483441,0.607636,-1.88711,-0.335753,0.397154,-1.86312,-0.399178,0.383029,-1.80165,0.311719,1.25177,-2.10758,0.364544,1.18903,-2.08828,0.201596,1.1585,-2.09529,0.255421,1.0987,-2.08104,0.365382,1.02334,-2.07837,0.372528,0.828171,-2.0808,0.261814,0.854235,-2.07898,0.249869,0.784993,-2.07187,0.23123,0.547292,-2.04907,0.150641,0.469593,-1.97969,0.426355,0.477019,-2.04502,0.369279,0.434933,-2.10155,0.112808,1.3493,-1.83613,0.106007,1.38333,-2.04855},
/*451*/{0.273127,1.94742,-1.74737,0.303505,1.88171,-1.90683,0.25215,1.79626,-1.6273,0.236165,1.67768,-1.54104,0.34234,1.70345,-1.66071,0.418004,1.71283,-1.71242,0.1757,1.96033,-2.11337,0.29111,1.88317,-1.97992,0.076355,1.92093,-1.9926,-0.063834,1.85266,-2.13041,-0.096814,1.76336,-2.18573,0.045781,1.63338,-2.16464,0.077153,1.5784,-2.19038,0.203633,1.42485,-1.80779,0.018911,1.52144,-1.86697,0.017215,1.54749,-1.91257,0.016072,1.53106,-1.98379,0.191311,1.47162,-2.06122,0.066128,1.1291,-1.75933,-0.061103,1.17845,-1.77581,-0.09369,1.10045,-1.79831,-0.090417,0.967366,-1.7938,-0.174353,0.794918,-1.77809,-0.212798,0.731481,-1.78512,-0.269672,0.85185,-1.79356,-0.306281,0.789859,-1.79688,-0.394922,0.569853,-1.80255,-0.488617,0.622973,-1.88061,-0.3519,0.405727,-1.86388,-0.415677,0.391532,-1.80285,0.309527,1.25114,-2.10749,0.361264,1.18748,-2.08855,0.198356,1.15954,-2.09512,0.251251,1.09872,-2.0814,0.362633,1.02141,-2.08032,0.377793,0.825904,-2.08116,0.266696,0.847205,-2.07949,0.258049,0.777278,-2.0724,0.25109,0.539127,-2.04858,0.174767,0.456925,-1.97976,0.450758,0.479646,-2.04315,0.395912,0.432745,-2.09836,0.113534,1.35213,-1.83525,0.105916,1.3856,-2.04773},
/*452*/{0.273692,1.94926,-1.74838,0.304908,1.88465,-1.90849,0.253529,1.79865,-1.62783,0.236968,1.67936,-1.54095,0.342119,1.70559,-1.66074,0.417576,1.71383,-1.71456,0.175734,1.9622,-2.11365,0.291411,1.88466,-1.98099,0.076887,1.92366,-1.99257,-0.064327,1.85348,-2.12805,-0.097836,1.76454,-2.18451,0.045171,1.63501,-2.16455,0.077389,1.57988,-2.19002,0.203848,1.42696,-1.8079,0.020565,1.52377,-1.8665,0.018101,1.55083,-1.91139,0.016793,1.53371,-1.98203,0.192243,1.47412,-2.0609,0.066379,1.13073,-1.75927,-0.062267,1.1786,-1.77618,-0.092867,1.10302,-1.79879,-0.090198,0.97004,-1.79428,-0.176486,0.798168,-1.77786,-0.216592,0.736058,-1.78498,-0.270002,0.858821,-1.79199,-0.309311,0.79824,-1.79512,-0.400404,0.578988,-1.79996,-0.494618,0.63893,-1.87432,-0.367741,0.414284,-1.86704,-0.431283,0.401259,-1.80465,0.305996,1.2496,-2.10855,0.358696,1.18478,-2.08951,0.195352,1.15864,-2.09639,0.246419,1.09704,-2.0813,0.361784,1.01872,-2.08152,0.382745,0.823557,-2.08145,0.27041,0.839574,-2.0804,0.265132,0.770258,-2.07254,0.270021,0.531221,-2.04811,0.197146,0.445922,-1.97918,0.471954,0.482003,-2.04149,0.420378,0.432069,-2.09669,0.11407,1.35436,-1.83502,0.106151,1.3885,-2.04739},
/*453*/{0.275663,1.95106,-1.74951,0.304081,1.88624,-1.90912,0.254242,1.80084,-1.62876,0.236695,1.68195,-1.54199,0.342486,1.70705,-1.66292,0.416864,1.71496,-1.71629,0.17624,1.96329,-2.11444,0.291951,1.88581,-1.98178,0.077335,1.925,-1.99266,-0.065272,1.85434,-2.12653,-0.097947,1.76555,-2.18277,0.045256,1.63585,-2.16407,0.077419,1.58089,-2.19017,0.204503,1.42977,-1.80735,0.020924,1.52661,-1.86626,0.017806,1.55344,-1.91193,0.017856,1.53609,-1.98191,0.192158,1.47511,-2.06065,0.06677,1.13259,-1.75952,-0.061493,1.18066,-1.77832,-0.090731,1.10477,-1.80016,-0.087846,0.970782,-1.79484,-0.176627,0.800772,-1.77855,-0.220865,0.739298,-1.78511,-0.269513,0.864308,-1.79064,-0.309904,0.805014,-1.79342,-0.409655,0.588189,-1.79775,-0.502545,0.653357,-1.867,-0.383431,0.425096,-1.87069,-0.444414,0.412553,-1.80543,0.303718,1.24709,-2.10932,0.354524,1.18171,-2.08966,0.190297,1.15751,-2.09629,0.241863,1.09539,-2.08193,0.35845,1.01529,-2.08259,0.388019,0.821789,-2.08223,0.273751,0.831973,-2.0815,0.271893,0.76214,-2.07247,0.288275,0.523527,-2.04789,0.219712,0.436586,-1.9783,0.492582,0.484934,-2.03877,0.444192,0.431632,-2.09388,0.114159,1.35729,-1.83386,0.10605,1.3899,-2.04645},
/*454*/{0.276325,1.95229,-1.75022,0.306259,1.88836,-1.91047,0.254723,1.80256,-1.62908,0.237307,1.6838,-1.5419,0.342657,1.70802,-1.66432,0.416677,1.71532,-1.71802,0.176122,1.96426,-2.11472,0.292306,1.88723,-1.98314,0.077932,1.92637,-1.99277,-0.065584,1.85471,-2.12504,-0.098504,1.76579,-2.1816,0.045485,1.63626,-2.16337,0.077995,1.58164,-2.1902,0.205056,1.43243,-1.80742,0.02154,1.52826,-1.86514,0.017759,1.55522,-1.91244,0.017881,1.53806,-1.98067,0.192925,1.47648,-2.06022,0.069159,1.13406,-1.75982,-0.058263,1.18202,-1.77801,-0.089537,1.10472,-1.80077,-0.084454,0.971775,-1.79519,-0.177577,0.802749,-1.779,-0.222538,0.742466,-1.78622,-0.267733,0.868873,-1.78823,-0.310526,0.811403,-1.79104,-0.415992,0.599231,-1.79698,-0.510961,0.66727,-1.85979,-0.396863,0.437104,-1.87452,-0.455932,0.423625,-1.80683,0.300033,1.24383,-2.10972,0.351174,1.17778,-2.09042,0.186291,1.15647,-2.09514,0.237047,1.09311,-2.08149,0.355518,1.01166,-2.08308,0.391037,0.819824,-2.08227,0.276951,0.82414,-2.08225,0.278322,0.755145,-2.07428,0.305103,0.517313,-2.04832,0.239775,0.427779,-1.97868,0.511589,0.486955,-2.03733,0.467553,0.431205,-2.09155,0.115005,1.35949,-1.83302,0.10646,1.39146,-2.0457},
/*455*/{0.276574,1.95318,-1.75129,0.305996,1.88911,-1.91103,0.255053,1.80366,-1.62968,0.238126,1.68478,-1.54198,0.341788,1.70804,-1.66538,0.417728,1.71567,-1.71965,0.176291,1.96527,-2.11552,0.293495,1.88831,-1.98368,0.078337,1.92763,-1.99341,-0.065703,1.85507,-2.12373,-0.099089,1.76555,-2.17998,0.047873,1.63697,-2.16316,0.078395,1.58172,-2.19018,0.205355,1.43427,-1.80692,0.021447,1.5299,-1.86571,0.018418,1.55823,-1.91178,0.018092,1.53911,-1.9803,0.193445,1.47706,-2.05972,0.071676,1.13495,-1.76078,-0.056708,1.18052,-1.77942,-0.086673,1.10413,-1.80152,-0.080137,0.97087,-1.79608,-0.176926,0.804137,-1.77953,-0.225973,0.745469,-1.7869,-0.265354,0.873673,-1.78645,-0.309397,0.817788,-1.78797,-0.424731,0.609616,-1.79653,-0.520752,0.680793,-1.85168,-0.410095,0.44898,-1.87865,-0.465939,0.435141,-1.80852,0.297574,1.23996,-2.10963,0.346994,1.17325,-2.0912,0.18219,1.15441,-2.09495,0.231815,1.09051,-2.08164,0.351311,1.00659,-2.0835,0.394455,0.817792,-2.08271,0.280394,0.819045,-2.08541,0.284868,0.748604,-2.07633,0.323372,0.512243,-2.04772,0.259788,0.420529,-1.97759,0.529504,0.489831,-2.03564,0.487164,0.430446,-2.08827,0.114895,1.36147,-1.83207,0.106507,1.3925,-2.04488},
/*456*/{0.277124,1.95352,-1.75154,0.306445,1.89003,-1.91257,0.25559,1.80448,-1.63056,0.237432,1.68507,-1.54196,0.341125,1.70751,-1.66651,0.414927,1.71278,-1.72109,0.176415,1.96571,-2.11631,0.294065,1.88911,-1.98393,0.078745,1.92853,-1.9929,-0.065269,1.8538,-2.12312,-0.098725,1.76533,-2.17923,0.047949,1.63636,-2.1627,0.079255,1.58142,-2.1902,0.205264,1.43639,-1.80619,0.022024,1.53141,-1.86502,0.01862,1.5589,-1.91183,0.018185,1.54007,-1.98053,0.193867,1.47798,-2.05912,0.074674,1.1343,-1.76183,-0.053641,1.17892,-1.7794,-0.082434,1.10282,-1.80208,-0.075416,0.969299,-1.79642,-0.176805,0.80388,-1.78088,-0.228253,0.748396,-1.7879,-0.261969,0.877823,-1.78374,-0.308288,0.823415,-1.78532,-0.434789,0.619759,-1.79547,-0.529256,0.693952,-1.84427,-0.422889,0.462297,-1.88243,-0.474867,0.446537,-1.8103,0.293858,1.23573,-2.11044,0.342497,1.16851,-2.09183,0.177793,1.15216,-2.09411,0.226346,1.08724,-2.08084,0.34671,1.00291,-2.08395,0.397502,0.816598,-2.08269,0.282607,0.812582,-2.08659,0.289996,0.742151,-2.07673,0.339021,0.507829,-2.0484,0.277904,0.414853,-1.97762,0.546224,0.492794,-2.03325,0.505804,0.430735,-2.08636,0.115352,1.36318,-1.83102,0.107098,1.39322,-2.04399},
/*457*/{0.278942,1.95418,-1.75211,0.306331,1.89076,-1.91267,0.254882,1.80546,-1.63135,0.236012,1.68587,-1.54303,0.340928,1.70685,-1.667,0.414212,1.71232,-1.72211,0.177369,1.96549,-2.11703,0.293934,1.88978,-1.98539,0.079368,1.92909,-1.99374,-0.065051,1.85284,-2.12123,-0.098189,1.76445,-2.17809,0.048292,1.63604,-2.16248,0.080041,1.58071,-2.19009,0.205759,1.43792,-1.80591,0.021177,1.53237,-1.86467,0.018294,1.5601,-1.91242,0.018185,1.54007,-1.98053,0.195095,1.47824,-2.05828,0.078706,1.13304,-1.76305,-0.048109,1.17857,-1.77829,-0.077632,1.10101,-1.80245,-0.068999,0.967109,-1.79723,-0.177165,0.804159,-1.78148,-0.229385,0.751146,-1.78876,-0.258749,0.881431,-1.782,-0.305696,0.829959,-1.78388,-0.439499,0.630447,-1.79424,-0.536969,0.707433,-1.83688,-0.435044,0.476214,-1.88575,-0.484412,0.459093,-1.81167,0.290415,1.23098,-2.11072,0.338218,1.16317,-2.09292,0.173072,1.14944,-2.09407,0.220983,1.0836,-2.08062,0.341924,0.998115,-2.08438,0.398717,0.815056,-2.08132,0.28589,0.806327,-2.08704,0.295069,0.736403,-2.07739,0.353609,0.504192,-2.04684,0.295474,0.412711,-1.97074,0.560401,0.494573,-2.03141,0.523245,0.43096,-2.08372,0.115696,1.36451,-1.83008,0.107964,1.39349,-2.04321},
/*458*/{0.279448,1.95408,-1.75283,0.306236,1.89137,-1.91299,0.254572,1.80531,-1.63188,0.235955,1.68611,-1.54331,0.340177,1.70539,-1.66794,0.413506,1.70925,-1.7232,0.177362,1.96553,-2.11747,0.293929,1.88989,-1.9855,0.080806,1.92943,-1.99435,-0.065198,1.8514,-2.11983,-0.097682,1.76348,-2.17765,0.049502,1.63403,-2.16211,0.081188,1.57946,-2.19019,0.205717,1.43939,-1.80521,0.021177,1.53237,-1.86467,0.018543,1.56053,-1.91272,0.018185,1.54007,-1.98053,0.195897,1.47763,-2.0578,0.078854,1.13287,-1.76594,-0.045149,1.17681,-1.78219,-0.072682,1.09798,-1.80191,-0.063283,0.963981,-1.79799,-0.175957,0.804742,-1.78254,-0.231852,0.753704,-1.79074,-0.253707,0.885884,-1.77979,-0.304045,0.836601,-1.78177,-0.445616,0.641739,-1.79461,-0.54301,0.722505,-1.8301,-0.446001,0.490563,-1.88871,-0.492068,0.472108,-1.81369,0.287195,1.22673,-2.11158,0.333896,1.15759,-2.09331,0.168276,1.14606,-2.09302,0.215498,1.08043,-2.08036,0.336681,0.993408,-2.08403,0.40146,0.813596,-2.08046,0.28803,0.800595,-2.08814,0.301,0.732222,-2.0786,0.366625,0.500461,-2.04646,0.309906,0.40558,-1.97472,0.572943,0.496928,-2.03091,0.537994,0.431534,-2.08123,0.116006,1.36541,-1.82894,0.108632,1.39303,-2.04227},
/*459*/{0.279559,1.9537,-1.75397,0.30572,1.89196,-1.91402,0.253792,1.80532,-1.6328,0.234672,1.68661,-1.54401,0.339561,1.70326,-1.66825,0.412836,1.70687,-1.72395,0.178266,1.96539,-2.1188,0.293961,1.88965,-1.98611,0.081019,1.92966,-1.99499,-0.064704,1.84989,-2.11933,-0.096253,1.76174,-2.17638,0.051126,1.63284,-2.1618,0.082519,1.57787,-2.19014,0.206188,1.43995,-1.80464,0.02114,1.53225,-1.8647,0.018543,1.56053,-1.91272,0.018771,1.53861,-1.98023,0.197022,1.47697,-2.05653,0.090409,1.13225,-1.76798,-0.040154,1.1735,-1.77816,-0.067176,1.0935,-1.80178,-0.056661,0.961032,-1.79907,-0.174916,0.805003,-1.78385,-0.233735,0.757339,-1.79099,-0.248992,0.889878,-1.77837,-0.302574,0.842635,-1.78013,-0.450315,0.652938,-1.79322,-0.547099,0.737304,-1.82429,-0.456709,0.505447,-1.89023,-0.501733,0.486424,-1.81439,0.283419,1.22138,-2.11188,0.329835,1.15259,-2.09452,0.16371,1.14249,-2.09162,0.210148,1.07579,-2.07929,0.331754,0.988909,-2.08409,0.402952,0.8119,-2.07877,0.291051,0.795848,-2.08922,0.305454,0.727234,-2.07941,0.375948,0.497595,-2.04633,0.322561,0.400946,-1.97574,0.583004,0.499028,-2.02933,0.550521,0.43238,-2.07971,0.116681,1.36565,-1.82771,0.109829,1.39216,-2.04119},
/*460*/{0.279169,1.95288,-1.75461,0.305084,1.89116,-1.91443,0.252888,1.80502,-1.63383,0.232735,1.68582,-1.54439,0.338696,1.70165,-1.66973,0.411878,1.70354,-1.7249,0.179048,1.96477,-2.11979,0.29381,1.88969,-1.98634,0.081082,1.9295,-1.99676,-0.062631,1.84817,-2.11874,-0.095355,1.76004,-2.17607,0.053343,1.63059,-2.16138,0.084135,1.57579,-2.19053,0.205987,1.44002,-1.80424,0.021118,1.53209,-1.86516,0.018196,1.55989,-1.91279,0.018812,1.53799,-1.98111,0.197643,1.47654,-2.05612,0.096235,1.13016,-1.77032,-0.034054,1.16873,-1.7775,-0.061886,1.08977,-1.80238,-0.049812,0.958053,-1.80031,-0.173304,0.806467,-1.78494,-0.233895,0.760755,-1.792,-0.244133,0.893732,-1.77744,-0.300213,0.849427,-1.77913,-0.453838,0.667034,-1.79137,-0.549445,0.753769,-1.82021,-0.46628,0.520056,-1.89024,-0.511055,0.501003,-1.81464,0.280255,1.21636,-2.11224,0.325188,1.14715,-2.09517,0.159971,1.13999,-2.09134,0.205509,1.07245,-2.07845,0.32672,0.98477,-2.08326,0.405489,0.810546,-2.07689,0.293006,0.791217,-2.08961,0.309248,0.723839,-2.08024,0.386105,0.49501,-2.04657,0.332702,0.397196,-1.97508,0.592661,0.501225,-2.02737,0.56174,0.433178,-2.07851,0.116672,1.36556,-1.82743,0.110504,1.39159,-2.041},
/*461*/{0.279143,1.95215,-1.75498,0.305166,1.89014,-1.91467,0.251412,1.80473,-1.63444,0.23126,1.68501,-1.54485,0.337602,1.69883,-1.67011,0.410676,1.69993,-1.72549,0.179318,1.96394,-2.12049,0.293591,1.88894,-1.98641,0.081313,1.92912,-1.99727,-0.060707,1.84653,-2.11806,-0.0933,1.75761,-2.1762,0.054727,1.62837,-2.16123,0.085608,1.57304,-2.19047,0.205924,1.44021,-1.80294,0.020614,1.53083,-1.86592,0.018226,1.55885,-1.91276,0.019312,1.53565,-1.98125,0.198452,1.47544,-2.05497,0.102844,1.12745,-1.77313,-0.029884,1.16454,-1.77676,-0.055824,1.08559,-1.80143,-0.041857,0.954209,-1.80173,-0.171832,0.808635,-1.78447,-0.233955,0.764892,-1.79241,-0.238681,0.899121,-1.77487,-0.2958,0.85618,-1.77754,-0.456269,0.679338,-1.78837,-0.550019,0.770762,-1.81766,-0.475234,0.534888,-1.88926,-0.522317,0.51648,-1.81427,0.277449,1.21136,-2.11281,0.321855,1.14108,-2.09601,0.156226,1.13611,-2.09066,0.201115,1.0684,-2.07778,0.321905,0.980158,-2.08263,0.405721,0.808747,-2.07496,0.294533,0.787275,-2.08958,0.311106,0.719966,-2.08045,0.393089,0.491747,-2.04546,0.342477,0.393475,-1.9749,0.59987,0.502886,-2.02656,0.569623,0.433861,-2.07704,0.117139,1.36512,-1.82619,0.111967,1.38994,-2.03993},
/*462*/{0.27891,1.95063,-1.75642,0.304717,1.88932,-1.91528,0.25018,1.80343,-1.6356,0.227653,1.68484,-1.54704,0.335462,1.69651,-1.67104,0.409823,1.69586,-1.72616,0.179609,1.9628,-2.12108,0.293926,1.8883,-1.98711,0.081753,1.9289,-1.99838,-0.060754,1.84363,-2.11772,-0.091807,1.75481,-2.17608,0.056479,1.62538,-2.16204,0.08765,1.57038,-2.19034,0.206011,1.44032,-1.80269,0.020665,1.52969,-1.86646,0.017605,1.55796,-1.91385,0.019406,1.53403,-1.9818,0.199124,1.47395,-2.05414,0.108551,1.12493,-1.7746,-0.02516,1.16061,-1.77605,-0.049774,1.08091,-1.80276,-0.034031,0.950028,-1.80298,-0.169097,0.811341,-1.78512,-0.23344,0.770155,-1.79176,-0.2325,0.903647,-1.77499,-0.291434,0.863256,-1.77751,-0.459358,0.694244,-1.78849,-0.549424,0.788747,-1.81635,-0.483015,0.549863,-1.88769,-0.531577,0.53302,-1.81333,0.275112,1.20698,-2.11324,0.318106,1.1367,-2.09691,0.152601,1.13315,-2.08995,0.197268,1.06482,-2.0766,0.317277,0.976089,-2.08231,0.405306,0.806501,-2.07403,0.294512,0.782778,-2.08898,0.312395,0.715986,-2.07991,0.396951,0.489501,-2.04591,0.349011,0.389505,-1.97537,0.604913,0.503644,-2.02619,0.576029,0.434609,-2.07631,0.117423,1.36481,-1.82546,0.112877,1.3883,-2.03936},
/*463*/{0.278586,1.94951,-1.75729,0.304339,1.88909,-1.91542,0.24884,1.80254,-1.63631,0.225581,1.68426,-1.54772,0.33371,1.69289,-1.67108,0.407438,1.69117,-1.72595,0.18014,1.9615,-2.12168,0.293689,1.88732,-1.98774,0.082461,1.92743,-2.00063,-0.058974,1.84171,-2.11714,-0.089616,1.75199,-2.17676,0.05792,1.62243,-2.16185,0.089689,1.56731,-2.19085,0.205972,1.4392,-1.80191,0.020108,1.52713,-1.86637,0.017886,1.55602,-1.91368,0.019327,1.53232,-1.98269,0.200297,1.47231,-2.05391,0.114352,1.12265,-1.77657,-0.019982,1.15525,-1.77555,-0.042605,1.07524,-1.80284,-0.025962,0.945846,-1.80479,-0.166171,0.813952,-1.78479,-0.231572,0.774974,-1.79071,-0.226878,0.908807,-1.77482,-0.286147,0.871356,-1.77655,-0.462537,0.708685,-1.78598,-0.547372,0.80604,-1.81552,-0.490084,0.564313,-1.88531,-0.540729,0.550823,-1.81194,0.272808,1.20209,-2.11398,0.315515,1.13072,-2.0983,0.149933,1.12991,-2.08945,0.193543,1.06105,-2.07577,0.312912,0.971594,-2.08198,0.404218,0.804498,-2.07235,0.294347,0.779663,-2.08798,0.313717,0.712958,-2.07875,0.400665,0.487757,-2.04465,0.353397,0.387511,-1.97437,0.608826,0.503336,-2.02568,0.579661,0.434328,-2.07659,0.117726,1.36315,-1.82524,0.114045,1.38657,-2.03916},
/*464*/{0.277697,1.94781,-1.75804,0.303581,1.88692,-1.91569,0.246058,1.80119,-1.63702,0.22399,1.68165,-1.54839,0.332124,1.6889,-1.67174,0.405635,1.68633,-1.7265,0.180844,1.9598,-2.1227,0.292979,1.8857,-1.98769,0.082306,1.92635,-2.00085,-0.058263,1.83789,-2.11668,-0.087699,1.74839,-2.17723,0.060658,1.61888,-2.16214,0.092013,1.56376,-2.19117,0.2061,1.43825,-1.80148,0.020258,1.52553,-1.86647,0.017853,1.55382,-1.91417,0.019881,1.52952,-1.98386,0.2014,1.46968,-2.05393,0.119512,1.11938,-1.77751,-0.015358,1.14803,-1.77544,-0.036179,1.06918,-1.8037,-0.017933,0.941849,-1.80632,-0.163036,0.816694,-1.78433,-0.229462,0.780337,-1.79026,-0.219087,0.914131,-1.77525,-0.280288,0.878077,-1.77629,-0.463647,0.723188,-1.78462,-0.544137,0.824025,-1.81612,-0.495442,0.579368,-1.88188,-0.548513,0.568344,-1.80996,0.270952,1.19733,-2.1156,0.31242,1.12562,-2.09945,0.147803,1.12656,-2.08839,0.190339,1.05775,-2.07509,0.308195,0.967191,-2.08137,0.402713,0.801936,-2.07083,0.292942,0.775576,-2.08653,0.313349,0.709627,-2.07685,0.401895,0.485432,-2.04379,0.357784,0.3847,-1.97382,0.610682,0.503453,-2.0247,0.584707,0.435244,-2.07611,0.11823,1.36184,-1.8245,0.115068,1.38383,-2.03858},
/*465*/{0.276692,1.94593,-1.75803,0.304088,1.88543,-1.91633,0.244051,1.79914,-1.63751,0.21983,1.68013,-1.54995,0.32926,1.68519,-1.67114,0.404194,1.68073,-1.72648,0.18111,1.95794,-2.1234,0.293302,1.88399,-1.98834,0.082095,1.92461,-2.00245,-0.056407,1.83523,-2.11774,-0.086229,1.74455,-2.17776,0.062213,1.61513,-2.16251,0.094204,1.56068,-2.19156,0.206344,1.43709,-1.80118,0.020366,1.5231,-1.86837,0.016979,1.55092,-1.91473,0.019639,1.52601,-1.98397,0.201413,1.46705,-2.05424,0.124961,1.11643,-1.77842,-0.010257,1.14198,-1.77494,-0.029813,1.06364,-1.80372,-0.009969,0.937361,-1.80684,-0.158916,0.819762,-1.78388,-0.227548,0.786058,-1.78876,-0.210901,0.918807,-1.77637,-0.274101,0.885869,-1.7762,-0.463673,0.737102,-1.78401,-0.539814,0.84194,-1.81743,-0.499772,0.594583,-1.87847,-0.555091,0.586269,-1.80659,0.269927,1.19216,-2.11617,0.311094,1.12044,-2.09949,0.146169,1.12392,-2.08763,0.187824,1.05464,-2.07385,0.305704,0.96327,-2.08095,0.400933,0.799646,-2.07013,0.291094,0.772406,-2.08517,0.312545,0.705901,-2.07489,0.40421,0.483873,-2.04216,0.359377,0.383092,-1.97122,0.612352,0.502188,-2.02382,0.585351,0.434806,-2.07573,0.118888,1.36012,-1.82408,0.115717,1.3807,-2.0383},
/*466*/{0.275501,1.94373,-1.75861,0.303737,1.88342,-1.91658,0.241909,1.79767,-1.63804,0.215243,1.67769,-1.5505,0.32647,1.68045,-1.67167,0.401348,1.67481,-1.72623,0.180423,1.95535,-2.12323,0.29285,1.88181,-1.98782,0.082365,1.92316,-2.00347,-0.055428,1.83107,-2.11831,-0.083785,1.74022,-2.17863,0.064934,1.6106,-2.16324,0.096551,1.55616,-2.19214,0.20638,1.43543,-1.80074,0.020382,1.52057,-1.8687,0.017009,1.54798,-1.91568,0.01985,1.52358,-1.98552,0.202079,1.46424,-2.0543,0.130988,1.11465,-1.77848,-0.004589,1.13568,-1.77443,-0.022744,1.05754,-1.80386,-0.002171,0.932945,-1.80711,-0.154735,0.821873,-1.78279,-0.223303,0.791304,-1.78734,-0.20297,0.92404,-1.77744,-0.26706,0.892832,-1.77685,-0.461987,0.751765,-1.78092,-0.533379,0.858995,-1.81809,-0.5037,0.608919,-1.87491,-0.55917,0.604799,-1.8038,0.269007,1.18781,-2.11704,0.309691,1.11549,-2.10031,0.144853,1.12166,-2.08727,0.185778,1.05171,-2.07367,0.301837,0.959014,-2.08068,0.398338,0.796614,-2.06945,0.288824,0.768515,-2.08379,0.310927,0.702012,-2.07362,0.403957,0.480723,-2.04047,0.358938,0.379709,-1.96955,0.609897,0.499216,-2.02445,0.583859,0.432068,-2.07524,0.119078,1.35813,-1.82389,0.116601,1.3778,-2.03821},
/*467*/{0.274081,1.94156,-1.75896,0.303612,1.88215,-1.91762,0.238415,1.79531,-1.63827,0.212051,1.67545,-1.55182,0.324582,1.67603,-1.67165,0.399579,1.66849,-1.7255,0.181578,1.95303,-2.12402,0.292174,1.87966,-1.98844,0.081583,1.92127,-2.00453,-0.053443,1.8271,-2.11854,-0.081611,1.7352,-2.18072,0.067038,1.6062,-2.16449,0.099349,1.55184,-2.19265,0.206703,1.43403,-1.80065,0.020833,1.51765,-1.86964,0.018313,1.54495,-1.91619,0.020082,1.52055,-1.98626,0.201836,1.4606,-2.05501,0.134765,1.11021,-1.77864,0.00056,1.13072,-1.77443,-0.017166,1.05129,-1.80493,0.005547,0.929129,-1.80792,-0.149154,0.825155,-1.78182,-0.219469,0.796801,-1.78599,-0.193815,0.928958,-1.77787,-0.259694,0.900077,-1.77737,-0.459279,0.766421,-1.7781,-0.525448,0.875412,-1.81974,-0.505146,0.623697,-1.87073,-0.562497,0.622593,-1.80055,0.268315,1.18373,-2.11841,0.307543,1.11049,-2.10151,0.143148,1.11938,-2.08731,0.183304,1.04957,-2.07354,0.300303,0.954946,-2.08076,0.39519,0.792821,-2.06834,0.285715,0.764487,-2.08232,0.307505,0.698411,-2.07212,0.400187,0.476364,-2.0389,0.357341,0.375799,-1.96792,0.608963,0.495396,-2.02254,0.58082,0.428477,-2.07452,0.11978,1.35612,-1.82343,0.11692,1.37415,-2.03789},
/*468*/{0.272615,1.9384,-1.75914,0.30167,1.87941,-1.91653,0.235987,1.79283,-1.63845,0.208276,1.6729,-1.55321,0.320924,1.67122,-1.67093,0.396503,1.66203,-1.72475,0.181148,1.94996,-2.12463,0.292094,1.87708,-1.98859,0.080854,1.91886,-2.00678,-0.052515,1.82202,-2.12103,-0.079683,1.72988,-2.18177,0.068995,1.60173,-2.16549,0.102273,1.54715,-2.1929,0.20618,1.43118,-1.80001,0.019992,1.51407,-1.87041,0.017661,1.54204,-1.91682,0.019269,1.51709,-1.98698,0.202043,1.45735,-2.05563,0.139527,1.10811,-1.77838,0.005714,1.12648,-1.77529,-0.009486,1.04594,-1.8055,0.013572,0.924798,-1.80841,-0.143624,0.827507,-1.78166,-0.214305,0.801194,-1.78531,-0.184898,0.931803,-1.77945,-0.252327,0.905735,-1.77871,-0.455536,0.780865,-1.77457,-0.518066,0.890904,-1.82128,-0.506895,0.637783,-1.86604,-0.562987,0.64033,-1.79592,0.267715,1.1804,-2.11953,0.306422,1.10649,-2.10257,0.142192,1.11705,-2.08703,0.181901,1.04645,-2.07312,0.298988,0.950606,-2.08008,0.391154,0.789102,-2.06801,0.282915,0.760796,-2.08157,0.3043,0.694777,-2.07133,0.397918,0.473821,-2.03712,0.353474,0.371871,-1.96474,0.605662,0.4911,-2.0211,0.576538,0.423324,-2.07341,0.119277,1.35314,-1.82355,0.117011,1.37083,-2.03804},
/*469*/{0.271995,1.9363,-1.75906,0.301036,1.8764,-1.91656,0.233039,1.78992,-1.63864,0.2028,1.67042,-1.55479,0.317271,1.6666,-1.67085,0.39353,1.65509,-1.72306,0.181394,1.9468,-2.12527,0.29215,1.874,-1.98859,0.080133,1.91536,-2.00737,-0.050522,1.81709,-2.12143,-0.077784,1.72411,-2.18351,0.071507,1.59663,-2.16629,0.105935,1.54201,-2.19335,0.206951,1.42959,-1.80095,0.020315,1.51064,-1.87,0.017535,1.5385,-1.91779,0.019398,1.51309,-1.98686,0.202122,1.45468,-2.05615,0.143876,1.1046,-1.77736,0.008815,1.11864,-1.77579,-0.004232,1.03856,-1.80357,0.021404,0.920442,-1.80749,-0.137386,0.829659,-1.78064,-0.208678,0.805968,-1.78458,-0.175218,0.935343,-1.78103,-0.242601,0.911511,-1.77855,-0.451258,0.795025,-1.77144,-0.508614,0.90582,-1.82329,-0.506521,0.651769,-1.86193,-0.563154,0.657546,-1.79213,0.267644,1.17681,-2.11956,0.304844,1.10228,-2.10219,0.141577,1.11477,-2.08674,0.179509,1.04341,-2.07283,0.297903,0.947208,-2.07902,0.388418,0.784769,-2.06776,0.278804,0.756599,-2.08056,0.300136,0.690436,-2.06977,0.394291,0.469869,-2.0349,0.347853,0.369127,-1.96241,0.600808,0.485135,-2.02007,0.571211,0.416574,-2.07129,0.120919,1.3507,-1.82348,0.117794,1.36753,-2.03804},
/*470*/{0.269762,1.93297,-1.75902,0.301581,1.87239,-1.91711,0.229327,1.78679,-1.63862,0.198735,1.66744,-1.55574,0.31401,1.66085,-1.67088,0.390084,1.64747,-1.72236,0.181289,1.94318,-2.12602,0.291805,1.8709,-1.98867,0.079484,1.9122,-2.00895,-0.051351,1.81281,-2.12235,-0.075927,1.71742,-2.18604,0.073999,1.59084,-2.16783,0.109148,1.53642,-2.19441,0.208051,1.42684,-1.80132,0.01939,1.50685,-1.87067,0.018423,1.53471,-1.91784,0.018975,1.50899,-1.98807,0.201553,1.45164,-2.05641,0.149241,1.1023,-1.77677,0.014056,1.11463,-1.77589,0.001019,1.03325,-1.80456,0.028245,0.916347,-1.80725,-0.13112,0.831837,-1.78014,-0.202708,0.811618,-1.78293,-0.164398,0.938944,-1.78145,-0.232567,0.917551,-1.77861,-0.445638,0.80801,-1.77198,-0.498731,0.919614,-1.82514,-0.505213,0.663409,-1.85791,-0.561594,0.674229,-1.78763,0.266972,1.17334,-2.11999,0.304069,1.09864,-2.10332,0.140617,1.11246,-2.08557,0.1783,1.04052,-2.07226,0.298332,0.944106,-2.07826,0.385335,0.779717,-2.06735,0.27481,0.752404,-2.07877,0.295582,0.68591,-2.06821,0.386101,0.462468,-2.03333,0.340272,0.364718,-1.9591,0.594378,0.478505,-2.01902,0.565487,0.409135,-2.06868,0.121818,1.34755,-1.82376,0.118244,1.36393,-2.03834},
/*471*/{0.267963,1.9297,-1.75887,0.300612,1.86973,-1.91689,0.226171,1.78388,-1.63841,0.194505,1.66442,-1.55679,0.31025,1.65488,-1.67065,0.386986,1.6399,-1.72096,0.18161,1.93956,-2.12674,0.291121,1.86767,-1.98884,0.078047,1.90856,-2.01075,-0.049788,1.80626,-2.12306,-0.073446,1.711,-2.18791,0.077469,1.58538,-2.16875,0.112482,1.53128,-2.19528,0.20797,1.42379,-1.80144,0.019233,1.50284,-1.87086,0.017943,1.53042,-1.91867,0.018271,1.50458,-1.98762,0.201861,1.44868,-2.05708,0.154077,1.09769,-1.77711,0.016857,1.10719,-1.77567,0.007599,1.02767,-1.80465,0.035973,0.912044,-1.8063,-0.124365,0.833202,-1.77891,-0.198164,0.81444,-1.78218,-0.154012,0.941573,-1.78253,-0.223028,0.922767,-1.77978,-0.438503,0.820235,-1.77281,-0.488468,0.93264,-1.82713,-0.502096,0.676455,-1.85402,-0.558156,0.69045,-1.78394,0.266313,1.16951,-2.1199,0.303279,1.09504,-2.10361,0.139601,1.10897,-2.0858,0.17751,1.03724,-2.07224,0.297846,0.940849,-2.07741,0.380997,0.774147,-2.06726,0.270279,0.748169,-2.07785,0.290501,0.681433,-2.06701,0.379986,0.457728,-2.03216,0.332385,0.360874,-1.95613,0.587454,0.469612,-2.01745,0.556451,0.39982,-2.06555,0.122513,1.34402,-1.82402,0.11882,1.36035,-2.0386},
/*472*/{0.266771,1.92619,-1.75869,0.300653,1.86559,-1.91705,0.222513,1.77983,-1.63858,0.188278,1.66184,-1.55881,0.30619,1.64853,-1.67058,0.383252,1.63224,-1.71965,0.180085,1.9349,-2.12728,0.291143,1.86404,-1.98902,0.077742,1.90426,-2.01257,-0.056628,1.80471,-2.12765,-0.071162,1.70392,-2.19023,0.080985,1.57925,-2.1708,0.115838,1.526,-2.19588,0.208049,1.4208,-1.80183,0.018683,1.4983,-1.87134,0.017471,1.52602,-1.91898,0.017476,1.4997,-1.98755,0.201801,1.44523,-2.05801,0.158727,1.0937,-1.77464,0.021692,1.10161,-1.77658,0.013066,1.0211,-1.80576,0.044188,0.907859,-1.80526,-0.116866,0.83531,-1.7781,-0.190501,0.819486,-1.77935,-0.144246,0.944213,-1.78433,-0.213594,0.928287,-1.78146,-0.430257,0.832069,-1.77375,-0.477983,0.944916,-1.82994,-0.49881,0.688015,-1.84923,-0.554225,0.705509,-1.77969,0.26605,1.1661,-2.11962,0.302386,1.0909,-2.10384,0.139535,1.10536,-2.08478,0.1769,1.0339,-2.07167,0.296715,0.93766,-2.0762,0.376478,0.767956,-2.06791,0.265595,0.74356,-2.07721,0.285347,0.676744,-2.06596,0.371048,0.451442,-2.03051,0.323055,0.356098,-1.95454,0.580515,0.461245,-2.01371,0.548398,0.390977,-2.06255,0.123321,1.34033,-1.82427,0.119179,1.35633,-2.03887},
/*473*/{0.265018,1.92215,-1.75814,0.301236,1.86214,-1.91794,0.218525,1.77549,-1.63842,0.182863,1.65746,-1.55936,0.300965,1.64272,-1.66975,0.379224,1.62397,-1.71789,0.180458,1.93018,-2.12803,0.290602,1.8604,-1.98926,0.077284,1.89948,-2.01331,-0.048389,1.79164,-2.12983,-0.069316,1.69652,-2.19257,0.083906,1.57308,-2.17255,0.119241,1.51937,-2.1967,0.207863,1.41748,-1.80239,0.0184,1.49334,-1.87202,0.017103,1.5214,-1.91933,0.017117,1.49471,-1.98793,0.200984,1.44229,-2.05913,0.161388,1.09192,-1.77377,0.025753,1.09599,-1.77816,0.021189,1.01551,-1.80389,0.052109,0.9039,-1.8032,-0.109233,0.837151,-1.77634,-0.183128,0.822797,-1.77824,-0.132795,0.945983,-1.78574,-0.202758,0.93164,-1.78231,-0.421631,0.842564,-1.77449,-0.467057,0.955839,-1.83226,-0.494037,0.698438,-1.8448,-0.548798,0.719268,-1.77571,0.265679,1.16254,-2.1198,0.302392,1.08644,-2.10317,0.138242,1.10209,-2.08446,0.17634,1.03046,-2.07172,0.295246,0.934196,-2.07565,0.372255,0.760756,-2.06717,0.260681,0.738607,-2.07652,0.278989,0.671696,-2.06507,0.361659,0.445279,-2.02873,0.312198,0.351977,-1.95214,0.57073,0.451053,-2.01199,0.538293,0.380819,-2.05913,0.124134,1.33627,-1.82512,0.119523,1.35251,-2.03969},
/*474*/{0.263479,1.91812,-1.75757,0.300078,1.85732,-1.9172,0.215428,1.77126,-1.63879,0.178199,1.6538,-1.56009,0.296431,1.63566,-1.66902,0.375021,1.61533,-1.71673,0.17978,1.92503,-2.1282,0.290198,1.85631,-1.98964,0.076676,1.89426,-2.01578,-0.048321,1.78341,-2.13244,-0.066924,1.68844,-2.19495,0.086957,1.56618,-2.17384,0.123578,1.51317,-2.19721,0.208536,1.41418,-1.80311,0.018471,1.48784,-1.87181,0.016836,1.51676,-1.91929,0.016493,1.48944,-1.98732,0.201075,1.43906,-2.06001,0.166859,1.08822,-1.77123,0.029933,1.09078,-1.77897,0.026838,1.01032,-1.80664,0.060154,0.899842,-1.80167,-0.100569,0.838651,-1.77516,-0.1757,0.825009,-1.77723,-0.121438,0.947545,-1.78723,-0.191844,0.934921,-1.78352,-0.414092,0.853459,-1.77117,-0.456469,0.96509,-1.83433,-0.4875,0.708656,-1.84151,-0.54124,0.73311,-1.77159,0.265032,1.15858,-2.11995,0.302252,1.08383,-2.10317,0.138115,1.09838,-2.08488,0.175541,1.02585,-2.0716,0.29422,0.930025,-2.07546,0.367197,0.755026,-2.06715,0.255587,0.734197,-2.07543,0.272557,0.666563,-2.06431,0.351376,0.438802,-2.0279,0.298094,0.350155,-1.95228,0.560315,0.440161,-2.00909,0.527235,0.371076,-2.05643,0.125836,1.33207,-1.82556,0.120265,1.34853,-2.0401},
/*475*/{0.261323,1.9131,-1.75713,0.300103,1.85362,-1.91694,0.212359,1.76702,-1.6386,0.173691,1.65039,-1.56062,0.291414,1.62888,-1.66879,0.370765,1.60697,-1.71456,0.180821,1.92007,-2.12965,0.290602,1.85201,-1.98968,0.075396,1.88875,-2.01754,-0.04612,1.77605,-2.13531,-0.064683,1.68087,-2.19775,0.091016,1.55983,-2.17539,0.128182,1.50724,-2.19823,0.208823,1.41042,-1.80425,0.01865,1.48242,-1.87157,0.016725,1.51107,-1.91935,0.016369,1.48406,-1.98707,0.201167,1.43555,-2.06102,0.169242,1.08497,-1.77216,0.033225,1.08547,-1.78126,0.030911,1.00403,-1.80631,0.069281,0.895831,-1.79969,-0.091656,0.838826,-1.77381,-0.167394,0.827456,-1.77653,-0.109566,0.949265,-1.78851,-0.180884,0.938098,-1.78502,-0.40328,0.863109,-1.77285,-0.444809,0.974684,-1.83787,-0.480293,0.71876,-1.83774,-0.53346,0.744731,-1.76753,0.264241,1.15442,-2.11953,0.301536,1.07975,-2.10285,0.137347,1.09405,-2.08422,0.175427,1.02175,-2.07176,0.291797,0.923411,-2.07494,0.362907,0.748033,-2.0658,0.250446,0.729638,-2.07462,0.265966,0.661553,-2.06354,0.336975,0.434421,-2.0256,0.281527,0.353372,-1.94946,0.549518,0.429662,-2.00612,0.511942,0.359074,-2.05366,0.127437,1.3274,-1.8263,0.121042,1.34426,-2.04078},
/*476*/{0.259435,1.90827,-1.75688,0.30102,1.84868,-1.91657,0.208427,1.76175,-1.6387,0.166175,1.64602,-1.56138,0.286462,1.62225,-1.66831,0.365195,1.59872,-1.71257,0.180907,1.91461,-2.13031,0.290552,1.84726,-1.98944,0.074852,1.88349,-2.01948,-0.046275,1.76745,-2.13829,-0.061895,1.67236,-2.20111,0.095233,1.55248,-2.17688,0.133234,1.50113,-2.19871,0.209229,1.40717,-1.80529,0.018144,1.47657,-1.87176,0.016112,1.50568,-1.91946,0.015154,1.47824,-1.98618,0.20042,1.43128,-2.06191,0.172822,1.08193,-1.7697,0.038014,1.07981,-1.78182,0.037118,0.998755,-1.80711,0.077588,0.892023,-1.79811,-0.083231,0.840108,-1.77188,-0.158228,0.831512,-1.77437,-0.098068,0.950065,-1.79027,-0.169599,0.940956,-1.7874,-0.392567,0.872609,-1.77406,-0.433903,0.982848,-1.84112,-0.471771,0.727129,-1.8325,-0.523584,0.755496,-1.76451,0.263744,1.15039,-2.11945,0.301004,1.07562,-2.10255,0.136388,1.08912,-2.08446,0.174923,1.01726,-2.07146,0.290464,0.917765,-2.07491,0.357217,0.740272,-2.06493,0.244695,0.724062,-2.07413,0.258699,0.655753,-2.06279,0.329818,0.431947,-2.02359,0.263048,0.354312,-1.94895,0.534575,0.414342,-2.004,0.493137,0.349309,-2.05145,0.128839,1.3231,-1.82644,0.121083,1.33936,-2.04092},
/*477*/{0.25772,1.90308,-1.75573,0.300861,1.8431,-1.91649,0.204633,1.75673,-1.63924,0.159961,1.64174,-1.56206,0.281547,1.61549,-1.66754,0.360077,1.58962,-1.71046,0.181486,1.90927,-2.13141,0.290688,1.84269,-1.98906,0.074686,1.8773,-2.02038,-0.044415,1.75759,-2.14121,-0.058829,1.66381,-2.20426,0.099525,1.54539,-2.17872,0.138398,1.49429,-2.19922,0.20923,1.40306,-1.80614,0.017864,1.47087,-1.8709,0.015154,1.49987,-1.92016,0.014189,1.47246,-1.98645,0.200176,1.42749,-2.06317,0.17602,1.07812,-1.76664,0.042188,1.076,-1.78272,0.043479,0.991811,-1.80717,0.085862,0.888188,-1.79567,-0.073873,0.840681,-1.77039,-0.149157,0.83366,-1.77272,-0.08574,0.950161,-1.79105,-0.157418,0.942861,-1.78822,-0.382922,0.880446,-1.77284,-0.421776,0.989789,-1.84365,-0.462587,0.734338,-1.82994,-0.515076,0.766064,-1.7613,0.262333,1.14561,-2.11918,0.300673,1.07116,-2.10284,0.135452,1.08461,-2.08437,0.17423,1.01283,-2.07113,0.287879,0.911328,-2.07493,0.351171,0.733612,-2.06417,0.239079,0.71892,-2.07334,0.251854,0.65062,-2.06189,0.317449,0.425914,-2.02085,0.244486,0.356867,-1.94501,0.52326,0.396045,-2.0018,0.475499,0.339106,-2.04976,0.12994,1.31827,-1.82719,0.121395,1.33476,-2.04162},
/*478*/{0.256688,1.89895,-1.75566,0.29979,1.83783,-1.91537,0.200412,1.75116,-1.63917,0.15361,1.63859,-1.56272,0.275812,1.60834,-1.6658,0.355201,1.58102,-1.7081,0.181264,1.90319,-2.13287,0.290193,1.83763,-1.98882,0.07328,1.87138,-2.02324,-0.044067,1.74847,-2.14377,-0.056014,1.65504,-2.20722,0.103895,1.53982,-2.17997,0.143498,1.48771,-2.20016,0.209669,1.39839,-1.80704,0.016842,1.46484,-1.87114,0.015037,1.49472,-1.91996,0.013035,1.46672,-1.98578,0.199169,1.42349,-2.06444,0.178789,1.07404,-1.76378,0.046646,1.06738,-1.78265,0.049981,0.985072,-1.80678,0.095439,0.88427,-1.79401,-0.063191,0.841481,-1.76793,-0.140059,0.835765,-1.77103,-0.073483,0.950557,-1.79294,-0.145859,0.945175,-1.78946,-0.370588,0.888471,-1.77356,-0.410097,0.995768,-1.84656,-0.45208,0.741087,-1.8253,-0.503688,0.774847,-1.75732,0.261535,1.14169,-2.11943,0.29936,1.06696,-2.10251,0.134741,1.08014,-2.0853,0.173587,1.00786,-2.07122,0.285717,0.905726,-2.07513,0.345967,0.726286,-2.06196,0.232814,0.714365,-2.07313,0.245871,0.645524,-2.06036,0.299474,0.42153,-2.01472,0.223755,0.353568,-1.94575,0.505517,0.387281,-1.98889,0.455133,0.341983,-2.04932,0.130779,1.3131,-1.82811,0.121028,1.33018,-2.04244},
/*479*/{0.254794,1.8927,-1.75433,0.298659,1.83307,-1.91481,0.196215,1.74573,-1.63948,0.147058,1.63363,-1.56344,0.270528,1.6018,-1.66472,0.348878,1.57288,-1.70538,0.182099,1.89744,-2.134,0.29025,1.83248,-1.98923,0.072537,1.86464,-2.02466,-0.042163,1.739,-2.14686,-0.052512,1.64547,-2.21029,0.109176,1.53265,-2.18141,0.149404,1.48085,-2.20062,0.209552,1.39386,-1.80856,0.016206,1.45984,-1.87068,0.014305,1.48817,-1.92052,0.01087,1.46115,-1.98601,0.197873,1.41893,-2.06578,0.185916,1.07033,-1.76064,0.050647,1.0627,-1.784,0.056129,0.979266,-1.80624,0.104634,0.881091,-1.79088,-0.053062,0.841945,-1.76619,-0.129048,0.836853,-1.76959,-0.060844,0.949571,-1.7939,-0.132266,0.946416,-1.79026,-0.360345,0.894571,-1.77295,-0.398304,1.00054,-1.84892,-0.441158,0.746531,-1.82189,-0.492308,0.781815,-1.75432,0.258763,1.13756,-2.12013,0.297455,1.06335,-2.1043,0.132383,1.07629,-2.08526,0.171903,1.00467,-2.07129,0.281504,0.899649,-2.07548,0.339202,0.718439,-2.05736,0.227193,0.71012,-2.07193,0.236185,0.641618,-2.05919,0.283409,0.422522,-2.00898,0.199533,0.353678,-1.94618,0.480869,0.385955,-1.98993,0.43137,0.34189,-2.04904,0.131268,1.30817,-1.82893,0.120055,1.32506,-2.04321},
/*480*/{0.252851,1.88749,-1.7539,0.299719,1.82743,-1.91378,0.192292,1.74056,-1.63942,0.140226,1.63023,-1.56411,0.264244,1.59478,-1.66429,0.343699,1.5647,-1.70317,0.183021,1.89149,-2.135,0.290685,1.82689,-1.98891,0.071399,1.85897,-2.02728,-0.040528,1.72909,-2.15162,-0.048074,1.63622,-2.21349,0.113843,1.52529,-2.18258,0.155616,1.47428,-2.20086,0.209002,1.3889,-1.80908,0.014913,1.45326,-1.87097,0.012441,1.48193,-1.92024,0.008437,1.4566,-1.98561,0.196454,1.41389,-2.06702,0.191291,1.06507,-1.7593,0.055574,1.05443,-1.78361,0.062987,0.97193,-1.8065,0.114303,0.876766,-1.78947,-0.042156,0.841464,-1.76449,-0.116861,0.839376,-1.76778,-0.047271,0.949472,-1.79517,-0.119629,0.947259,-1.79199,-0.347208,0.899524,-1.77408,-0.386203,1.00479,-1.85195,-0.429298,0.751254,-1.81857,-0.480602,0.788748,-1.75196,0.255176,1.13506,-2.12314,0.294283,1.06077,-2.10748,0.130246,1.07308,-2.08559,0.169748,1.00245,-2.07096,0.276751,0.894386,-2.07609,0.334621,0.71321,-2.05272,0.222587,0.707792,-2.06984,0.227495,0.639621,-2.05556,0.2604,0.42288,-2.00391,0.177231,0.354382,-1.94092,0.456417,0.386742,-1.98601,0.408028,0.342595,-2.04797,0.130847,1.30262,-1.82975,0.118682,1.32005,-2.04394},
/*481*/{0.251403,1.88172,-1.75292,0.300324,1.82138,-1.91311,0.18773,1.73523,-1.63988,0.134,1.62677,-1.56574,0.258313,1.5883,-1.6631,0.336834,1.55713,-1.70077,0.183365,1.88616,-2.13657,0.291637,1.82166,-1.98872,0.070193,1.85195,-2.02887,-0.037843,1.72018,-2.15658,-0.04394,1.62651,-2.21678,0.120208,1.51809,-2.18394,0.162447,1.46775,-2.20149,0.208668,1.38371,-1.81074,0.012277,1.44786,-1.87,0.010966,1.47548,-1.91955,0.004497,1.45248,-1.98621,0.194019,1.40988,-2.06779,0.195719,1.0626,-1.75765,0.061227,1.04915,-1.78396,0.069795,0.965985,-1.80745,0.12389,0.873163,-1.78611,-0.031024,0.840499,-1.76387,-0.105885,0.840239,-1.76601,-0.033747,0.948724,-1.79605,-0.104562,0.947673,-1.79105,-0.333391,0.90384,-1.77471,-0.373822,1.0075,-1.85455,-0.416429,0.754477,-1.81481,-0.46711,0.793871,-1.74871,0.252218,1.13276,-2.12782,0.291202,1.05874,-2.11152,0.128451,1.0721,-2.08557,0.167449,1.00194,-2.07091,0.272097,0.890841,-2.07614,0.329552,0.710748,-2.04766,0.218826,0.711558,-2.06673,0.218547,0.642948,-2.05087,0.235793,0.424457,-1.99922,0.154398,0.355689,-1.93856,0.435899,0.383161,-1.98464,0.385073,0.34287,-2.04662,0.13004,1.29721,-1.83112,0.116283,1.31583,-2.04511},
/*482*/{0.250258,1.87671,-1.75177,0.301571,1.81539,-1.91212,0.185005,1.73012,-1.64003,0.127095,1.62284,-1.56652,0.25187,1.58187,-1.66131,0.329938,1.54955,-1.69802,0.184643,1.88079,-2.13848,0.291993,1.81614,-1.98863,0.070026,1.84843,-2.02992,-0.036047,1.70988,-2.16132,-0.038662,1.6164,-2.21976,0.126821,1.51121,-2.18537,0.169198,1.46145,-2.2018,0.207304,1.37866,-1.81303,0.010315,1.44217,-1.87025,0.008105,1.47037,-1.91926,0.001148,1.44768,-1.98593,0.191228,1.40821,-2.06822,0.198156,1.05865,-1.75609,0.06497,1.04256,-1.78521,0.076086,0.958742,-1.80695,0.134595,0.869816,-1.78414,-0.018676,0.839285,-1.7628,-0.093028,0.839642,-1.76499,-0.020212,0.946706,-1.79654,-0.091767,0.947294,-1.7912,-0.323349,0.90683,-1.77449,-0.361674,1.00912,-1.85705,-0.402869,0.757898,-1.81202,-0.453362,0.7971,-1.74684,0.249257,1.13056,-2.13281,0.288852,1.0574,-2.11497,0.125806,1.07179,-2.08503,0.164995,1.00154,-2.07105,0.269229,0.891146,-2.07606,0.322473,0.710602,-2.04326,0.211778,0.71728,-2.0639,0.208333,0.648467,-2.04786,0.219399,0.427058,-1.99782,0.131808,0.357946,-1.93734,0.414041,0.38401,-1.98248,0.363004,0.342683,-2.04517,0.129258,1.29187,-1.83358,0.114326,1.31312,-2.04725},
/*483*/{0.249747,1.87167,-1.75063,0.301404,1.81021,-1.91107,0.180959,1.72441,-1.64014,0.119928,1.61877,-1.56648,0.245487,1.57605,-1.65983,0.322935,1.54394,-1.69544,0.186116,1.87578,-2.14066,0.293179,1.81044,-1.98763,0.071047,1.84632,-2.03019,-0.032059,1.70134,-2.16748,-0.032983,1.60653,-2.2229,0.133038,1.50448,-2.1863,0.17722,1.45573,-2.20222,0.20614,1.37377,-1.81535,0.007301,1.43686,-1.87003,0.005221,1.4649,-1.91818,-0.001945,1.44372,-1.98582,0.188517,1.40619,-2.06977,0.200975,1.05495,-1.75485,0.070349,1.03546,-1.78535,0.083602,0.952582,-1.80737,0.145661,0.865712,-1.781,-0.005942,0.837865,-1.76168,-0.081879,0.838876,-1.76361,-0.007298,0.944974,-1.79605,-0.077782,0.947382,-1.79215,-0.309226,0.909782,-1.77479,-0.349097,1.00966,-1.85896,-0.388283,0.758688,-1.80922,-0.440627,0.800056,-1.74568,0.24686,1.12966,-2.13555,0.286781,1.05605,-2.11674,0.124351,1.07153,-2.08514,0.16421,1.00048,-2.07055,0.268455,0.892421,-2.07604,0.314213,0.7102,-2.04231,0.203742,0.722684,-2.06257,0.19696,0.654144,-2.04684,0.200624,0.429574,-1.995,0.109902,0.357525,-1.93709,0.391785,0.381221,-1.98049,0.339615,0.343331,-2.04406,0.128322,1.28665,-1.83613,0.111859,1.31051,-2.04941},
/*484*/{0.248308,1.86683,-1.74972,0.301037,1.8055,-1.91013,0.176749,1.72015,-1.64035,0.112016,1.61585,-1.5676,0.238772,1.57099,-1.65846,0.315712,1.53709,-1.69283,0.187078,1.87098,-2.14253,0.294133,1.80611,-1.98749,0.071159,1.84397,-2.03041,-0.02615,1.69056,-2.17435,-0.025811,1.59632,-2.22598,0.141153,1.49831,-2.18713,0.18507,1.45032,-2.20223,0.20413,1.36885,-1.81649,0.004949,1.43247,-1.8696,0.002957,1.46147,-1.91857,-0.005379,1.43994,-1.9831,0.186159,1.40412,-2.07184,0.205586,1.05432,-1.75406,0.076501,1.0289,-1.78452,0.091428,0.946714,-1.80725,0.156952,0.86268,-1.7795,0.007268,0.83656,-1.76052,-0.068353,0.837726,-1.76344,0.00723,0.943803,-1.79534,-0.06462,0.946177,-1.79188,-0.294958,0.909903,-1.77393,-0.33651,1.00963,-1.86009,-0.373148,0.759264,-1.80694,-0.425047,0.80026,-1.74435,0.24351,1.1281,-2.13607,0.283717,1.05522,-2.11743,0.122076,1.06899,-2.08403,0.162503,0.999625,-2.07007,0.271598,0.894009,-2.07545,0.303864,0.709314,-2.04333,0.192815,0.726723,-2.06177,0.184005,0.658394,-2.04741,0.180366,0.429431,-1.99264,0.088544,0.358468,-1.93415,0.370468,0.380729,-1.98123,0.318398,0.343472,-2.04251,0.126582,1.282,-1.83796,0.108774,1.30805,-2.05087},
/*485*/{0.248255,1.86266,-1.74819,0.301544,1.80082,-1.9088,0.171496,1.71644,-1.64092,0.103704,1.61409,-1.56853,0.230999,1.56677,-1.65718,0.307833,1.53146,-1.69073,0.188492,1.86655,-2.14384,0.294705,1.80215,-1.98696,0.071176,1.84252,-2.03064,-0.021291,1.68177,-2.18221,-0.018017,1.58663,-2.22869,0.149237,1.49287,-2.18767,0.193827,1.44516,-2.20222,0.202806,1.36443,-1.81858,0.002171,1.42774,-1.86788,0.001115,1.45956,-1.91675,-0.007714,1.43704,-1.9812,0.182956,1.40302,-2.07381,0.209922,1.05502,-1.75423,0.081808,1.02471,-1.78486,0.100958,0.942401,-1.80625,0.168789,0.859515,-1.77967,0.019849,0.834719,-1.76028,-0.054312,0.836006,-1.76388,0.020727,0.942804,-1.79526,-0.050013,0.944714,-1.79035,-0.281621,0.909874,-1.77612,-0.324218,1.00812,-1.86156,-0.357466,0.757594,-1.80533,-0.40944,0.799246,-1.74276,0.239943,1.12707,-2.13628,0.280011,1.05399,-2.11889,0.119096,1.06742,-2.08321,0.159837,0.997557,-2.06861,0.274374,0.893806,-2.07374,0.292863,0.708167,-2.04633,0.181259,0.729543,-2.06135,0.172219,0.660821,-2.04733,0.163964,0.43094,-1.99178,0.067198,0.360179,-1.93471,0.348834,0.379766,-1.97939,0.296508,0.343005,-2.04226,0.125288,1.27764,-1.84025,0.105218,1.3068,-2.05256},
/*486*/{0.24811,1.85824,-1.74603,0.301933,1.79764,-1.9078,0.166845,1.71474,-1.64117,0.094321,1.61367,-1.56983,0.223652,1.56263,-1.65592,0.300495,1.52638,-1.68797,0.190032,1.86351,-2.14393,0.294679,1.79924,-1.98584,0.071752,1.84044,-2.03048,-0.014182,1.67238,-2.18784,-0.009232,1.57749,-2.231,0.158117,1.48829,-2.18808,0.203702,1.44114,-2.20219,0.201011,1.36088,-1.81939,0.000371,1.42545,-1.86533,-0.000413,1.45775,-1.91615,-0.009643,1.43588,-1.97866,0.180455,1.40246,-2.07589,0.216829,1.05692,-1.75365,0.087067,1.02023,-1.78358,0.109601,0.94085,-1.80537,0.181762,0.858947,-1.7781,0.033954,0.832844,-1.76023,-0.04107,0.834612,-1.76368,0.035138,0.941576,-1.79254,-0.036429,0.943416,-1.79069,-0.267602,0.908187,-1.77576,-0.313598,1.00549,-1.86228,-0.341458,0.754846,-1.80435,-0.393369,0.795474,-1.7417,0.235014,1.12487,-2.13699,0.275593,1.051,-2.12029,0.114553,1.06396,-2.08148,0.15549,0.995414,-2.06869,0.275831,0.895304,-2.07232,0.280586,0.70649,-2.0501,0.169227,0.729572,-2.06264,0.158802,0.661398,-2.04697,0.140713,0.43131,-1.99258,0.044773,0.362319,-1.93439,0.328216,0.378448,-1.97964,0.274565,0.342486,-2.04199,0.123619,1.27456,-1.8417,0.101861,1.3062,-2.05349},
/*487*/{0.248243,1.85493,-1.74515,0.301766,1.7952,-1.90728,0.161373,1.71395,-1.64162,0.087115,1.61428,-1.57212,0.216055,1.55984,-1.65447,0.29222,1.52233,-1.68511,0.191287,1.86057,-2.1436,0.294413,1.79643,-1.98505,0.071587,1.83948,-2.03058,-0.008988,1.66575,-2.19511,0.000341,1.56937,-2.2334,0.167487,1.48459,-2.18808,0.213901,1.43814,-2.20125,0.198428,1.35747,-1.82038,-0.000929,1.42389,-1.86286,-0.002234,1.45716,-1.9162,-0.011418,1.43541,-1.97535,0.178512,1.40181,-2.07768,0.223587,1.05946,-1.7536,0.094134,1.01801,-1.78215,0.120346,0.939397,-1.80199,0.195687,0.858656,-1.77852,0.046474,0.831632,-1.76005,-0.02606,0.83335,-1.76512,0.048412,0.940435,-1.79314,-0.022466,0.943459,-1.79008,-0.253246,0.906492,-1.77737,-0.303174,1.00212,-1.8627,-0.325434,0.750671,-1.80327,-0.376678,0.790711,-1.73993,0.23065,1.12222,-2.13752,0.269961,1.04761,-2.12144,0.110218,1.06177,-2.08075,0.149559,0.993543,-2.06812,0.269663,0.893298,-2.0729,0.26682,0.702711,-2.05354,0.15704,0.728214,-2.06322,0.143016,0.660581,-2.04695,0.120618,0.430865,-1.99236,0.023656,0.362225,-1.93528,0.305972,0.37871,-1.98046,0.25294,0.342057,-2.04277,0.121172,1.27188,-1.84296,0.09821,1.30594,-2.05424},
/*488*/{0.24787,1.85224,-1.74491,0.301611,1.7922,-1.90661,0.156165,1.714,-1.64223,0.079019,1.6157,-1.57412,0.208342,1.55923,-1.65518,0.284638,1.51907,-1.68243,0.192489,1.85896,-2.14317,0.294884,1.79406,-1.98415,0.072168,1.83747,-2.03049,-0.001633,1.65837,-2.19896,0.011358,1.56237,-2.23541,0.177255,1.48166,-2.18722,0.2248,1.43622,-2.20037,0.195888,1.35435,-1.82123,-0.001774,1.42337,-1.86251,-0.004044,1.45693,-1.91619,-0.012603,1.43523,-1.97395,0.176051,1.40117,-2.07883,0.230663,1.0617,-1.75327,0.102132,1.01647,-1.78045,0.128878,0.93874,-1.80105,0.210438,0.860681,-1.77741,0.061085,0.83149,-1.76016,-0.013921,0.832163,-1.76519,0.061028,0.940122,-1.79151,-0.010987,0.941495,-1.79096,-0.240696,0.901817,-1.77693,-0.294249,0.997586,-1.8616,-0.307563,0.745017,-1.80321,-0.357814,0.783131,-1.73859,0.22412,1.11871,-2.13931,0.263371,1.04337,-2.12274,0.103783,1.06058,-2.07998,0.142282,0.99128,-2.06689,0.260904,0.88851,-2.07507,0.253789,0.697329,-2.05461,0.143941,0.72727,-2.06449,0.128548,0.660148,-2.04813,0.103186,0.432284,-1.99276,0.001531,0.36195,-1.93438,0.285565,0.37749,-1.9803,0.231471,0.341726,-2.04304,0.118283,1.26977,-1.84434,0.094819,1.30572,-2.05525},
/*489*/{0.248227,1.85064,-1.74433,0.301007,1.79075,-1.90528,0.150513,1.71449,-1.64258,0.071046,1.61846,-1.57712,0.200748,1.55851,-1.65459,0.276884,1.51706,-1.68115,0.194302,1.85742,-2.14182,0.294678,1.79244,-1.98348,0.072715,1.83666,-2.0307,0.005725,1.65188,-2.2024,0.020048,1.55758,-2.23642,0.187587,1.4803,-2.18684,0.236312,1.4357,-2.1993,0.193776,1.35221,-1.82117,-0.003734,1.42344,-1.86145,-0.005933,1.45652,-1.91556,-0.013667,1.436,-1.97305,0.174817,1.40042,-2.07955,0.237655,1.06522,-1.75301,0.110594,1.01664,-1.77941,0.140176,0.938886,-1.7987,0.223681,0.864025,-1.77595,0.07388,0.83081,-1.76015,-0.00165,0.830901,-1.76655,0.073569,0.940227,-1.79023,0.002817,0.94061,-1.78884,-0.227678,0.896771,-1.77829,-0.285641,0.99142,-1.86076,-0.289047,0.738281,-1.80495,-0.339318,0.775004,-1.73736,0.217958,1.11554,-2.14012,0.256391,1.03952,-2.12411,0.098198,1.05869,-2.0799,0.135022,0.989435,-2.06727,0.250368,0.883355,-2.07646,0.239136,0.693185,-2.05649,0.13127,0.724709,-2.06643,0.113513,0.658815,-2.04967,0.080825,0.43247,-1.99484,-0.019786,0.363203,-1.93591,0.26418,0.377438,-1.98131,0.21001,0.341417,-2.04365,0.115454,1.26842,-1.84476,0.092159,1.3057,-2.05546},
/*490*/{0.247879,1.84935,-1.7439,0.300551,1.78951,-1.90441,0.145041,1.71557,-1.64362,0.0627,1.62204,-1.57962,0.192918,1.55929,-1.65398,0.26827,1.516,-1.67847,0.196147,1.85644,-2.14143,0.295251,1.79082,-1.98191,0.073003,1.83577,-2.03188,0.013428,1.64837,-2.20407,0.029074,1.55353,-2.23703,0.197789,1.47937,-2.18548,0.247696,1.43607,-2.19736,0.192923,1.3511,-1.82126,-0.00416,1.42418,-1.86148,-0.006773,1.45656,-1.91583,-0.013744,1.43603,-1.97255,0.174785,1.4002,-2.07998,0.244729,1.06884,-1.75317,0.120066,1.01917,-1.77758,0.151027,0.940624,-1.79707,0.237135,0.866262,-1.77623,0.087267,0.830275,-1.76131,0.011186,0.829776,-1.7678,0.085193,0.94064,-1.78947,0.013618,0.939963,-1.78819,-0.212985,0.890688,-1.77755,-0.278121,0.984481,-1.85992,-0.26958,0.73157,-1.8051,-0.32007,0.765625,-1.73646,0.212786,1.11066,-2.14167,0.248465,1.03522,-2.12531,0.090772,1.05856,-2.08074,0.127128,0.987584,-2.06803,0.239171,0.879317,-2.07792,0.225421,0.688062,-2.05662,0.118335,0.721972,-2.06771,0.098984,0.656418,-2.05061,0.057956,0.432164,-1.99646,-0.040931,0.36331,-1.93723,0.242442,0.377132,-1.98301,0.187787,0.340944,-2.04563,0.114262,1.26794,-1.84506,0.091293,1.30571,-2.0557},
/*491*/{0.247118,1.84901,-1.74301,0.300718,1.78889,-1.9032,0.139001,1.71758,-1.6439,0.055335,1.62641,-1.58216,0.18517,1.55929,-1.65285,0.260271,1.51555,-1.67686,0.197934,1.85574,-2.14106,0.294938,1.78992,-1.98094,0.073989,1.8357,-2.03246,0.0209,1.6454,-2.20531,0.038368,1.55099,-2.238,0.208357,1.47941,-2.18418,0.259317,1.43835,-2.19504,0.189963,1.35025,-1.81963,-0.004912,1.42498,-1.86197,-0.007551,1.45674,-1.91669,-0.014734,1.43613,-1.97386,0.173411,1.3992,-2.08056,0.250897,1.07366,-1.75348,0.128103,1.01964,-1.77606,0.161234,0.942042,-1.79621,0.2516,0.870579,-1.77538,0.100273,0.831525,-1.76119,0.025054,0.8286,-1.76804,0.096485,0.941315,-1.78764,0.025193,0.939603,-1.78725,-0.203662,0.889099,-1.77946,-0.27118,0.976481,-1.85886,-0.249805,0.722848,-1.80655,-0.299302,0.753815,-1.73698,0.206639,1.10734,-2.14222,0.240632,1.03108,-2.12625,0.083261,1.05809,-2.08108,0.117894,0.986523,-2.06938,0.227174,0.875121,-2.0795,0.21135,0.682307,-2.056,0.105174,0.719612,-2.06848,0.086131,0.652039,-2.05058,0.040248,0.434217,-1.99737,-0.062659,0.363344,-1.93855,0.221071,0.376188,-1.98297,0.166006,0.340385,-2.04657,0.111355,1.26774,-1.84465,0.089676,1.30494,-2.05554},
/*492*/{0.245319,1.84918,-1.74247,0.298802,1.78809,-1.90229,0.133923,1.72034,-1.64448,0.046629,1.62996,-1.58428,0.177674,1.56104,-1.65198,0.25183,1.51627,-1.67432,0.200477,1.85558,-2.1404,0.295148,1.78973,-1.97951,0.074968,1.8358,-2.03288,0.026592,1.64347,-2.20595,0.047061,1.5485,-2.23869,0.218504,1.47999,-2.18206,0.27023,1.44123,-2.19262,0.188863,1.35053,-1.81849,-0.00577,1.42518,-1.86258,-0.008717,1.45711,-1.91703,-0.015424,1.437,-1.97492,0.173411,1.3992,-2.08056,0.257423,1.07805,-1.75343,0.137486,1.02163,-1.77535,0.172,0.945045,-1.79487,0.265683,0.873582,-1.77565,0.114021,0.832491,-1.76119,0.039089,0.828383,-1.76879,0.10702,0.942033,-1.78654,0.034624,0.938862,-1.78639,-0.18596,0.877874,-1.78071,-0.264131,0.966539,-1.85813,-0.22944,0.714323,-1.80756,-0.277903,0.742934,-1.73658,0.200472,1.10515,-2.1427,0.232781,1.02727,-2.12679,0.075321,1.05836,-2.08271,0.109797,0.983478,-2.06924,0.21453,0.870235,-2.08017,0.197039,0.677019,-2.05509,0.091371,0.717016,-2.0695,0.071128,0.649612,-2.0514,0.018261,0.434154,-1.99956,-0.083522,0.364424,-1.93847,0.199702,0.375692,-1.98446,0.145378,0.340665,-2.04711,0.110024,1.26814,-1.84445,0.089472,1.30514,-2.05548},
/*493*/{0.242546,1.85037,-1.74123,0.297618,1.78835,-1.90044,0.127784,1.7239,-1.64516,0.038191,1.6344,-1.58642,0.170255,1.56354,-1.65117,0.244437,1.51706,-1.67262,0.203247,1.85596,-2.13971,0.29545,1.78988,-1.97853,0.075412,1.83595,-2.03362,0.033969,1.64157,-2.20812,0.055725,1.54744,-2.2393,0.228246,1.48373,-2.18005,0.281045,1.44591,-2.18975,0.187032,1.35112,-1.81729,-0.007663,1.42602,-1.863,-0.009411,1.45717,-1.9175,-0.015927,1.43713,-1.97573,0.171072,1.39757,-2.0813,0.263758,1.08605,-1.75363,0.146112,1.02319,-1.77376,0.181917,0.948791,-1.79375,0.277279,0.87903,-1.77679,0.127097,0.833214,-1.76298,0.052337,0.827566,-1.77,0.116324,0.943387,-1.78693,0.045359,0.937981,-1.78543,-0.173871,0.868928,-1.78157,-0.256936,0.955619,-1.8575,-0.20848,0.705619,-1.80963,-0.257945,0.730735,-1.73672,0.194464,1.10281,-2.14259,0.224504,1.02343,-2.12734,0.068582,1.05894,-2.08343,0.100017,0.983648,-2.0708,0.201335,0.865514,-2.08075,0.181864,0.67249,-2.05473,0.077029,0.715017,-2.07066,0.055836,0.646904,-2.05157,-0.002798,0.434645,-2.00034,-0.104622,0.366456,-1.94007,0.177651,0.375549,-1.98499,0.123767,0.340285,-2.04777,0.107907,1.26874,-1.84336,0.087557,1.3039,-2.05472},
/*494*/{0.240161,1.8523,-1.74112,0.297203,1.78881,-1.89932,0.121801,1.72767,-1.64589,0.030768,1.63952,-1.58846,0.162514,1.56672,-1.65102,0.235906,1.51934,-1.67127,0.204663,1.85711,-2.13969,0.295343,1.7908,-1.97673,0.076883,1.83669,-2.03473,0.0393,1.64091,-2.2089,0.063448,1.54638,-2.24005,0.238764,1.48794,-2.17779,0.291557,1.4516,-2.18638,0.184893,1.35223,-1.81608,-0.008144,1.42624,-1.86418,-0.009943,1.45761,-1.91824,-0.015679,1.43778,-1.97724,0.172861,1.39748,-2.08087,0.269854,1.0918,-1.75284,0.153894,1.02502,-1.77289,0.192057,0.952661,-1.7932,0.289836,0.885174,-1.77654,0.14039,0.835152,-1.76369,0.064998,0.826553,-1.77057,0.126658,0.945031,-1.78447,0.054638,0.937191,-1.78547,-0.160351,0.859792,-1.78291,-0.250022,0.943281,-1.85761,-0.186405,0.696818,-1.81029,-0.23604,0.718664,-1.73697,0.188327,1.10053,-2.14277,0.215502,1.02018,-2.12803,0.061878,1.05913,-2.08456,0.090875,0.983511,-2.07201,0.187481,0.861145,-2.08176,0.165224,0.670529,-2.0541,0.061932,0.713284,-2.07095,0.037085,0.650659,-2.05434,-0.023696,0.436566,-2.00047,-0.125912,0.366773,-1.94347,0.156759,0.375328,-1.98578,0.101962,0.340207,-2.04823,0.106698,1.26943,-1.84287,0.088753,1.30406,-2.05454},
/*495*/{0.236811,1.85444,-1.74032,0.296422,1.79006,-1.8975,0.115215,1.7324,-1.64638,0.021665,1.64407,-1.59058,0.154983,1.56995,-1.64972,0.228447,1.52243,-1.66935,0.207384,1.85889,-2.139,0.29573,1.79159,-1.97506,0.077453,1.83708,-2.03591,0.044696,1.63947,-2.20938,0.071694,1.54659,-2.2405,0.247301,1.49337,-2.17513,0.301126,1.45826,-2.18246,0.184419,1.35425,-1.81579,-0.009214,1.42741,-1.8663,-0.010116,1.45812,-1.91905,-0.016889,1.43923,-1.9795,0.172896,1.39718,-2.08072,0.275618,1.09938,-1.75239,0.160008,1.02859,-1.77193,0.201289,0.957572,-1.79346,0.301611,0.890938,-1.77644,0.153642,0.836922,-1.76427,0.07866,0.825295,-1.77235,0.135046,0.945886,-1.78347,0.064793,0.934901,-1.78346,-0.149701,0.852301,-1.7852,-0.242516,0.929692,-1.85714,-0.164839,0.687084,-1.8112,-0.214198,0.706177,-1.73714,0.181373,1.09802,-2.14304,0.206889,1.01734,-2.12792,0.053781,1.06076,-2.08585,0.080443,0.983283,-2.07326,0.172621,0.856671,-2.0819,0.150088,0.668658,-2.05407,0.046284,0.712898,-2.07088,0.020917,0.650671,-2.05483,-0.048683,0.435132,-2.00019,-0.144699,0.367091,-1.94005,0.135361,0.375469,-1.98684,0.081365,0.340783,-2.04888,0.105836,1.2711,-1.84255,0.088873,1.30414,-2.05456},
/*496*/{0.233922,1.85711,-1.73924,0.296773,1.79221,-1.89515,0.109945,1.73675,-1.64694,0.013882,1.64993,-1.59236,0.147853,1.57508,-1.64985,0.221012,1.52672,-1.66795,0.209674,1.86132,-2.13795,0.296181,1.79404,-1.97373,0.078469,1.83748,-2.03681,0.048717,1.63943,-2.2095,0.079511,1.54714,-2.24082,0.255495,1.49903,-2.17222,0.310832,1.46658,-2.17861,0.18304,1.3554,-1.81545,-0.010048,1.42779,-1.86765,-0.011258,1.45979,-1.92092,-0.016695,1.44007,-1.98017,0.172868,1.39699,-2.08079,0.280913,1.10685,-1.75216,0.168703,1.03483,-1.77194,0.211525,0.963157,-1.79234,0.312599,0.897782,-1.77699,0.166036,0.837929,-1.76527,0.091791,0.823963,-1.77139,0.143714,0.947591,-1.78243,0.072942,0.933169,-1.78283,-0.135739,0.841353,-1.78535,-0.234327,0.915375,-1.85841,-0.143963,0.67712,-1.8123,-0.193438,0.693524,-1.73785,0.174574,1.09662,-2.14295,0.197324,1.015,-2.12752,0.045156,1.06267,-2.08617,0.070763,0.983344,-2.07312,0.156702,0.853634,-2.08185,0.133219,0.667614,-2.05294,0.030399,0.713725,-2.07134,0.004517,0.649631,-2.05497,-0.069131,0.435711,-2.00109,-0.167414,0.368022,-1.94456,0.11394,0.37606,-1.98657,0.059253,0.340517,-2.04929,0.104403,1.27216,-1.84245,0.088723,1.30437,-2.05468},
/*497*/{0.23028,1.86003,-1.73865,0.295463,1.79452,-1.89365,0.103748,1.74137,-1.64783,0.00707,1.65542,-1.59463,0.140704,1.57998,-1.64908,0.212702,1.53066,-1.66689,0.212126,1.86384,-2.13663,0.295751,1.79544,-1.97144,0.078521,1.83935,-2.0377,0.055512,1.6402,-2.20916,0.086168,1.54831,-2.24111,0.262817,1.50517,-2.16864,0.319463,1.47465,-2.17426,0.183102,1.3585,-1.8143,-0.010307,1.42955,-1.87012,-0.010082,1.46028,-1.92128,-0.016427,1.44096,-1.98198,0.173319,1.39713,-2.0807,0.285644,1.11346,-1.75198,0.174457,1.03851,-1.77224,0.220458,0.968271,-1.79201,0.323104,0.905028,-1.77689,0.178947,0.839447,-1.76582,0.106273,0.822986,-1.77276,0.151804,0.947491,-1.78165,0.081808,0.930541,-1.78249,-0.122863,0.830237,-1.78619,-0.225713,0.899293,-1.85916,-0.121473,0.666757,-1.81372,-0.172569,0.680817,-1.73906,0.167403,1.09497,-2.14175,0.188713,1.0131,-2.12645,0.036732,1.06456,-2.08718,0.059253,0.985837,-2.0745,0.140744,0.852649,-2.08177,0.115198,0.667711,-2.05277,0.013396,0.714559,-2.07095,-0.012691,0.651897,-2.05479,-0.090485,0.437657,-2.00072,-0.189129,0.371913,-1.94247,0.092887,0.375723,-1.9875,0.038441,0.340731,-2.04967,0.104782,1.27456,-1.84138,0.090039,1.30443,-2.05402},
/*498*/{0.22683,1.86303,-1.73788,0.294912,1.79774,-1.89172,0.098209,1.74616,-1.64843,-0.000565,1.661,-1.59699,0.132373,1.58533,-1.65001,0.205571,1.53505,-1.66567,0.213896,1.86747,-2.13583,0.295934,1.7986,-1.96917,0.079939,1.84026,-2.03935,0.059516,1.64083,-2.20937,0.09387,1.54985,-2.24141,0.269053,1.51221,-2.16576,0.328383,1.48369,-2.16946,0.182085,1.36023,-1.81363,-0.010642,1.4309,-1.8711,-0.009982,1.46306,-1.92271,-0.015894,1.44343,-1.98365,0.173451,1.39712,-2.08072,0.290288,1.12214,-1.75209,0.180649,1.04322,-1.77271,0.228379,0.973524,-1.79275,0.333246,0.913287,-1.77708,0.191103,0.841271,-1.76605,0.118243,0.820407,-1.77531,0.159,0.94786,-1.78126,0.089715,0.927473,-1.78235,-0.112563,0.822413,-1.78711,-0.216422,0.882801,-1.86054,-0.098884,0.656963,-1.81381,-0.151159,0.667727,-1.73936,0.160291,1.0942,-2.1413,0.17866,1.01159,-2.126,0.028217,1.06662,-2.08744,0.049043,0.987612,-2.07451,0.124793,0.853338,-2.08172,0.098203,0.666554,-2.05186,-0.003925,0.716604,-2.0699,-0.031911,0.653536,-2.05447,-0.106892,0.441658,-2.00183,-0.210252,0.373772,-1.9442,0.072112,0.375653,-1.98753,0.017261,0.340308,-2.04994,0.103205,1.27643,-1.84112,0.089835,1.30531,-2.05399},
/*499*/{0.22303,1.86655,-1.737,0.293282,1.8001,-1.88913,0.092154,1.75139,-1.64911,-0.008123,1.66622,-1.59888,0.126126,1.5901,-1.64957,0.198447,1.54009,-1.6637,0.215252,1.87033,-2.13505,0.296245,1.80146,-1.96761,0.081432,1.84152,-2.04033,0.063135,1.64221,-2.20872,0.100883,1.55233,-2.2424,0.277108,1.52122,-2.1624,0.335133,1.49431,-2.16521,0.181706,1.36321,-1.81322,-0.01068,1.43309,-1.87327,-0.008672,1.46484,-1.92393,-0.015378,1.44536,-1.98557,0.173744,1.39736,-2.08061,0.295355,1.12884,-1.74973,0.18705,1.04529,-1.77171,0.236911,0.980209,-1.79284,0.343189,0.921743,-1.77742,0.203641,0.842949,-1.76631,0.131655,0.819539,-1.77427,0.166046,0.948279,-1.78059,0.097785,0.92486,-1.78194,-0.097695,0.808283,-1.78917,-0.206442,0.865504,-1.86223,-0.077623,0.646109,-1.81472,-0.130073,0.654319,-1.7411,0.153353,1.0934,-2.13978,0.169059,1.01019,-2.12406,0.01958,1.07004,-2.08776,0.03712,0.989737,-2.07515,0.108414,0.853898,-2.08097,0.079092,0.668086,-2.05187,-0.021335,0.718229,-2.06926,-0.049409,0.655395,-2.05337,-0.127809,0.443431,-2.00219,-0.231067,0.376148,-1.94403,0.050743,0.375336,-1.98769,-0.004484,0.339973,-2.04971,0.1028,1.27906,-1.84055,0.090511,1.30596,-2.05375},
/*500*/{0.218449,1.86983,-1.73661,0.29401,1.80424,-1.88705,0.086691,1.75635,-1.64992,-0.014853,1.67262,-1.601,0.119239,1.59621,-1.64996,0.191092,1.54602,-1.66353,0.217655,1.87422,-2.13376,0.296602,1.80465,-1.96565,0.08145,1.84379,-2.04081,0.066849,1.6444,-2.20844,0.107197,1.55515,-2.24288,0.282644,1.52873,-2.15879,0.342395,1.50459,-2.16107,0.182373,1.36633,-1.81311,-0.010619,1.436,-1.87509,-0.009662,1.46738,-1.92528,-0.013787,1.44736,-1.98665,0.174122,1.39767,-2.08054,0.298725,1.13573,-1.75012,0.194818,1.05221,-1.77277,0.243747,0.986226,-1.79369,0.353195,0.931408,-1.778,0.215411,0.84406,-1.76711,0.144344,0.817781,-1.77568,0.173343,0.947599,-1.77925,0.105332,0.921024,-1.78158,-0.082648,0.795493,-1.79152,-0.19513,0.847511,-1.86482,-0.055312,0.635634,-1.81522,-0.108141,0.641114,-1.74237,0.146175,1.09249,-2.13815,0.159633,1.0096,-2.1224,0.010745,1.07322,-2.08835,0.026968,0.992655,-2.07478,0.093255,0.855676,-2.08012,0.060577,0.669525,-2.05124,-0.03983,0.721183,-2.06857,-0.068167,0.65767,-2.05261,-0.148177,0.447263,-2.00162,-0.250952,0.380405,-1.9443,0.028881,0.375018,-1.98706,-0.025921,0.340993,-2.04996,0.102673,1.28218,-1.83978,0.091005,1.30685,-2.05327},
/*501*/{0.215257,1.87384,-1.73628,0.293555,1.80737,-1.88563,0.081695,1.76167,-1.6505,-0.023182,1.67884,-1.60341,0.112338,1.6023,-1.6513,0.184469,1.55145,-1.6625,0.219475,1.87857,-2.13273,0.297762,1.80815,-1.96316,0.082736,1.84618,-2.0413,0.070578,1.64612,-2.20777,0.114648,1.55836,-2.2436,0.288611,1.53745,-2.15533,0.34923,1.51477,-2.15628,0.18182,1.37015,-1.81322,-0.010453,1.43914,-1.87619,-0.009006,1.46961,-1.92626,-0.013103,1.45046,-1.98782,0.174993,1.39884,-2.0808,0.303083,1.14351,-1.75026,0.199601,1.05695,-1.77359,0.251066,0.992129,-1.79528,0.36176,0.941274,-1.77799,0.22641,0.845879,-1.76717,0.157633,0.816097,-1.77555,0.179575,0.947562,-1.78032,0.113556,0.917562,-1.78136,-0.069399,0.784124,-1.79058,-0.183987,0.828473,-1.8681,-0.031835,0.625663,-1.81558,-0.086147,0.627884,-1.74343,0.139484,1.09231,-2.13706,0.150023,1.00909,-2.12003,0.004092,1.07703,-2.08801,0.015972,0.995766,-2.07369,0.078082,0.857073,-2.07809,0.043209,0.671911,-2.05049,-0.056256,0.724352,-2.06701,-0.085304,0.661728,-2.05227,-0.163523,0.450803,-2.00201,-0.271398,0.384439,-1.94452,0.008152,0.375584,-1.98713,-0.047349,0.34078,-2.05041,0.102457,1.28555,-1.83929,0.091555,1.3086,-2.05301},
/*502*/{0.21078,1.87795,-1.73557,0.29133,1.81196,-1.88261,0.07616,1.76691,-1.65133,-0.029207,1.68512,-1.60541,0.105991,1.60865,-1.65139,0.17786,1.55718,-1.66187,0.22086,1.88266,-2.13173,0.298267,1.81223,-1.96084,0.084248,1.8487,-2.04267,0.075943,1.64906,-2.20744,0.120904,1.56205,-2.24396,0.293997,1.54648,-2.15178,0.35451,1.52566,-2.15156,0.182328,1.37387,-1.81322,-0.010063,1.44245,-1.8774,-0.006354,1.47285,-1.92859,-0.011054,1.45284,-1.98923,0.176093,1.39936,-2.08104,0.305599,1.15037,-1.74984,0.203911,1.06258,-1.77436,0.256777,0.998004,-1.79496,0.369452,0.950493,-1.77803,0.237449,0.847789,-1.76696,0.170153,0.813317,-1.77633,0.185612,0.946307,-1.77894,0.121611,0.912357,-1.78239,-0.056602,0.771656,-1.7923,-0.171904,0.81006,-1.87052,-0.009207,0.615261,-1.81623,-0.064307,0.614824,-1.74461,0.13297,1.0928,-2.13447,0.141548,1.00916,-2.11762,-0.004643,1.08133,-2.08861,0.006118,0.999847,-2.0748,0.064003,0.859078,-2.07602,0.02635,0.67536,-2.04979,-0.072781,0.727836,-2.06602,-0.102904,0.664993,-2.05144,-0.187728,0.45438,-2.00165,-0.291036,0.392013,-1.94451,-0.013092,0.375405,-1.98712,-0.068854,0.34051,-2.04838,0.102733,1.28915,-1.83856,0.092709,1.30975,-2.05258},
/*503*/{0.207515,1.88285,-1.73503,0.29255,1.8144,-1.88078,0.071103,1.7723,-1.65234,-0.034491,1.69195,-1.60721,0.099662,1.61457,-1.65193,0.170842,1.56334,-1.66181,0.223945,1.8878,-2.13069,0.298615,1.81635,-1.95961,0.085307,1.85223,-2.04368,0.080348,1.65232,-2.20816,0.127067,1.56634,-2.24484,0.298969,1.55615,-2.14818,0.360202,1.53624,-2.14676,0.182863,1.3776,-1.81373,-0.00861,1.44619,-1.87913,-0.006491,1.47518,-1.92983,-0.009856,1.45629,-1.9912,0.17796,1.40021,-2.08087,0.307453,1.15879,-1.75012,0.207527,1.0685,-1.77517,0.261695,1.0043,-1.7965,0.376248,0.960094,-1.77887,0.248085,0.849432,-1.76709,0.182719,0.811291,-1.77624,0.189952,0.945651,-1.7801,0.12907,0.908839,-1.78289,-0.041221,0.758337,-1.79337,-0.158445,0.790335,-1.87269,0.014428,0.605731,-1.81652,-0.042114,0.601992,-1.74535,0.126702,1.09417,-2.13298,0.132323,1.00963,-2.11504,-0.010624,1.08578,-2.08849,-0.003688,1.00438,-2.07468,0.051064,0.861711,-2.07416,0.009622,0.678362,-2.04881,-0.089645,0.732004,-2.06536,-0.119586,0.669712,-2.05107,-0.201681,0.458785,-2.00149,-0.309836,0.397154,-1.94446,-0.034482,0.3756,-1.98669,-0.090224,0.340831,-2.04841,0.102961,1.2928,-1.8382,0.093868,1.31146,-2.05243},
/*504*/{0.204186,1.88624,-1.73432,0.291273,1.82088,-1.87961,0.066879,1.77813,-1.65277,-0.041705,1.69874,-1.6103,0.09318,1.62112,-1.65303,0.16512,1.56914,-1.66103,0.224997,1.89213,-2.12889,0.298933,1.82084,-1.95714,0.086443,1.85554,-2.04478,0.083609,1.65666,-2.20922,0.133921,1.57073,-2.24506,0.30281,1.56414,-2.14452,0.364475,1.54767,-2.14221,0.18499,1.38178,-1.81358,-0.006974,1.44953,-1.88016,-0.005131,1.47865,-1.93123,-0.007926,1.45983,-1.99205,0.178808,1.40079,-2.08095,0.310898,1.16514,-1.74942,0.213783,1.07379,-1.77491,0.268984,1.01178,-1.79626,0.38325,0.969983,-1.77906,0.258286,0.850901,-1.7677,0.19406,0.809592,-1.77679,0.195247,0.943921,-1.78052,0.13603,0.903862,-1.78409,-0.022742,0.745177,-1.79559,-0.143858,0.770359,-1.87473,0.038473,0.596385,-1.81681,-0.018313,0.589547,-1.74628,0.120329,1.09549,-2.12998,0.124185,1.01076,-2.11188,-0.018816,1.09069,-2.08888,-0.012956,1.0099,-2.07445,0.037207,0.864771,-2.07175,-0.007313,0.682596,-2.048,-0.105389,0.737491,-2.06478,-0.136177,0.674579,-2.05061,-0.220957,0.464793,-2.00275,-0.328052,0.406019,-1.9453,-0.055086,0.376508,-1.9864,-0.110902,0.341166,-2.04812,0.1041,1.29692,-1.83719,0.094821,1.31299,-2.05163},
/*505*/{0.201488,1.89064,-1.73384,0.291572,1.82447,-1.87707,0.062321,1.78352,-1.65422,-0.048433,1.70513,-1.6128,0.087581,1.62717,-1.65407,0.159133,1.57507,-1.66176,0.22657,1.89688,-2.12788,0.299543,1.82529,-1.95505,0.087677,1.8589,-2.04506,0.089181,1.66259,-2.21013,0.140246,1.5754,-2.24571,0.307069,1.57268,-2.14087,0.369147,1.55803,-2.13754,0.185031,1.38547,-1.81443,-0.006107,1.45436,-1.88054,-0.003512,1.48282,-1.93322,-0.005371,1.46313,-1.9929,0.180156,1.4016,-2.08175,0.313551,1.17192,-1.7492,0.217903,1.07955,-1.77498,0.272462,1.01784,-1.79763,0.387975,0.978344,-1.77878,0.26771,0.852132,-1.76762,0.206189,0.807457,-1.77739,0.200856,0.942082,-1.78057,0.141684,0.899147,-1.78642,-0.010787,0.732239,-1.79694,-0.12981,0.750568,-1.8788,0.063068,0.587546,-1.81776,0.006725,0.577133,-1.7475,0.11469,1.09631,-2.12785,0.116135,1.01254,-2.10923,-0.024785,1.09637,-2.08841,-0.0218,1.01471,-2.07448,0.024223,0.86948,-2.07025,-0.024051,0.686912,-2.04741,-0.121765,0.742821,-2.06397,-0.152757,0.681163,-2.05053,-0.242836,0.468728,-2.00177,-0.347878,0.413896,-1.94579,-0.076078,0.376333,-1.98561,-0.132102,0.341561,-2.04788,0.103878,1.30098,-1.83674,0.095078,1.31497,-2.05133},
/*506*/{0.198335,1.89477,-1.73402,0.290931,1.83037,-1.87583,0.058213,1.78946,-1.65521,-0.05329,1.71214,-1.61553,0.083326,1.63403,-1.65558,0.153392,1.58126,-1.66125,0.229361,1.90251,-2.12638,0.299409,1.82998,-1.95359,0.088975,1.86275,-2.04614,0.093015,1.66609,-2.21124,0.146525,1.58072,-2.24625,0.310011,1.58151,-2.13779,0.372325,1.5687,-2.13332,0.187226,1.38994,-1.81515,-0.004319,1.45913,-1.88094,-0.001468,1.48606,-1.93421,-0.003125,1.46686,-1.9946,0.182182,1.40219,-2.08198,0.315711,1.17935,-1.74925,0.219412,1.08219,-1.77372,0.276989,1.02434,-1.79789,0.392875,0.986952,-1.77873,0.277099,0.853485,-1.76705,0.218123,0.806227,-1.77778,0.205876,0.939699,-1.78201,0.150066,0.893133,-1.78718,0.005659,0.719562,-1.79946,-0.114199,0.730958,-1.88065,0.088713,0.579742,-1.818,0.031326,0.565277,-1.74865,0.109905,1.09759,-2.12454,0.1075,1.01376,-2.10635,-0.031034,1.10159,-2.08809,-0.030081,1.02025,-2.07378,0.009928,0.874424,-2.0689,-0.039365,0.692376,-2.04716,-0.136925,0.749309,-2.06318,-0.170623,0.686636,-2.04864,-0.264727,0.473252,-2.00166,-0.365617,0.42265,-1.94543,-0.096935,0.376932,-1.9863,-0.154191,0.342387,-2.0471,0.105321,1.30553,-1.8358,0.096341,1.31675,-2.05055},
/*507*/{0.195724,1.899,-1.73379,0.290191,1.83348,-1.87303,0.054366,1.79474,-1.6567,-0.058904,1.71895,-1.61835,0.077422,1.63971,-1.65616,0.147586,1.58664,-1.66124,0.231349,1.90765,-2.12503,0.301267,1.83441,-1.95052,0.091252,1.86556,-2.04718,0.097882,1.67245,-2.21268,0.152399,1.58587,-2.24703,0.313502,1.59194,-2.1347,0.376852,1.57783,-2.12845,0.188337,1.39408,-1.8158,-0.002479,1.46336,-1.8826,0.000516,1.4897,-1.93655,-0.000738,1.46985,-1.99485,0.183195,1.40309,-2.0822,0.318494,1.18656,-1.74924,0.224825,1.09034,-1.77265,0.280808,1.03104,-1.79767,0.395655,0.993664,-1.77877,0.286423,0.854678,-1.76764,0.231666,0.804941,-1.77821,0.210638,0.936981,-1.78345,0.158541,0.888395,-1.78855,0.022074,0.706311,-1.8006,-0.097637,0.709598,-1.88235,0.112153,0.571111,-1.81958,0.056728,0.554003,-1.7497,0.104135,1.09971,-2.12226,0.099621,1.01586,-2.10385,-0.03716,1.10791,-2.08822,-0.038762,1.02642,-2.07403,-0.00439,0.879445,-2.06843,-0.054301,0.697516,-2.0472,-0.151521,0.755573,-2.06275,-0.18505,0.695879,-2.04912,-0.277275,0.481089,-2.00482,-0.383811,0.432348,-1.94539,-0.117467,0.378576,-1.98613,-0.175458,0.343315,-2.04679,0.10614,1.30982,-1.83516,0.097249,1.31845,-2.05003},
/*508*/{0.193478,1.90357,-1.73364,0.290056,1.84009,-1.87245,0.049878,1.80013,-1.65855,-0.062882,1.72573,-1.62098,0.072419,1.64587,-1.65738,0.143307,1.59255,-1.66147,0.233492,1.91297,-2.12388,0.301224,1.83927,-1.94877,0.092197,1.86906,-2.04766,0.099827,1.67742,-2.21427,0.157796,1.59109,-2.24817,0.316149,1.59895,-2.13102,0.378635,1.5878,-2.12358,0.189302,1.39712,-1.81726,-0.000354,1.46833,-1.88274,0.002007,1.49431,-1.93887,0.002262,1.47332,-1.99587,0.185339,1.40379,-2.08247,0.319579,1.19364,-1.74983,0.229614,1.09719,-1.77369,0.28404,1.03767,-1.79714,0.397375,1.00027,-1.77919,0.295452,0.85483,-1.76809,0.239547,0.802317,-1.77722,0.215741,0.93397,-1.78371,0.164811,0.881918,-1.79015,0.038592,0.692661,-1.80206,-0.079065,0.688345,-1.88529,0.137268,0.563054,-1.81954,0.082312,0.543083,-1.75101,0.09873,1.10177,-2.11993,0.092535,1.01842,-2.10089,-0.041493,1.11409,-2.0878,-0.046678,1.03207,-2.07304,-0.018463,0.884537,-2.06769,-0.070635,0.703997,-2.04699,-0.166481,0.762531,-2.06255,-0.200193,0.703236,-2.04949,-0.290024,0.489615,-2.0041,-0.399017,0.442676,-1.94511,-0.14176,0.37632,-1.98458,-0.196426,0.343624,-2.04705,0.106355,1.31374,-1.83499,0.09784,1.32061,-2.04995},
/*509*/{0.190989,1.9079,-1.73344,0.289533,1.84391,-1.86979,0.046857,1.80642,-1.66022,-0.06783,1.73213,-1.62459,0.067405,1.65148,-1.6582,0.138342,1.5983,-1.66106,0.235707,1.91801,-2.12217,0.301518,1.8445,-1.94712,0.09387,1.8724,-2.04832,0.104133,1.68241,-2.21522,0.163632,1.59618,-2.24866,0.318581,1.60702,-2.12766,0.381177,1.59654,-2.12071,0.19106,1.40121,-1.81719,0.001584,1.47253,-1.88288,0.004819,1.49709,-1.94013,0.004605,1.47704,-1.99665,0.187419,1.40454,-2.08234,0.320687,1.20022,-1.74965,0.231418,1.10287,-1.77365,0.287177,1.04367,-1.79709,0.399168,1.00644,-1.78017,0.303159,0.855381,-1.76779,0.253765,0.799745,-1.77863,0.219947,0.929867,-1.78597,0.172968,0.876178,-1.79053,0.058897,0.680446,-1.80395,-0.0611,0.668247,-1.8862,0.163252,0.555689,-1.82016,0.108029,0.532387,-1.75217,0.093554,1.1036,-2.11749,0.084179,1.02152,-2.0985,-0.046516,1.12155,-2.08768,-0.053629,1.03972,-2.07252,-0.031192,0.890371,-2.06715,-0.085263,0.710695,-2.04747,-0.180372,0.77037,-2.06182,-0.215444,0.710719,-2.04931,-0.306522,0.496061,-2.00447,-0.416548,0.454647,-1.9445,-0.163179,0.376734,-1.98388,-0.219198,0.343699,-2.04576,0.107714,1.31789,-1.83389,0.099358,1.32242,-2.04892},
/*510*/{0.189193,1.91235,-1.73332,0.28845,1.84869,-1.86852,0.043207,1.81193,-1.66206,-0.070945,1.73872,-1.62738,0.06334,1.65719,-1.65996,0.134133,1.60347,-1.66168,0.236656,1.92254,-2.12077,0.301766,1.84892,-1.94548,0.095093,1.87656,-2.04907,0.107674,1.68757,-2.21653,0.168878,1.60164,-2.24914,0.320395,1.61518,-2.12496,0.383738,1.606,-2.11663,0.193698,1.406,-1.818,0.003214,1.47801,-1.88354,0.0064,1.50121,-1.94201,0.006402,1.48029,-1.99731,0.189595,1.40515,-2.0819,0.322662,1.20642,-1.74947,0.232037,1.1088,-1.77376,0.288901,1.04955,-1.79707,0.400647,1.01258,-1.78034,0.312026,0.855474,-1.76859,0.266323,0.798284,-1.77974,0.224124,0.925481,-1.78729,0.180807,0.868996,-1.7927,0.075639,0.665661,-1.80494,-0.041122,0.648161,-1.88867,0.188302,0.548948,-1.82163,0.135582,0.522891,-1.7531,0.089162,1.10614,-2.11537,0.076979,1.02422,-2.09593,-0.051581,1.12772,-2.08723,-0.061502,1.047,-2.0724,-0.043254,0.8967,-2.06679,-0.099556,0.717969,-2.04838,-0.194636,0.777906,-2.0618,-0.228659,0.718816,-2.04956,-0.320266,0.502257,-2.00622,-0.430954,0.466183,-1.94428,-0.185068,0.377485,-1.98377,-0.242039,0.344403,-2.04569,0.109222,1.32323,-1.83248,0.100511,1.32425,-2.04754},
/*511*/{0.187345,1.91574,-1.7329,0.28769,1.85408,-1.86797,0.04048,1.81707,-1.66369,-0.075862,1.7446,-1.63142,0.058851,1.66188,-1.66081,0.129888,1.60875,-1.66117,0.238074,1.92715,-2.11887,0.301002,1.85343,-1.94358,0.095897,1.87979,-2.04985,0.112615,1.69245,-2.21754,0.174172,1.60704,-2.24963,0.322085,1.62235,-2.1221,0.385886,1.61501,-2.11379,0.194737,1.40982,-1.81868,0.004764,1.48297,-1.88404,0.008047,1.50505,-1.94294,0.009731,1.48312,-1.99768,0.191548,1.4062,-2.08143,0.324378,1.21122,-1.74908,0.236165,1.11442,-1.77218,0.290634,1.0557,-1.79673,0.400542,1.01741,-1.78108,0.320575,0.854888,-1.76881,0.27595,0.794528,-1.77988,0.229992,0.920473,-1.78824,0.188484,0.861414,-1.79455,0.096367,0.65352,-1.80634,-0.021139,0.628283,-1.88968,0.214319,0.543072,-1.82359,0.162925,0.5127,-1.75511,0.084502,1.10876,-2.114,0.068847,1.02718,-2.09402,-0.055114,1.13608,-2.08657,-0.068586,1.05478,-2.07179,-0.05492,0.903842,-2.06695,-0.112425,0.725382,-2.04939,-0.208893,0.78522,-2.06163,-0.242702,0.724711,-2.04841,-0.335823,0.509848,-2.00707,-0.443784,0.478598,-1.94201,-0.20637,0.377662,-1.98371,-0.263386,0.345377,-2.04515,0.110001,1.32749,-1.83148,0.101667,1.32634,-2.04655},
/*512*/{0.185534,1.91964,-1.7332,0.287232,1.85759,-1.86601,0.036912,1.82269,-1.66581,-0.080752,1.75042,-1.63443,0.055665,1.66681,-1.66184,0.125975,1.61318,-1.66127,0.24051,1.932,-2.11802,0.301487,1.85801,-1.94201,0.097521,1.88293,-2.0506,0.116986,1.69718,-2.21944,0.178988,1.61165,-2.25046,0.323732,1.62953,-2.11915,0.38805,1.62292,-2.11014,0.195913,1.4137,-1.81899,0.007306,1.48666,-1.88393,0.010278,1.50942,-1.94468,0.01216,1.48706,-1.99828,0.19373,1.40709,-2.08091,0.326764,1.21599,-1.74894,0.236205,1.11897,-1.77097,0.29168,1.06036,-1.79527,0.399659,1.0218,-1.78153,0.327828,0.854191,-1.76903,0.286456,0.791372,-1.78013,0.234658,0.914255,-1.78959,0.195167,0.853956,-1.79606,0.113321,0.638686,-1.80714,-0.000344,0.608789,-1.89124,0.239782,0.537084,-1.82508,0.189082,0.502966,-1.75738,0.080092,1.11179,-2.11243,0.061245,1.03021,-2.09191,-0.059295,1.14185,-2.0861,-0.074774,1.06298,-2.07161,-0.066723,0.911254,-2.06699,-0.125208,0.733719,-2.05091,-0.221673,0.793857,-2.06186,-0.256207,0.732033,-2.04817,-0.350713,0.516384,-2.00869,-0.45552,0.492487,-1.94178,-0.227721,0.377776,-1.98461,-0.28553,0.34648,-2.04497,0.110827,1.33165,-1.83066,0.102868,1.32862,-2.04573},
/*513*/{0.18358,1.92293,-1.73361,0.286032,1.86225,-1.86533,0.034063,1.8276,-1.66776,-0.084046,1.75578,-1.63839,0.052061,1.67122,-1.66272,0.122697,1.61761,-1.6613,0.241639,1.93635,-2.11638,0.301217,1.86202,-1.94067,0.098338,1.88628,-2.05178,0.121426,1.70123,-2.22098,0.183637,1.61703,-2.25129,0.325911,1.6363,-2.11654,0.389558,1.6306,-2.10635,0.197864,1.41809,-1.81858,0.009782,1.49136,-1.88385,0.013765,1.51227,-1.94592,0.015478,1.48942,-1.9989,0.19569,1.40797,-2.0806,0.327942,1.22143,-1.74903,0.235813,1.12357,-1.77087,0.291013,1.06546,-1.79536,0.398232,1.02596,-1.7822,0.33555,0.85322,-1.7691,0.298229,0.787845,-1.78039,0.238758,0.908344,-1.79128,0.203621,0.84557,-1.79725,0.133538,0.625633,-1.80743,0.021113,0.589156,-1.89195,0.265666,0.531144,-1.82634,0.216879,0.494307,-1.75894,0.075991,1.11416,-2.11127,0.054839,1.03327,-2.09035,-0.063088,1.15014,-2.08606,-0.080766,1.07107,-2.07082,-0.076986,0.919312,-2.06747,-0.138817,0.741519,-2.05243,-0.234115,0.801789,-2.06159,-0.267648,0.740573,-2.04801,-0.36439,0.523056,-2.01109,-0.46702,0.507308,-1.94267,-0.248824,0.377971,-1.9854,-0.309175,0.348522,-2.04474,0.112828,1.33618,-1.82907,0.10485,1.33016,-2.04407},
/*514*/{0.182359,1.92673,-1.7335,0.286307,1.8663,-1.86359,0.031974,1.83255,-1.6693,-0.087507,1.76112,-1.64162,0.04899,1.67625,-1.66428,0.119785,1.62147,-1.66135,0.243023,1.94037,-2.11481,0.300465,1.86681,-1.93927,0.100023,1.88878,-2.05201,0.125756,1.70581,-2.22233,0.187596,1.62178,-2.2524,0.327142,1.64255,-2.11467,0.390925,1.63742,-2.10343,0.1995,1.42178,-1.81909,0.01124,1.49603,-1.8845,0.014871,1.5158,-1.94754,0.017452,1.49301,-1.99973,0.197514,1.40891,-2.07955,0.328187,1.22566,-1.74895,0.235259,1.12843,-1.76982,0.291636,1.06913,-1.79374,0.396369,1.02901,-1.78276,0.342623,0.851347,-1.76937,0.308646,0.783713,-1.78076,0.244082,0.901532,-1.79311,0.211541,0.837057,-1.79863,0.154089,0.613368,-1.80896,0.043605,0.571546,-1.89296,0.290168,0.526594,-1.82825,0.245114,0.485754,-1.76018,0.071927,1.11669,-2.10968,0.048836,1.03582,-2.08897,-0.064497,1.15677,-2.08558,-0.085804,1.07932,-2.07063,-0.086632,0.92779,-2.06812,-0.148444,0.750232,-2.05481,-0.245499,0.809023,-2.06177,-0.278367,0.748669,-2.04868,-0.375081,0.530229,-2.01294,-0.47646,0.522037,-1.94253,-0.268111,0.378127,-1.98697,-0.330327,0.350433,-2.04428,0.113416,1.34057,-1.82816,0.105788,1.33228,-2.0431},
/*515*/{0.181605,1.92948,-1.73324,0.285886,1.86996,-1.86243,0.029931,1.83686,-1.67131,-0.089517,1.76551,-1.64531,0.04587,1.6802,-1.6655,0.116541,1.62502,-1.66112,0.243965,1.94379,-2.11375,0.30132,1.86907,-1.93756,0.10112,1.89206,-2.0523,0.129804,1.71011,-2.22385,0.192758,1.62598,-2.25262,0.327826,1.64798,-2.11264,0.392175,1.6431,-2.10015,0.199983,1.42596,-1.81848,0.013535,1.4996,-1.88517,0.017255,1.51939,-1.94826,0.019773,1.49622,-2.0004,0.19933,1.41009,-2.07829,0.330157,1.22894,-1.74968,0.233307,1.13027,-1.7688,0.289992,1.07298,-1.79107,0.394738,1.03089,-1.78325,0.349401,0.849703,-1.76943,0.31816,0.779627,-1.78088,0.248541,0.89433,-1.7946,0.220445,0.828844,-1.79919,0.17336,0.602153,-1.81011,0.065946,0.553722,-1.89338,0.315444,0.521227,-1.8285,0.271588,0.478551,-1.76276,0.067963,1.11958,-2.10924,0.041867,1.04138,-2.08895,-0.066905,1.1643,-2.08555,-0.090014,1.08703,-2.07033,-0.097123,0.935603,-2.06916,-0.159064,0.758564,-2.05676,-0.255302,0.817598,-2.06187,-0.288542,0.756758,-2.04904,-0.386203,0.537605,-2.01464,-0.484336,0.537066,-1.9416,-0.286686,0.378799,-1.98849,-0.350015,0.354923,-2.04366,0.114032,1.34477,-1.82682,0.107282,1.33436,-2.0417},
/*516*/{0.181101,1.93216,-1.73321,0.285204,1.87137,-1.86137,0.027575,1.8412,-1.67386,-0.09389,1.76955,-1.64872,0.043084,1.68392,-1.66644,0.113335,1.62802,-1.66038,0.245769,1.94747,-2.11221,0.301323,1.87213,-1.93651,0.102344,1.89529,-2.05299,0.134546,1.71455,-2.2259,0.196372,1.63025,-2.25351,0.330298,1.65403,-2.11168,0.392858,1.64887,-2.09786,0.200244,1.42929,-1.81844,0.014742,1.50392,-1.88455,0.01956,1.52239,-1.94944,0.022031,1.49869,-2.00072,0.201366,1.41114,-2.07729,0.330189,1.23084,-1.75031,0.232565,1.13493,-1.76795,0.289907,1.07521,-1.78965,0.393044,1.03125,-1.78302,0.356641,0.847034,-1.76934,0.328307,0.776278,-1.781,0.252927,0.886442,-1.79534,0.227808,0.820017,-1.79927,0.192668,0.590388,-1.81075,0.088629,0.536598,-1.89324,0.339624,0.517422,-1.83031,0.299735,0.471182,-1.76476,0.065931,1.12207,-2.10932,0.036528,1.04459,-2.08848,-0.068174,1.17123,-2.08528,-0.094371,1.09381,-2.06988,-0.106481,0.944311,-2.0699,-0.169102,0.766096,-2.05922,-0.26475,0.825528,-2.0618,-0.297761,0.764545,-2.04984,-0.39566,0.546039,-2.01642,-0.491088,0.553581,-1.94259,-0.305433,0.378892,-1.99019,-0.371508,0.359814,-2.04273,0.114381,1.34848,-1.82562,0.108418,1.33627,-2.04043},
/*517*/{0.180615,1.93495,-1.73401,0.278764,1.87743,-1.86249,0.026336,1.84532,-1.67541,-0.095403,1.77404,-1.65224,0.040941,1.68708,-1.66758,0.110714,1.63117,-1.65991,0.247744,1.95116,-2.11123,0.300259,1.87587,-1.93581,0.103494,1.89732,-2.05366,0.138957,1.7187,-2.22771,0.200339,1.63432,-2.25422,0.331983,1.65845,-2.11042,0.394636,1.65364,-2.09549,0.201496,1.43266,-1.81872,0.01699,1.50773,-1.88516,0.021861,1.52551,-1.94957,0.024494,1.50145,-2.00097,0.203509,1.41212,-2.07664,0.330429,1.23338,-1.75164,0.231569,1.13837,-1.76661,0.286422,1.07765,-1.78918,0.390866,1.03036,-1.78395,0.362088,0.844147,-1.76992,0.338375,0.772319,-1.78091,0.258403,0.878222,-1.79631,0.235915,0.810118,-1.80185,0.215286,0.579166,-1.81122,0.111761,0.520212,-1.89384,0.363275,0.514598,-1.8319,0.326476,0.466183,-1.76628,0.063036,1.12524,-2.10952,0.032454,1.04893,-2.08962,-0.069223,1.17666,-2.08345,-0.097035,1.10038,-2.0687,-0.113607,0.952352,-2.07052,-0.176757,0.773722,-2.06076,-0.271992,0.834432,-2.06246,-0.306356,0.772829,-2.05079,-0.405153,0.554995,-2.01891,-0.497165,0.569353,-1.94267,-0.323321,0.379134,-1.99161,-0.39451,0.366263,-2.04308,0.115585,1.35213,-1.82472,0.10982,1.33823,-2.03943},
/*518*/{0.180244,1.93726,-1.73397,0.278113,1.87902,-1.86163,0.024213,1.84888,-1.67738,-0.097526,1.77756,-1.65566,0.038382,1.68959,-1.66841,0.108074,1.63387,-1.65959,0.248684,1.95383,-2.10986,0.300959,1.87886,-1.93441,0.104975,1.90039,-2.05496,0.142899,1.72303,-2.22973,0.203802,1.63795,-2.25522,0.332656,1.66165,-2.10882,0.395825,1.65741,-2.09289,0.20407,1.43562,-1.8184,0.018747,1.51035,-1.88568,0.022812,1.52862,-1.95089,0.026494,1.50457,-2.00131,0.20537,1.41377,-2.07577,0.330691,1.23456,-1.75281,0.228836,1.14213,-1.76711,0.284133,1.07931,-1.78807,0.389201,1.02974,-1.78398,0.368477,0.841245,-1.76978,0.348073,0.767712,-1.78094,0.262722,0.870734,-1.79768,0.243727,0.800645,-1.80238,0.233933,0.567487,-1.81181,0.134937,0.504148,-1.89388,0.388148,0.512319,-1.83479,0.352502,0.460267,-1.76845,0.060208,1.12877,-2.11033,0.028231,1.05162,-2.09056,-0.070543,1.18202,-2.08309,-0.099689,1.1058,-2.06872,-0.118745,0.958789,-2.07111,-0.184168,0.780583,-2.06249,-0.278154,0.842108,-2.06261,-0.313502,0.780882,-2.05319,-0.414283,0.564296,-2.02057,-0.502892,0.585956,-1.94315,-0.341413,0.378882,-1.99241,-0.415406,0.373739,-2.04118,0.117098,1.35546,-1.82421,0.111595,1.34039,-2.03885},
/*519*/{0.179836,1.93953,-1.73384,0.27782,1.88125,-1.86055,0.023374,1.85207,-1.6787,-0.100674,1.78022,-1.65902,0.037085,1.69281,-1.66955,0.10589,1.63587,-1.6596,0.249149,1.95661,-2.10844,0.301398,1.88144,-1.93384,0.106028,1.90291,-2.05545,0.147439,1.72666,-2.23086,0.207089,1.64113,-2.25581,0.333551,1.66516,-2.10828,0.396316,1.66102,-2.09133,0.20524,1.43836,-1.81815,0.019992,1.51437,-1.8858,0.024935,1.53142,-1.95052,0.028845,1.50702,-2.00159,0.205949,1.41578,-2.0752,0.331341,1.23474,-1.75345,0.229908,1.14162,-1.76693,0.283371,1.08001,-1.7866,0.386192,1.02764,-1.78352,0.374537,0.837538,-1.7693,0.358855,0.765456,-1.78049,0.267423,0.862287,-1.79943,0.252101,0.790977,-1.80349,0.254515,0.557491,-1.81216,0.157892,0.488986,-1.89325,0.409774,0.509746,-1.83556,0.379058,0.455212,-1.76934,0.057544,1.13158,-2.1113,0.025507,1.05638,-2.09302,-0.071891,1.18646,-2.08206,-0.101632,1.1102,-2.06806,-0.120852,0.962968,-2.07131,-0.189913,0.786305,-2.06401,-0.283387,0.849258,-2.06385,-0.31944,0.788944,-2.05386,-0.422121,0.574043,-2.02305,-0.508085,0.603251,-1.94526,-0.359075,0.37759,-1.99093,-0.435419,0.382951,-2.03893,0.117907,1.35868,-1.82352,0.112348,1.34271,-2.03809},
/*520*/{0.179607,1.94095,-1.73363,0.279435,1.88315,-1.86,0.022395,1.85398,-1.68096,-0.10122,1.78312,-1.66173,0.034661,1.69441,-1.67061,0.104582,1.63762,-1.65884,0.249624,1.95905,-2.10756,0.300977,1.88348,-1.93296,0.106896,1.90521,-2.05563,0.150904,1.72965,-2.23242,0.21013,1.6441,-2.25693,0.334887,1.66691,-2.10789,0.396981,1.66284,-2.08931,0.205583,1.44022,-1.81814,0.020771,1.51703,-1.8854,0.02591,1.53468,-1.95064,0.029909,1.51033,-2.0018,0.206944,1.41694,-2.07475,0.329713,1.23477,-1.75496,0.227142,1.14484,-1.76611,0.280073,1.0798,-1.78634,0.383432,1.02519,-1.78356,0.379019,0.833554,-1.76923,0.366702,0.759268,-1.77997,0.271393,0.852552,-1.79994,0.258957,0.781184,-1.80495,0.275096,0.546718,-1.81203,0.180937,0.475151,-1.89391,0.432273,0.507546,-1.83752,0.404494,0.451389,-1.77119,0.056351,1.1355,-2.11246,0.023858,1.05964,-2.0944,-0.0732,1.18989,-2.08114,-0.10318,1.11414,-2.06727,-0.121597,0.965816,-2.07109,-0.195092,0.79189,-2.06444,-0.286253,0.857641,-2.06519,-0.324362,0.796401,-2.05539,-0.429236,0.584633,-2.02503,-0.514375,0.620225,-1.94729,-0.377849,0.377225,-1.98954,-0.453171,0.392897,-2.03605,0.117589,1.36107,-1.82329,0.112334,1.34498,-2.03786},
/*521*/{0.179487,1.9426,-1.73386,0.278608,1.88486,-1.85918,0.021554,1.85618,-1.68323,-0.104123,1.78448,-1.66477,0.033288,1.69677,-1.6715,0.102266,1.63902,-1.65843,0.250148,1.9612,-2.10727,0.301596,1.88558,-1.93194,0.107903,1.90789,-2.05604,0.154629,1.73248,-2.23405,0.212881,1.64664,-2.25769,0.335105,1.66881,-2.10601,0.398017,1.66533,-2.08809,0.20722,1.44387,-1.81745,0.021881,1.51973,-1.88506,0.026824,1.53733,-1.95049,0.031304,1.51345,-2.00142,0.207852,1.41913,-2.0743,0.329119,1.23373,-1.75577,0.225069,1.14366,-1.76671,0.276226,1.07863,-1.78634,0.381156,1.02225,-1.78297,0.38387,0.829792,-1.76873,0.375613,0.755258,-1.78016,0.275517,0.842945,-1.80059,0.26696,0.771068,-1.80506,0.293068,0.537652,-1.81239,0.203669,0.462468,-1.89398,0.45311,0.505808,-1.83853,0.42829,0.448451,-1.77359,0.055556,1.13817,-2.11334,0.023467,1.0614,-2.09623,-0.073973,1.19242,-2.08017,-0.103856,1.11584,-2.06723,-0.120947,0.968157,-2.07128,-0.199114,0.794808,-2.06489,-0.289645,0.862124,-2.06672,-0.327952,0.803614,-2.05662,-0.438298,0.594798,-2.02631,-0.520304,0.63612,-1.95008,-0.401083,0.381682,-1.98791,-0.473031,0.403073,-2.0342,0.119052,1.36449,-1.82237,0.113511,1.34745,-2.03686},
/*522*/{0.17909,1.94408,-1.73357,0.278688,1.88683,-1.85878,0.021555,1.8577,-1.68395,-0.104004,1.78647,-1.66765,0.032044,1.69785,-1.67213,0.101489,1.64015,-1.65813,0.250573,1.96265,-2.10586,0.301292,1.88725,-1.93145,0.108359,1.90906,-2.05615,0.157776,1.73538,-2.23467,0.215006,1.64865,-2.25781,0.3361,1.67146,-2.10595,0.398749,1.66583,-2.08691,0.207024,1.44619,-1.8177,0.022184,1.52167,-1.88674,0.027931,1.53971,-1.95026,0.031643,1.51557,-2.00148,0.208247,1.42138,-2.0736,0.327524,1.23099,-1.75648,0.224856,1.14473,-1.76486,0.272735,1.07726,-1.78633,0.377026,1.01736,-1.7828,0.387645,0.825946,-1.76903,0.383145,0.750999,-1.78019,0.278825,0.834071,-1.80081,0.275017,0.761826,-1.80448,0.312491,0.53018,-1.81318,0.225868,0.450565,-1.89436,0.473325,0.504801,-1.83975,0.451268,0.445578,-1.77396,0.055349,1.14124,-2.11401,0.024161,1.06375,-2.09719,-0.074237,1.19462,-2.08016,-0.103418,1.11795,-2.06635,-0.119796,0.96936,-2.07095,-0.202519,0.798081,-2.06469,-0.291214,0.868312,-2.06798,-0.331622,0.810865,-2.05853,-0.447538,0.604655,-2.02867,-0.526474,0.652914,-1.95548,-0.419493,0.393816,-1.98338,-0.493152,0.415374,-2.03262,0.118985,1.36674,-1.82246,0.114062,1.34959,-2.03696},
/*523*/{0.1795,1.94474,-1.7332,0.286486,1.88432,-1.85577,0.021001,1.85914,-1.68525,-0.104647,1.7878,-1.67063,0.030271,1.69921,-1.67306,0.09987,1.64061,-1.65759,0.251186,1.96415,-2.1052,0.302972,1.88841,-1.93043,0.109218,1.9112,-2.05606,0.160642,1.73711,-2.23612,0.217043,1.65008,-2.25865,0.337638,1.67141,-2.10521,0.399332,1.66589,-2.0858,0.207856,1.44759,-1.81763,0.023076,1.52387,-1.88603,0.027648,1.54218,-1.9501,0.032512,1.51717,-2.00134,0.208695,1.42336,-2.07313,0.325462,1.22692,-1.75727,0.223819,1.14264,-1.7644,0.268635,1.07408,-1.78599,0.372435,1.01335,-1.7826,0.391226,0.822219,-1.76865,0.391045,0.746408,-1.78035,0.281856,0.824123,-1.80006,0.28104,0.752476,-1.80477,0.33038,0.520655,-1.81246,0.247161,0.439692,-1.8953,0.492351,0.504145,-1.83976,0.472563,0.44308,-1.7772,0.056733,1.14243,-2.11512,0.025158,1.06568,-2.09843,-0.073439,1.19624,-2.07973,-0.101388,1.11942,-2.06704,-0.117437,0.970139,-2.07103,-0.204528,0.799975,-2.06421,-0.290939,0.873861,-2.06942,-0.333721,0.816766,-2.0595,-0.456484,0.61466,-2.03012,-0.534988,0.668701,-1.95749,-0.440304,0.404765,-1.98056,-0.510989,0.428564,-2.02988,0.119478,1.36857,-1.82225,0.1144,1.35157,-2.03675},
/*524*/{0.18022,1.94581,-1.7323,0.286799,1.88589,-1.85561,0.020759,1.85903,-1.68643,-0.106363,1.78854,-1.67287,0.030265,1.69935,-1.67301,0.099453,1.64063,-1.6574,0.251402,1.96532,-2.1048,0.302841,1.88951,-1.92978,0.110523,1.91252,-2.05616,0.162484,1.73869,-2.2363,0.218072,1.65124,-2.25885,0.337842,1.6714,-2.10512,0.399813,1.66518,-2.08493,0.207334,1.45,-1.81774,0.024155,1.52489,-1.8856,0.028313,1.54376,-1.94957,0.032848,1.51921,-2.00093,0.2096,1.42566,-2.07291,0.323012,1.22307,-1.75785,0.214989,1.13752,-1.7659,0.263281,1.07077,-1.7867,0.36879,1.00801,-1.78211,0.394375,0.818278,-1.76886,0.397041,0.743166,-1.78051,0.284673,0.814667,-1.79772,0.288131,0.742454,-1.80364,0.347249,0.515029,-1.81365,0.266906,0.429643,-1.89659,0.510708,0.503964,-1.84,0.493652,0.441823,-1.77632,0.058424,1.1443,-2.11585,0.026548,1.06691,-2.0988,-0.070962,1.19618,-2.07998,-0.099289,1.11916,-2.06659,-0.114762,0.969776,-2.07066,-0.206132,0.80086,-2.06356,-0.290409,0.877657,-2.07091,-0.335408,0.822243,-2.06091,-0.465497,0.626794,-2.03103,-0.541482,0.683885,-1.96151,-0.457256,0.416816,-1.97715,-0.527083,0.441487,-2.02802,0.120139,1.37023,-1.82219,0.115354,1.35367,-2.03673},
/*525*/{0.180521,1.94633,-1.73159,0.28559,1.88792,-1.85532,0.020499,1.85913,-1.68683,-0.106411,1.78786,-1.6739,0.029748,1.7,-1.67356,0.099373,1.64024,-1.65564,0.25192,1.96606,-2.10445,0.303109,1.89078,-1.9295,0.110593,1.91333,-2.05578,0.163847,1.7401,-2.23655,0.219116,1.65167,-2.25913,0.338467,1.6701,-2.10469,0.40067,1.66403,-2.08447,0.208484,1.45116,-1.81812,0.024013,1.5262,-1.88506,0.027781,1.54566,-1.94929,0.033094,1.52087,-2.00088,0.210284,1.42766,-2.07243,0.321038,1.21727,-1.75811,0.211471,1.13552,-1.76609,0.256894,1.06704,-1.78788,0.365227,1.0029,-1.78153,0.397441,0.81388,-1.76958,0.403216,0.738027,-1.78067,0.287589,0.805629,-1.79635,0.293685,0.734279,-1.80204,0.364781,0.508621,-1.81343,0.287519,0.421833,-1.89791,0.526344,0.503986,-1.84029,0.512298,0.441781,-1.77649,0.06059,1.14463,-2.11594,0.029757,1.06689,-2.09972,-0.07041,1.19524,-2.07976,-0.096676,1.11831,-2.06701,-0.111417,0.968701,-2.07057,-0.209072,0.801388,-2.06253,-0.290576,0.881171,-2.07226,-0.336728,0.827783,-2.06292,-0.474856,0.638886,-2.03208,-0.552527,0.699752,-1.96584,-0.473927,0.430069,-1.97384,-0.539371,0.455555,-2.02586,0.120778,1.37154,-1.82234,0.115902,1.35556,-2.03693},
/*526*/{0.180952,1.94667,-1.73104,0.286169,1.88864,-1.85527,0.021004,1.8594,-1.68647,-0.106209,1.788,-1.67585,0.029414,1.6992,-1.67363,0.099205,1.6397,-1.65495,0.252716,1.96608,-2.10384,0.30328,1.89164,-1.92904,0.11123,1.91422,-2.05568,0.165035,1.74087,-2.23649,0.219589,1.65244,-2.25965,0.339041,1.66922,-2.10523,0.401059,1.6623,-2.0844,0.206567,1.45136,-1.81865,0.023806,1.52644,-1.88462,0.027541,1.5468,-1.94841,0.033656,1.5213,-2.00021,0.210513,1.42933,-2.07227,0.318524,1.21329,-1.75898,0.205552,1.13357,-1.76773,0.252512,1.06381,-1.78748,0.359961,0.997285,-1.78238,0.400788,0.810306,-1.7703,0.408837,0.734995,-1.78182,0.290169,0.797306,-1.79425,0.29985,0.725893,-1.79966,0.378634,0.502312,-1.81443,0.305787,0.413178,-1.89819,0.541341,0.50576,-1.84094,0.529057,0.44154,-1.77782,0.063426,1.14446,-2.11568,0.03378,1.06625,-2.09962,-0.066502,1.19388,-2.08066,-0.09291,1.11725,-2.06695,-0.106782,0.966837,-2.06949,-0.210587,0.801925,-2.0618,-0.286698,0.885644,-2.07405,-0.335825,0.834868,-2.06595,-0.485232,0.650821,-2.03173,-0.559823,0.714981,-1.96922,-0.489196,0.442928,-1.97004,-0.554693,0.469647,-2.02557,0.119998,1.37139,-1.82284,0.115903,1.35696,-2.03755},
/*527*/{0.181376,1.94649,-1.73038,0.287983,1.88853,-1.85388,0.021301,1.85828,-1.68671,-0.105893,1.7871,-1.6768,0.029877,1.69801,-1.67387,0.099378,1.63839,-1.65428,0.252854,1.96598,-2.10357,0.303691,1.8925,-1.9285,0.111539,1.91455,-2.05482,0.165618,1.74155,-2.23644,0.219335,1.6522,-2.2599,0.340814,1.66803,-2.10508,0.401649,1.65926,-2.08381,0.206228,1.45173,-1.81875,0.023605,1.52626,-1.88424,0.026837,1.54744,-1.94863,0.032623,1.5227,-1.99918,0.210887,1.43168,-2.07188,0.315117,1.20709,-1.75821,0.201414,1.12893,-1.76717,0.244539,1.05852,-1.78758,0.355679,0.991551,-1.78237,0.40426,0.806744,-1.77103,0.41366,0.732076,-1.78444,0.293715,0.789409,-1.79069,0.305672,0.719109,-1.79836,0.390839,0.498424,-1.8143,0.321617,0.406278,-1.89848,0.55546,0.508823,-1.83999,0.545072,0.442761,-1.77761,0.067415,1.14358,-2.11563,0.038782,1.06503,-2.09913,-0.064143,1.1924,-2.08142,-0.089086,1.11396,-2.06696,-0.101964,0.96492,-2.06885,-0.212268,0.802659,-2.06007,-0.282318,0.888087,-2.07564,-0.336381,0.840938,-2.06529,-0.490747,0.66378,-2.03254,-0.566787,0.731599,-1.9717,-0.503215,0.457591,-1.96677,-0.567102,0.485017,-2.02473,0.119995,1.37146,-1.82346,0.116311,1.35867,-2.03828},
/*528*/{0.182043,1.94618,-1.72983,0.287966,1.88828,-1.85326,0.021585,1.85691,-1.68714,-0.104904,1.78491,-1.67766,0.030245,1.69648,-1.67346,0.099799,1.63586,-1.65274,0.253701,1.96521,-2.10312,0.304004,1.89263,-1.9279,0.111982,1.91437,-2.05424,0.165563,1.74139,-2.23596,0.21907,1.65182,-2.26012,0.341465,1.66586,-2.10543,0.401533,1.65588,-2.08391,0.206116,1.4518,-1.81892,0.023537,1.52619,-1.88382,0.02657,1.54757,-1.94786,0.032623,1.5227,-1.99918,0.211286,1.43295,-2.07169,0.310703,1.20057,-1.75889,0.195676,1.12379,-1.76808,0.239116,1.05344,-1.78832,0.349301,0.985437,-1.78289,0.40714,0.803499,-1.77218,0.419162,0.729191,-1.78495,0.296742,0.782188,-1.78839,0.311082,0.711936,-1.79588,0.403181,0.494862,-1.81428,0.336282,0.400378,-1.89845,0.567593,0.510262,-1.84065,0.561067,0.444947,-1.77959,0.071649,1.14229,-2.11513,0.044111,1.0636,-2.09858,-0.060279,1.18964,-2.08219,-0.084951,1.11173,-2.06711,-0.096744,0.962195,-2.06786,-0.212689,0.803344,-2.05876,-0.279919,0.890038,-2.0745,-0.334912,0.847191,-2.06786,-0.500153,0.676427,-2.03218,-0.573242,0.748369,-1.97531,-0.51802,0.471907,-1.96471,-0.578354,0.501016,-2.02408,0.120321,1.37128,-1.82375,0.116853,1.35942,-2.03863},
/*529*/{0.183297,1.94527,-1.72881,0.288229,1.8882,-1.85298,0.022588,1.85543,-1.68701,-0.104687,1.78255,-1.6783,0.031592,1.69485,-1.67343,0.100624,1.63407,-1.6519,0.254691,1.96457,-2.10282,0.30457,1.89252,-1.92742,0.112359,1.91448,-2.05321,0.164181,1.74093,-2.23554,0.217538,1.65077,-2.25958,0.340958,1.66309,-2.10562,0.402353,1.65192,-2.08433,0.208565,1.45351,-1.81909,0.022985,1.52517,-1.88253,0.026145,1.54743,-1.94689,0.032294,1.52289,-1.99828,0.210812,1.43417,-2.07176,0.305854,1.19487,-1.75933,0.189825,1.12174,-1.76916,0.231158,1.04807,-1.78949,0.343474,0.97967,-1.78341,0.409829,0.80118,-1.77385,0.424553,0.726719,-1.78677,0.298995,0.776023,-1.78798,0.316097,0.706828,-1.79452,0.412297,0.490495,-1.81418,0.348883,0.39511,-1.89781,0.575608,0.510151,-1.84149,0.572367,0.444436,-1.77983,0.076523,1.14056,-2.11376,0.0498,1.06176,-2.09727,-0.056323,1.18661,-2.08188,-0.079847,1.10723,-2.0668,-0.091004,0.959594,-2.06718,-0.212753,0.805034,-2.05799,-0.276712,0.89652,-2.0769,-0.332167,0.855003,-2.06796,-0.50551,0.691775,-2.03261,-0.576875,0.765127,-1.97791,-0.530781,0.488076,-1.96307,-0.588538,0.517682,-2.02464,0.122851,1.37202,-1.82324,0.117688,1.35992,-2.03807},
/*530*/{0.183827,1.94426,-1.72812,0.288566,1.88739,-1.85272,0.023774,1.85312,-1.6864,-0.103089,1.78013,-1.67876,0.033178,1.69101,-1.67228,0.102202,1.63044,-1.65109,0.254243,1.96332,-2.10231,0.305191,1.8919,-1.92711,0.11234,1.91427,-2.05307,0.163468,1.74067,-2.2348,0.215944,1.64998,-2.25982,0.341561,1.65929,-2.10634,0.401945,1.64716,-2.0848,0.207547,1.45304,-1.81964,0.022895,1.52402,-1.88325,0.026593,1.54603,-1.94647,0.031355,1.52195,-1.99791,0.211634,1.43486,-2.07164,0.303069,1.18736,-1.75914,0.186089,1.11848,-1.76951,0.225268,1.04431,-1.79241,0.337522,0.974144,-1.78375,0.410435,0.798666,-1.77575,0.428664,0.724949,-1.78802,0.3014,0.770743,-1.78672,0.319565,0.702253,-1.79324,0.42266,0.489078,-1.81441,0.359142,0.391053,-1.89744,0.582709,0.511709,-1.84404,0.581095,0.445734,-1.78125,0.081615,1.13832,-2.11299,0.055208,1.0595,-2.0966,-0.053481,1.18132,-2.08207,-0.075324,1.10341,-2.06783,-0.085076,0.956021,-2.0666,-0.212514,0.8069,-2.05722,-0.272129,0.901552,-2.0772,-0.330627,0.86074,-2.06749,-0.509287,0.706483,-2.03291,-0.580927,0.783578,-1.97983,-0.541987,0.505308,-1.96307,-0.598395,0.535787,-2.02491,0.123047,1.37092,-1.82384,0.118538,1.35981,-2.03874},
/*531*/{0.184666,1.94302,-1.72764,0.288923,1.88646,-1.85252,0.024589,1.85009,-1.68569,-0.100954,1.77636,-1.67825,0.035504,1.68844,-1.67213,0.103916,1.62775,-1.64891,0.25443,1.96153,-2.10141,0.305148,1.89105,-1.9271,0.112344,1.91358,-2.05207,0.160843,1.73923,-2.23399,0.213873,1.64866,-2.25876,0.341418,1.65595,-2.10731,0.401731,1.64169,-2.086,0.208724,1.45294,-1.81967,0.022913,1.52198,-1.88219,0.026238,1.54556,-1.94574,0.031193,1.52039,-1.99714,0.211264,1.43493,-2.07236,0.29745,1.18158,-1.75859,0.180431,1.11154,-1.77056,0.218321,1.04014,-1.79293,0.330964,0.968665,-1.78351,0.410621,0.797112,-1.77666,0.43007,0.723946,-1.78859,0.301706,0.766464,-1.78698,0.320868,0.697555,-1.79395,0.42923,0.486666,-1.8146,0.367116,0.388237,-1.89663,0.591111,0.513593,-1.84491,0.589943,0.446231,-1.78355,0.086291,1.13625,-2.11171,0.061644,1.0561,-2.09552,-0.048756,1.17733,-2.0824,-0.06988,1.09806,-2.067,-0.077765,0.952276,-2.06605,-0.212161,0.808287,-2.05723,-0.267481,0.905538,-2.07688,-0.326702,0.868636,-2.0669,-0.512538,0.721719,-2.03303,-0.581739,0.800734,-1.98158,-0.552993,0.521494,-1.96305,-0.606372,0.554232,-2.02518,0.124739,1.37013,-1.82378,0.119023,1.35925,-2.03866},
/*532*/{0.185533,1.94154,-1.72665,0.289217,1.88534,-1.85282,0.02547,1.84734,-1.68487,-0.099838,1.77136,-1.6775,0.036588,1.68424,-1.67026,0.105914,1.62362,-1.64751,0.25499,1.95984,-2.10081,0.304413,1.88942,-1.92645,0.112118,1.91303,-2.05158,0.158713,1.73819,-2.23283,0.211779,1.6469,-2.25838,0.341087,1.65197,-2.10787,0.401204,1.63593,-2.08721,0.209234,1.4513,-1.82062,0.02254,1.51909,-1.88218,0.025121,1.54377,-1.94597,0.030978,1.51909,-1.99673,0.211181,1.43483,-2.07245,0.294502,1.17447,-1.75796,0.174641,1.1073,-1.7711,0.211699,1.03554,-1.79417,0.325623,0.963771,-1.78416,0.409479,0.795421,-1.7778,0.4301,0.722718,-1.78909,0.301493,0.762512,-1.78754,0.322225,0.694509,-1.79452,0.433893,0.484429,-1.81454,0.373347,0.385793,-1.89622,0.595729,0.512137,-1.84712,0.595544,0.445976,-1.78421,0.091181,1.13378,-2.11112,0.067943,1.05312,-2.09477,-0.044861,1.17211,-2.08253,-0.06421,1.09288,-2.06685,-0.070537,0.947399,-2.0655,-0.210223,0.810328,-2.05655,-0.261401,0.910135,-2.07608,-0.3228,0.875195,-2.0665,-0.513329,0.738435,-2.03578,-0.579843,0.819925,-1.98113,-0.562049,0.53878,-1.96373,-0.615679,0.574129,-2.02635,0.125462,1.36798,-1.82478,0.119564,1.35844,-2.03972},
/*533*/{0.186494,1.93926,-1.72573,0.289301,1.88375,-1.85254,0.027032,1.84373,-1.68346,-0.096562,1.76776,-1.67623,0.039093,1.68043,-1.6688,0.108133,1.61939,-1.64588,0.255197,1.95784,-2.1008,0.304678,1.88782,-1.92603,0.111655,1.91122,-2.04977,0.155416,1.73654,-2.23141,0.208886,1.6454,-2.25789,0.340375,1.64658,-2.10859,0.40058,1.62951,-2.08814,0.207677,1.44976,-1.82052,0.021487,1.51763,-1.88155,0.024096,1.54146,-1.94602,0.030075,1.51746,-1.99675,0.211061,1.43368,-2.07225,0.291682,1.16832,-1.75688,0.169172,1.10521,-1.77274,0.205869,1.03213,-1.79617,0.31886,0.957962,-1.78399,0.407219,0.793297,-1.77814,0.427692,0.720672,-1.78934,0.300002,0.758229,-1.7886,0.322252,0.690323,-1.79493,0.437976,0.482301,-1.81439,0.377463,0.382377,-1.89575,0.599179,0.511216,-1.84956,0.599278,0.445357,-1.78617,0.096635,1.13036,-2.11003,0.074765,1.04957,-2.09342,-0.040649,1.16646,-2.08223,-0.058774,1.08665,-2.06633,-0.062399,0.942234,-2.06513,-0.207694,0.812597,-2.05739,-0.254927,0.914095,-2.07486,-0.317396,0.882949,-2.06529,-0.514878,0.755056,-2.0367,-0.57768,0.838419,-1.98199,-0.570318,0.557219,-1.96578,-0.622968,0.594344,-2.02828,0.124506,1.36621,-1.82477,0.119214,1.35705,-2.03974},
/*534*/{0.186859,1.93684,-1.7254,0.288542,1.88219,-1.85227,0.028204,1.83976,-1.68144,-0.094575,1.76299,-1.67472,0.041984,1.67571,-1.66686,0.11077,1.61495,-1.64384,0.254928,1.95559,-2.10056,0.304294,1.8856,-1.92607,0.110947,1.90988,-2.04944,0.152842,1.7351,-2.22968,0.205547,1.6433,-2.25691,0.339934,1.64126,-2.11,0.399561,1.62326,-2.09027,0.206794,1.44729,-1.82074,0.021709,1.5142,-1.88088,0.024923,1.53853,-1.94576,0.029584,1.51431,-1.99614,0.211238,1.43226,-2.07296,0.287071,1.16361,-1.75634,0.164954,1.10246,-1.7725,0.201642,1.02837,-1.79563,0.312383,0.952546,-1.78471,0.403633,0.790662,-1.7787,0.425257,0.719844,-1.79024,0.296132,0.752818,-1.79155,0.3208,0.686378,-1.79569,0.440181,0.481368,-1.81539,0.378858,0.378993,-1.89513,0.600266,0.510482,-1.85124,0.603751,0.44475,-1.78833,0.101459,1.12671,-2.1098,0.08135,1.04581,-2.09237,-0.035939,1.15977,-2.08162,-0.052891,1.08038,-2.06587,-0.055149,0.937617,-2.06613,-0.205189,0.81438,-2.05742,-0.247507,0.918792,-2.07433,-0.310985,0.888114,-2.06367,-0.513528,0.770424,-2.03724,-0.573403,0.856348,-1.98086,-0.579125,0.575231,-1.96802,-0.627935,0.615191,-2.0291,0.125038,1.36305,-1.82527,0.119685,1.35492,-2.04029},
/*535*/{0.187559,1.93442,-1.72474,0.28887,1.87992,-1.85234,0.02934,1.83507,-1.68053,-0.09204,1.7569,-1.67251,0.044177,1.67063,-1.66468,0.113494,1.61023,-1.64185,0.254533,1.9529,-2.0999,0.304461,1.88307,-1.92587,0.11056,1.90789,-2.04871,0.14888,1.734,-2.22868,0.202454,1.64111,-2.25606,0.338947,1.63527,-2.11148,0.398292,1.61565,-2.092,0.208306,1.44498,-1.82032,0.020654,1.51155,-1.88045,0.024031,1.53556,-1.94556,0.029885,1.51108,-1.99571,0.211631,1.4312,-2.073,0.28578,1.15926,-1.75471,0.163476,1.0988,-1.77182,0.196753,1.02435,-1.79815,0.31028,0.949269,-1.78451,0.400258,0.787376,-1.77773,0.42426,0.715017,-1.78954,0.293919,0.750531,-1.79123,0.317676,0.682302,-1.79748,0.440719,0.47838,-1.8161,0.379869,0.375652,-1.89554,0.60019,0.508673,-1.85353,0.603705,0.442186,-1.79023,0.106694,1.12264,-2.10898,0.088794,1.04092,-2.09147,-0.03275,1.15325,-2.08177,-0.047691,1.07312,-2.06386,-0.046336,0.93142,-2.06431,-0.200723,0.816627,-2.05797,-0.239208,0.922511,-2.07255,-0.304232,0.895389,-2.06376,-0.51193,0.785902,-2.03786,-0.56694,0.874425,-1.98074,-0.586501,0.592301,-1.9705,-0.631644,0.636424,-2.03128,0.126313,1.36056,-1.82532,0.120827,1.35291,-2.04035},
/*536*/{0.18828,1.93117,-1.72401,0.288838,1.87737,-1.85235,0.030976,1.8303,-1.67806,-0.088408,1.75128,-1.67009,0.047569,1.66477,-1.6623,0.11753,1.60515,-1.63978,0.254332,1.94995,-2.09967,0.304072,1.87995,-1.92536,0.110524,1.90645,-2.04784,0.145123,1.73124,-2.22694,0.198582,1.63898,-2.25513,0.336737,1.62889,-2.11247,0.396581,1.60799,-2.09407,0.208403,1.44149,-1.82052,0.020722,1.50783,-1.88022,0.023234,1.53215,-1.94576,0.0289,1.50802,-1.9954,0.212191,1.42905,-2.07299,0.283014,1.15464,-1.75296,0.159576,1.09391,-1.77292,0.195703,1.02157,-1.79839,0.309309,0.947609,-1.78454,0.396531,0.783465,-1.77801,0.419922,0.713004,-1.79095,0.291272,0.746529,-1.79131,0.314859,0.678601,-1.7985,0.437441,0.474379,-1.81792,0.37728,0.372932,-1.89737,0.597128,0.506366,-1.85633,0.603124,0.439675,-1.79265,0.110696,1.11862,-2.10898,0.095025,1.03667,-2.09083,-0.027447,1.14683,-2.08087,-0.040949,1.0661,-2.06388,-0.038279,0.925111,-2.06411,-0.196548,0.818397,-2.05801,-0.230044,0.926159,-2.07205,-0.296402,0.900239,-2.06174,-0.509142,0.802295,-2.03912,-0.559062,0.89094,-1.97809,-0.590117,0.610417,-1.97393,-0.638632,0.657699,-2.03299,0.126593,1.35695,-1.82588,0.121229,1.35031,-2.04095},
/*537*/{0.189265,1.92763,-1.72332,0.288575,1.8742,-1.85228,0.032189,1.82516,-1.67704,-0.085475,1.74454,-1.66733,0.050347,1.65889,-1.66041,0.120027,1.59961,-1.63816,0.25323,1.94707,-2.09963,0.303618,1.87749,-1.92562,0.110504,1.90383,-2.0466,0.141491,1.72903,-2.22508,0.195176,1.63638,-2.25405,0.335059,1.62234,-2.11367,0.394412,1.59977,-2.09665,0.205768,1.43827,-1.82043,0.019592,1.50415,-1.88055,0.022741,1.52892,-1.94622,0.02843,1.50419,-1.99625,0.212349,1.42667,-2.07316,0.280681,1.15244,-1.75173,0.159513,1.0936,-1.77311,0.193721,1.01934,-1.79858,0.309224,0.946791,-1.78446,0.393242,0.779,-1.77841,0.415656,0.708173,-1.79152,0.287357,0.741721,-1.79305,0.310883,0.67408,-1.80034,0.435864,0.470784,-1.81987,0.373421,0.369191,-1.89875,0.594679,0.50178,-1.85771,0.599405,0.435341,-1.79622,0.115762,1.11483,-2.1089,0.101139,1.03216,-2.09023,-0.024,1.13939,-2.08047,-0.035471,1.05893,-2.0635,-0.030067,0.918974,-2.06365,-0.191113,0.81961,-2.05828,-0.221244,0.929636,-2.07153,-0.288419,0.90525,-2.06168,-0.503912,0.816988,-2.03872,-0.550138,0.907529,-1.97719,-0.594674,0.628089,-1.97689,-0.639986,0.678617,-2.03553,0.125125,1.35329,-1.82652,0.121312,1.34746,-2.04164},
/*538*/{0.189956,1.9241,-1.72236,0.28859,1.87047,-1.85251,0.033909,1.81925,-1.67482,-0.082552,1.73794,-1.66389,0.053812,1.65337,-1.6574,0.124138,1.59405,-1.63523,0.25313,1.94323,-2.09992,0.303627,1.87434,-1.9251,0.109556,1.90087,-2.04564,0.136788,1.72667,-2.22432,0.190204,1.63305,-2.25339,0.334133,1.61597,-2.11578,0.392361,1.59093,-2.0993,0.20858,1.43884,-1.82281,0.019789,1.50012,-1.88041,0.022042,1.52441,-1.9459,0.027703,1.5006,-1.99655,0.212212,1.42364,-2.07273,0.277488,1.15046,-1.75123,0.15677,1.09067,-1.77378,0.191664,1.0173,-1.79946,0.309382,0.945759,-1.78488,0.389723,0.774308,-1.77866,0.413046,0.702633,-1.79126,0.283817,0.737494,-1.79407,0.30708,0.670701,-1.80121,0.430533,0.466626,-1.82117,0.367807,0.365113,-1.90144,0.588189,0.496467,-1.8608,0.59457,0.429692,-1.79757,0.12048,1.11026,-2.10847,0.10769,1.02831,-2.0902,-0.019138,1.13297,-2.07996,-0.030369,1.05188,-2.06335,-0.021987,0.912782,-2.06332,-0.185421,0.820816,-2.05847,-0.21115,0.930954,-2.07059,-0.278254,0.910336,-2.06146,-0.497528,0.83027,-2.03896,-0.53886,0.922478,-1.9763,-0.596274,0.644838,-1.98072,-0.64023,0.698752,-2.03767,0.128836,1.35227,-1.82569,0.122734,1.34377,-2.04067},
/*539*/{0.190545,1.91969,-1.72186,0.288597,1.86683,-1.85259,0.035839,1.8138,-1.67153,-0.080188,1.73058,-1.66035,0.057058,1.64601,-1.6543,0.128375,1.58867,-1.63368,0.252293,1.93966,-2.09987,0.303851,1.8704,-1.92482,0.108509,1.89758,-2.0449,0.132793,1.7232,-2.22234,0.185268,1.62941,-2.25255,0.330041,1.60771,-2.11662,0.389602,1.58185,-2.10131,0.204532,1.43171,-1.8196,0.017525,1.49616,-1.88041,0.022156,1.52115,-1.94585,0.027197,1.49588,-1.99669,0.211919,1.42063,-2.07256,0.277359,1.14761,-1.75018,0.156,1.0891,-1.77363,0.191524,1.01458,-1.79865,0.309129,0.944196,-1.78522,0.386599,0.769554,-1.77913,0.409635,0.697824,-1.79211,0.279644,0.734097,-1.79474,0.302985,0.666313,-1.80163,0.422365,0.459759,-1.82293,0.360799,0.361438,-1.90528,0.584218,0.489198,-1.86058,0.586761,0.420974,-1.79984,0.125792,1.10633,-2.10801,0.114326,1.02337,-2.08956,-0.015562,1.1256,-2.07956,-0.02316,1.04449,-2.06243,-0.013541,0.906727,-2.06315,-0.180203,0.820978,-2.05915,-0.200422,0.932901,-2.07005,-0.268998,0.914218,-2.06169,-0.490425,0.843892,-2.04104,-0.527674,0.936546,-1.9754,-0.596219,0.661762,-1.98405,-0.636058,0.718952,-2.04332,0.124625,1.34607,-1.82625,0.121688,1.34044,-2.04139},
/*540*/{0.190181,1.91493,-1.72178,0.289628,1.8617,-1.85238,0.03765,1.80692,-1.66951,-0.076165,1.72374,-1.65647,0.060492,1.63933,-1.6509,0.13321,1.58268,-1.63108,0.251278,1.93579,-2.1002,0.302842,1.86614,-1.9254,0.108928,1.8942,-2.0443,0.128119,1.72068,-2.22069,0.18127,1.62585,-2.25131,0.327305,1.59976,-2.11819,0.386706,1.57209,-2.10427,0.204782,1.42831,-1.81876,0.017559,1.4928,-1.88099,0.021289,1.51726,-1.9458,0.027549,1.49408,-1.99692,0.21159,1.41734,-2.07273,0.275542,1.14581,-1.74959,0.153709,1.08698,-1.77492,0.190292,1.01254,-1.79836,0.308412,0.940929,-1.78604,0.382519,0.763906,-1.77939,0.404234,0.691635,-1.7938,0.275524,0.730112,-1.79554,0.297641,0.661605,-1.80408,0.414401,0.454087,-1.82441,0.351487,0.357488,-1.90842,0.577342,0.4823,-1.86107,0.577665,0.413501,-1.80204,0.130092,1.102,-2.10769,0.120587,1.01875,-2.08978,-0.010283,1.1177,-2.07852,-0.017092,1.03741,-2.06193,-0.006328,0.900689,-2.06313,-0.173304,0.820641,-2.05864,-0.189487,0.932752,-2.06806,-0.25809,0.917201,-2.06106,-0.481518,0.855168,-2.0413,-0.515195,0.949124,-1.97525,-0.594855,0.677599,-1.98687,-0.632403,0.735111,-2.0438,0.124239,1.34269,-1.82645,0.12157,1.33743,-2.0416},
/*541*/{0.190832,1.9096,-1.72095,0.288528,1.85811,-1.85254,0.039677,1.80009,-1.66708,-0.074607,1.7151,-1.65195,0.06519,1.63246,-1.64739,0.136874,1.57667,-1.62949,0.250822,1.93152,-2.1007,0.303473,1.8621,-1.92521,0.107372,1.89088,-2.04325,0.124412,1.71538,-2.21955,0.17624,1.62232,-2.25054,0.323885,1.59137,-2.12045,0.383246,1.56176,-2.10792,0.203321,1.42447,-1.81854,0.01675,1.48848,-1.88104,0.020837,1.51301,-1.94597,0.026058,1.48639,-1.99678,0.211475,1.41399,-2.07198,0.274081,1.14345,-1.74925,0.152657,1.08228,-1.77538,0.190387,1.00965,-1.79936,0.306244,0.936201,-1.78612,0.377479,0.758064,-1.78151,0.39817,0.685801,-1.79438,0.270271,0.726106,-1.79616,0.290832,0.657767,-1.80501,0.405386,0.447949,-1.82688,0.34127,0.353737,-1.91127,0.567713,0.473761,-1.86301,0.569194,0.405167,-1.80381,0.134832,1.09762,-2.10858,0.127568,1.01397,-2.09004,-0.004692,1.11046,-2.07807,-0.009809,1.02947,-2.06153,0.002965,0.894922,-2.06297,-0.165621,0.820489,-2.05859,-0.178908,0.93298,-2.06818,-0.248107,0.920251,-2.06175,-0.473144,0.866632,-2.04179,-0.502737,0.960768,-1.97558,-0.590203,0.691519,-1.99043,-0.628618,0.754687,-2.04585,0.124165,1.33862,-1.82578,0.122029,1.33263,-2.04092},
/*542*/{0.191748,1.90469,-1.72036,0.289293,1.8522,-1.8523,0.041726,1.79279,-1.66426,-0.070101,1.70621,-1.64793,0.069014,1.62557,-1.64449,0.141782,1.57077,-1.62823,0.249127,1.92619,-2.10104,0.303081,1.85739,-1.92558,0.106924,1.88579,-2.0418,0.120295,1.71171,-2.21804,0.170676,1.61802,-2.25022,0.320518,1.58291,-2.12242,0.378966,1.5517,-2.11099,0.202654,1.42161,-1.81806,0.014746,1.48388,-1.88225,0.0208,1.51053,-1.94648,0.025482,1.48137,-1.99783,0.212139,1.41048,-2.07039,0.274057,1.14139,-1.74897,0.152274,1.08199,-1.77638,0.189928,1.00704,-1.79956,0.303754,0.931081,-1.7858,0.373264,0.751617,-1.78199,0.392711,0.679635,-1.79587,0.265318,0.722069,-1.79709,0.285094,0.653256,-1.80579,0.396681,0.443316,-1.82877,0.329822,0.348511,-1.91444,0.558181,0.46483,-1.86293,0.556997,0.395428,-1.80555,0.140065,1.09248,-2.1092,0.134342,1.00904,-2.09075,-0.000228,1.10297,-2.07729,-0.00328,1.02235,-2.06056,0.011328,0.888965,-2.06322,-0.158134,0.820421,-2.0589,-0.167113,0.933389,-2.06824,-0.237056,0.922396,-2.06197,-0.463077,0.877028,-2.04112,-0.490732,0.971115,-1.97542,-0.586099,0.705082,-1.9926,-0.621588,0.767351,-2.04741,0.123373,1.33547,-1.82528,0.122933,1.32874,-2.04041},
/*543*/{0.191793,1.89878,-1.7194,0.289246,1.84904,-1.85235,0.044173,1.78554,-1.66128,-0.066645,1.6968,-1.64253,0.073237,1.61829,-1.64113,0.147428,1.56446,-1.6258,0.249065,1.92174,-2.1019,0.303307,1.85262,-1.92604,0.10613,1.88166,-2.04096,0.116343,1.70777,-2.21714,0.165395,1.61362,-2.24942,0.316431,1.57441,-2.12465,0.374842,1.54104,-2.11426,0.202338,1.41816,-1.81701,0.014735,1.47858,-1.88241,0.019824,1.50466,-1.94706,0.023865,1.47653,-1.99827,0.211166,1.40573,-2.07141,0.272021,1.13713,-1.74903,0.152137,1.07891,-1.77719,0.186666,1.00388,-1.79905,0.301196,0.9261,-1.78612,0.368021,0.745914,-1.78231,0.386228,0.673198,-1.79721,0.258505,0.718053,-1.79869,0.27717,0.649204,-1.80715,0.385651,0.438444,-1.83068,0.315696,0.34728,-1.91691,0.546997,0.455383,-1.86432,0.543911,0.385168,-1.80595,0.145763,1.08799,-2.10944,0.141506,1.0043,-2.09085,0.004676,1.09605,-2.07677,0.003934,1.01498,-2.06028,0.020386,0.883427,-2.06394,-0.15065,0.819413,-2.05918,-0.154769,0.932346,-2.0684,-0.225901,0.924293,-2.06182,-0.452555,0.88585,-2.042,-0.47745,0.979817,-1.97562,-0.579543,0.716138,-1.99537,-0.613572,0.779978,-2.04925,0.123623,1.33136,-1.82497,0.122746,1.3236,-2.04006},
/*544*/{0.192625,1.89327,-1.71854,0.288727,1.84354,-1.85313,0.046688,1.7771,-1.65831,-0.06355,1.68833,-1.63783,0.078509,1.6109,-1.63784,0.15273,1.55817,-1.62329,0.247244,1.91663,-2.1022,0.302948,1.84817,-1.92643,0.105591,1.8769,-2.04078,0.111302,1.70367,-2.2165,0.160372,1.60906,-2.24875,0.312754,1.56569,-2.12723,0.371372,1.52954,-2.11727,0.200655,1.4148,-1.81648,0.012654,1.47395,-1.88293,0.018184,1.49946,-1.947,0.023879,1.4704,-1.99901,0.211047,1.40205,-2.07116,0.270216,1.13389,-1.75014,0.150625,1.07406,-1.77715,0.185074,0.999929,-1.79991,0.298031,0.921095,-1.78626,0.360905,0.739058,-1.78358,0.377907,0.66601,-1.79756,0.251985,0.712938,-1.80029,0.268595,0.644819,-1.80912,0.370556,0.433116,-1.83193,0.29752,0.351796,-1.91795,0.533053,0.443516,-1.86477,0.525413,0.373725,-1.80489,0.151,1.08343,-2.10926,0.148256,0.999981,-2.09144,0.010163,1.08928,-2.07521,0.010427,1.00818,-2.05982,0.030117,0.877456,-2.06447,-0.141515,0.818974,-2.05974,-0.143304,0.933055,-2.06822,-0.213107,0.926398,-2.06243,-0.441747,0.894014,-2.04246,-0.46498,0.989746,-1.9765,-0.571187,0.726673,-1.99705,-0.603296,0.790416,-2.05234,0.123019,1.32732,-1.8246,0.123378,1.31904,-2.03967},
/*545*/{0.193249,1.88669,-1.7176,0.289046,1.83802,-1.85326,0.04977,1.76838,-1.65479,-0.059687,1.67893,-1.63227,0.083141,1.60292,-1.63411,0.15765,1.55216,-1.62109,0.246874,1.91147,-2.10307,0.30289,1.84279,-1.92683,0.103901,1.8718,-2.0406,0.106989,1.69958,-2.21591,0.154935,1.60484,-2.24845,0.307872,1.55542,-2.12948,0.364412,1.51896,-2.12202,0.199999,1.41077,-1.81499,0.012413,1.46782,-1.88324,0.017621,1.49454,-1.94677,0.023169,1.46456,-1.99928,0.210367,1.39794,-2.07004,0.270714,1.12881,-1.74934,0.14867,1.06945,-1.77826,0.185526,0.995865,-1.79962,0.294585,0.915869,-1.78699,0.354161,0.732678,-1.78371,0.367973,0.659606,-1.79949,0.245044,0.708592,-1.80113,0.26044,0.638298,-1.8112,0.356563,0.428515,-1.83295,0.279507,0.351174,-1.9206,0.5189,0.431211,-1.86687,0.505876,0.363968,-1.80663,0.155977,1.07959,-2.10924,0.155479,0.995341,-2.09174,0.015881,1.08185,-2.07405,0.016948,1.00077,-2.05943,0.039661,0.871894,-2.06583,-0.13294,0.818483,-2.06135,-0.131503,0.931714,-2.06818,-0.202303,0.927271,-2.06235,-0.42957,0.901533,-2.04407,-0.452065,0.996124,-1.97631,-0.562345,0.735767,-1.99918,-0.593664,0.799976,-2.05384,0.122927,1.3227,-1.82386,0.124009,1.31409,-2.03892},
/*546*/{0.194158,1.88065,-1.71633,0.288973,1.83318,-1.85351,0.053165,1.76013,-1.65144,-0.055148,1.66941,-1.62751,0.088881,1.59574,-1.63094,0.164499,1.54658,-1.61973,0.245259,1.90592,-2.10341,0.302839,1.83743,-1.92766,0.103107,1.86656,-2.03994,0.103331,1.69475,-2.21467,0.14885,1.59996,-2.24738,0.303446,1.54533,-2.13226,0.358842,1.50772,-2.12567,0.198272,1.40697,-1.81428,0.011137,1.46301,-1.88444,0.017202,1.48951,-1.94682,0.022096,1.45869,-1.99974,0.210299,1.39389,-2.06973,0.269209,1.1238,-1.74943,0.147425,1.06542,-1.77865,0.183443,0.991073,-1.79993,0.291183,0.910589,-1.78691,0.345611,0.724278,-1.78522,0.361256,0.651606,-1.79988,0.236757,0.704358,-1.80304,0.250673,0.633921,-1.81331,0.342593,0.422687,-1.8364,0.260744,0.355027,-1.92237,0.505629,0.416068,-1.86769,0.48643,0.349795,-1.80555,0.160818,1.0747,-2.11012,0.162062,0.99094,-2.09266,0.020949,1.07476,-2.07378,0.023673,0.99329,-2.05896,0.050218,0.862738,-2.06616,-0.122887,0.817684,-2.06228,-0.118323,0.93189,-2.06972,-0.187891,0.928151,-2.06211,-0.418009,0.907805,-2.0441,-0.441209,1.00302,-1.97752,-0.55107,0.744309,-2.00176,-0.580398,0.808195,-2.05643,0.122131,1.31844,-1.82356,0.124375,1.30935,-2.03859},
/*547*/{0.194846,1.87453,-1.71549,0.290507,1.82616,-1.85356,0.05654,1.7513,-1.64828,-0.050318,1.65859,-1.62133,0.094324,1.58812,-1.62774,0.170762,1.54083,-1.61849,0.244631,1.90044,-2.10409,0.302668,1.83162,-1.92808,0.101852,1.86135,-2.0394,0.098346,1.69028,-2.21463,0.143924,1.5953,-2.24719,0.297739,1.53508,-2.13531,0.352089,1.49594,-2.1296,0.197714,1.40395,-1.81287,0.010662,1.45755,-1.88526,0.015933,1.4829,-1.94605,0.021171,1.45216,-2.00046,0.210482,1.38837,-2.06827,0.268069,1.11784,-1.74916,0.145898,1.06164,-1.7792,0.180954,0.985383,-1.80064,0.287619,0.90413,-1.78728,0.338813,0.719394,-1.78612,0.352181,0.644947,-1.80084,0.229237,0.699826,-1.80411,0.241946,0.630067,-1.81462,0.327236,0.418557,-1.83772,0.239862,0.354816,-1.92167,0.49066,0.40295,-1.86858,0.468858,0.338847,-1.80693,0.165561,1.07118,-2.11097,0.168115,0.986549,-2.09362,0.025366,1.06803,-2.07394,0.031158,0.98613,-2.05848,0.060052,0.858888,-2.06754,-0.112672,0.816273,-2.06323,-0.105558,0.929581,-2.06945,-0.17592,0.928284,-2.06228,-0.405962,0.913121,-2.0444,-0.428214,1.00943,-1.97863,-0.540621,0.749645,-2.00258,-0.567587,0.81418,-2.05893,0.122383,1.31457,-1.82176,0.125426,1.30328,-2.03668},
/*548*/{0.195857,1.86857,-1.71427,0.289116,1.82151,-1.85436,0.060236,1.74178,-1.6444,-0.044667,1.64979,-1.61597,0.099706,1.58078,-1.6255,0.177923,1.53533,-1.61775,0.243459,1.89522,-2.10515,0.302095,1.82635,-1.92896,0.100576,1.85634,-2.03906,0.094538,1.68575,-2.21353,0.137661,1.59087,-2.24754,0.292207,1.52418,-2.13837,0.345703,1.48437,-2.13351,0.197297,1.4003,-1.81094,0.008649,1.45212,-1.88607,0.014758,1.4772,-1.94617,0.019581,1.44729,-2.00094,0.209821,1.38372,-2.06736,0.264821,1.11079,-1.74803,0.142657,1.05522,-1.77843,0.178656,0.980251,-1.80152,0.281541,0.897645,-1.78658,0.331422,0.712971,-1.78722,0.341865,0.637346,-1.80329,0.221466,0.697351,-1.8048,0.233235,0.627262,-1.81499,0.309476,0.416817,-1.83976,0.219535,0.356162,-1.92108,0.473449,0.395611,-1.87555,0.449246,0.33925,-1.80894,0.170816,1.06662,-2.11196,0.175109,0.98262,-2.09494,0.031175,1.06011,-2.07319,0.038474,0.979114,-2.05855,0.070087,0.854244,-2.0679,-0.10209,0.814721,-2.06383,-0.09207,0.928458,-2.07009,-0.162806,0.928108,-2.06227,-0.392071,0.917995,-2.04445,-0.415709,1.01408,-1.97967,-0.527787,0.754846,-2.00399,-0.553916,0.826323,-2.07318,0.121576,1.31043,-1.82084,0.125556,1.29827,-2.03569},
/*549*/{0.197364,1.86278,-1.71316,0.290914,1.81498,-1.85424,0.0648,1.73268,-1.6411,-0.039428,1.63923,-1.61025,0.106725,1.57374,-1.62186,0.185082,1.53058,-1.61624,0.242004,1.89028,-2.10567,0.302683,1.82119,-1.92953,0.098383,1.85099,-2.03851,0.088781,1.68238,-2.21389,0.13157,1.58595,-2.24738,0.285967,1.51375,-2.14188,0.338288,1.47229,-2.13754,0.19577,1.39584,-1.81057,0.006543,1.44752,-1.88701,0.01338,1.47144,-1.94683,0.01854,1.44131,-2.00266,0.209501,1.37922,-2.06758,0.260992,1.1063,-1.74622,0.138934,1.0499,-1.77791,0.173968,0.976712,-1.80262,0.275982,0.890559,-1.78595,0.32548,0.708711,-1.78936,0.332703,0.633862,-1.80508,0.214294,0.697177,-1.80605,0.222089,0.626625,-1.81785,0.293918,0.418173,-1.84386,0.196847,0.35595,-1.92191,0.451804,0.392905,-1.88043,0.42717,0.338865,-1.8094,0.175724,1.06217,-2.11179,0.182542,0.979053,-2.09624,0.037124,1.05339,-2.07315,0.045597,0.972228,-2.05786,0.081321,0.849701,-2.06867,-0.09034,0.812818,-2.06555,-0.078696,0.925983,-2.0702,-0.14731,0.92708,-2.06279,-0.378953,0.919996,-2.04517,-0.404028,1.01827,-1.98147,-0.514294,0.75787,-2.00684,-0.540581,0.823146,-2.06354,0.120323,1.30579,-1.82106,0.12549,1.29322,-2.03586},
/*550*/{0.198627,1.85762,-1.71181,0.291039,1.81052,-1.85446,0.069926,1.72317,-1.63746,-0.032802,1.62981,-1.60469,0.11407,1.5672,-1.61919,0.192544,1.52474,-1.61483,0.241477,1.88597,-2.10639,0.302895,1.81529,-1.93068,0.097668,1.84658,-2.03628,0.085592,1.67676,-2.21314,0.124854,1.58094,-2.24726,0.279899,1.50335,-2.14526,0.331421,1.4614,-2.14119,0.192859,1.39249,-1.80992,0.003466,1.4428,-1.88783,0.010946,1.46501,-1.9481,0.016556,1.43567,-2.00375,0.208326,1.37363,-2.06681,0.254276,1.10417,-1.74355,0.135044,1.04956,-1.77812,0.169877,0.975709,-1.80368,0.268439,0.883132,-1.78689,0.318843,0.708102,-1.79004,0.324329,0.633033,-1.80647,0.208278,0.70104,-1.80633,0.213101,0.629906,-1.81673,0.271719,0.417157,-1.84759,0.175218,0.357333,-1.92401,0.430296,0.391701,-1.88319,0.404933,0.34099,-1.81159,0.179942,1.05849,-2.11243,0.189461,0.975698,-2.09734,0.041996,1.0462,-2.07338,0.052487,0.965511,-2.05836,0.090916,0.844146,-2.07107,-0.078374,0.809935,-2.06614,-0.064518,0.923858,-2.07062,-0.134086,0.925769,-2.06362,-0.365084,0.922729,-2.04563,-0.389755,1.01978,-1.98131,-0.501085,0.760279,-2.00716,-0.526608,0.825661,-2.06565,0.117915,1.30191,-1.82014,0.124555,1.28747,-2.03479},
/*551*/{0.199822,1.85277,-1.71073,0.291705,1.80332,-1.85498,0.074964,1.71475,-1.63492,-0.024712,1.62069,-1.59901,0.120931,1.56137,-1.61745,0.200694,1.52059,-1.61421,0.238657,1.88208,-2.10803,0.303852,1.81035,-1.93125,0.096475,1.84327,-2.03522,0.08163,1.67275,-2.21271,0.119116,1.57685,-2.24705,0.273708,1.49392,-2.1488,0.322498,1.45128,-2.14559,0.190346,1.38868,-1.80947,0.000246,1.43914,-1.88889,0.008148,1.46025,-1.94942,0.01349,1.43012,-2.00384,0.207282,1.36914,-2.0653,0.253821,1.10149,-1.7377,0.131024,1.04936,-1.7805,0.166735,0.975447,-1.80431,0.264611,0.881859,-1.78712,0.314601,0.70884,-1.79085,0.315957,0.63417,-1.80804,0.202422,0.70705,-1.80518,0.20532,0.635966,-1.81572,0.25042,0.422599,-1.84875,0.152563,0.357999,-1.9253,0.407921,0.390544,-1.88356,0.383707,0.339344,-1.81218,0.184699,1.05585,-2.11315,0.195817,0.972667,-2.09789,0.046225,1.03902,-2.07324,0.059899,0.959108,-2.05837,0.101867,0.83966,-2.0718,-0.065627,0.807477,-2.06649,-0.050365,0.920126,-2.07008,-0.1197,0.924029,-2.06378,-0.350771,0.925094,-2.04736,-0.376435,1.02127,-1.98281,-0.48573,0.760836,-2.00892,-0.508336,0.823171,-2.06515,0.115118,1.29833,-1.81933,0.123116,1.28262,-2.03384},
/*552*/{0.201172,1.8483,-1.70956,0.290853,1.79984,-1.85663,0.08086,1.70633,-1.63228,-0.01764,1.61176,-1.59377,0.129294,1.55604,-1.61634,0.208732,1.51658,-1.61354,0.237709,1.87819,-2.10926,0.303821,1.80624,-1.93344,0.095416,1.84211,-2.03287,0.0775,1.66905,-2.21243,0.112406,1.57285,-2.24622,0.266771,1.48604,-2.15217,0.314893,1.44152,-2.14884,0.187682,1.38607,-1.80882,-0.003329,1.43586,-1.88997,0.005895,1.4551,-1.9509,0.010863,1.42487,-2.00579,0.208241,1.36481,-2.06132,0.252183,1.10162,-1.73437,0.13275,1.05237,-1.78201,0.166259,0.976347,-1.80414,0.26519,0.886047,-1.78563,0.309081,0.707918,-1.79211,0.303456,0.632862,-1.81028,0.196982,0.712487,-1.80377,0.194839,0.641106,-1.81624,0.231628,0.42406,-1.84912,0.130728,0.359244,-1.92629,0.387146,0.389334,-1.88341,0.359799,0.33921,-1.81242,0.189489,1.05413,-2.11349,0.202805,0.97125,-2.09859,0.052264,1.03298,-2.07411,0.067964,0.952821,-2.05826,0.113344,0.835592,-2.07168,-0.052356,0.80496,-2.06621,-0.035921,0.917975,-2.07185,-0.104744,0.92211,-2.06533,-0.336675,0.92419,-2.04793,-0.363866,1.02166,-1.98438,-0.471051,0.760424,-2.00995,-0.49311,0.821981,-2.06679,0.112153,1.29569,-1.81767,0.123408,1.2779,-2.03187},
/*553*/{0.202681,1.84416,-1.70879,0.291729,1.79482,-1.85763,0.086353,1.69907,-1.63016,-0.009923,1.60347,-1.58863,0.137878,1.5512,-1.61518,0.21802,1.51273,-1.61322,0.23686,1.87481,-2.11084,0.304379,1.80212,-1.93478,0.094999,1.84007,-2.03054,0.073371,1.6665,-2.21168,0.106242,1.56983,-2.24556,0.25876,1.47688,-2.15476,0.30575,1.4325,-2.15251,0.185271,1.38372,-1.80746,-0.006453,1.43231,-1.89275,0.002959,1.4525,-1.951,0.00791,1.41991,-2.00732,0.205552,1.36049,-2.06118,0.248857,1.10186,-1.73487,0.129372,1.05066,-1.78094,0.166431,0.975008,-1.80411,0.269247,0.892141,-1.78431,0.301903,0.706978,-1.79313,0.295928,0.632408,-1.80991,0.188754,0.714775,-1.8028,0.184728,0.644517,-1.81458,0.212136,0.424951,-1.85029,0.109301,0.359875,-1.92669,0.36566,0.388324,-1.88348,0.33905,0.338509,-1.81299,0.19483,1.0542,-2.11372,0.210069,0.971499,-2.09912,0.057275,1.02869,-2.07406,0.074781,0.948746,-2.05917,0.125295,0.832604,-2.07211,-0.038438,0.802065,-2.06644,-0.021588,0.915097,-2.0723,-0.091049,0.91883,-2.06601,-0.321714,0.923432,-2.04873,-0.350338,1.02104,-1.98619,-0.454652,0.757766,-2.01095,-0.480396,0.819923,-2.07014,0.109019,1.29334,-1.81705,0.12112,1.2736,-2.03104},
/*554*/{0.204193,1.84089,-1.70845,0.292385,1.79086,-1.858,0.092124,1.6932,-1.62883,-0.000274,1.59688,-1.58432,0.14764,1.54728,-1.61386,0.227687,1.51026,-1.61258,0.236248,1.87224,-2.11163,0.30427,1.79848,-1.93611,0.094007,1.83948,-2.02947,0.069468,1.6656,-2.20958,0.100156,1.56849,-2.24478,0.250776,1.47154,-2.15577,0.296637,1.42485,-2.15584,0.183102,1.38206,-1.80552,-0.009236,1.42978,-1.89483,0.001191,1.45068,-1.95172,0.005549,1.41486,-2.00791,0.204044,1.35695,-2.06003,0.244649,1.10242,-1.73501,0.12684,1.0477,-1.7795,0.166445,0.973972,-1.80319,0.274094,0.896929,-1.78412,0.292021,0.705336,-1.79253,0.284411,0.632017,-1.8096,0.179472,0.717582,-1.80058,0.172777,0.646304,-1.81345,0.191901,0.424132,-1.84987,0.088152,0.360165,-1.92682,0.344196,0.387036,-1.88354,0.316758,0.338813,-1.81281,0.200001,1.0547,-2.11331,0.218361,0.972827,-2.09919,0.063243,1.02489,-2.0742,0.084223,0.945549,-2.06006,0.138758,0.829718,-2.07229,-0.024124,0.799393,-2.06572,-0.006998,0.912113,-2.07468,-0.075666,0.916702,-2.06706,-0.307567,0.921283,-2.05066,-0.337977,1.0182,-1.9875,-0.438464,0.754024,-2.01266,-0.464501,0.816758,-2.07165,0.106293,1.29187,-1.81566,0.119817,1.26982,-2.02934},
/*555*/{0.205594,1.83878,-1.70913,0.291829,1.79001,-1.86025,0.097787,1.6889,-1.62735,0.009429,1.59145,-1.57946,0.156741,1.54384,-1.61293,0.237714,1.50846,-1.6125,0.236321,1.87008,-2.11214,0.302733,1.79706,-1.93758,0.093944,1.83917,-2.02955,0.065856,1.6655,-2.20735,0.092858,1.56858,-2.24354,0.241929,1.46666,-2.15758,0.28761,1.41806,-2.15939,0.17994,1.38117,-1.80351,-0.011214,1.42832,-1.89578,-0.00013,1.45079,-1.95311,0.003634,1.41174,-2.00972,0.202735,1.35484,-2.05966,0.24066,1.1016,-1.73471,0.123256,1.04627,-1.77966,0.16265,0.971833,-1.80163,0.279516,0.897109,-1.78456,0.281343,0.704091,-1.791,0.271731,0.630632,-1.80799,0.169068,0.719106,-1.79997,0.160427,0.648906,-1.81215,0.171859,0.425367,-1.8499,0.066347,0.361303,-1.9261,0.323506,0.386623,-1.88331,0.295723,0.338032,-1.81204,0.206741,1.05575,-2.11348,0.226385,0.974474,-2.09903,0.069681,1.02124,-2.07576,0.092979,0.944152,-2.06172,0.153755,0.82811,-2.07142,-0.009162,0.79637,-2.0646,0.007919,0.908294,-2.07481,-0.061035,0.914241,-2.06831,-0.293544,0.918163,-2.05081,-0.325825,1.01434,-1.98861,-0.421421,0.748854,-2.01397,-0.448794,0.810738,-2.07237,0.103058,1.29113,-1.81505,0.11839,1.26773,-2.02846},
/*556*/{0.206947,1.83692,-1.70953,0.291066,1.7868,-1.86017,0.103975,1.68539,-1.62587,0.019209,1.58629,-1.57608,0.165988,1.54191,-1.61186,0.248207,1.50759,-1.61176,0.23635,1.86867,-2.11121,0.302618,1.79559,-1.93768,0.093303,1.83805,-2.0293,0.060888,1.66713,-2.20509,0.086132,1.5703,-2.24218,0.233457,1.46315,-2.15845,0.277754,1.41324,-2.163,0.177696,1.38003,-1.8009,-0.012033,1.42781,-1.89593,-0.000873,1.44952,-1.95299,0.001667,1.41113,-2.01033,0.20094,1.35208,-2.0591,0.23762,1.09853,-1.73417,0.120729,1.04446,-1.778,0.159347,0.970243,-1.8005,0.278605,0.89506,-1.78414,0.268604,0.701217,-1.78841,0.256322,0.628387,-1.80691,0.157868,0.719591,-1.79891,0.146941,0.648642,-1.81082,0.152249,0.425168,-1.84847,0.045621,0.362249,-1.92581,0.302972,0.386699,-1.88238,0.274545,0.337217,-1.81086,0.213186,1.05765,-2.1131,0.235187,0.976975,-2.0983,0.077139,1.01953,-2.07752,0.102359,0.941711,-2.06363,0.169293,0.82755,-2.07124,0.00538,0.794363,-2.06393,0.021622,0.904829,-2.07709,-0.046962,0.911237,-2.06892,-0.279836,0.913581,-2.05137,-0.315648,1.01018,-1.99075,-0.403059,0.742434,-2.01321,-0.4287,0.801159,-2.07215,0.100168,1.29032,-1.81386,0.116185,1.26572,-2.02708},
/*557*/{0.207535,1.83551,-1.71039,0.29002,1.78628,-1.86065,0.109273,1.68295,-1.62474,0.027688,1.5821,-1.57252,0.176739,1.54027,-1.61109,0.258817,1.50818,-1.61327,0.23508,1.86692,-2.11097,0.300377,1.79368,-1.93831,0.093287,1.83799,-2.02951,0.055053,1.6702,-2.20142,0.079918,1.57286,-2.2409,0.225548,1.46135,-2.16024,0.268335,1.40922,-2.16597,0.174585,1.37965,-1.79997,-0.013711,1.42684,-1.89702,-0.003035,1.4494,-1.95287,0.000433,1.4111,-2.01084,0.198534,1.35064,-2.05917,0.234105,1.0972,-1.73175,0.114303,1.04248,-1.77797,0.151654,0.968107,-1.80043,0.272885,0.890203,-1.78391,0.255933,0.698059,-1.78641,0.242833,0.625213,-1.80385,0.144677,0.718678,-1.79903,0.132106,0.648505,-1.80995,0.132184,0.424173,-1.84747,0.024677,0.361978,-1.92542,0.281736,0.385456,-1.88059,0.25312,0.336795,-1.80943,0.219947,1.05996,-2.1128,0.246144,0.980269,-2.09812,0.086343,1.01703,-2.07914,0.11242,0.940365,-2.0652,0.185197,0.828323,-2.07055,0.02026,0.792053,-2.06284,0.035617,0.903044,-2.07818,-0.033177,0.908799,-2.07032,-0.266695,0.907641,-2.05228,-0.305492,1.00456,-1.99289,-0.385414,0.734065,-2.014,-0.415184,0.793036,-2.0747,0.097076,1.28981,-1.81372,0.113837,1.26485,-2.02685},
/*558*/{0.208778,1.83402,-1.71086,0.290082,1.78511,-1.86115,0.114401,1.68131,-1.62374,0.037332,1.57957,-1.56932,0.186337,1.53973,-1.61021,0.269455,1.50965,-1.61366,0.235061,1.86595,-2.11068,0.300226,1.79302,-1.93791,0.092858,1.83813,-2.03009,0.049918,1.67384,-2.19795,0.07208,1.57622,-2.24022,0.216633,1.46031,-2.16204,0.25878,1.40791,-2.16861,0.173307,1.37954,-1.79822,-0.014466,1.42711,-1.89705,-0.003773,1.44972,-1.9531,-0.001042,1.41185,-2.01113,0.198002,1.35069,-2.05906,0.227707,1.09376,-1.73173,0.107892,1.04071,-1.77911,0.145343,0.966243,-1.80083,0.262299,0.885238,-1.78239,0.241573,0.693022,-1.78565,0.227281,0.622749,-1.8031,0.131561,0.717457,-1.79835,0.117166,0.648251,-1.81065,0.110068,0.425964,-1.84647,0.003043,0.362879,-1.9239,0.259818,0.385855,-1.88021,0.231217,0.336512,-1.80923,0.228422,1.06363,-2.11296,0.256095,0.984405,-2.09797,0.093747,1.01883,-2.08198,0.124305,0.939657,-2.06615,0.201605,0.830379,-2.06964,0.035947,0.790327,-2.06229,0.049961,0.901639,-2.07893,-0.020234,0.905947,-2.07117,-0.25275,0.90193,-2.05314,-0.296341,0.998284,-1.99574,-0.365431,0.72489,-2.01389,-0.398308,0.781712,-2.07557,0.09541,1.28987,-1.8135,0.11289,1.26511,-2.02659},
/*559*/{0.209582,1.83376,-1.71169,0.290188,1.78434,-1.86148,0.119118,1.68039,-1.62272,0.046567,1.57572,-1.56614,0.196145,1.54009,-1.61034,0.280194,1.51189,-1.61487,0.234599,1.86585,-2.11066,0.299916,1.79202,-1.93823,0.092277,1.8383,-2.0308,0.043956,1.67861,-2.19504,0.064995,1.5802,-2.23958,0.20857,1.46122,-2.16376,0.248923,1.40692,-2.17125,0.170579,1.37924,-1.79689,-0.014879,1.42692,-1.89644,-0.005033,1.44861,-1.95198,-0.001383,1.41293,-2.00958,0.196567,1.35161,-2.05899,0.222637,1.08927,-1.73142,0.102513,1.03868,-1.77806,0.137469,0.964233,-1.80147,0.250884,0.88069,-1.78155,0.226783,0.689406,-1.78435,0.208992,0.616891,-1.80205,0.118363,0.71645,-1.79782,0.102262,0.647073,-1.8098,0.091096,0.424942,-1.84502,-0.01804,0.363805,-1.92368,0.239227,0.385366,-1.87959,0.20922,0.335546,-1.80874,0.236156,1.06749,-2.11282,0.266348,0.989437,-2.09745,0.103009,1.01776,-2.08329,0.135954,0.941243,-2.06703,0.217148,0.832007,-2.06835,0.051088,0.788677,-2.0614,0.062552,0.900816,-2.07954,-0.006916,0.904208,-2.0728,-0.239928,0.89531,-2.05374,-0.286206,0.990399,-1.99842,-0.346838,0.713837,-2.01345,-0.379757,0.768817,-2.07654,0.093954,1.28915,-1.81322,0.111961,1.26575,-2.02643},
/*560*/{0.210654,1.83389,-1.71169,0.289247,1.78259,-1.86203,0.124066,1.68031,-1.62139,0.056656,1.57362,-1.5629,0.205812,1.54123,-1.60974,0.290597,1.51559,-1.61632,0.233515,1.86611,-2.11073,0.298585,1.7915,-1.9386,0.091721,1.83905,-2.03052,0.039212,1.68444,-2.19135,0.058117,1.58507,-2.23949,0.200601,1.46261,-2.16632,0.239725,1.40793,-2.17349,0.169287,1.37911,-1.79673,-0.016216,1.42718,-1.8963,-0.00656,1.44929,-1.95171,-0.003106,1.41353,-2.00854,0.195623,1.35284,-2.05927,0.217443,1.0863,-1.73155,0.09507,1.03855,-1.77888,0.128727,0.96317,-1.80056,0.238692,0.87576,-1.77996,0.212863,0.685605,-1.78432,0.192927,0.613743,-1.80163,0.104371,0.715187,-1.79735,0.087429,0.646725,-1.81028,0.070674,0.426357,-1.84459,-0.038271,0.364381,-1.92275,0.218601,0.384971,-1.87915,0.189914,0.336289,-1.80735,0.244316,1.07289,-2.11274,0.276745,0.995259,-2.0974,0.112587,1.01838,-2.08445,0.148194,0.942254,-2.06837,0.231715,0.839198,-2.07111,0.066142,0.788139,-2.06077,0.07633,0.900387,-2.07933,0.006668,0.901303,-2.07443,-0.229258,0.887087,-2.05315,-0.279398,0.981872,-1.99985,-0.32539,0.702717,-2.01415,-0.360479,0.755765,-2.07704,0.092817,1.28909,-1.81352,0.110745,1.26674,-2.02684},
/*561*/{0.211817,1.83406,-1.7116,0.288748,1.78495,-1.8634,0.128273,1.68097,-1.62061,0.064829,1.57217,-1.56018,0.215213,1.54331,-1.60957,0.301341,1.52016,-1.61851,0.232238,1.86669,-2.11135,0.297819,1.79162,-1.93968,0.090683,1.84126,-2.02974,0.033602,1.69004,-2.18893,0.050139,1.59059,-2.23925,0.191591,1.46465,-2.16839,0.22977,1.4102,-2.1763,0.168206,1.3795,-1.79591,-0.017608,1.42761,-1.89607,-0.007698,1.44976,-1.95163,-0.00461,1.41475,-2.0074,0.193163,1.35525,-2.06048,0.21046,1.08283,-1.7319,0.086289,1.03931,-1.77963,0.119744,0.961189,-1.7997,0.224703,0.870875,-1.77957,0.197474,0.681056,-1.78419,0.176895,0.609841,-1.80148,0.090317,0.713106,-1.79761,0.071038,0.644485,-1.81064,0.050102,0.426986,-1.84397,-0.059532,0.364875,-1.92209,0.19802,0.384756,-1.87711,0.169315,0.33599,-1.80704,0.252311,1.0778,-2.11216,0.287048,1.00225,-2.09721,0.122353,1.02013,-2.08522,0.160182,0.944506,-2.06989,0.246452,0.8426,-2.07001,0.081633,0.787306,-2.06008,0.090236,0.900877,-2.07974,0.019276,0.899993,-2.07476,-0.214298,0.880282,-2.05517,-0.272456,0.971642,-2.00071,-0.303217,0.68973,-2.0125,-0.340058,0.741433,-2.07822,0.09204,1.28931,-1.81414,0.10939,1.26841,-2.02766},
/*562*/{0.213121,1.83608,-1.71182,0.288558,1.78529,-1.86373,0.132575,1.68162,-1.61878,0.074329,1.57086,-1.55723,0.224957,1.54688,-1.60994,0.311685,1.52517,-1.62054,0.230627,1.86809,-2.1115,0.296848,1.79269,-1.94003,0.089086,1.84219,-2.02929,0.027892,1.69604,-2.18667,0.042612,1.59631,-2.23946,0.183801,1.46819,-2.17082,0.220401,1.41308,-2.17817,0.167452,1.37975,-1.79504,-0.01806,1.42813,-1.89598,-0.00784,1.45068,-1.95132,-0.005818,1.41621,-2.00774,0.19273,1.35678,-2.06106,0.205226,1.08249,-1.73246,0.080235,1.04097,-1.77958,0.109591,0.961605,-1.80037,0.210906,0.865816,-1.77939,0.182343,0.677529,-1.78407,0.161999,0.608849,-1.80167,0.075795,0.711922,-1.79848,0.054886,0.643573,-1.81136,0.030159,0.427218,-1.84355,-0.080186,0.365931,-1.9216,0.177709,0.384431,-1.87724,0.148396,0.335529,-1.80634,0.259152,1.08541,-2.11347,0.296895,1.01005,-2.09711,0.131878,1.02244,-2.08627,0.170132,0.951202,-2.072,0.261329,0.847726,-2.07061,0.097306,0.787957,-2.05981,0.101651,0.901168,-2.08195,0.031729,0.899469,-2.07512,-0.200549,0.871111,-2.05538,-0.264536,0.960167,-2.00327,-0.280784,0.677233,-2.00982,-0.320178,0.726391,-2.0783,0.09131,1.28956,-1.81467,0.108873,1.26981,-2.02828},
/*563*/{0.214148,1.8384,-1.71224,0.288214,1.78737,-1.86499,0.136927,1.6835,-1.61839,0.083714,1.57126,-1.55542,0.233963,1.55091,-1.6102,0.320541,1.53109,-1.62312,0.22833,1.86996,-2.1117,0.295887,1.79364,-1.94103,0.087543,1.84482,-2.02898,0.023487,1.70246,-2.18507,0.035116,1.60257,-2.23928,0.175312,1.47242,-2.17259,0.211794,1.41711,-2.17988,0.167048,1.38056,-1.79582,-0.018734,1.42907,-1.8958,-0.008538,1.45154,-1.95078,-0.006093,1.41702,-2.0066,0.191992,1.35919,-2.0617,0.198542,1.08068,-1.73302,0.073713,1.04129,-1.77924,0.101541,0.960667,-1.79984,0.196592,0.860285,-1.77867,0.167433,0.676269,-1.78477,0.144662,0.605297,-1.80203,0.061061,0.711286,-1.79816,0.038973,0.643285,-1.81029,0.01134,0.427306,-1.84315,-0.100208,0.366963,-1.92125,0.156126,0.384212,-1.87748,0.127983,0.335604,-1.80564,0.265813,1.09251,-2.11364,0.306168,1.01842,-2.09715,0.140626,1.026,-2.08764,0.181111,0.955683,-2.07348,0.275022,0.852871,-2.07118,0.113193,0.788959,-2.05993,0.113618,0.902068,-2.0825,0.04379,0.898641,-2.07681,-0.187557,0.862606,-2.0562,-0.257146,0.948258,-2.0044,-0.258692,0.664804,-2.01169,-0.299345,0.711266,-2.0795,0.091601,1.29019,-1.81525,0.108616,1.27158,-2.029},
/*564*/{0.215754,1.84092,-1.71282,0.287575,1.78911,-1.86568,0.140658,1.6859,-1.61712,0.092044,1.57205,-1.5531,0.242285,1.55531,-1.61142,0.329939,1.53815,-1.62623,0.225537,1.87243,-2.11203,0.294419,1.79554,-1.94228,0.086025,1.84614,-2.02747,0.017651,1.70855,-2.18452,0.026968,1.60922,-2.23976,0.167669,1.47779,-2.17435,0.202415,1.42189,-2.18161,0.166911,1.38085,-1.79528,-0.018558,1.4303,-1.89618,-0.009061,1.45345,-1.95087,-0.006827,1.41839,-2.00644,0.19169,1.36218,-2.06244,0.189945,1.07792,-1.73402,0.066997,1.04185,-1.77902,0.089954,0.961804,-1.80111,0.181616,0.856214,-1.77922,0.152053,0.674183,-1.78512,0.12711,0.603552,-1.80256,0.045829,0.710784,-1.7989,0.023514,0.643178,-1.80999,-0.009109,0.427319,-1.8422,-0.120985,0.368183,-1.92179,0.136318,0.384031,-1.87671,0.106937,0.3355,-1.80552,0.272471,1.1002,-2.11366,0.31453,1.02761,-2.09738,0.149148,1.02988,-2.08842,0.191928,0.96045,-2.07402,0.288361,0.858641,-2.07134,0.129031,0.790563,-2.06052,0.124638,0.903251,-2.08316,0.055408,0.897367,-2.07713,-0.175017,0.85256,-2.05913,-0.248494,0.933902,-2.00577,-0.236183,0.651562,-2.01202,-0.277712,0.695924,-2.08024,0.091452,1.2908,-1.81627,0.108554,1.27389,-2.03016},
/*565*/{0.216782,1.84411,-1.71362,0.28679,1.79103,-1.86698,0.145932,1.68838,-1.6169,0.100953,1.57289,-1.55158,0.250618,1.56051,-1.61323,0.33808,1.54515,-1.6294,0.222304,1.8749,-2.11175,0.293587,1.79774,-1.94309,0.083595,1.84822,-2.02627,0.011335,1.71471,-2.18373,0.019758,1.61604,-2.23956,0.159184,1.48343,-2.17554,0.193991,1.42754,-2.18275,0.166912,1.38172,-1.79604,-0.019123,1.4324,-1.89555,-0.008282,1.45513,-1.95042,-0.007439,1.42035,-2.00611,0.190983,1.36468,-2.06278,0.182629,1.07574,-1.73545,0.058072,1.04264,-1.77953,0.081371,0.962505,-1.80113,0.164846,0.854019,-1.78008,0.136296,0.672651,-1.78614,0.111049,0.603317,-1.80317,0.030534,0.711705,-1.79879,0.007239,0.644388,-1.8108,-0.028408,0.428381,-1.84321,-0.141286,0.369181,-1.92147,0.115253,0.383056,-1.87648,0.085192,0.335012,-1.80522,0.278608,1.108,-2.11407,0.322195,1.03702,-2.09759,0.156791,1.03376,-2.08874,0.202006,0.966255,-2.07409,0.30154,0.866591,-2.07195,0.1444,0.792733,-2.06079,0.135485,0.905505,-2.08242,0.066881,0.895572,-2.07873,-0.162292,0.841676,-2.05811,-0.242808,0.920447,-2.0055,-0.210957,0.638478,-2.01302,-0.256045,0.679958,-2.08106,0.091428,1.29194,-1.81689,0.107909,1.27611,-2.03091},
/*566*/{0.218708,1.84759,-1.71411,0.287456,1.79443,-1.86806,0.149777,1.69094,-1.61647,0.108891,1.57482,-1.55035,0.258006,1.56583,-1.61463,0.345702,1.55288,-1.63282,0.218611,1.87826,-2.11222,0.292445,1.80019,-1.94462,0.081882,1.85119,-2.02503,0.005254,1.72156,-2.1838,0.012157,1.62291,-2.24005,0.151346,1.48986,-2.17663,0.18596,1.43397,-2.18382,0.167318,1.38189,-1.79621,-0.018268,1.43433,-1.89485,-0.008583,1.4566,-1.95022,-0.006517,1.4223,-2.00614,0.190858,1.36775,-2.06316,0.178195,1.07684,-1.73456,0.049514,1.04483,-1.78026,0.071107,0.963049,-1.80113,0.149811,0.852542,-1.78196,0.121092,0.671703,-1.7869,0.094954,0.602933,-1.80375,0.015634,0.712421,-1.79938,-0.00956,0.645809,-1.81151,-0.049872,0.428241,-1.8414,-0.161538,0.370512,-1.92112,0.094892,0.382599,-1.87677,0.064916,0.335482,-1.80543,0.282893,1.11685,-2.1145,0.329629,1.04601,-2.09786,0.164058,1.03823,-2.08892,0.210355,0.971951,-2.07429,0.314774,0.875137,-2.07216,0.158689,0.794043,-2.06101,0.146588,0.9064,-2.0848,0.077833,0.89228,-2.07988,-0.149872,0.830809,-2.05808,-0.234543,0.903885,-2.00759,-0.187554,0.625168,-2.01349,-0.234113,0.663921,-2.0818,0.091857,1.29254,-1.81792,0.108178,1.27863,-2.03208},
/*567*/{0.220109,1.85118,-1.71467,0.286626,1.79801,-1.86945,0.155142,1.69396,-1.61584,0.118007,1.5771,-1.54962,0.264744,1.57192,-1.61641,0.35231,1.56084,-1.63637,0.215456,1.8819,-2.11251,0.291257,1.8035,-1.9458,0.080306,1.85274,-2.02268,-0.000626,1.72792,-2.18344,0.004464,1.62974,-2.24047,0.143809,1.49696,-2.17671,0.177954,1.44077,-2.18464,0.167266,1.38341,-1.79643,-0.016403,1.43815,-1.89486,-0.008004,1.45868,-1.94959,-0.006098,1.42403,-2.00608,0.190709,1.37092,-2.06304,0.170494,1.07377,-1.73747,0.040697,1.04723,-1.78104,0.060269,0.964783,-1.80171,0.132927,0.852056,-1.78365,0.104991,0.671554,-1.78786,0.076964,0.602981,-1.80426,0.00063,0.71354,-1.79963,-0.025601,0.647791,-1.81106,-0.069683,0.429553,-1.84162,-0.181578,0.372313,-1.92013,0.075562,0.382821,-1.87621,0.04528,0.335547,-1.80526,0.287183,1.12445,-2.11447,0.336572,1.05555,-2.09814,0.171043,1.04342,-2.08844,0.219666,0.977968,-2.07382,0.326566,0.884692,-2.07262,0.173828,0.796449,-2.06187,0.156394,0.907825,-2.08505,0.088023,0.892218,-2.08105,-0.132749,0.816859,-2.05698,-0.22599,0.887716,-2.00762,-0.16277,0.611602,-2.01538,-0.211922,0.647903,-2.08311,0.092249,1.29465,-1.81811,0.1083,1.2812,-2.03233},
/*568*/{0.22198,1.85506,-1.71549,0.286467,1.80085,-1.87118,0.161355,1.69705,-1.61533,0.125703,1.58,-1.5483,0.271792,1.57852,-1.61872,0.358928,1.56994,-1.64007,0.211627,1.88607,-2.11272,0.290183,1.80704,-1.94792,0.077966,1.85537,-2.0209,-0.006249,1.73449,-2.18299,-0.002032,1.63674,-2.24001,0.136203,1.50406,-2.17765,0.170685,1.44784,-2.18577,0.167752,1.38439,-1.79661,-0.017586,1.43869,-1.89455,-0.007848,1.46015,-1.94873,-0.006328,1.42812,-2.00633,0.190981,1.37432,-2.06329,0.162556,1.07169,-1.73912,0.033273,1.04992,-1.78081,0.04923,0.967027,-1.80243,0.119375,0.853737,-1.78553,0.08769,0.671378,-1.78859,0.059554,0.603593,-1.80579,-0.015804,0.715453,-1.80007,-0.042702,0.649634,-1.8121,-0.088347,0.432294,-1.84137,-0.201573,0.374861,-1.91987,0.055336,0.382748,-1.87654,0.024478,0.33511,-1.80606,0.292729,1.13267,-2.11459,0.342454,1.06474,-2.09802,0.178075,1.0479,-2.08802,0.227776,0.984848,-2.0742,0.337826,0.894796,-2.07256,0.188369,0.798915,-2.0625,0.165224,0.908906,-2.08549,0.096547,0.891508,-2.08183,-0.118613,0.80473,-2.05682,-0.217233,0.869449,-2.00598,-0.136573,0.598522,-2.01632,-0.189006,0.632069,-2.08409,0.092419,1.2953,-1.81949,0.10867,1.28456,-2.03385},
/*569*/{0.223606,1.85954,-1.71619,0.286357,1.8042,-1.87147,0.166707,1.70024,-1.61549,0.132807,1.58244,-1.54772,0.277356,1.58539,-1.6211,0.365066,1.57866,-1.64425,0.206401,1.88982,-2.11182,0.289927,1.81091,-1.9487,0.075359,1.85785,-2.01923,-0.011879,1.74195,-2.18195,-0.009065,1.64368,-2.24006,0.12886,1.51125,-2.17848,0.163464,1.45592,-2.18627,0.168532,1.3856,-1.79662,-0.015746,1.44113,-1.89426,-0.007024,1.46347,-1.94741,-0.004904,1.42942,-2.0058,0.190756,1.37792,-2.06269,0.156587,1.07171,-1.74094,0.026697,1.05233,-1.78039,0.039408,0.970107,-1.80439,0.105327,0.855188,-1.78713,0.070667,0.672977,-1.78973,0.042222,0.605257,-1.80625,-0.03156,0.717026,-1.80242,-0.059391,0.652725,-1.81235,-0.108694,0.432923,-1.84111,-0.221355,0.378312,-1.91952,0.034992,0.382322,-1.8763,0.004075,0.334967,-1.80609,0.296947,1.13996,-2.11373,0.348681,1.07441,-2.09784,0.184085,1.05326,-2.08799,0.236078,0.990602,-2.07342,0.34726,0.905192,-2.07291,0.202276,0.801872,-2.06408,0.173844,0.910233,-2.08599,0.106882,0.889293,-2.08197,-0.105338,0.793078,-2.05775,-0.205971,0.851018,-2.00527,-0.109791,0.586673,-2.01962,-0.164547,0.616038,-2.08526,0.09344,1.29697,-1.81968,0.109338,1.28742,-2.03411},
/*570*/{0.225549,1.86437,-1.71686,0.287444,1.80955,-1.87363,0.172717,1.70416,-1.61558,0.141641,1.58611,-1.54751,0.284059,1.59267,-1.62352,0.369315,1.58734,-1.64844,0.202634,1.89456,-2.11191,0.288658,1.81547,-1.9502,0.073901,1.85995,-2.01694,-0.017224,1.74908,-2.18123,-0.015775,1.65049,-2.23972,0.122711,1.51988,-2.17852,0.155976,1.46346,-2.18666,0.169554,1.38707,-1.79576,-0.015418,1.44358,-1.89291,-0.006603,1.4663,-1.94716,-0.004039,1.43276,-2.00511,0.192965,1.38292,-2.06244,0.149887,1.07394,-1.74377,0.019764,1.0554,-1.78012,0.029831,0.972515,-1.80253,0.094581,0.85705,-1.78849,0.05455,0.674557,-1.79051,0.02514,0.606656,-1.80774,-0.048351,0.719238,-1.80283,-0.0751,0.654359,-1.81284,-0.128323,0.434794,-1.84005,-0.241117,0.382311,-1.91882,0.015086,0.381658,-1.87573,-0.017025,0.334729,-1.80561,0.300974,1.148,-2.11455,0.354596,1.08359,-2.0978,0.190116,1.05865,-2.088,0.241629,0.997129,-2.0725,0.357197,0.915871,-2.07308,0.215582,0.804877,-2.06471,0.181262,0.911901,-2.08753,0.115376,0.886657,-2.08169,-0.092213,0.779762,-2.05825,-0.195468,0.831362,-2.00578,-0.083557,0.574132,-2.022,-0.140796,0.60062,-2.08743,0.09459,1.29865,-1.82039,0.111229,1.29176,-2.03487},
/*571*/{0.227375,1.86906,-1.71773,0.286792,1.81297,-1.87488,0.17888,1.70777,-1.61595,0.148285,1.5905,-1.54736,0.288471,1.59945,-1.62585,0.375129,1.59657,-1.65267,0.198665,1.89907,-2.1119,0.287793,1.81972,-1.9517,0.071491,1.86209,-2.01554,-0.022437,1.75614,-2.18065,-0.021801,1.65808,-2.23908,0.117228,1.52746,-2.17771,0.149841,1.47185,-2.18772,0.170738,1.38746,-1.79571,-0.013838,1.44594,-1.89215,-0.005174,1.46897,-1.94503,-0.003573,1.43637,-2.0052,0.193136,1.38691,-2.0614,0.144221,1.07454,-1.74596,0.010976,1.05712,-1.77998,0.020096,0.97623,-1.8029,0.083641,0.858978,-1.78985,0.038508,0.676168,-1.79172,0.007631,0.608668,-1.80685,-0.064646,0.721975,-1.80387,-0.092262,0.657913,-1.8133,-0.145949,0.437419,-1.83844,-0.260511,0.387647,-1.91778,-0.004561,0.380775,-1.8761,-0.037468,0.335034,-1.80627,0.304811,1.15575,-2.11452,0.358709,1.09235,-2.09764,0.19528,1.06393,-2.0879,0.249349,1.00442,-2.07293,0.36602,0.926394,-2.07297,0.228493,0.807713,-2.06614,0.188724,0.912761,-2.08748,0.124738,0.884311,-2.08182,-0.081292,0.768841,-2.06035,-0.185832,0.812007,-2.00498,-0.056593,0.563595,-2.02538,-0.116193,0.585683,-2.08927,0.0953,1.29966,-1.82122,0.111704,1.29544,-2.03579},
/*572*/{0.228731,1.87419,-1.71863,0.28628,1.81837,-1.87662,0.184502,1.71215,-1.61636,0.154457,1.59451,-1.54658,0.293035,1.60681,-1.62808,0.378699,1.60547,-1.6566,0.194919,1.90428,-2.1119,0.287424,1.82443,-1.95345,0.069283,1.8659,-2.01295,-0.026938,1.76289,-2.17934,-0.028339,1.66508,-2.2383,0.108987,1.5355,-2.17844,0.14345,1.4798,-2.18854,0.172613,1.38906,-1.79479,-0.012731,1.44926,-1.89047,-0.005015,1.47167,-1.94381,-0.002586,1.44063,-2.00541,0.193778,1.39114,-2.06044,0.13806,1.07319,-1.7478,0.004655,1.0616,-1.78064,0.010542,0.980758,-1.80304,0.073261,0.862037,-1.79241,0.021785,0.679092,-1.79245,-0.008876,0.612351,-1.80833,-0.080313,0.726248,-1.80489,-0.10926,0.660882,-1.81479,-0.1657,0.441331,-1.83903,-0.279507,0.394279,-1.91714,-0.023748,0.380387,-1.87606,-0.057697,0.335698,-1.80645,0.308166,1.16333,-2.11432,0.364241,1.09966,-2.09703,0.200429,1.06985,-2.08808,0.255871,1.01102,-2.0728,0.374143,0.936553,-2.07349,0.241385,0.810376,-2.06728,0.195959,0.913676,-2.08674,0.133362,0.881479,-2.08136,-0.062599,0.754432,-2.05794,-0.175008,0.792038,-2.00491,-0.029236,0.551305,-2.02767,-0.091247,0.571106,-2.09064,0.096264,1.30184,-1.82142,0.112536,1.29948,-2.03603},
/*573*/{0.230059,1.87961,-1.72003,0.286552,1.82287,-1.87761,0.190812,1.71663,-1.61722,0.161072,1.59882,-1.54681,0.297628,1.61454,-1.63052,0.382517,1.6145,-1.66081,0.19089,1.90867,-2.11114,0.285974,1.82922,-1.95492,0.06779,1.86933,-2.01054,-0.032053,1.76973,-2.17864,-0.034109,1.67231,-2.23719,0.102429,1.54398,-2.17861,0.13753,1.48819,-2.18904,0.172569,1.39048,-1.7947,-0.01092,1.45212,-1.89111,-0.002931,1.47498,-1.94332,-0.001599,1.44552,-2.00508,0.194741,1.39539,-2.05954,0.133059,1.07537,-1.75087,0.000143,1.06761,-1.77979,0.00195,0.985888,-1.80303,0.061933,0.863814,-1.79422,0.005464,0.682849,-1.79303,-0.025589,0.616185,-1.80853,-0.095763,0.730497,-1.80529,-0.126381,0.664297,-1.81628,-0.183229,0.445772,-1.8376,-0.29796,0.401763,-1.91641,-0.042795,0.379299,-1.87663,-0.078238,0.335946,-1.80694,0.311724,1.17147,-2.11432,0.367627,1.10995,-2.09763,0.205176,1.0764,-2.08827,0.261995,1.01876,-2.07311,0.380866,0.946434,-2.07339,0.25336,0.81411,-2.06881,0.202417,0.914538,-2.08675,0.141237,0.879441,-2.08155,-0.049122,0.741256,-2.05939,-0.160487,0.770322,-2.0025,-0.001034,0.540388,-2.03041,-0.06446,0.557218,-2.09336,0.096276,1.30371,-1.82253,0.113511,1.30374,-2.03708},
/*574*/{0.231359,1.88491,-1.72103,0.28764,1.82809,-1.87931,0.195364,1.72187,-1.61808,0.167568,1.60365,-1.54661,0.301183,1.62162,-1.63296,0.385908,1.62312,-1.66468,0.187409,1.91334,-2.11064,0.284946,1.83427,-1.95603,0.066909,1.87153,-2.01068,-0.036076,1.7759,-2.17791,-0.040125,1.67994,-2.23618,0.096943,1.55094,-2.17795,0.132237,1.49655,-2.18972,0.174266,1.39149,-1.79394,-0.008969,1.45562,-1.89058,-0.002218,1.47862,-1.9417,0.000559,1.44998,-2.00508,0.19639,1.40099,-2.05918,0.127656,1.0761,-1.7522,-0.007545,1.07498,-1.78185,-0.006545,0.990564,-1.80388,0.048849,0.866577,-1.79561,-0.009831,0.686622,-1.79375,-0.042486,0.620086,-1.80841,-0.11154,0.735032,-1.80619,-0.141427,0.671036,-1.81476,-0.200822,0.450702,-1.83786,-0.315144,0.408857,-1.91561,-0.062028,0.378102,-1.87618,-0.09863,0.336606,-1.80704,0.314899,1.17885,-2.11477,0.371954,1.11844,-2.09688,0.209624,1.08222,-2.08893,0.266886,1.02541,-2.07305,0.387543,0.956776,-2.07326,0.264598,0.817314,-2.07037,0.208957,0.914734,-2.08684,0.148977,0.87561,-2.0812,-0.036482,0.728721,-2.05934,-0.146604,0.748804,-2.00159,0.027403,0.530028,-2.03321,-0.038483,0.54415,-2.09546,0.097576,1.30555,-1.82382,0.115284,1.30889,-2.0383},
/*575*/{0.231915,1.89031,-1.72271,0.287353,1.83298,-1.88083,0.200195,1.72687,-1.61882,0.172798,1.60846,-1.54616,0.304302,1.62873,-1.63541,0.388702,1.63243,-1.66874,0.184638,1.91793,-2.11006,0.284894,1.83927,-1.95769,0.06414,1.87698,-2.00739,-0.04064,1.78252,-2.1773,-0.046037,1.68705,-2.23493,0.090996,1.55881,-2.17767,0.126975,1.50481,-2.19064,0.175958,1.39312,-1.7943,-0.007485,1.459,-1.89026,-0.00042,1.48265,-1.94056,0.001382,1.45465,-2.00496,0.197135,1.40568,-2.05802,0.122894,1.07713,-1.75548,-0.012502,1.0806,-1.78161,-0.014465,0.995788,-1.80389,0.034829,0.87024,-1.79647,-0.025405,0.691542,-1.79386,-0.05749,0.62512,-1.80829,-0.126026,0.740492,-1.80679,-0.156421,0.676945,-1.81467,-0.218491,0.456893,-1.83772,-0.333147,0.417831,-1.91552,-0.080822,0.376993,-1.87704,-0.11885,0.337155,-1.80719,0.317645,1.18631,-2.1144,0.375891,1.12698,-2.09624,0.213932,1.08919,-2.08922,0.271553,1.03266,-2.07348,0.392626,0.966437,-2.07267,0.275371,0.820061,-2.07136,0.213763,0.914846,-2.08662,0.156981,0.873101,-2.08061,-0.020878,0.714653,-2.05961,-0.132702,0.728706,-2.00146,0.056292,0.520177,-2.03757,-0.0098,0.531249,-2.09871,0.098464,1.3079,-1.82478,0.11615,1.31353,-2.03921},
/*576*/{0.232954,1.89585,-1.72419,0.287128,1.8385,-1.8827,0.204559,1.73242,-1.61971,0.17787,1.61322,-1.54631,0.307627,1.63633,-1.6376,0.390536,1.64106,-1.67255,0.181694,1.92253,-2.10955,0.284419,1.84437,-1.95887,0.065157,1.87885,-2.00592,-0.045077,1.78811,-2.17609,-0.051043,1.69382,-2.23272,0.086258,1.56706,-2.17675,0.122098,1.51235,-2.191,0.177721,1.39454,-1.79446,-0.005083,1.46284,-1.88989,0.000887,1.48639,-1.93948,0.003056,1.45992,-2.00476,0.19731,1.40978,-2.05698,0.115673,1.07905,-1.76041,-0.017866,1.08582,-1.78227,-0.022307,1.00224,-1.80398,0.021354,0.875994,-1.79692,-0.039876,0.697262,-1.79402,-0.073591,0.629893,-1.80808,-0.140339,0.746338,-1.8069,-0.172087,0.683283,-1.81599,-0.234393,0.462057,-1.83569,-0.349424,0.42733,-1.91457,-0.100767,0.376481,-1.87725,-0.139565,0.336895,-1.80809,0.321234,1.19369,-2.11374,0.378649,1.13456,-2.09555,0.217642,1.09583,-2.0896,0.276068,1.03875,-2.07331,0.395877,0.975288,-2.07245,0.28531,0.822913,-2.0731,0.21893,0.914467,-2.08599,0.164977,0.869713,-2.08035,-0.009312,0.699768,-2.059,-0.115962,0.706576,-1.99941,0.085368,0.512142,-2.04084,0.018197,0.519752,-2.10182,0.099137,1.3103,-1.8256,0.116575,1.31791,-2.03999},
/*577*/{0.234392,1.90156,-1.72535,0.287128,1.84216,-1.8843,0.207391,1.73777,-1.62047,0.183377,1.61904,-1.54656,0.310334,1.64319,-1.64015,0.393049,1.64878,-1.67633,0.17917,1.92684,-2.10901,0.283373,1.84914,-1.96055,0.063433,1.88202,-2.00397,-0.048666,1.79437,-2.17521,-0.056478,1.70083,-2.23168,0.080762,1.5745,-2.17618,0.117322,1.52043,-2.19148,0.179954,1.39616,-1.79475,-0.003526,1.46627,-1.88866,0.002932,1.49012,-1.93792,0.004913,1.46491,-2.00448,0.198506,1.41541,-2.05641,0.111765,1.08164,-1.76018,-0.021522,1.09195,-1.78226,-0.0295,1.00827,-1.8052,0.007769,0.881955,-1.79675,-0.054145,0.702909,-1.79341,-0.088049,0.636622,-1.80792,-0.153727,0.753129,-1.80726,-0.186363,0.688968,-1.81698,-0.250336,0.466834,-1.83398,-0.365807,0.437599,-1.91424,-0.120174,0.375889,-1.87696,-0.160683,0.337642,-1.80768,0.323638,1.20089,-2.11372,0.381924,1.14239,-2.09554,0.220683,1.1028,-2.09061,0.279566,1.04541,-2.07299,0.398011,0.983718,-2.07272,0.2956,0.825188,-2.07399,0.223703,0.913256,-2.0856,0.171933,0.865345,-2.08028,0.013558,0.688483,-2.06049,-0.100762,0.686516,-1.99925,0.113852,0.50456,-2.0446,0.046105,0.508924,-2.10471,0.100915,1.31253,-1.82692,0.118132,1.32328,-2.04119},
/*578*/{0.234531,1.90626,-1.72681,0.287392,1.84756,-1.8861,0.211219,1.74318,-1.62103,0.186192,1.62399,-1.54667,0.311881,1.65052,-1.64277,0.394359,1.65712,-1.67995,0.17721,1.9309,-2.10916,0.281932,1.85413,-1.96217,0.062941,1.88561,-2.00351,-0.05136,1.80031,-2.17449,-0.061569,1.70746,-2.22958,0.077259,1.58199,-2.17542,0.113133,1.52712,-2.19205,0.181566,1.39808,-1.79535,-0.001225,1.47,-1.8884,0.004952,1.49416,-1.93689,0.007118,1.47006,-2.00462,0.199254,1.41992,-2.05628,0.109665,1.0839,-1.76142,-0.025829,1.09829,-1.78133,-0.035939,1.01495,-1.80451,-0.003838,0.888524,-1.79703,-0.067624,0.708937,-1.79338,-0.101529,0.642728,-1.80735,-0.167318,0.760089,-1.80785,-0.199188,0.69609,-1.81684,-0.265322,0.474303,-1.83319,-0.380951,0.448022,-1.91375,-0.138979,0.37561,-1.8768,-0.181629,0.337858,-1.80804,0.325752,1.20755,-2.1138,0.385052,1.1502,-2.09418,0.223997,1.10908,-2.09145,0.282786,1.05262,-2.07296,0.399181,0.990954,-2.07244,0.304784,0.827659,-2.07529,0.227447,0.910463,-2.08422,0.179214,0.859222,-2.07896,0.033147,0.674935,-2.05971,-0.081884,0.664145,-1.99833,0.143221,0.498177,-2.0489,0.074482,0.498984,-2.10764,0.102048,1.31514,-1.8282,0.119074,1.328,-2.04237},
/*579*/{0.235947,1.91157,-1.72811,0.286572,1.85189,-1.88721,0.214584,1.748,-1.62188,0.190701,1.62996,-1.54681,0.314354,1.6571,-1.64481,0.396278,1.66423,-1.68322,0.174761,1.93438,-2.10865,0.281772,1.85864,-1.9638,0.061904,1.88878,-2.00193,-0.055331,1.80569,-2.17233,-0.065648,1.71387,-2.22774,0.071926,1.5885,-2.17536,0.109339,1.53456,-2.1926,0.184161,1.39944,-1.79651,0.001038,1.47365,-1.88815,0.006306,1.49858,-1.93618,0.008269,1.47508,-2.00456,0.199201,1.42457,-2.0561,0.105806,1.08684,-1.76264,-0.029375,1.10536,-1.782,-0.042836,1.02237,-1.80555,-0.014839,0.894639,-1.79755,-0.080076,0.715644,-1.79277,-0.114708,0.649105,-1.80633,-0.180134,0.767337,-1.80823,-0.212863,0.70426,-1.81663,-0.281736,0.479462,-1.83204,-0.396175,0.459703,-1.91302,-0.157618,0.375143,-1.87737,-0.201698,0.338876,-1.80765,0.327542,1.21374,-2.11367,0.386472,1.15601,-2.09291,0.226711,1.1144,-2.09202,0.285312,1.05882,-2.07283,0.40012,0.997752,-2.07251,0.314054,0.829614,-2.0768,0.231995,0.907733,-2.08337,0.186367,0.853749,-2.07866,0.051504,0.66099,-2.05909,-0.062655,0.641615,-1.99621,0.172491,0.49234,-2.05268,0.102623,0.489299,-2.1107,0.103291,1.3176,-1.82986,0.119312,1.33281,-2.04396},
/*580*/{0.236608,1.91619,-1.72956,0.287282,1.85596,-1.88858,0.216563,1.75336,-1.62231,0.194083,1.63409,-1.5471,0.315395,1.6638,-1.64757,0.396736,1.67164,-1.68597,0.173463,1.93793,-2.1089,0.281427,1.86264,-1.96485,0.06119,1.89201,-2.00107,-0.058845,1.81056,-2.17114,-0.070605,1.71976,-2.22586,0.068939,1.59526,-2.17461,0.105269,1.54084,-2.19306,0.186844,1.40084,-1.79737,0.00272,1.4778,-1.88782,0.008079,1.50247,-1.93493,0.010827,1.48029,-2.00424,0.20007,1.42938,-2.05623,0.100581,1.09037,-1.76645,-0.032298,1.11097,-1.78021,-0.050162,1.0289,-1.80559,-0.023656,0.901447,-1.79729,-0.091733,0.722175,-1.79235,-0.127559,0.656299,-1.80482,-0.190652,0.774976,-1.80874,-0.224209,0.711338,-1.81682,-0.295067,0.486671,-1.8301,-0.409493,0.471792,-1.9126,-0.176843,0.375105,-1.87752,-0.221938,0.340631,-1.80874,0.329833,1.22,-2.11273,0.388584,1.16226,-2.09217,0.228253,1.1198,-2.09264,0.286622,1.06471,-2.07309,0.398693,1.00395,-2.07277,0.322727,0.830272,-2.07776,0.236365,0.904346,-2.08226,0.194633,0.847593,-2.07754,0.065672,0.646996,-2.05939,-0.042209,0.620402,-1.99449,0.201187,0.487695,-2.0557,0.131992,0.480916,-2.11343,0.104798,1.32006,-1.83146,0.120244,1.33784,-2.0454},
/*581*/{0.237361,1.92137,-1.73061,0.28759,1.86084,-1.89027,0.21848,1.75842,-1.62274,0.196853,1.6392,-1.54721,0.316555,1.66996,-1.64948,0.397146,1.67903,-1.69001,0.171696,1.94118,-2.10866,0.280554,1.86667,-1.9657,0.060497,1.89508,-2.00065,-0.060883,1.81478,-2.16722,-0.074739,1.72552,-2.22315,0.06485,1.60101,-2.17388,0.102065,1.54706,-2.19318,0.188887,1.40298,-1.79887,0.004848,1.48094,-1.88752,0.008814,1.50608,-1.93312,0.012734,1.48482,-2.00419,0.199823,1.43375,-2.05611,0.096806,1.09223,-1.7669,-0.035379,1.11737,-1.78038,-0.054809,1.03672,-1.80546,-0.032293,0.907377,-1.79904,-0.103288,0.728982,-1.79154,-0.138126,0.663643,-1.80436,-0.201002,0.781623,-1.80735,-0.235074,0.719236,-1.81601,-0.307262,0.493695,-1.82808,-0.42279,0.484828,-1.91118,-0.195521,0.37552,-1.87743,-0.242808,0.341522,-1.80857,0.33148,1.22518,-2.11238,0.389971,1.16672,-2.09101,0.229443,1.1247,-2.09398,0.28718,1.06946,-2.07393,0.397925,1.00903,-2.07279,0.330915,0.830725,-2.07855,0.241141,0.899985,-2.08176,0.201549,0.841689,-2.07699,0.081316,0.63246,-2.05883,-0.02139,0.599352,-1.99392,0.230015,0.483596,-2.05903,0.160687,0.473458,-2.11628,0.106353,1.32257,-1.83275,0.120642,1.34235,-2.0466},
/*582*/{0.237607,1.9256,-1.73156,0.288312,1.86537,-1.89204,0.220133,1.76321,-1.62328,0.200754,1.64423,-1.54739,0.317321,1.67614,-1.6509,0.398126,1.68604,-1.69298,0.170449,1.94421,-2.10882,0.28037,1.87035,-1.96746,0.060819,1.89654,-2,-0.061135,1.81905,-2.16605,-0.078224,1.73068,-2.22148,0.061509,1.60609,-2.17307,0.099339,1.55294,-2.19373,0.191257,1.405,-1.79998,0.007487,1.48475,-1.88631,0.010271,1.50973,-1.93251,0.014372,1.48976,-2.00363,0.200835,1.43875,-2.05653,0.094016,1.0956,-1.76674,-0.040334,1.12541,-1.78126,-0.059045,1.04306,-1.80394,-0.03963,0.9135,-1.79959,-0.112324,0.735968,-1.79106,-0.1499,0.670441,-1.80254,-0.210994,0.789974,-1.80875,-0.244724,0.72632,-1.816,-0.318578,0.500836,-1.82664,-0.433649,0.498856,-1.90985,-0.214184,0.375722,-1.87713,-0.26316,0.343629,-1.80878,0.332117,1.22975,-2.11147,0.390377,1.17165,-2.08985,0.229911,1.12935,-2.09422,0.287694,1.0742,-2.07511,0.396229,1.01216,-2.07285,0.338978,0.830624,-2.07957,0.246213,0.895643,-2.08071,0.20901,0.834969,-2.07568,0.103107,0.621476,-2.05878,0.000926,0.579172,-1.99244,0.258072,0.480144,-2.06146,0.188833,0.467005,-2.11812,0.108359,1.32528,-1.83422,0.121624,1.34736,-2.04791},
/*583*/{0.239113,1.92926,-1.73353,0.287757,1.86865,-1.89324,0.220884,1.76753,-1.62375,0.20246,1.64833,-1.54704,0.318792,1.6805,-1.65293,0.398562,1.69127,-1.69553,0.169137,1.94678,-2.10865,0.279738,1.87455,-1.96773,0.060846,1.89967,-1.99919,-0.061334,1.82406,-2.16462,-0.08145,1.73587,-2.21901,0.059309,1.61134,-2.17237,0.096447,1.55797,-2.19396,0.193795,1.4067,-1.80175,0.009302,1.48881,-1.88553,0.012635,1.514,-1.93126,0.0161,1.4943,-2.00291,0.20034,1.44258,-2.05648,0.091123,1.09806,-1.76692,-0.043492,1.13156,-1.78155,-0.064537,1.05038,-1.80481,-0.047106,0.91937,-1.79995,-0.122092,0.742421,-1.79042,-0.156714,0.677559,-1.80147,-0.219541,0.796438,-1.80825,-0.254347,0.733231,-1.81549,-0.330837,0.507652,-1.8248,-0.443638,0.512421,-1.90931,-0.231543,0.376627,-1.87655,-0.283237,0.346632,-1.80917,0.333879,1.23384,-2.111,0.391277,1.17514,-2.08893,0.229971,1.13419,-2.09509,0.287495,1.07786,-2.07683,0.395898,1.01547,-2.07414,0.346328,0.830185,-2.08096,0.250269,0.889753,-2.08022,0.217633,0.827019,-2.07534,0.123082,0.608391,-2.05855,0.024003,0.559354,-1.99057,0.285349,0.478,-2.06319,0.216887,0.460973,-2.11944,0.109614,1.32797,-1.83532,0.121258,1.35163,-2.04893},
/*584*/{0.240359,1.93421,-1.73502,0.288591,1.87299,-1.89401,0.222135,1.77261,-1.62397,0.204831,1.65262,-1.54764,0.319567,1.68576,-1.654,0.398383,1.69693,-1.69833,0.168676,1.94957,-2.1084,0.279764,1.87744,-1.96895,0.060992,1.90112,-1.99827,-0.063696,1.8283,-2.16384,-0.084719,1.74086,-2.21618,0.057012,1.6162,-2.17226,0.094508,1.56268,-2.1938,0.195745,1.40953,-1.80222,0.011053,1.49211,-1.88542,0.014276,1.51681,-1.92975,0.017711,1.49879,-2.00265,0.20095,1.4468,-2.05715,0.087108,1.10091,-1.76799,-0.04297,1.13537,-1.77971,-0.068464,1.05765,-1.8055,-0.053463,0.925871,-1.80063,-0.128656,0.749698,-1.79059,-0.166484,0.683865,-1.80025,-0.227272,0.80301,-1.80799,-0.261721,0.741313,-1.81407,-0.340796,0.51518,-1.82294,-0.452304,0.529049,-1.90646,-0.249141,0.378374,-1.87584,-0.301614,0.350175,-1.80825,0.334003,1.23758,-2.10962,0.39056,1.17799,-2.08797,0.229613,1.13881,-2.09597,0.287006,1.08064,-2.07767,0.394367,1.01708,-2.07485,0.35416,0.829537,-2.082,0.255238,0.883765,-2.08024,0.225377,0.819615,-2.07462,0.143191,0.596746,-2.05868,0.047063,0.540041,-1.99055,0.312678,0.476299,-2.06477,0.244438,0.454667,-2.12086,0.111497,1.33086,-1.83618,0.122231,1.35587,-2.04968},
/*585*/{0.241191,1.93696,-1.73598,0.288403,1.87616,-1.89556,0.223329,1.77694,-1.62479,0.206548,1.65664,-1.54724,0.319618,1.68997,-1.65567,0.397335,1.70238,-1.70183,0.168646,1.95112,-2.10815,0.279924,1.88075,-1.96972,0.060486,1.90365,-1.99818,-0.067293,1.83338,-2.15635,-0.086713,1.74477,-2.21402,0.055825,1.62049,-2.17201,0.092696,1.56688,-2.19367,0.198052,1.41088,-1.80409,0.012739,1.496,-1.88456,0.015474,1.52053,-1.9293,0.019369,1.50251,-2.00181,0.20164,1.45022,-2.05719,0.085559,1.10406,-1.76821,-0.044251,1.14111,-1.77919,-0.071977,1.06235,-1.80591,-0.059278,0.931571,-1.80208,-0.136243,0.75575,-1.79039,-0.173817,0.690991,-1.79974,-0.233278,0.810923,-1.80755,-0.268183,0.748434,-1.8121,-0.350613,0.521593,-1.82085,-0.460412,0.542919,-1.90458,-0.266337,0.379198,-1.87526,-0.321714,0.353746,-1.80821,0.333679,1.24042,-2.10911,0.390434,1.17954,-2.08759,0.228999,1.14206,-2.09675,0.286036,1.08264,-2.07863,0.39326,1.01784,-2.07609,0.361323,0.828568,-2.08268,0.260385,0.877467,-2.08004,0.233276,0.811873,-2.07458,0.159565,0.583906,-2.05781,0.069718,0.522399,-1.99105,0.33882,0.474957,-2.0653,0.272204,0.450286,-2.1222,0.112723,1.33322,-1.8373,0.122345,1.35971,-2.05068},
/*586*/{0.24163,1.94034,-1.73735,0.289463,1.87919,-1.8964,0.223755,1.78098,-1.62494,0.207629,1.65992,-1.5479,0.319435,1.69392,-1.65758,0.397564,1.70642,-1.7039,0.166547,1.95401,-2.10844,0.279578,1.8833,-1.97102,0.061295,1.90608,-1.99736,-0.065388,1.83797,-2.15399,-0.088746,1.74864,-2.21185,0.054543,1.62339,-2.17158,0.091141,1.57066,-2.19411,0.199108,1.4133,-1.80406,0.014153,1.4994,-1.88435,0.016403,1.52382,-1.92797,0.020499,1.50671,-2.00038,0.201457,1.45316,-2.05748,0.083446,1.10807,-1.76804,-0.045242,1.1455,-1.77896,-0.075088,1.0692,-1.80724,-0.063667,0.936581,-1.80326,-0.14283,0.761818,-1.7903,-0.180578,0.696976,-1.80023,-0.239176,0.817246,-1.80696,-0.274674,0.755554,-1.81272,-0.357619,0.530133,-1.81967,-0.466256,0.558355,-1.90167,-0.283985,0.381221,-1.87494,-0.341178,0.359198,-1.80826,0.333876,1.24241,-2.10751,0.388889,1.18125,-2.08722,0.227684,1.14467,-2.09749,0.28298,1.0859,-2.08228,0.391885,1.01778,-2.07711,0.367936,0.826901,-2.08396,0.264104,0.869821,-2.07996,0.240988,0.804251,-2.07415,0.182573,0.574119,-2.0586,0.091882,0.505721,-1.99051,0.364754,0.474813,-2.06539,0.299076,0.445721,-2.12233,0.113287,1.33604,-1.83731,0.121985,1.36314,-2.05066},
/*587*/{0.242921,1.94303,-1.7379,0.289486,1.8821,-1.89736,0.224193,1.78505,-1.62563,0.208215,1.66313,-1.54713,0.319795,1.69744,-1.6586,0.397013,1.71028,-1.7061,0.166985,1.95559,-2.10866,0.279435,1.88576,-1.97115,0.060745,1.90832,-1.99713,-0.066835,1.84132,-2.15136,-0.090584,1.75205,-2.20935,0.053034,1.62665,-2.17084,0.090017,1.57396,-2.19395,0.200624,1.41515,-1.80486,0.015737,1.50259,-1.88254,0.017828,1.52769,-1.92697,0.020592,1.51041,-1.99876,0.202088,1.45686,-2.05719,0.080503,1.11008,-1.7682,-0.047382,1.15177,-1.78007,-0.076283,1.07312,-1.80602,-0.066222,0.941742,-1.8044,-0.14626,0.768144,-1.79062,-0.185778,0.703215,-1.79858,-0.243573,0.824229,-1.8061,-0.279333,0.762186,-1.81114,-0.368258,0.53826,-1.81702,-0.471966,0.573855,-1.8989,-0.300656,0.383681,-1.87503,-0.359441,0.365168,-1.8084,0.333044,1.24324,-2.10689,0.38841,1.18153,-2.08695,0.226099,1.1464,-2.09761,0.280234,1.08727,-2.08272,0.389759,1.01749,-2.07862,0.374286,0.825186,-2.08532,0.268162,0.863511,-2.07878,0.248289,0.796514,-2.07402,0.201438,0.563484,-2.05872,0.116687,0.490941,-1.99255,0.389464,0.474647,-2.06499,0.325762,0.44176,-2.12145,0.11437,1.33853,-1.83768,0.121901,1.3671,-2.05088},
/*588*/{0.244078,1.94625,-1.73969,0.290625,1.88523,-1.89833,0.225066,1.78838,-1.62553,0.208593,1.66655,-1.54796,0.31963,1.70086,-1.6604,0.396716,1.71334,-1.70809,0.166922,1.95781,-2.109,0.280174,1.88792,-1.97277,0.060765,1.91035,-1.99696,-0.067468,1.84291,-2.1486,-0.091696,1.75509,-2.20729,0.052276,1.62907,-2.17072,0.089816,1.5771,-2.19411,0.202015,1.41794,-1.80529,0.01706,1.50612,-1.88187,0.018623,1.53108,-1.9253,0.021599,1.51391,-1.99789,0.202203,1.45895,-2.05695,0.080056,1.11281,-1.76969,-0.046821,1.15479,-1.77998,-0.077643,1.07851,-1.8071,-0.068435,0.946177,-1.8063,-0.151001,0.773818,-1.79133,-0.190047,0.70866,-1.79794,-0.24713,0.830487,-1.80604,-0.283511,0.76801,-1.80857,-0.373139,0.547255,-1.81455,-0.47623,0.589551,-1.89511,-0.317678,0.387256,-1.875,-0.376438,0.37169,-1.80846,0.331279,1.24344,-2.10674,0.385632,1.18063,-2.08719,0.223206,1.14822,-2.09832,0.27752,1.08722,-2.08322,0.387616,1.01604,-2.07974,0.380338,0.822991,-2.08606,0.272777,0.856083,-2.07937,0.255652,0.788236,-2.07336,0.217004,0.551867,-2.05896,0.139022,0.475059,-1.99189,0.413092,0.47543,-2.0638,0.351633,0.438335,-2.12082,0.115114,1.34159,-1.83703,0.121493,1.36985,-2.05031},
/*589*/{0.245403,1.94875,-1.74036,0.290895,1.88737,-1.89949,0.225902,1.79114,-1.62661,0.208735,1.66926,-1.5472,0.319026,1.7033,-1.66101,0.396288,1.71593,-1.71004,0.166516,1.95944,-2.1098,0.280283,1.89029,-1.97332,0.062737,1.91174,-1.99735,-0.066445,1.84629,-2.14707,-0.092432,1.75747,-2.20562,0.051836,1.63151,-2.17015,0.089281,1.57917,-2.19395,0.202875,1.41973,-1.8058,0.017852,1.50876,-1.88077,0.019217,1.53487,-1.9245,0.020929,1.51726,-1.99639,0.201985,1.46167,-2.05645,0.078494,1.1153,-1.76975,-0.04774,1.15867,-1.78006,-0.078336,1.08245,-1.80806,-0.069909,0.949666,-1.80741,-0.154176,0.777895,-1.79229,-0.195251,0.714106,-1.79831,-0.249139,0.836058,-1.80476,-0.286194,0.775523,-1.80687,-0.379199,0.554714,-1.81333,-0.479499,0.605634,-1.88824,-0.333322,0.393708,-1.87649,-0.393101,0.379479,-1.81023,0.329758,1.24278,-2.10698,0.383166,1.17966,-2.08767,0.220777,1.14823,-2.09871,0.274093,1.08737,-2.08459,0.384942,1.01454,-2.08143,0.385394,0.820542,-2.08763,0.276417,0.848959,-2.07986,0.262095,0.780078,-2.07337,0.239174,0.542978,-2.05981,0.160955,0.462597,-1.99305,0.435466,0.476035,-2.06281,0.37722,0.435988,-2.11959,0.115247,1.34397,-1.83704,0.120626,1.37304,-2.05024},
/*590*/{0.246221,1.95043,-1.74138,0.291733,1.88953,-1.90052,0.226146,1.79408,-1.62679,0.209409,1.67205,-1.54702,0.319151,1.70547,-1.66319,0.395015,1.71872,-1.71301,0.166213,1.96087,-2.10962,0.281234,1.89147,-1.97486,0.062885,1.91334,-1.9973,-0.066702,1.84821,-2.14459,-0.092666,1.7592,-2.20376,0.051884,1.63293,-2.17011,0.089519,1.58114,-2.19421,0.20323,1.42208,-1.80553,0.019217,1.51167,-1.87977,0.019212,1.53707,-1.92446,0.020783,1.52065,-1.99471,0.202107,1.46423,-2.05638,0.079128,1.11894,-1.7717,-0.049616,1.161,-1.78223,-0.078059,1.08423,-1.80807,-0.069812,0.951875,-1.80855,-0.156558,0.780847,-1.79314,-0.198432,0.718768,-1.79895,-0.24998,0.841672,-1.80415,-0.288595,0.781215,-1.8048,-0.384239,0.563264,-1.8107,-0.48304,0.620449,-1.88258,-0.349034,0.400892,-1.87897,-0.407355,0.387538,-1.81217,0.32726,1.241,-2.10751,0.379891,1.17716,-2.08838,0.217077,1.14764,-2.09931,0.270231,1.08655,-2.08504,0.381776,1.01196,-2.0823,0.390188,0.818178,-2.08879,0.27869,0.84219,-2.08195,0.269151,0.772462,-2.07496,0.25838,0.534688,-2.06035,0.181769,0.44904,-1.99268,0.456044,0.476794,-2.06193,0.401591,0.433319,-2.11807,0.115634,1.34651,-1.83666,0.120345,1.3758,-2.04984},
/*591*/{0.247302,1.95236,-1.74245,0.29078,1.89112,-1.90158,0.226349,1.79632,-1.62718,0.210087,1.67393,-1.54649,0.318266,1.70628,-1.66261,0.39443,1.71938,-1.71342,0.166654,1.96153,-2.11035,0.282019,1.89236,-1.97545,0.064422,1.91541,-1.99757,-0.066745,1.84882,-2.14248,-0.093094,1.76026,-2.2025,0.051965,1.63417,-2.16947,0.089693,1.5825,-2.19379,0.203589,1.42403,-1.80503,0.0198,1.51373,-1.87848,0.019949,1.53937,-1.92363,0.013628,1.52789,-1.99518,0.202219,1.4667,-2.05598,0.081185,1.1185,-1.77211,-0.047179,1.16482,-1.78399,-0.07688,1.08631,-1.80921,-0.069131,0.953464,-1.81003,-0.157279,0.784124,-1.79363,-0.202117,0.722231,-1.79974,-0.249686,0.847882,-1.80279,-0.290829,0.788393,-1.80514,-0.389945,0.571421,-1.8085,-0.4867,0.635634,-1.87418,-0.365318,0.408574,-1.88291,-0.421982,0.395802,-1.8139,0.323971,1.23878,-2.10788,0.376425,1.17416,-2.08906,0.213642,1.14688,-2.09997,0.265652,1.08569,-2.08523,0.378736,1.00946,-2.08418,0.394276,0.816008,-2.08942,0.281711,0.833841,-2.08323,0.275299,0.764507,-2.07645,0.275493,0.526519,-2.06083,0.201835,0.438256,-1.99369,0.47615,0.476897,-2.05983,0.424022,0.429436,-2.11518,0.114526,1.34909,-1.83708,0.118247,1.37957,-2.05011},
/*592*/{0.248631,1.95369,-1.74282,0.291907,1.89279,-1.90272,0.226524,1.79838,-1.6278,0.209281,1.67565,-1.54689,0.317681,1.70773,-1.66247,0.392976,1.71995,-1.71526,0.168578,1.96411,-2.11157,0.282353,1.89331,-1.97633,0.063537,1.917,-1.99777,-0.066948,1.84984,-2.14092,-0.093269,1.76028,-2.20115,0.053767,1.63552,-2.16917,0.090317,1.58356,-2.19413,0.203497,1.4259,-1.80519,0.020943,1.51546,-1.87692,0.020631,1.54204,-1.92238,0.023472,1.52389,-1.99198,0.202779,1.46808,-2.05604,0.083144,1.1198,-1.7742,-0.046381,1.16363,-1.78363,-0.075307,1.08755,-1.80964,-0.06681,0.954293,-1.81124,-0.157603,0.786645,-1.79487,-0.203309,0.725036,-1.80162,-0.249352,0.851742,-1.80124,-0.29082,0.793203,-1.80399,-0.396595,0.580247,-1.80835,-0.490298,0.649801,-1.86623,-0.38259,0.417257,-1.88741,-0.437083,0.405292,-1.81607,0.321137,1.23592,-2.10797,0.37247,1.17113,-2.08991,0.208577,1.14545,-2.10105,0.260093,1.08387,-2.08586,0.375588,1.00638,-2.08469,0.397827,0.813319,-2.09059,0.285133,0.82667,-2.0857,0.280568,0.756842,-2.07876,0.292577,0.518917,-2.06183,0.222263,0.429711,-1.99354,0.495636,0.477805,-2.05693,0.445124,0.427304,-2.11313,0.116831,1.35016,-1.83538,0.12064,1.37984,-2.04852},
/*593*/{0.24934,1.95465,-1.74383,0.292012,1.89411,-1.90398,0.226203,1.80025,-1.62799,0.209057,1.67802,-1.54715,0.316435,1.70789,-1.66348,0.391856,1.71948,-1.71664,0.169104,1.96461,-2.11224,0.28266,1.89377,-1.97774,0.064828,1.91848,-1.99741,-0.06551,1.85016,-2.13984,-0.093137,1.76032,-2.19992,0.053949,1.6357,-2.16839,0.091871,1.58411,-2.19411,0.204142,1.42727,-1.80457,0.021157,1.51772,-1.87555,0.020165,1.5435,-1.92205,0.024339,1.52418,-1.99188,0.203641,1.46988,-2.05534,0.086831,1.11966,-1.77579,-0.041206,1.16431,-1.78396,-0.071853,1.08676,-1.81062,-0.062967,0.954102,-1.81201,-0.156781,0.78717,-1.79599,-0.20379,0.728541,-1.80223,-0.246917,0.855261,-1.80114,-0.289599,0.798343,-1.80111,-0.398745,0.587922,-1.80729,-0.495266,0.663703,-1.85786,-0.396896,0.427791,-1.8921,-0.447987,0.415234,-1.8198,0.317799,1.23307,-2.10883,0.368267,1.16703,-2.09042,0.204467,1.14434,-2.10151,0.255218,1.08144,-2.08585,0.371265,1.00243,-2.08565,0.401305,0.811588,-2.09023,0.287718,0.819974,-2.08921,0.28674,0.75022,-2.08182,0.309102,0.51273,-2.06177,0.241275,0.42095,-1.99408,0.512735,0.478307,-2.05503,0.465439,0.424619,-2.10979,0.117511,1.35177,-1.83455,0.121449,1.38119,-2.04773},
/*594*/{0.250429,1.95496,-1.74475,0.292577,1.89474,-1.90442,0.225622,1.80117,-1.62876,0.207125,1.67805,-1.54681,0.315587,1.70748,-1.66486,0.390682,1.719,-1.71778,0.170409,1.96508,-2.11362,0.283065,1.8935,-1.97791,0.065044,1.91927,-1.99832,-0.065322,1.84913,-2.1379,-0.092339,1.75956,-2.19884,0.055127,1.63513,-2.16813,0.093234,1.58372,-2.19431,0.204925,1.42859,-1.8054,0.020931,1.51813,-1.87514,0.020373,1.54486,-1.92154,0.024399,1.52634,-1.99089,0.203262,1.47087,-2.05466,0.090176,1.11979,-1.77766,-0.040661,1.16216,-1.78493,-0.069075,1.08596,-1.81095,-0.058563,0.953195,-1.8132,-0.156771,0.787437,-1.79745,-0.205693,0.730434,-1.80336,-0.243436,0.859531,-1.7987,-0.28819,0.803078,-1.79944,-0.405043,0.596657,-1.80685,-0.500366,0.677277,-1.85027,-0.410544,0.439556,-1.89732,-0.459611,0.426058,-1.82257,0.314833,1.22901,-2.10955,0.364203,1.16269,-2.09126,0.199732,1.14225,-2.10186,0.249868,1.07893,-2.08613,0.36749,0.998686,-2.08673,0.404632,0.80957,-2.08987,0.290626,0.8119,-2.09184,0.293082,0.743495,-2.0859,0.324526,0.506722,-2.06273,0.257931,0.412394,-1.99484,0.528798,0.478997,-2.05298,0.484378,0.422643,-2.10713,0.117849,1.35282,-1.83457,0.121131,1.38267,-2.0477},
/*595*/{0.250897,1.95496,-1.74554,0.292325,1.89482,-1.90554,0.225569,1.80174,-1.62937,0.205951,1.6796,-1.54756,0.314535,1.70809,-1.66652,0.390616,1.71852,-1.71914,0.170694,1.96486,-2.11415,0.283388,1.89365,-1.97882,0.067045,1.92009,-1.99982,-0.064705,1.84825,-2.13722,-0.092139,1.75852,-2.19863,0.057035,1.63488,-2.16821,0.094603,1.58315,-2.19429,0.204775,1.42961,-1.80546,0.020658,1.51936,-1.87346,0.019812,1.54606,-1.92102,0.02345,1.52668,-1.99013,0.204231,1.47217,-2.0544,0.095293,1.11905,-1.77913,-0.037373,1.16059,-1.78499,-0.063833,1.08428,-1.81234,-0.05301,0.95136,-1.81406,-0.15512,0.787197,-1.79907,-0.206767,0.732067,-1.80569,-0.238974,0.862079,-1.79686,-0.287751,0.807739,-1.79891,-0.411583,0.60505,-1.80663,-0.504543,0.690015,-1.84217,-0.422217,0.453507,-1.90168,-0.468931,0.437104,-1.82556,0.310416,1.22489,-2.10999,0.360201,1.158,-2.09212,0.194711,1.1407,-2.10053,0.24377,1.07546,-2.08677,0.362907,0.994187,-2.08791,0.40758,0.807509,-2.08847,0.293599,0.807169,-2.09618,0.298239,0.736211,-2.08827,0.337077,0.49964,-2.06325,0.274132,0.406641,-1.99504,0.543647,0.480761,-2.04952,0.501286,0.421307,-2.10422,0.118085,1.3538,-1.83409,0.121156,1.38387,-2.04719},
/*596*/{0.251427,1.95504,-1.74637,0.292715,1.895,-1.90628,0.225354,1.80173,-1.63047,0.204379,1.67952,-1.54758,0.312756,1.70619,-1.66659,0.389983,1.71762,-1.71955,0.171244,1.96482,-2.11503,0.28365,1.89357,-1.97947,0.06752,1.9205,-2.00091,-0.064576,1.84676,-2.13542,-0.090664,1.75699,-2.198,0.058454,1.63349,-2.16792,0.096115,1.58231,-2.19446,0.205092,1.43021,-1.80508,0.020461,1.51969,-1.87336,0.018776,1.54641,-1.92016,0.023173,1.52664,-1.98984,0.204295,1.47232,-2.05376,0.099291,1.11845,-1.78173,-0.032472,1.1579,-1.78615,-0.059488,1.08071,-1.81258,-0.047136,0.948556,-1.8158,-0.153592,0.786764,-1.80146,-0.207627,0.733595,-1.80776,-0.235204,0.865461,-1.79504,-0.284209,0.813194,-1.79599,-0.412433,0.6137,-1.81081,-0.509181,0.702807,-1.83556,-0.432823,0.466259,-1.90623,-0.47789,0.448766,-1.82872,0.307298,1.22101,-2.11067,0.355233,1.15299,-2.09305,0.189663,1.13707,-2.09996,0.239217,1.07117,-2.086,0.357578,0.989883,-2.08807,0.411063,0.805461,-2.0866,0.297645,0.801454,-2.09889,0.304955,0.731668,-2.09094,0.350097,0.494955,-2.0631,0.287637,0.400916,-1.99585,0.556249,0.482393,-2.04754,0.518125,0.420917,-2.10096,0.118231,1.3543,-1.83339,0.121166,1.38401,-2.04655},
/*597*/{0.25277,1.95446,-1.74707,0.29305,1.89477,-1.90674,0.223921,1.80181,-1.63123,0.201932,1.67912,-1.54778,0.311539,1.70471,-1.66691,0.386052,1.71228,-1.72048,0.171997,1.96447,-2.1171,0.284484,1.89352,-1.97996,0.067984,1.92035,-2.00175,-0.063593,1.84368,-2.13451,-0.089321,1.755,-2.19717,0.059989,1.63129,-2.16764,0.098208,1.58018,-2.19464,0.205111,1.43116,-1.80528,0.020633,1.51927,-1.8733,0.019729,1.54596,-1.92066,0.022961,1.52637,-1.98911,0.204457,1.47251,-2.05347,0.104915,1.11678,-1.78403,-0.027938,1.15441,-1.78552,-0.053633,1.07769,-1.81337,-0.040369,0.94513,-1.81672,-0.152343,0.786228,-1.80304,-0.208182,0.735991,-1.80983,-0.230568,0.867388,-1.79297,-0.281676,0.818269,-1.7941,-0.416662,0.622737,-1.81147,-0.513017,0.715672,-1.8289,-0.443496,0.480342,-1.90894,-0.485331,0.460713,-1.83121,0.303036,1.21662,-2.11184,0.350388,1.148,-2.09412,0.18475,1.13452,-2.09966,0.233874,1.06647,-2.0854,0.352888,0.985085,-2.08868,0.413851,0.803409,-2.08475,0.300669,0.795612,-2.1018,0.310389,0.727144,-2.09337,0.361266,0.491959,-2.06389,0.30136,0.394124,-1.99676,0.567016,0.483956,-2.04339,0.531238,0.420441,-2.09802,0.118999,1.35456,-1.83306,0.121748,1.38389,-2.04627},
/*598*/{0.253471,1.95396,-1.74737,0.29336,1.89497,-1.90716,0.222915,1.80087,-1.63191,0.199969,1.67788,-1.54806,0.309947,1.70249,-1.66783,0.385214,1.70993,-1.72111,0.173205,1.96311,-2.11721,0.284426,1.89325,-1.98046,0.068909,1.92007,-2.00227,-0.062985,1.84178,-2.13404,-0.087801,1.75259,-2.19723,0.06333,1.62945,-2.16825,0.100259,1.57812,-2.19509,0.205106,1.43148,-1.8051,0.02064,1.51817,-1.87266,0.019729,1.54596,-1.92066,0.02218,1.52516,-1.98892,0.204159,1.47239,-2.05251,0.109911,1.11518,-1.78608,-0.022983,1.15047,-1.78528,-0.046775,1.07389,-1.81417,-0.033413,0.941907,-1.81826,-0.150637,0.785656,-1.80464,-0.208399,0.738773,-1.81199,-0.224363,0.869904,-1.79159,-0.278517,0.822848,-1.79262,-0.423614,0.636886,-1.8058,-0.515745,0.728745,-1.82458,-0.45385,0.495152,-1.91181,-0.493122,0.474092,-1.8335,0.299673,1.2122,-2.11244,0.34581,1.14299,-2.09524,0.180147,1.13122,-2.09954,0.226525,1.06513,-2.08641,0.34856,0.980474,-2.08875,0.415236,0.801418,-2.08268,0.30316,0.790933,-2.10327,0.313857,0.72184,-2.09547,0.370441,0.488009,-2.06503,0.31121,0.390371,-1.99716,0.575926,0.484706,-2.04193,0.54317,0.420552,-2.09475,0.119419,1.35443,-1.83238,0.121974,1.38335,-2.04565},
/*599*/{0.253321,1.95248,-1.74778,0.293625,1.89364,-1.90779,0.22251,1.80025,-1.63237,0.197554,1.67767,-1.54862,0.307915,1.69944,-1.66759,0.383355,1.70555,-1.72095,0.173139,1.96194,-2.1178,0.284544,1.892,-1.98054,0.069939,1.91962,-2.00381,-0.061276,1.83894,-2.13399,-0.085928,1.74966,-2.19754,0.064665,1.62722,-2.16781,0.102716,1.57545,-2.19556,0.205179,1.43124,-1.80508,0.020632,1.51721,-1.87217,0.019266,1.54522,-1.92004,0.021667,1.52435,-1.98869,0.204317,1.47192,-2.0523,0.116252,1.11358,-1.78893,-0.017236,1.14614,-1.7859,-0.041676,1.06889,-1.81498,-0.025551,0.937274,-1.82025,-0.148042,0.785456,-1.80687,-0.208705,0.740612,-1.81331,-0.218502,0.87207,-1.79003,-0.273698,0.828401,-1.79066,-0.42844,0.647079,-1.80681,-0.517054,0.743388,-1.82207,-0.463238,0.508583,-1.91304,-0.501048,0.488427,-1.83385,0.296116,1.20772,-2.11288,0.340884,1.1372,-2.0969,0.175528,1.12883,-2.09987,0.221485,1.06163,-2.08582,0.343057,0.976076,-2.0892,0.415691,0.799628,-2.08057,0.305093,0.786115,-2.10467,0.317193,0.71759,-2.09669,0.377696,0.485081,-2.06512,0.320588,0.387091,-1.99853,0.583735,0.485524,-2.03851,0.552751,0.420388,-2.09283,0.119784,1.35387,-1.83209,0.122059,1.38278,-2.04537},
/*600*/{0.253094,1.95081,-1.74792,0.292226,1.89237,-1.90727,0.220144,1.79859,-1.63333,0.195235,1.67648,-1.5491,0.305924,1.69709,-1.66844,0.381346,1.70136,-1.72137,0.174474,1.9608,-2.11883,0.284472,1.89091,-1.98074,0.070424,1.91909,-2.00498,-0.060226,1.83488,-2.1332,-0.08386,1.74653,-2.19779,0.066055,1.62414,-2.16814,0.105454,1.57245,-2.19622,0.205159,1.43029,-1.80496,0.020361,1.51566,-1.87185,0.019117,1.54416,-1.91968,0.021654,1.5215,-1.98851,0.204589,1.47151,-2.05246,0.121396,1.11147,-1.79128,-0.012089,1.1426,-1.78595,-0.035392,1.06398,-1.81519,-0.017813,0.93263,-1.82247,-0.14611,0.786243,-1.80757,-0.210163,0.742135,-1.81547,-0.212242,0.875224,-1.78877,-0.269149,0.83376,-1.79057,-0.431269,0.660828,-1.80411,-0.517056,0.758523,-1.82108,-0.469335,0.523078,-1.91253,-0.509831,0.503132,-1.83376,0.292981,1.20307,-2.11363,0.337034,1.13231,-2.09788,0.171616,1.12577,-2.09953,0.215914,1.0583,-2.08555,0.33792,0.971493,-2.08925,0.415695,0.797611,-2.07962,0.305213,0.781837,-2.10503,0.318386,0.713346,-2.09669,0.38243,0.482091,-2.06584,0.327579,0.383343,-2.00108,0.590047,0.486093,-2.03667,0.559612,0.419587,-2.09066,0.120517,1.3526,-1.83199,0.122683,1.38163,-2.04525},
/*601*/{0.253169,1.94906,-1.74905,0.292571,1.89054,-1.90815,0.218741,1.79748,-1.63386,0.19142,1.67443,-1.54967,0.303586,1.69339,-1.66928,0.379658,1.69678,-1.72128,0.175653,1.95897,-2.11972,0.284059,1.88973,-1.98073,0.070717,1.91868,-2.00637,-0.058389,1.83203,-2.1335,-0.082087,1.74281,-2.19852,0.068703,1.62004,-2.16902,0.107458,1.56891,-2.19711,0.205288,1.42988,-1.8053,0.019993,1.51345,-1.87213,0.018388,1.54229,-1.91974,0.020892,1.52023,-1.9887,0.204839,1.47021,-2.0524,0.126617,1.10889,-1.79247,-0.007721,1.13814,-1.78635,-0.029794,1.05963,-1.81705,-0.009965,0.928425,-1.8246,-0.143046,0.787028,-1.80905,-0.207598,0.747093,-1.81498,-0.205415,0.878665,-1.78821,-0.264716,0.838768,-1.78967,-0.434296,0.673544,-1.80319,-0.516037,0.774689,-1.82172,-0.476025,0.536226,-1.90947,-0.518985,0.518583,-1.83193,0.290388,1.19872,-2.1145,0.33314,1.12712,-2.09872,0.167726,1.1231,-2.09957,0.211431,1.05487,-2.08501,0.333135,0.967539,-2.08904,0.413572,0.795751,-2.07891,0.304531,0.778615,-2.10436,0.318142,0.710477,-2.09624,0.387644,0.479281,-2.06578,0.332688,0.381748,-1.99996,0.594866,0.484921,-2.03485,0.565799,0.419603,-2.08906,0.121029,1.35145,-1.83198,0.123082,1.38025,-2.04527},
/*602*/{0.25311,1.94717,-1.74956,0.292282,1.88982,-1.9087,0.216406,1.79521,-1.63461,0.187289,1.67272,-1.55122,0.301229,1.68919,-1.66883,0.377361,1.69128,-1.7212,0.176141,1.95686,-2.12023,0.283867,1.88764,-1.98068,0.071178,1.91641,-2.00784,-0.057332,1.82781,-2.13335,-0.07965,1.73888,-2.19895,0.072228,1.61673,-2.17003,0.109993,1.56508,-2.19781,0.205523,1.4289,-1.80485,0.019265,1.51167,-1.87225,0.017461,1.54041,-1.91946,0.020208,1.51735,-1.98881,0.204476,1.46815,-2.05258,0.132313,1.1066,-1.79457,-0.00313,1.13081,-1.78714,-0.023409,1.05315,-1.81744,-0.002598,0.924592,-1.82608,-0.139206,0.788686,-1.81007,-0.205038,0.750764,-1.8165,-0.197975,0.882005,-1.78803,-0.259078,0.844527,-1.78936,-0.435613,0.685257,-1.80479,-0.512761,0.791026,-1.82329,-0.480984,0.549084,-1.90616,-0.525637,0.535003,-1.82898,0.287932,1.19419,-2.11586,0.329626,1.12274,-2.1002,0.164204,1.1205,-2.09944,0.207154,1.05174,-2.08543,0.327977,0.96389,-2.08913,0.411595,0.793865,-2.07903,0.302135,0.775274,-2.10281,0.316843,0.707043,-2.09491,0.39042,0.477243,-2.06463,0.334803,0.377547,-2.00067,0.595997,0.48494,-2.03383,0.568646,0.418429,-2.08845,0.121309,1.35016,-1.83121,0.122945,1.37786,-2.04465},
/*603*/{0.251898,1.94487,-1.75013,0.291253,1.88765,-1.90878,0.214455,1.79337,-1.63497,0.183499,1.67047,-1.55166,0.298333,1.6847,-1.66802,0.375629,1.68585,-1.72116,0.177357,1.95486,-2.12087,0.283717,1.8862,-1.98057,0.071294,1.9155,-2.0087,-0.055118,1.8249,-2.1343,-0.077467,1.73463,-2.20057,0.074244,1.61255,-2.17102,0.112684,1.56108,-2.19843,0.205673,1.42768,-1.80524,0.019358,1.50968,-1.87211,0.017902,1.53761,-1.91968,0.02033,1.51502,-1.98866,0.204097,1.46566,-2.05357,0.136786,1.10433,-1.7947,0.002119,1.12573,-1.78742,-0.01708,1.04783,-1.81786,0.005855,0.920816,-1.82741,-0.13511,0.790238,-1.8097,-0.20276,0.755194,-1.81455,-0.189872,0.886407,-1.78868,-0.252572,0.851211,-1.79033,-0.435169,0.700189,-1.80171,-0.509656,0.807507,-1.82696,-0.483577,0.561067,-1.90089,-0.53197,0.55244,-1.82501,0.285821,1.19047,-2.11704,0.327209,1.11826,-2.1003,0.16163,1.1187,-2.09867,0.203443,1.05003,-2.08533,0.323272,0.960398,-2.08927,0.407995,0.791913,-2.07901,0.298326,0.771541,-2.10211,0.314533,0.703791,-2.09321,0.391843,0.474986,-2.06444,0.338328,0.373156,-1.99923,0.597562,0.482959,-2.0327,0.570174,0.416709,-2.08789,0.121969,1.34844,-1.83098,0.12278,1.37525,-2.04454},
/*604*/{0.251314,1.94291,-1.75026,0.290442,1.88534,-1.90886,0.211932,1.7913,-1.6357,0.179645,1.66856,-1.55281,0.29488,1.68022,-1.66914,0.372324,1.67946,-1.72035,0.177318,1.9522,-2.12117,0.283103,1.88356,-1.98074,0.071612,1.91292,-2.00998,-0.054735,1.82021,-2.13576,-0.074857,1.72998,-2.20195,0.07697,1.60782,-2.17199,0.115649,1.55634,-2.19933,0.206053,1.4259,-1.80567,0.01889,1.5061,-1.87277,0.016804,1.53561,-1.92018,0.0195,1.51301,-1.98949,0.203489,1.46308,-2.05458,0.142084,1.10136,-1.79484,0.007192,1.12255,-1.78804,-0.010885,1.04198,-1.81832,0.013828,0.916521,-1.82886,-0.129654,0.790192,-1.81191,-0.198422,0.759999,-1.81468,-0.182256,0.890781,-1.78968,-0.246152,0.857687,-1.79088,-0.432414,0.712585,-1.80414,-0.50435,0.823444,-1.83063,-0.487337,0.574999,-1.8959,-0.536612,0.569306,-1.82122,0.283945,1.18659,-2.11842,0.324541,1.11393,-2.10182,0.158999,1.11734,-2.09903,0.200248,1.0475,-2.08528,0.319754,0.957352,-2.08924,0.403858,0.788949,-2.07958,0.293655,0.76765,-2.10077,0.311349,0.700396,-2.09246,0.390577,0.471787,-2.06295,0.33731,0.372614,-1.99884,0.596113,0.481943,-2.03287,0.569901,0.415342,-2.0873,0.122088,1.34624,-1.83157,0.12239,1.37282,-2.04515},
/*605*/{0.250318,1.93948,-1.75047,0.288764,1.88195,-1.90859,0.209104,1.78845,-1.63593,0.174178,1.66599,-1.55423,0.292188,1.67564,-1.66889,0.370414,1.67248,-1.71937,0.178374,1.94905,-2.12174,0.283343,1.88086,-1.98017,0.071401,1.91116,-2.01169,-0.053,1.81541,-2.13687,-0.072051,1.72492,-2.2034,0.079154,1.60292,-2.17438,0.118183,1.55163,-2.20022,0.206398,1.42411,-1.80612,0.01813,1.50338,-1.87296,0.016414,1.53247,-1.92008,0.018832,1.50923,-1.98929,0.203447,1.4604,-2.05538,0.147209,1.09866,-1.79624,0.01046,1.11487,-1.78886,-0.004364,1.03583,-1.81982,0.021399,0.912558,-1.82943,-0.12592,0.794831,-1.80814,-0.195974,0.764251,-1.81275,-0.17492,0.895052,-1.79053,-0.237628,0.86447,-1.7912,-0.429343,0.725089,-1.80591,-0.49787,0.839277,-1.83508,-0.488437,0.587401,-1.89105,-0.540235,0.587674,-1.81622,0.283067,1.1833,-2.11992,0.321356,1.10963,-2.1036,0.157155,1.11574,-2.09882,0.197261,1.04579,-2.08547,0.31615,0.954182,-2.08903,0.399314,0.784955,-2.07929,0.290244,0.764275,-2.09994,0.307681,0.696357,-2.09103,0.387945,0.46833,-2.06164,0.335787,0.36704,-1.99525,0.594528,0.477777,-2.03344,0.567169,0.411993,-2.08589,0.122849,1.34394,-1.83137,0.122419,1.36975,-2.04505},
/*606*/{0.249665,1.9367,-1.75058,0.289743,1.87932,-1.90812,0.205642,1.7854,-1.63624,0.17064,1.66341,-1.55531,0.288544,1.66975,-1.66892,0.366673,1.66496,-1.71918,0.179131,1.94603,-2.12202,0.28306,1.87756,-1.97979,0.071036,1.9085,-2.01269,-0.050884,1.8106,-2.13854,-0.069564,1.71938,-2.20525,0.082588,1.59758,-2.17519,0.121435,1.54647,-2.2012,0.206232,1.42221,-1.80637,0.018271,1.49957,-1.87244,0.016787,1.52955,-1.92066,0.018838,1.50662,-1.99044,0.203053,1.4578,-2.05615,0.150619,1.09483,-1.79404,0.015399,1.10913,-1.79002,0.000687,1.03008,-1.82285,0.02959,0.908445,-1.82936,-0.121163,0.797692,-1.80735,-0.19107,0.768924,-1.81101,-0.165531,0.899584,-1.79214,-0.231656,0.870935,-1.79274,-0.426543,0.739618,-1.80397,-0.490627,0.854064,-1.8399,-0.488564,0.599726,-1.88505,-0.541951,0.604785,-1.81175,0.280735,1.17928,-2.12122,0.319916,1.10572,-2.10477,0.155174,1.11368,-2.09904,0.194705,1.04318,-2.08511,0.313716,0.951391,-2.08889,0.395102,0.781905,-2.08053,0.285813,0.760101,-2.09838,0.30338,0.692513,-2.09001,0.385562,0.46543,-2.05971,0.331645,0.364754,-1.99292,0.591881,0.474881,-2.03079,0.564013,0.408035,-2.08464,0.123367,1.34135,-1.83171,0.122665,1.36697,-2.04541},
/*607*/{0.24806,1.9334,-1.75022,0.289308,1.87612,-1.90875,0.202034,1.78233,-1.63658,0.165025,1.66067,-1.55711,0.284438,1.6638,-1.66861,0.363283,1.6573,-1.71757,0.179535,1.94262,-2.12266,0.282514,1.87394,-1.98027,0.070888,1.90532,-2.01461,-0.049483,1.80483,-2.14008,-0.066558,1.71366,-2.20716,0.086459,1.592,-2.17648,0.124861,1.5411,-2.20202,0.205982,1.41956,-1.80732,0.01775,1.49678,-1.87274,0.015983,1.52584,-1.92025,0.017359,1.50298,-1.99034,0.20178,1.45496,-2.05702,0.154204,1.09218,-1.79496,0.018811,1.10319,-1.7913,0.008362,1.0236,-1.82211,0.037736,0.904012,-1.82978,-0.115395,0.799533,-1.80652,-0.186365,0.773719,-1.80983,-0.156526,0.903323,-1.79461,-0.222693,0.877971,-1.79375,-0.422984,0.753936,-1.80209,-0.482213,0.868023,-1.84496,-0.488407,0.612076,-1.87939,-0.54117,0.622093,-1.80679,0.279542,1.17631,-2.12188,0.31847,1.10245,-2.10599,0.152906,1.11189,-2.09852,0.192181,1.04119,-2.08514,0.311851,0.947957,-2.08835,0.391119,0.777939,-2.08057,0.281194,0.756104,-2.09762,0.298148,0.688573,-2.08848,0.37885,0.459953,-2.05819,0.328187,0.360393,-1.98885,0.587331,0.469329,-2.03,0.558102,0.401971,-2.0833,0.123449,1.33845,-1.83201,0.121582,1.36379,-2.04574},
/*608*/{0.246969,1.93026,-1.75002,0.288574,1.87196,-1.90834,0.198342,1.77894,-1.63671,0.159461,1.65705,-1.55873,0.280635,1.65801,-1.66807,0.360645,1.64955,-1.71585,0.179914,1.93863,-2.12296,0.282113,1.87043,-1.97995,0.07064,1.90214,-2.01527,-0.047871,1.79929,-2.14227,-0.063856,1.70731,-2.20979,0.089008,1.5865,-2.17881,0.128704,1.53596,-2.20275,0.205726,1.41687,-1.80757,0.017402,1.49259,-1.87323,0.015662,1.52188,-1.92061,0.016651,1.49884,-1.99039,0.201747,1.45271,-2.05812,0.157889,1.08962,-1.79414,0.023126,1.09865,-1.79181,0.012787,1.01793,-1.82252,0.046021,0.899925,-1.82926,-0.109328,0.802894,-1.8041,-0.182375,0.777653,-1.80993,-0.147011,0.907939,-1.79656,-0.214732,0.883989,-1.7958,-0.418389,0.768049,-1.80022,-0.473409,0.881443,-1.84918,-0.48546,0.624221,-1.87399,-0.539086,0.638046,-1.80227,0.277827,1.17339,-2.12385,0.315547,1.09967,-2.10719,0.151265,1.11028,-2.09868,0.189577,1.03883,-2.0847,0.310403,0.94488,-2.08778,0.386875,0.772751,-2.08085,0.276499,0.751994,-2.09677,0.294591,0.684001,-2.08734,0.374261,0.456329,-2.0556,0.320827,0.35761,-1.9856,0.581431,0.462496,-2.02921,0.551902,0.394503,-2.08039,0.124242,1.33508,-1.83272,0.122136,1.36079,-2.0464},
/*609*/{0.245707,1.9259,-1.74937,0.288465,1.86849,-1.90825,0.19499,1.77488,-1.63642,0.153656,1.65306,-1.55956,0.276571,1.65124,-1.66798,0.356732,1.64058,-1.71455,0.179269,1.93468,-2.12336,0.281856,1.86675,-1.97972,0.070716,1.89858,-2.01692,-0.046156,1.79256,-2.14462,-0.060778,1.70036,-2.21172,0.091842,1.58014,-2.18018,0.132179,1.52981,-2.20371,0.205815,1.4143,-1.80807,0.016335,1.48865,-1.8733,0.015054,1.51889,-1.92053,0.016028,1.4948,-1.99057,0.200901,1.45042,-2.05917,0.161676,1.08539,-1.79189,0.026001,1.09145,-1.79281,0.018527,1.01204,-1.82424,0.054154,0.895462,-1.82803,-0.101945,0.804759,-1.80437,-0.174859,0.783262,-1.80709,-0.136845,0.911536,-1.79888,-0.20436,0.889534,-1.7971,-0.41314,0.781424,-1.79787,-0.46445,0.89332,-1.85348,-0.48193,0.635822,-1.86813,-0.535399,0.654049,-1.79672,0.277077,1.17098,-2.1245,0.313639,1.09605,-2.10782,0.149389,1.10705,-2.09851,0.187696,1.03637,-2.08556,0.308161,0.941627,-2.08796,0.382486,0.76805,-2.08128,0.271712,0.747783,-2.09562,0.288823,0.679766,-2.08592,0.36664,0.451239,-2.05459,0.31239,0.355992,-1.98265,0.574391,0.454552,-2.02823,0.543542,0.38632,-2.07838,0.124766,1.33203,-1.83328,0.121938,1.35792,-2.04694},
/*610*/{0.244016,1.92147,-1.74859,0.287662,1.86415,-1.90702,0.191439,1.77053,-1.63635,0.148489,1.64971,-1.56152,0.271874,1.6444,-1.66758,0.35304,1.63198,-1.71272,0.179576,1.92999,-2.12375,0.28149,1.86199,-1.97864,0.069557,1.89445,-2.01829,-0.045205,1.7852,-2.14734,-0.058252,1.69306,-2.21446,0.095335,1.57367,-2.18196,0.136412,1.52391,-2.2042,0.205201,1.41102,-1.80943,0.016052,1.48454,-1.87342,0.014358,1.51416,-1.92061,0.015188,1.49025,-1.99039,0.200204,1.44741,-2.0606,0.166935,1.0815,-1.79,0.028765,1.08526,-1.79526,0.024848,1.00545,-1.82454,0.062617,0.891736,-1.82673,-0.095197,0.807524,-1.80169,-0.167823,0.787702,-1.8055,-0.127482,0.91544,-1.80176,-0.196013,0.894845,-1.79978,-0.406705,0.794404,-1.7964,-0.454884,0.90456,-1.85797,-0.477136,0.647624,-1.86353,-0.529582,0.66863,-1.79237,0.275022,1.16743,-2.12501,0.312244,1.0926,-2.1091,0.147556,1.10465,-2.09874,0.185885,1.03302,-2.08662,0.305637,0.938367,-2.08812,0.377515,0.762954,-2.08069,0.267058,0.74387,-2.09467,0.282809,0.67528,-2.08495,0.356973,0.444832,-2.05278,0.302588,0.352781,-1.97894,0.567235,0.447108,-2.0251,0.53528,0.376711,-2.0747,0.125329,1.32814,-1.8342,0.121538,1.35435,-2.0478},
/*611*/{0.242773,1.91646,-1.74818,0.288085,1.85945,-1.90738,0.187492,1.76624,-1.63635,0.142054,1.64516,-1.56262,0.267028,1.63763,-1.66711,0.348952,1.62277,-1.71129,0.179846,1.92515,-2.12381,0.281206,1.85752,-1.97909,0.068967,1.88957,-2.01929,-0.043701,1.77901,-2.1503,-0.055058,1.68593,-2.21749,0.098999,1.56853,-2.18375,0.139976,1.51788,-2.205,0.205422,1.40706,-1.81023,0.015693,1.47938,-1.87391,0.013401,1.50988,-1.92034,0.01435,1.48532,-1.98995,0.199373,1.44488,-2.06143,0.167823,1.07899,-1.78913,0.032982,1.08102,-1.79621,0.031186,0.999114,-1.82535,0.070914,0.887262,-1.82488,-0.087675,0.809387,-1.80021,-0.16161,0.79126,-1.80335,-0.116855,0.918184,-1.80452,-0.186224,0.899907,-1.80259,-0.399806,0.806227,-1.79488,-0.444985,0.914596,-1.8617,-0.471758,0.657653,-1.85856,-0.523905,0.682576,-1.78858,0.273112,1.1641,-2.12632,0.311547,1.08845,-2.10908,0.145723,1.10148,-2.09917,0.184207,1.029,-2.08648,0.303327,0.933792,-2.08832,0.372921,0.75661,-2.08081,0.261036,0.738738,-2.09427,0.276676,0.670502,-2.0843,0.348871,0.440374,-2.05081,0.290221,0.348606,-1.97999,0.557399,0.437191,-2.0246,0.524512,0.367383,-2.0712,0.126181,1.32376,-1.83532,0.121535,1.35104,-2.04877},
/*612*/{0.241851,1.91215,-1.74755,0.287424,1.85493,-1.90614,0.183704,1.7621,-1.63643,0.136695,1.64212,-1.56446,0.261312,1.63027,-1.66666,0.342572,1.6134,-1.70883,0.179641,1.92043,-2.12426,0.281007,1.85329,-1.9789,0.06942,1.88443,-2.0204,-0.042655,1.77125,-2.15365,-0.052126,1.67813,-2.21995,0.103602,1.56174,-2.18549,0.144699,1.5111,-2.20584,0.205712,1.40405,-1.81146,0.014837,1.47487,-1.87398,0.013055,1.50554,-1.92136,0.013132,1.48059,-1.98931,0.198984,1.44238,-2.06256,0.174904,1.07567,-1.78678,0.03663,1.07326,-1.79836,0.037542,0.992963,-1.82617,0.078969,0.882926,-1.82359,-0.079154,0.811854,-1.79866,-0.153195,0.794781,-1.80164,-0.105524,0.921131,-1.80717,-0.17605,0.90455,-1.80481,-0.390928,0.817085,-1.79651,-0.43522,0.924329,-1.86536,-0.465078,0.667537,-1.85462,-0.516185,0.695437,-1.78544,0.270809,1.16057,-2.1272,0.308993,1.08575,-2.10997,0.143666,1.09803,-2.10007,0.182212,1.02525,-2.08707,0.299957,0.928149,-2.08847,0.367521,0.750899,-2.08119,0.255505,0.734254,-2.09373,0.269416,0.665774,-2.08359,0.340928,0.436284,-2.04953,0.275721,0.355046,-1.97619,0.547184,0.426268,-2.02148,0.511085,0.357669,-2.0676,0.127281,1.32011,-1.83626,0.121694,1.34773,-2.04964},
/*613*/{0.240334,1.90679,-1.74657,0.28601,1.84912,-1.90532,0.179037,1.75724,-1.63667,0.129924,1.63742,-1.5657,0.256589,1.62256,-1.66631,0.338074,1.60349,-1.70741,0.17969,1.91475,-2.12493,0.281029,1.84837,-1.97813,0.068148,1.87853,-2.02122,-0.040381,1.76365,-2.15678,-0.048988,1.67046,-2.22298,0.107989,1.55514,-2.18683,0.149466,1.50472,-2.20668,0.205801,1.40006,-1.81235,0.014713,1.46883,-1.87393,0.012263,1.50013,-1.92143,0.011933,1.47515,-1.98956,0.198038,1.43961,-2.06428,0.176878,1.0717,-1.78539,0.041743,1.06883,-1.79996,0.043974,0.98668,-1.82692,0.087301,0.879052,-1.82157,-0.070597,0.814251,-1.79601,-0.144029,0.799253,-1.80045,-0.093905,0.923478,-1.8092,-0.164747,0.908745,-1.80791,-0.379867,0.826979,-1.79753,-0.424845,0.932203,-1.8684,-0.455966,0.675582,-1.85007,-0.506778,0.706176,-1.7832,0.268739,1.15646,-2.12768,0.307186,1.08184,-2.11138,0.142067,1.09346,-2.10045,0.180074,1.02123,-2.08786,0.296532,0.922222,-2.08886,0.360281,0.74409,-2.08149,0.248758,0.729131,-2.09363,0.261632,0.660414,-2.08281,0.330886,0.432694,-2.04712,0.258684,0.356445,-1.97736,0.535838,0.412682,-2.0183,0.494874,0.34702,-2.06558,0.128624,1.31534,-1.83769,0.121828,1.34393,-2.05091},
/*614*/{0.238362,1.90129,-1.74594,0.286957,1.84352,-1.90482,0.175104,1.75168,-1.63682,0.123697,1.6347,-1.5666,0.251105,1.61505,-1.66532,0.33321,1.59374,-1.70537,0.180954,1.90985,-2.12561,0.280252,1.84304,-1.97782,0.067591,1.87348,-2.02309,-0.038953,1.75454,-2.16042,-0.045434,1.66197,-2.22576,0.111634,1.54808,-2.18847,0.154097,1.49757,-2.20743,0.205204,1.39654,-1.81349,0.0142,1.46397,-1.87385,0.012458,1.49486,-1.92206,0.01096,1.47025,-1.98859,0.197802,1.43642,-2.06594,0.178319,1.06822,-1.78401,0.046858,1.06064,-1.80129,0.049882,0.979837,-1.82841,0.095557,0.875684,-1.81971,-0.060806,0.815885,-1.79481,-0.134717,0.80256,-1.79907,-0.081847,0.92504,-1.81215,-0.153169,0.912576,-1.81051,-0.369782,0.834713,-1.79771,-0.414708,0.939861,-1.87156,-0.447708,0.683758,-1.84737,-0.497994,0.716121,-1.77937,0.266966,1.15241,-2.12893,0.305028,1.07796,-2.1126,0.139767,1.08796,-2.10053,0.178904,1.01708,-2.08786,0.292595,0.916599,-2.08958,0.354723,0.737548,-2.08062,0.242162,0.723378,-2.09327,0.25474,0.65495,-2.08263,0.317675,0.42726,-2.04695,0.241346,0.358976,-1.97367,0.522978,0.396773,-2.01379,0.476856,0.337439,-2.06374,0.129508,1.31106,-1.83862,0.121809,1.34009,-2.05175},
/*615*/{0.236467,1.89585,-1.74525,0.286482,1.8381,-1.90425,0.171334,1.74684,-1.63663,0.117106,1.63028,-1.56797,0.24507,1.60706,-1.6646,0.326847,1.58359,-1.70348,0.180378,1.90446,-2.12586,0.28059,1.83797,-1.97745,0.067354,1.86708,-2.02395,-0.037267,1.74648,-2.16442,-0.042012,1.65358,-2.2287,0.116627,1.54123,-2.19063,0.159769,1.49162,-2.20815,0.204994,1.39241,-1.8143,0.01299,1.45835,-1.87462,0.010876,1.48923,-1.92269,0.00926,1.46445,-1.98876,0.19645,1.43254,-2.06774,0.186467,1.06347,-1.78042,0.050942,1.05665,-1.80217,0.056974,0.973245,-1.83013,0.105083,0.872913,-1.81719,-0.050698,0.817128,-1.79319,-0.126836,0.805964,-1.79722,-0.069658,0.925799,-1.8153,-0.141067,0.91487,-1.81216,-0.360682,0.842243,-1.79766,-0.403664,0.946263,-1.87413,-0.43662,0.691096,-1.84388,-0.486242,0.725146,-1.77675,0.26366,1.14775,-2.13085,0.302484,1.07349,-2.11508,0.137093,1.0839,-2.10108,0.176467,1.01198,-2.08818,0.28817,0.910745,-2.09022,0.347824,0.73032,-2.08018,0.235645,0.718513,-2.09275,0.246802,0.649714,-2.08243,0.29865,0.422314,-2.04134,0.219099,0.356069,-1.97347,0.504724,0.387112,-2.00202,0.455872,0.338942,-2.06445,0.129914,1.30639,-1.83968,0.121196,1.33544,-2.05277},
/*616*/{0.235606,1.89006,-1.7441,0.286409,1.83241,-1.90305,0.166656,1.74145,-1.63695,0.109886,1.62546,-1.56814,0.239471,1.59917,-1.66408,0.32173,1.5737,-1.70107,0.181379,1.89894,-2.12667,0.28122,1.83254,-1.97684,0.066528,1.86181,-2.02444,-0.035216,1.73736,-2.16846,-0.038112,1.64481,-2.23232,0.121576,1.53431,-2.19177,0.165013,1.48522,-2.209,0.204057,1.38783,-1.81521,0.011964,1.45204,-1.87467,0.009305,1.48354,-1.92339,0.007015,1.45962,-1.98904,0.195496,1.42819,-2.07005,0.190598,1.06015,-1.77777,0.054472,1.04807,-1.80382,0.062652,0.968371,-1.83051,0.113728,0.869304,-1.81513,-0.041042,0.818592,-1.79142,-0.115472,0.809321,-1.79539,-0.057328,0.926926,-1.817,-0.128044,0.916987,-1.81471,-0.347874,0.849787,-1.79814,-0.392833,0.951689,-1.87612,-0.42595,0.697693,-1.84136,-0.475078,0.732723,-1.77468,0.259623,1.14318,-2.13309,0.298307,1.06891,-2.11799,0.133838,1.07973,-2.10169,0.17316,1.00802,-2.08882,0.284466,0.904403,-2.09248,0.342097,0.72263,-2.07709,0.228957,0.71399,-2.09272,0.23749,0.645123,-2.08126,0.281202,0.423708,-2.03493,0.196343,0.35465,-1.97302,0.478325,0.386284,-2.003,0.431732,0.340527,-2.06423,0.129727,1.30122,-1.84108,0.120119,1.33085,-2.05405},
/*617*/{0.233921,1.88428,-1.74287,0.286368,1.82559,-1.90164,0.162653,1.7357,-1.63718,0.102559,1.62237,-1.56923,0.233324,1.59218,-1.66314,0.314498,1.56402,-1.69894,0.18191,1.89407,-2.12739,0.281222,1.82685,-1.97664,0.065769,1.85446,-2.02642,-0.03231,1.7288,-2.17234,-0.033418,1.63617,-2.23543,0.126622,1.52737,-2.19386,0.171122,1.47911,-2.20987,0.204141,1.38342,-1.81667,0.010793,1.44675,-1.87339,0.007372,1.47793,-1.92323,0.004844,1.45446,-1.98896,0.193718,1.42374,-2.07152,0.193102,1.05805,-1.77628,0.060314,1.04367,-1.80438,0.069536,0.961052,-1.83071,0.12325,0.867362,-1.81253,-0.030035,0.819776,-1.78997,-0.10487,0.810586,-1.79337,-0.044336,0.927434,-1.81888,-0.115758,0.919252,-1.81629,-0.336614,0.854235,-1.79809,-0.381823,0.956687,-1.87861,-0.413773,0.702256,-1.83827,-0.463481,0.739432,-1.77167,0.255828,1.13969,-2.13726,0.294651,1.06514,-2.12233,0.130035,1.07752,-2.10141,0.169159,1.00545,-2.08833,0.279253,0.89875,-2.09377,0.334809,0.715339,-2.07254,0.222928,0.712008,-2.09301,0.22761,0.642783,-2.07825,0.257377,0.42496,-2.02928,0.171835,0.354485,-1.96826,0.452344,0.386754,-2.00099,0.407983,0.340882,-2.06456,0.129925,1.29646,-1.8418,0.118369,1.32611,-2.05467},
/*618*/{0.232574,1.87857,-1.74175,0.286081,1.81978,-1.90053,0.157617,1.73029,-1.63769,0.096039,1.61844,-1.57064,0.227653,1.58467,-1.66129,0.308341,1.55489,-1.69668,0.183409,1.88915,-2.12845,0.281652,1.82148,-1.97585,0.064573,1.8499,-2.02723,-0.031009,1.72002,-2.17632,-0.030688,1.62842,-2.23873,0.132488,1.52124,-2.19571,0.176876,1.47304,-2.21068,0.203192,1.37845,-1.81816,0.009077,1.4408,-1.87435,0.005644,1.47154,-1.92316,0.001804,1.45059,-1.98929,0.190232,1.41917,-2.07261,0.199577,1.05414,-1.77363,0.064179,1.0355,-1.80508,0.076895,0.954705,-1.82963,0.132865,0.864299,-1.8092,-0.018214,0.819902,-1.78881,-0.093395,0.811933,-1.79334,-0.030572,0.92693,-1.82176,-0.102802,0.921043,-1.81822,-0.325422,0.861843,-1.79943,-0.370728,0.960099,-1.88103,-0.401297,0.706416,-1.83686,-0.450444,0.744188,-1.77028,0.251372,1.13643,-2.14266,0.290141,1.06162,-2.12797,0.126238,1.07577,-2.10104,0.165882,1.00483,-2.08756,0.272748,0.893579,-2.09456,0.328242,0.711608,-2.06749,0.217382,0.713966,-2.09015,0.217202,0.645053,-2.07449,0.231027,0.424958,-2.02513,0.148812,0.355813,-1.97211,0.430666,0.382929,-1.9996,0.384526,0.340861,-2.06369,0.128777,1.29109,-1.84342,0.115741,1.32154,-2.05609},
/*619*/{0.231101,1.87375,-1.74072,0.285897,1.81403,-1.8992,0.154044,1.72543,-1.63854,0.089762,1.61574,-1.57166,0.220411,1.57727,-1.66172,0.301672,1.54563,-1.69431,0.183845,1.88446,-2.12966,0.282501,1.81572,-1.97558,0.064545,1.84658,-2.02723,-0.027756,1.71128,-2.1821,-0.023018,1.61836,-2.24152,0.138273,1.51468,-2.19683,0.183704,1.46721,-2.21089,0.201915,1.37399,-1.82046,0.005537,1.43552,-1.87441,0.002996,1.46647,-1.92273,-0.001861,1.4461,-1.99018,0.187593,1.41619,-2.07481,0.199813,1.05068,-1.77308,0.069535,1.02959,-1.80567,0.0841,0.949662,-1.83025,0.143673,0.861642,-1.80722,-0.005943,0.819578,-1.78722,-0.08056,0.814503,-1.79078,-0.017611,0.926611,-1.82298,-0.088935,0.921101,-1.8191,-0.312922,0.864672,-1.80093,-0.358973,0.962693,-1.88291,-0.387497,0.709945,-1.83487,-0.436857,0.748756,-1.76832,0.248098,1.13364,-2.14783,0.286089,1.05925,-2.13167,0.124303,1.07569,-2.09975,0.162371,1.00375,-2.08715,0.266662,0.891757,-2.09501,0.319317,0.711175,-2.06368,0.208373,0.718714,-2.08688,0.205572,0.649407,-2.07175,0.217572,0.427453,-2.02347,0.12603,0.355954,-1.9673,0.409162,0.382188,-1.99799,0.361863,0.341068,-2.06241,0.127526,1.28631,-1.84571,0.112988,1.31817,-2.05807},
/*620*/{0.229724,1.86935,-1.73947,0.286329,1.8069,-1.89754,0.149391,1.72117,-1.63892,0.081716,1.6123,-1.57405,0.21418,1.57098,-1.65983,0.294122,1.53792,-1.69124,0.184861,1.88029,-2.13126,0.283514,1.81001,-1.97476,0.065297,1.84323,-2.02679,-0.023625,1.70254,-2.18765,-0.016771,1.61001,-2.24452,0.145489,1.50882,-2.19744,0.190837,1.46139,-2.21106,0.200386,1.36826,-1.82149,0.003247,1.43034,-1.87481,0.000873,1.46107,-1.92293,-0.005259,1.44192,-1.98987,0.185345,1.41357,-2.07728,0.20566,1.04929,-1.77111,0.075218,1.02306,-1.80545,0.091588,0.943586,-1.83042,0.154219,0.85822,-1.80468,0.005588,0.81968,-1.78648,-0.069577,0.813635,-1.78946,-0.004136,0.926057,-1.82345,-0.073992,0.921305,-1.81847,-0.297622,0.86731,-1.80088,-0.347003,0.964339,-1.88525,-0.373549,0.711464,-1.83322,-0.421833,0.751538,-1.76664,0.244174,1.13169,-2.15066,0.283085,1.05767,-2.13349,0.121027,1.07508,-2.10011,0.159974,1.00388,-2.08715,0.265593,0.892255,-2.09486,0.309278,0.709729,-2.0633,0.198336,0.7234,-2.08528,0.192471,0.654239,-2.07046,0.196045,0.428723,-2.02173,0.103939,0.358288,-1.96696,0.387012,0.381087,-1.99594,0.339191,0.341421,-2.06162,0.126054,1.28084,-1.84824,0.110514,1.31501,-2.06018},
/*621*/{0.228547,1.86458,-1.73785,0.286767,1.8024,-1.8963,0.145714,1.71731,-1.63939,0.073653,1.61036,-1.57628,0.207267,1.56397,-1.65865,0.286954,1.53049,-1.68909,0.186848,1.87631,-2.13261,0.283955,1.80495,-1.9742,0.065965,1.84159,-2.02654,-0.018436,1.69466,-2.19365,-0.008553,1.60103,-2.24764,0.152736,1.50391,-2.19835,0.198636,1.45676,-2.21091,0.198872,1.36478,-1.82459,-0.000122,1.42574,-1.874,-0.001589,1.45682,-1.92278,-0.008506,1.43823,-1.98932,0.182621,1.41098,-2.07931,0.208702,1.04879,-1.77045,0.081036,1.02068,-1.8066,0.099676,0.939432,-1.82876,0.166085,0.856904,-1.80278,0.018802,0.819123,-1.78465,-0.056485,0.814772,-1.78936,0.010011,0.926664,-1.82287,-0.061187,0.921826,-1.81869,-0.286645,0.869861,-1.80235,-0.334692,0.96514,-1.88645,-0.358036,0.712961,-1.83159,-0.407384,0.752816,-1.76502,0.240087,1.13088,-2.15053,0.279491,1.05683,-2.13334,0.118002,1.07352,-2.09967,0.157102,1.00216,-2.0861,0.266024,0.893098,-2.09411,0.297441,0.709559,-2.06546,0.186895,0.727539,-2.08346,0.17898,0.658027,-2.07031,0.174614,0.428409,-2.02057,0.082645,0.35922,-1.96682,0.366011,0.380251,-1.99753,0.317316,0.341325,-2.06161,0.124917,1.27684,-1.8503,0.107358,1.31224,-2.06187},
/*622*/{0.226801,1.86116,-1.73688,0.285425,1.79777,-1.89465,0.140186,1.71467,-1.6401,0.067005,1.60968,-1.57763,0.200459,1.55968,-1.65779,0.278309,1.52371,-1.68611,0.187879,1.87254,-2.1335,0.284483,1.80114,-1.97308,0.066183,1.84006,-2.02603,-0.012702,1.68722,-2.19918,-0.001481,1.5928,-2.24927,0.160858,1.49935,-2.19826,0.207367,1.45312,-2.21072,0.196969,1.36088,-1.82616,-0.001847,1.42155,-1.87437,-0.003039,1.45573,-1.92231,-0.012256,1.43546,-1.98707,0.180016,1.40902,-2.08141,0.21451,1.05078,-1.76861,0.086541,1.0172,-1.80553,0.109247,0.936424,-1.82721,0.17809,0.855974,-1.79976,0.03168,0.819166,-1.78478,-0.042494,0.814323,-1.78969,0.023744,0.925395,-1.82293,-0.047317,0.922488,-1.81935,-0.275535,0.870933,-1.80413,-0.322974,0.964688,-1.88786,-0.342661,0.712365,-1.83048,-0.391674,0.752045,-1.7644,0.235566,1.12994,-2.15037,0.275537,1.05567,-2.13422,0.113125,1.07211,-2.09898,0.152735,1.00066,-2.08549,0.26681,0.894245,-2.09325,0.285872,0.709163,-2.06839,0.174688,0.729598,-2.08359,0.165188,0.660802,-2.07055,0.159271,0.429701,-2.01969,0.059935,0.359091,-1.96517,0.344389,0.3794,-1.99611,0.295269,0.340893,-2.06147,0.122976,1.27317,-1.85221,0.10372,1.31043,-2.06332},
/*623*/{0.226478,1.85759,-1.73506,0.286908,1.79392,-1.89392,0.134478,1.71327,-1.64109,0.058651,1.60935,-1.57957,0.192915,1.55605,-1.65694,0.269699,1.51819,-1.68358,0.189756,1.86979,-2.13336,0.283899,1.79776,-1.97236,0.066436,1.83927,-2.02654,-0.007198,1.68034,-2.20372,0.006645,1.58653,-2.25105,0.169397,1.49596,-2.19747,0.216162,1.45033,-2.2099,0.195484,1.3567,-1.82696,-0.00468,1.41879,-1.87309,-0.00516,1.45522,-1.92243,-0.013758,1.43448,-1.98514,0.178021,1.40837,-2.08356,0.219167,1.05324,-1.76836,0.092502,1.01435,-1.80519,0.117195,0.934516,-1.8261,0.19104,0.855695,-1.79871,0.044745,0.818214,-1.78405,-0.03048,0.81479,-1.78951,0.037529,0.925588,-1.82143,-0.033808,0.922951,-1.81858,-0.259326,0.867849,-1.80238,-0.311883,0.962869,-1.88902,-0.326072,0.711015,-1.82979,-0.375812,0.750397,-1.76379,0.230462,1.12821,-2.15071,0.269787,1.0534,-2.13562,0.109157,1.07086,-2.0985,0.148373,0.999443,-2.08525,0.266688,0.895214,-2.09195,0.273357,0.707632,-2.07217,0.162727,0.729641,-2.0854,0.151978,0.661467,-2.07077,0.135322,0.43071,-2.01998,0.038648,0.358715,-1.96444,0.323441,0.378294,-1.99639,0.273209,0.340851,-2.06126,0.120492,1.26994,-1.85429,0.100464,1.31005,-2.0648},
/*624*/{0.226018,1.85583,-1.73425,0.286666,1.79172,-1.89255,0.130281,1.71239,-1.64121,0.050082,1.60962,-1.58186,0.184745,1.55333,-1.65607,0.262779,1.51315,-1.68105,0.1902,1.86785,-2.13254,0.283974,1.79554,-1.97108,0.066441,1.83685,-2.02614,-0.001032,1.67399,-2.20721,0.015235,1.58069,-2.25261,0.177497,1.49365,-2.1969,0.225516,1.44839,-2.20867,0.192913,1.35322,-1.8284,-0.005542,1.41849,-1.8714,-0.005807,1.45498,-1.92175,-0.014673,1.43454,-1.98312,0.175729,1.40775,-2.08491,0.22557,1.05554,-1.76678,0.098701,1.01353,-1.80351,0.125412,0.933549,-1.8258,0.204485,0.85626,-1.79858,0.057572,0.818244,-1.78288,-0.016407,0.813921,-1.7901,0.050952,0.926036,-1.82034,-0.020834,0.922914,-1.81863,-0.244291,0.866842,-1.80386,-0.30097,0.960473,-1.89089,-0.309481,0.708007,-1.82926,-0.359276,0.746481,-1.7641,0.225785,1.12515,-2.15125,0.264067,1.05021,-2.1364,0.103758,1.07001,-2.09812,0.142472,0.9977,-2.08449,0.261011,0.894452,-2.09151,0.260693,0.703777,-2.07506,0.150419,0.729037,-2.0866,0.137036,0.661969,-2.07116,0.115279,0.430411,-2.02045,0.016355,0.362274,-1.96499,0.300795,0.378017,-1.99727,0.251476,0.340306,-2.06195,0.117727,1.26754,-1.85578,0.096697,1.31001,-2.06574},
/*625*/{0.225376,1.85235,-1.73335,0.284685,1.78957,-1.8912,0.124424,1.71187,-1.64192,0.04236,1.61152,-1.58438,0.176543,1.55121,-1.65477,0.254987,1.50915,-1.67732,0.192089,1.86624,-2.1311,0.284232,1.79377,-1.96963,0.066827,1.83608,-2.02613,0.005778,1.66846,-2.20968,0.024015,1.57589,-2.25338,0.186998,1.49167,-2.19542,0.236035,1.44871,-2.20694,0.191379,1.35088,-1.82886,-0.00744,1.41875,-1.87002,-0.008114,1.45485,-1.9219,-0.015103,1.43493,-1.98175,0.173787,1.40753,-2.08664,0.227828,1.059,-1.76813,0.105366,1.01336,-1.80178,0.134948,0.933919,-1.82259,0.21794,0.857974,-1.79814,0.071198,0.818998,-1.78264,-0.002833,0.813518,-1.78955,0.063021,0.926808,-1.81875,-0.007694,0.922542,-1.81763,-0.232001,0.864472,-1.80463,-0.292273,0.955977,-1.89037,-0.292184,0.703959,-1.82905,-0.341847,0.740583,-1.76332,0.220464,1.12225,-2.15177,0.257427,1.04691,-2.13766,0.097984,1.06865,-2.09767,0.137195,0.99364,-2.08249,0.252377,0.891115,-2.09298,0.247446,0.698268,-2.07521,0.138164,0.728508,-2.08772,0.123656,0.661254,-2.07198,0.096221,0.431863,-2.02177,-0.004305,0.362577,-1.9653,0.279612,0.376947,-1.99728,0.229469,0.339864,-2.06213,0.115275,1.26624,-1.8568,0.093674,1.31016,-2.0664},
/*626*/{0.224875,1.85026,-1.73254,0.284211,1.78764,-1.89005,0.118792,1.71262,-1.64252,0.034682,1.61511,-1.58684,0.169068,1.55031,-1.65379,0.246477,1.50701,-1.6753,0.19335,1.86507,-2.13009,0.28407,1.79224,-1.96843,0.066825,1.83597,-2.02637,0.011829,1.66491,-2.2117,0.03285,1.57244,-2.25381,0.196447,1.49164,-2.19395,0.245734,1.44882,-2.20455,0.188485,1.34884,-1.82868,-0.008176,1.41931,-1.87057,-0.00918,1.45379,-1.92231,-0.01642,1.435,-1.98134,0.173829,1.40721,-2.087,0.235523,1.06308,-1.76746,0.112111,1.01278,-1.8003,0.144458,0.934688,-1.82114,0.231743,0.861658,-1.79772,0.08389,0.820736,-1.78212,0.008995,0.814246,-1.79065,0.074361,0.927904,-1.81877,0.004001,0.922827,-1.81627,-0.219075,0.861368,-1.8064,-0.283105,0.950729,-1.89119,-0.27355,0.699076,-1.82973,-0.324559,0.734158,-1.76234,0.214876,1.11918,-2.15284,0.25126,1.04271,-2.13824,0.091879,1.06703,-2.09724,0.13078,0.99142,-2.08268,0.24262,0.886654,-2.09451,0.233806,0.694716,-2.07573,0.126072,0.726603,-2.08896,0.107697,0.66134,-2.07183,0.075028,0.432404,-2.0226,-0.027937,0.362453,-1.96611,0.257289,0.376982,-1.99917,0.207758,0.340207,-2.06282,0.112703,1.26495,-1.85749,0.09235,1.31007,-2.06695},
/*627*/{0.224252,1.84933,-1.73206,0.283331,1.78628,-1.88941,0.113877,1.71368,-1.64264,0.02664,1.61826,-1.58924,0.161073,1.5504,-1.6533,0.237567,1.50504,-1.67266,0.195371,1.86476,-2.12903,0.283669,1.79062,-1.96678,0.067662,1.83572,-2.02681,0.019497,1.66227,-2.21203,0.040221,1.56952,-2.2546,0.20544,1.49059,-2.19149,0.256039,1.45016,-2.2017,0.187395,1.34827,-1.82808,-0.009122,1.41908,-1.87047,-0.010607,1.4542,-1.92314,-0.017511,1.43616,-1.98159,0.171839,1.40688,-2.08784,0.243869,1.0671,-1.76545,0.120561,1.01178,-1.79823,0.154542,0.937085,-1.81921,0.243889,0.865449,-1.79689,0.096787,0.821759,-1.78271,0.021478,0.813857,-1.78931,0.086271,0.929437,-1.81683,0.014362,0.923472,-1.8167,-0.205537,0.857124,-1.80619,-0.274925,0.944548,-1.89099,-0.255006,0.693525,-1.83118,-0.306585,0.72619,-1.76285,0.209501,1.11605,-2.15372,0.244818,1.03893,-2.13869,0.085797,1.06334,-2.09687,0.122109,0.989778,-2.08393,0.232355,0.881485,-2.09527,0.220978,0.689201,-2.07487,0.113721,0.724814,-2.0898,0.095101,0.658243,-2.07231,0.052348,0.432243,-2.02339,-0.048828,0.363486,-1.96701,0.236476,0.376744,-1.99976,0.185536,0.338854,-2.06343,0.11085,1.26482,-1.85782,0.090455,1.31007,-2.06725},
/*628*/{0.222056,1.84876,-1.73164,0.283335,1.78518,-1.88783,0.108059,1.71552,-1.64344,0.018576,1.62197,-1.59171,0.153802,1.55179,-1.65231,0.2291,1.50469,-1.67028,0.197545,1.86463,-2.12833,0.28376,1.78936,-1.96589,0.068099,1.8357,-2.0272,0.024821,1.66058,-2.21283,0.048322,1.56703,-2.25486,0.214703,1.49273,-2.18967,0.266102,1.45303,-2.19881,0.184482,1.34805,-1.82687,-0.011024,1.41956,-1.87065,-0.011678,1.45404,-1.92341,-0.017476,1.43631,-1.9815,0.169112,1.40523,-2.08912,0.250525,1.0713,-1.76579,0.128801,1.01491,-1.79648,0.165179,0.938919,-1.81767,0.257503,0.870024,-1.79613,0.110217,0.823426,-1.78292,0.034864,0.814619,-1.78974,0.097375,0.931892,-1.81449,0.025673,0.923329,-1.81595,-0.196836,0.855378,-1.8074,-0.266887,0.93697,-1.89084,-0.234703,0.686811,-1.83118,-0.286483,0.717155,-1.76313,0.2039,1.11332,-2.1544,0.2374,1.03509,-2.13932,0.078657,1.06509,-2.09883,0.113784,0.988092,-2.0851,0.222009,0.87762,-2.09563,0.206456,0.685488,-2.07526,0.1009,0.72232,-2.09036,0.08039,0.6553,-2.07303,0.035517,0.433558,-2.0241,-0.07343,0.367,-1.97023,0.214065,0.375569,-2.00018,0.164051,0.338923,-2.06491,0.108091,1.26469,-1.85701,0.087962,1.30883,-2.06671},
/*629*/{0.220047,1.8489,-1.73052,0.281803,1.78469,-1.88726,0.102482,1.71818,-1.64475,0.009732,1.62648,-1.59373,0.145193,1.55267,-1.65033,0.220407,1.50536,-1.6674,0.199354,1.86486,-2.12792,0.283729,1.78938,-1.96462,0.069449,1.83573,-2.02792,0.029866,1.65871,-2.2131,0.056507,1.56603,-2.25528,0.224048,1.49513,-2.18699,0.27665,1.45673,-2.19552,0.18358,1.3488,-1.82623,-0.011349,1.42039,-1.87118,-0.012694,1.45426,-1.92433,-0.018214,1.43742,-1.98288,0.170037,1.40555,-2.08888,0.254973,1.07614,-1.76551,0.137386,1.0166,-1.79485,0.175286,0.942121,-1.81638,0.269756,0.875111,-1.79556,0.122373,0.825452,-1.7825,0.049109,0.81475,-1.78982,0.107786,0.933671,-1.81317,0.036177,0.923525,-1.81379,-0.181306,0.846292,-1.80906,-0.258539,0.927968,-1.89148,-0.215097,0.679468,-1.83242,-0.267125,0.707725,-1.76351,0.198373,1.11126,-2.15409,0.229988,1.03151,-2.13949,0.072435,1.06331,-2.09938,0.105538,0.98775,-2.08636,0.210631,0.873475,-2.09502,0.192949,0.680494,-2.07301,0.086653,0.719507,-2.09038,0.064904,0.655372,-2.0767,0.011488,0.433215,-2.02563,-0.089756,0.364995,-1.96816,0.193011,0.375083,-2.00068,0.14205,0.338317,-2.06598,0.107214,1.26548,-1.85689,0.088407,1.30929,-2.06678},
/*630*/{0.218003,1.85062,-1.72987,0.281507,1.78481,-1.88537,0.096772,1.7212,-1.64492,0.00193,1.63147,-1.5958,0.137309,1.55534,-1.64929,0.211764,1.5067,-1.66554,0.202852,1.86649,-2.12656,0.283634,1.7898,-1.96324,0.070325,1.8364,-2.02908,0.034741,1.65789,-2.21263,0.064407,1.56521,-2.25512,0.2335,1.49918,-2.18439,0.285863,1.46219,-2.19227,0.181389,1.35032,-1.82509,-0.012161,1.42142,-1.87266,-0.013189,1.45549,-1.925,-0.01894,1.43755,-1.98374,0.169818,1.40524,-2.0888,0.262386,1.08425,-1.76551,0.145953,1.01857,-1.79286,0.186224,0.946368,-1.81487,0.282042,0.881107,-1.79443,0.135951,0.827505,-1.78299,0.062084,0.81394,-1.79123,0.117824,0.934679,-1.81279,0.047563,0.923886,-1.81206,-0.167858,0.838417,-1.80814,-0.250926,0.918326,-1.89169,-0.193739,0.672713,-1.83401,-0.245916,0.696982,-1.76414,0.193082,1.10766,-2.15364,0.222262,1.02788,-2.13936,0.06556,1.0629,-2.10049,0.094899,0.987145,-2.08808,0.197902,0.868883,-2.09475,0.176859,0.675924,-2.07206,0.072387,0.717708,-2.09126,0.048441,0.653605,-2.0771,-0.009511,0.434112,-2.02563,-0.112953,0.365303,-1.9704,0.17168,0.374145,-2.00167,0.120653,0.339132,-2.06633,0.105667,1.26674,-1.85593,0.088159,1.30907,-2.06624},
/*631*/{0.214706,1.85123,-1.72895,0.27883,1.7854,-1.88385,0.091351,1.7252,-1.64511,-0.006661,1.63701,-1.59805,0.129167,1.55883,-1.64809,0.202929,1.50912,-1.66335,0.204894,1.86762,-2.12611,0.283036,1.79031,-1.96147,0.071016,1.83751,-2.0296,0.039548,1.65786,-2.21268,0.072346,1.5652,-2.25509,0.241405,1.50279,-2.18146,0.296029,1.46826,-2.18819,0.179204,1.35175,-1.82403,-0.012688,1.42214,-1.87381,-0.014547,1.45602,-1.92625,-0.019189,1.43843,-1.9859,0.170316,1.40473,-2.08871,0.269159,1.08957,-1.7638,0.153077,1.02094,-1.79108,0.194927,0.950549,-1.81334,0.293646,0.887384,-1.7938,0.149106,0.828808,-1.78302,0.074993,0.814383,-1.79161,0.127398,0.93628,-1.81007,0.056439,0.922107,-1.81102,-0.153439,0.832049,-1.81003,-0.242074,0.906375,-1.89151,-0.172266,0.664466,-1.83464,-0.226063,0.686806,-1.7651,0.18748,1.10505,-2.15343,0.213912,1.02461,-2.13878,0.057457,1.06418,-2.10221,0.086098,0.987276,-2.08839,0.184079,0.864723,-2.09453,0.160628,0.672478,-2.07115,0.056997,0.715792,-2.09153,0.032169,0.651675,-2.07616,-0.030219,0.435642,-2.02596,-0.133657,0.367768,-1.96992,0.149844,0.375616,-2.00118,0.099698,0.339553,-2.06668,0.10406,1.26785,-1.8553,0.088451,1.30886,-2.06601},
/*632*/{0.211869,1.85271,-1.7276,0.278683,1.78655,-1.88214,0.0853,1.72924,-1.64576,-0.013328,1.64181,-1.59941,0.121738,1.56276,-1.64724,0.194282,1.51194,-1.66133,0.206284,1.86973,-2.12518,0.283117,1.79107,-1.95985,0.071615,1.83937,-2.03074,0.044724,1.65718,-2.21222,0.079353,1.56564,-2.25481,0.249667,1.50793,-2.17827,0.304713,1.47538,-2.18458,0.178288,1.35299,-1.82325,-0.014631,1.42388,-1.8755,-0.013975,1.45641,-1.92713,-0.019313,1.43865,-1.98723,0.17075,1.40472,-2.0888,0.274018,1.09741,-1.76429,0.161264,1.02727,-1.79078,0.203656,0.955282,-1.81224,0.305205,0.894015,-1.79362,0.160943,0.830973,-1.78351,0.089136,0.814979,-1.79181,0.136351,0.938401,-1.80881,0.066272,0.922036,-1.80969,-0.147094,0.826649,-1.81081,-0.233648,0.89499,-1.89207,-0.150845,0.65607,-1.83628,-0.205243,0.675107,-1.76569,0.181266,1.10263,-2.15271,0.205556,1.02175,-2.13802,0.050095,1.06481,-2.10228,0.074783,0.990515,-2.09082,0.168939,0.860365,-2.09433,0.14289,0.671106,-2.07007,0.040904,0.714895,-2.09111,0.015422,0.650686,-2.07589,-0.049399,0.436911,-2.02679,-0.154977,0.368593,-1.97146,0.128166,0.375818,-2.00264,0.076965,0.339557,-2.06739,0.103046,1.26906,-1.85477,0.088869,1.30882,-2.06583},
/*633*/{0.208792,1.85543,-1.72718,0.277344,1.78795,-1.87986,0.079191,1.73373,-1.64692,-0.021857,1.64757,-1.6013,0.112729,1.56722,-1.64674,0.18543,1.51584,-1.65953,0.208955,1.87204,-2.12374,0.282905,1.79319,-1.95818,0.072444,1.84014,-2.03223,0.049192,1.65728,-2.21137,0.086858,1.56644,-2.25482,0.257306,1.51404,-2.17522,0.3139,1.48285,-2.18,0.176608,1.35488,-1.82152,-0.015277,1.42472,-1.87711,-0.014558,1.45773,-1.92867,-0.019627,1.44,-1.98925,0.171177,1.40449,-2.08855,0.280255,1.10421,-1.76251,0.168393,1.03097,-1.7895,0.213774,0.961579,-1.81143,0.316064,0.901162,-1.7933,0.173475,0.832644,-1.78488,0.102961,0.813174,-1.79252,0.144428,0.938656,-1.80683,0.075279,0.919872,-1.80852,-0.127765,0.814552,-1.81212,-0.22501,0.881427,-1.89207,-0.129316,0.647682,-1.83804,-0.18371,0.663403,-1.76688,0.174178,1.10115,-2.15223,0.196631,1.01959,-2.13657,0.041783,1.0668,-2.10264,0.066329,0.987761,-2.08966,0.152945,0.857918,-2.0941,0.126532,0.66999,-2.06824,0.024544,0.714988,-2.09053,-0.00086,0.65145,-2.07499,-0.068141,0.438516,-2.02628,-0.176373,0.369043,-1.9728,0.107284,0.374457,-2.00199,0.055448,0.339545,-2.06744,0.101534,1.27069,-1.85393,0.089398,1.3089,-2.0654},
/*634*/{0.204999,1.85816,-1.72671,0.276887,1.79021,-1.87782,0.073213,1.73821,-1.64683,-0.029016,1.654,-1.60319,0.10581,1.57306,-1.64691,0.177247,1.52038,-1.65846,0.211221,1.87481,-2.12255,0.282864,1.79501,-1.95581,0.073807,1.84132,-2.03293,0.053701,1.65748,-2.21012,0.09334,1.56795,-2.25475,0.264781,1.52139,-2.17225,0.321501,1.49171,-2.176,0.175759,1.35796,-1.82112,-0.016293,1.42642,-1.8789,-0.014762,1.45985,-1.93042,-0.019674,1.44145,-1.99135,0.171215,1.40441,-2.08863,0.283519,1.11307,-1.76278,0.174356,1.03595,-1.7893,0.223148,0.967431,-1.81132,0.325723,0.908029,-1.79314,0.186908,0.834844,-1.78357,0.114608,0.812246,-1.792,0.152496,0.940385,-1.80569,0.08339,0.918573,-1.80714,-0.116036,0.805498,-1.8135,-0.215501,0.867686,-1.89216,-0.107086,0.638735,-1.83926,-0.162685,0.651048,-1.76837,0.167527,1.0998,-2.14997,0.188078,1.01726,-2.13454,0.033844,1.06863,-2.10341,0.056147,0.990048,-2.09023,0.137444,0.8562,-2.09324,0.110004,0.669475,-2.06748,0.008295,0.716446,-2.08925,-0.018781,0.652578,-2.07428,-0.088691,0.440298,-2.0263,-0.198372,0.372896,-1.97266,0.085682,0.374814,-2.00268,0.034936,0.339459,-2.06741,0.100596,1.27329,-1.8532,0.089667,1.30922,-2.06513},
/*635*/{0.201654,1.86133,-1.72563,0.27448,1.79312,-1.87567,0.067271,1.74343,-1.6475,-0.037283,1.65988,-1.60457,0.097548,1.57841,-1.64701,0.169607,1.52523,-1.65631,0.213307,1.87779,-2.12096,0.282758,1.79772,-1.95376,0.074474,1.84341,-2.03414,0.057642,1.65824,-2.20973,0.100533,1.57013,-2.25528,0.272528,1.52889,-2.1696,0.329589,1.50082,-2.17138,0.174925,1.36038,-1.82056,-0.01685,1.42848,-1.88087,-0.014146,1.46152,-1.93233,-0.019044,1.44401,-1.99319,0.172325,1.4042,-2.08835,0.287604,1.12071,-1.76215,0.183389,1.04163,-1.78808,0.229608,0.97368,-1.81064,0.336465,0.916356,-1.79276,0.198468,0.836804,-1.78416,0.127619,0.811918,-1.79276,0.160201,0.94091,-1.80384,0.092532,0.916304,-1.80617,-0.101047,0.793309,-1.81235,-0.205027,0.852766,-1.89262,-0.084734,0.630303,-1.83989,-0.141285,0.638791,-1.76985,0.161276,1.09811,-2.14846,0.178391,1.01554,-2.13244,0.02605,1.07148,-2.10361,0.044291,0.991539,-2.09037,0.119756,0.856528,-2.09222,0.091362,0.669229,-2.06602,-0.009348,0.717984,-2.08825,-0.036926,0.654558,-2.07378,-0.11168,0.441438,-2.02763,-0.218964,0.375618,-1.97347,0.064177,0.374687,-2.00284,0.01258,0.339621,-2.06739,0.099423,1.27552,-1.85269,0.090421,1.30982,-2.06499},
/*636*/{0.19775,1.86465,-1.72504,0.274746,1.79669,-1.87368,0.061886,1.74894,-1.64806,-0.04527,1.66644,-1.60679,0.090418,1.5846,-1.64706,0.161765,1.53133,-1.65603,0.215604,1.88084,-2.12001,0.282152,1.80007,-1.95122,0.075379,1.8447,-2.0343,0.062678,1.65899,-2.20916,0.10797,1.57203,-2.25524,0.278202,1.53535,-2.16565,0.337333,1.51002,-2.16684,0.174662,1.36297,-1.81973,-0.016597,1.43002,-1.88293,-0.01377,1.46386,-1.93339,-0.018779,1.44542,-1.99528,0.173154,1.4043,-2.08816,0.291668,1.12866,-1.7613,0.188119,1.04626,-1.78816,0.236389,0.97887,-1.80932,0.345134,0.924796,-1.7927,0.210055,0.838731,-1.78447,0.139809,0.810177,-1.79375,0.167144,0.9415,-1.80255,0.100538,0.914174,-1.80503,-0.086806,0.782602,-1.81724,-0.194616,0.83733,-1.89336,-0.062635,0.621177,-1.8414,-0.119035,0.626783,-1.77175,0.154544,1.09729,-2.14648,0.1691,1.01439,-2.13019,0.01756,1.07467,-2.10384,0.034189,0.994646,-2.09022,0.103288,0.85771,-2.09127,0.073408,0.670555,-2.06508,-0.026182,0.720054,-2.08746,-0.054936,0.657132,-2.07305,-0.131497,0.444783,-2.02764,-0.240148,0.378357,-1.97382,0.042497,0.374584,-2.00275,-0.009627,0.339681,-2.06669,0.09899,1.27787,-1.85202,0.091333,1.31032,-2.06466},
/*637*/{0.194214,1.86833,-1.72419,0.274166,1.79841,-1.87038,0.056594,1.75437,-1.64883,-0.051356,1.67321,-1.60895,0.083971,1.59177,-1.64741,0.153838,1.53783,-1.65515,0.217182,1.88454,-2.11814,0.282436,1.80387,-1.94911,0.076053,1.84736,-2.03543,0.067809,1.6606,-2.20807,0.114749,1.57472,-2.2554,0.285012,1.54393,-2.16215,0.34522,1.52076,-2.16201,0.174696,1.36647,-1.81939,-0.016358,1.4335,-1.8838,-0.01352,1.46637,-1.93499,-0.017006,1.44769,-1.99682,0.173563,1.40458,-2.08796,0.296785,1.13603,-1.76079,0.194972,1.05115,-1.78765,0.244591,0.985937,-1.80961,0.354305,0.933881,-1.79238,0.221956,0.840973,-1.7837,0.153228,0.809288,-1.79395,0.173555,0.941536,-1.80079,0.108589,0.910795,-1.80354,-0.073783,0.774181,-1.81391,-0.183214,0.821128,-1.89413,-0.039006,0.611939,-1.84251,-0.097137,0.613892,-1.77315,0.147912,1.09645,-2.14411,0.160003,1.01302,-2.12732,0.009354,1.07846,-2.10441,0.023622,0.997189,-2.09,0.087387,0.859256,-2.08966,0.056136,0.671357,-2.06373,-0.044308,0.722247,-2.08598,-0.073802,0.659922,-2.072,-0.151718,0.448285,-2.02775,-0.261153,0.381967,-1.97436,0.020409,0.374659,-2.00191,-0.031618,0.339482,-2.06613,0.098667,1.28126,-1.85085,0.091887,1.31116,-2.06389},
/*638*/{0.190096,1.8722,-1.72413,0.272879,1.80246,-1.86954,0.050834,1.76014,-1.6496,-0.058852,1.68013,-1.61142,0.076934,1.59844,-1.64807,0.146899,1.54336,-1.65448,0.218564,1.8884,-2.11708,0.282575,1.80727,-1.94722,0.077517,1.84923,-2.03609,0.072233,1.66258,-2.20805,0.121578,1.5777,-2.25524,0.290853,1.55186,-2.15839,0.351556,1.53056,-2.15766,0.17441,1.37034,-1.81897,-0.015662,1.43598,-1.88632,-0.011876,1.46929,-1.93657,-0.015868,1.45107,-1.99879,0.175742,1.40416,-2.08739,0.298709,1.14405,-1.76117,0.200905,1.05612,-1.78698,0.251437,0.991756,-1.81043,0.36299,0.94326,-1.79208,0.232999,0.842218,-1.78406,0.166029,0.808085,-1.79378,0.179986,0.941403,-1.79977,0.114918,0.908345,-1.80438,-0.060148,0.761877,-1.81513,-0.171163,0.804382,-1.89551,-0.016402,0.603534,-1.84397,-0.0748,0.600813,-1.77477,0.140836,1.09611,-2.14178,0.150197,1.01256,-2.12469,0.002196,1.08204,-2.10426,0.012831,1.0004,-2.089,0.071965,0.860893,-2.08738,0.037737,0.673709,-2.06274,-0.061228,0.725665,-2.085,-0.090802,0.663345,-2.07089,-0.172456,0.451541,-2.02773,-0.280783,0.388551,-1.97398,-0.000154,0.375276,-2.00151,-0.053626,0.339782,-2.06605,0.098157,1.28461,-1.84987,0.093334,1.31203,-2.0633},
/*639*/{0.186829,1.87632,-1.72328,0.270592,1.8077,-1.86723,0.045328,1.76599,-1.65053,-0.065614,1.68661,-1.61352,0.070468,1.6053,-1.64885,0.140397,1.55105,-1.65414,0.220548,1.89231,-2.11568,0.282078,1.81103,-1.94452,0.078394,1.85189,-2.03706,0.076692,1.66492,-2.20806,0.128231,1.58116,-2.25534,0.297469,1.56094,-2.15503,0.357619,1.54066,-2.15277,0.175097,1.37392,-1.81914,-0.014752,1.44015,-1.8879,-0.01077,1.47181,-1.93817,-0.014576,1.45338,-2.0006,0.176309,1.40509,-2.08749,0.303183,1.15166,-1.7598,0.205193,1.06158,-1.78771,0.256826,0.999706,-1.81161,0.370045,0.952459,-1.79257,0.243596,0.844398,-1.78423,0.179394,0.807171,-1.79406,0.186146,0.940657,-1.79832,0.124319,0.903314,-1.80301,-0.04486,0.750496,-1.81524,-0.158586,0.787498,-1.89601,0.007043,0.594742,-1.84456,-0.052008,0.588098,-1.77676,0.134195,1.09628,-2.13968,0.140768,1.0126,-2.12145,-0.006055,1.08594,-2.10403,0.002551,1.00449,-2.08899,0.057917,0.86315,-2.08548,0.02058,0.676618,-2.06091,-0.077682,0.729303,-2.08356,-0.108682,0.66702,-2.07007,-0.196209,0.454856,-2.02646,-0.300222,0.394397,-1.97484,-0.021458,0.3751,-2.00103,-0.074059,0.340185,-2.06647,0.098401,1.28829,-1.84925,0.094084,1.31329,-2.06299},
/*640*/{0.18279,1.88058,-1.72317,0.271573,1.81058,-1.86461,0.040529,1.77163,-1.65158,-0.070372,1.69486,-1.61619,0.06373,1.61247,-1.64986,0.133334,1.55648,-1.65238,0.222462,1.89693,-2.11425,0.282299,1.81452,-1.9429,0.079291,1.85545,-2.03743,0.082262,1.66728,-2.20867,0.134972,1.58501,-2.25546,0.301855,1.5688,-2.15099,0.364128,1.55044,-2.14737,0.176429,1.37839,-1.81898,-0.013905,1.44388,-1.88856,-0.010055,1.47498,-1.9401,-0.012456,1.4567,-2.00254,0.177534,1.40528,-2.08756,0.305254,1.15857,-1.75953,0.207612,1.06785,-1.78848,0.262467,1.00616,-1.81062,0.376821,0.962318,-1.79184,0.25398,0.846438,-1.78372,0.19063,0.805105,-1.79392,0.191658,0.939745,-1.79773,0.133321,0.89902,-1.80257,-0.029832,0.739669,-1.81602,-0.145386,0.769873,-1.89648,0.030745,0.586616,-1.84624,-0.028728,0.576051,-1.77785,0.127552,1.09745,-2.13648,0.131842,1.01271,-2.11843,-0.01312,1.09095,-2.10419,-0.007098,1.00878,-2.08879,0.044594,0.865337,-2.08286,0.0036,0.680349,-2.06019,-0.094297,0.733331,-2.08242,-0.126444,0.67075,-2.06898,-0.206694,0.45897,-2.02647,-0.320203,0.401192,-1.97425,-0.04343,0.375096,-2.00121,-0.096591,0.340668,-2.06521,0.098892,1.29256,-1.84803,0.095127,1.31447,-2.06211},
/*641*/{0.180129,1.88521,-1.72251,0.270346,1.81484,-1.86345,0.035646,1.77773,-1.65271,-0.079267,1.70312,-1.61938,0.057833,1.61958,-1.6506,0.126957,1.5639,-1.6523,0.223512,1.90138,-2.11254,0.283583,1.81818,-1.94032,0.080729,1.85863,-2.03834,0.086521,1.67184,-2.21045,0.141506,1.58892,-2.25548,0.306671,1.57739,-2.14748,0.369607,1.56112,-2.14271,0.177142,1.38285,-1.82006,-0.013912,1.44806,-1.89087,-0.008221,1.4788,-1.94171,-0.010087,1.46019,-2.00252,0.17971,1.40496,-2.08724,0.307484,1.16655,-1.75958,0.211807,1.0744,-1.78773,0.26775,1.01396,-1.80942,0.383599,0.972087,-1.79176,0.264593,0.848247,-1.78376,0.203426,0.803674,-1.7941,0.197214,0.938307,-1.79693,0.140117,0.896009,-1.80261,-0.016592,0.728113,-1.81617,-0.130602,0.752556,-1.89644,0.055309,0.578839,-1.84734,-0.003916,0.563806,-1.77973,0.121471,1.0977,-2.13349,0.122694,1.0135,-2.11526,-0.020872,1.09575,-2.10371,-0.016616,1.01382,-2.08794,0.03123,0.868432,-2.08034,-0.013948,0.684786,-2.05957,-0.111626,0.738237,-2.08144,-0.143659,0.676316,-2.06881,-0.227535,0.466476,-2.02617,-0.338378,0.408892,-1.97456,-0.064592,0.375682,-1.99985,-0.118027,0.34101,-2.06423,0.09884,1.2968,-1.84691,0.095996,1.31576,-2.06129},
/*642*/{0.176245,1.88919,-1.72288,0.268616,1.81877,-1.86121,0.030969,1.78421,-1.65391,-0.083185,1.71059,-1.62184,0.051787,1.62616,-1.65116,0.121496,1.57111,-1.65176,0.224816,1.9063,-2.11075,0.28315,1.82221,-1.93874,0.081931,1.8623,-2.03943,0.091985,1.67547,-2.21193,0.138241,1.59359,-2.25883,0.312254,1.58647,-2.14293,0.374368,1.57176,-2.13756,0.177527,1.38795,-1.8203,-0.012407,1.45278,-1.89058,-0.00752,1.48218,-1.94345,-0.007965,1.46396,-2.00367,0.180427,1.40577,-2.08724,0.31077,1.17469,-1.75918,0.21417,1.08016,-1.78826,0.272022,1.02104,-1.80954,0.388674,0.981267,-1.79208,0.274655,0.849372,-1.78396,0.215756,0.802948,-1.79492,0.202971,0.935886,-1.79659,0.14821,0.890652,-1.80132,0.001509,0.715781,-1.81677,-0.116008,0.734659,-1.8972,0.079725,0.570836,-1.84785,0.021623,0.552521,-1.78122,0.115509,1.09889,-2.13084,0.113852,1.0147,-2.11227,-0.027232,1.10091,-2.10326,-0.026253,1.01928,-2.08816,0.018561,0.872711,-2.07817,-0.030228,0.689171,-2.05919,-0.127672,0.742933,-2.08039,-0.159594,0.681759,-2.06807,-0.248274,0.471044,-2.02752,-0.35726,0.416991,-1.97352,-0.08543,0.376099,-1.99934,-0.138902,0.341481,-2.06423,0.099189,1.30166,-1.84549,0.096447,1.31753,-2.06012},
/*643*/{0.173484,1.89355,-1.72281,0.267652,1.82466,-1.86002,0.026047,1.78998,-1.65535,-0.089719,1.71687,-1.62468,0.045578,1.63318,-1.65245,0.116084,1.57724,-1.65194,0.226725,1.91106,-2.10976,0.283367,1.82707,-1.93653,0.082788,1.8648,-2.03949,0.097634,1.6802,-2.2141,0.155908,1.5978,-2.25557,0.316267,1.59603,-2.14017,0.378522,1.58136,-2.13251,0.178458,1.39202,-1.82016,-0.010667,1.45723,-1.89201,-0.005316,1.48581,-1.94421,-0.005456,1.46727,-2.00467,0.183492,1.40548,-2.08686,0.312973,1.18205,-1.75926,0.214997,1.08669,-1.78826,0.276382,1.02842,-1.80921,0.392841,0.990339,-1.79237,0.284817,0.850897,-1.78295,0.228216,0.801914,-1.79418,0.209536,0.934356,-1.7958,0.15633,0.886577,-1.80143,0.016576,0.703176,-1.81712,-0.101247,0.716781,-1.8967,0.104087,0.564044,-1.85023,0.04738,0.541155,-1.78269,0.109605,1.1003,-2.12874,0.10517,1.01652,-2.10887,-0.033142,1.10679,-2.10247,-0.034314,1.02494,-2.08688,0.004606,0.878148,-2.07677,-0.046674,0.694373,-2.05885,-0.144176,0.749731,-2.08012,-0.176505,0.687764,-2.0674,-0.265761,0.476775,-2.02742,-0.375769,0.427132,-1.97372,-0.108326,0.375433,-1.99773,-0.160896,0.342241,-2.06325,0.099591,1.30585,-1.84399,0.097955,1.31878,-2.05884},
/*644*/{0.171121,1.89743,-1.7231,0.267917,1.82864,-1.85792,0.021984,1.79574,-1.65688,-0.09473,1.72446,-1.6279,0.040526,1.64042,-1.6537,0.110067,1.58461,-1.65142,0.229098,1.91615,-2.10771,0.28279,1.83086,-1.93472,0.084172,1.86857,-2.04024,0.103931,1.68445,-2.21617,0.163127,1.60329,-2.25589,0.319339,1.60361,-2.13627,0.382415,1.5917,-2.12742,0.180505,1.39619,-1.82149,-0.008705,1.46253,-1.89185,-0.00316,1.48968,-1.94571,-0.003384,1.47133,-2.00481,0.184843,1.40605,-2.08649,0.314813,1.18849,-1.75906,0.223729,1.09263,-1.78643,0.279339,1.03488,-1.80922,0.395993,0.998378,-1.79211,0.293569,0.851939,-1.78326,0.240332,0.799566,-1.79426,0.214496,0.931526,-1.79542,0.163332,0.880852,-1.80085,0.03448,0.69019,-1.81715,-0.084813,0.697713,-1.89594,0.129653,0.557219,-1.85095,0.074337,0.531318,-1.78461,0.104401,1.10168,-2.12554,0.096893,1.01831,-2.10577,-0.038547,1.11285,-2.10262,-0.043157,1.03134,-2.08733,-0.009946,0.883584,-2.07628,-0.06256,0.699392,-2.0582,-0.158624,0.756124,-2.0793,-0.192265,0.694848,-2.06745,-0.281141,0.483357,-2.02681,-0.39324,0.436316,-1.97379,-0.130183,0.376138,-1.99801,-0.18363,0.342539,-2.06262,0.100584,1.31048,-1.8429,0.098293,1.32073,-2.05788},
/*645*/{0.168127,1.90157,-1.72279,0.266573,1.83389,-1.8568,0.018105,1.80209,-1.65835,-0.099476,1.73176,-1.63108,0.035152,1.64685,-1.65459,0.104345,1.59081,-1.65116,0.230399,1.92079,-2.10643,0.283294,1.83536,-1.93253,0.085133,1.8723,-2.04111,0.10927,1.68878,-2.21748,0.16941,1.60819,-2.25598,0.322823,1.61141,-2.13287,0.386226,1.60157,-2.12338,0.181414,1.40097,-1.82201,-0.00783,1.46739,-1.89271,-0.001866,1.4936,-1.94743,-0.000894,1.47472,-2.00617,0.185484,1.4067,-2.08595,0.316226,1.19572,-1.75902,0.224398,1.09913,-1.78587,0.282513,1.04179,-1.8085,0.398668,1.00599,-1.79221,0.302828,0.852497,-1.78346,0.251583,0.797596,-1.79462,0.220475,0.928352,-1.79503,0.172845,0.87528,-1.80149,0.051818,0.677958,-1.81762,-0.066621,0.678057,-1.89535,0.153989,0.551185,-1.8532,0.100813,0.521141,-1.7863,0.09921,1.10357,-2.12282,0.088755,1.02029,-2.10313,-0.044415,1.11932,-2.10236,-0.051379,1.03794,-2.08683,-0.024615,0.888966,-2.07623,-0.078261,0.705214,-2.05774,-0.174056,0.763167,-2.07844,-0.206511,0.70186,-2.06707,-0.301091,0.490304,-2.02795,-0.409741,0.447791,-1.97026,-0.152431,0.376712,-1.99692,-0.203636,0.343504,-2.06211,0.100767,1.3154,-1.84165,0.098784,1.32246,-2.05676},
/*646*/{0.166124,1.90546,-1.7226,0.26682,1.8377,-1.85521,0.014273,1.80802,-1.66067,-0.105278,1.7384,-1.6342,0.03029,1.65292,-1.65498,0.098892,1.59737,-1.65128,0.231016,1.92545,-2.10429,0.282709,1.83939,-1.93139,0.086557,1.87559,-2.04149,0.114503,1.69372,-2.21962,0.176466,1.61303,-2.25616,0.326847,1.6209,-2.12942,0.389347,1.61096,-2.11936,0.182408,1.4054,-1.82152,-0.006542,1.47251,-1.89278,-2e-005,1.4976,-1.94819,0.002016,1.47826,-2.00598,0.188162,1.40693,-2.08505,0.317937,1.2026,-1.75891,0.226638,1.10454,-1.78474,0.285864,1.04835,-1.80785,0.399258,1.01198,-1.79318,0.312631,0.853452,-1.78373,0.26361,0.795138,-1.79485,0.226036,0.924776,-1.79502,0.179912,0.868662,-1.80076,0.071246,0.664567,-1.81803,-0.049358,0.65931,-1.89495,0.179821,0.545038,-1.85377,0.12863,0.511394,-1.78666,0.093609,1.10517,-2.12085,0.08063,1.02327,-2.10019,-0.048761,1.12582,-2.10158,-0.059261,1.04495,-2.08616,-0.038119,0.894851,-2.07551,-0.092383,0.712144,-2.05826,-0.188601,0.770943,-2.07868,-0.221414,0.709494,-2.06707,-0.314697,0.497286,-2.0291,-0.426085,0.457901,-1.97084,-0.174432,0.376755,-1.99714,-0.225147,0.343779,-2.06119,0.101185,1.32014,-1.83957,0.099971,1.32424,-2.05476},
/*647*/{0.164089,1.9093,-1.7227,0.265478,1.84167,-1.85379,0.011464,1.81366,-1.66267,-0.109276,1.74564,-1.63796,0.025595,1.65986,-1.65657,0.094382,1.60293,-1.65098,0.232604,1.93008,-2.10294,0.283203,1.84406,-1.9297,0.087257,1.87881,-2.04189,0.120506,1.69808,-2.22134,0.182659,1.61756,-2.25611,0.329021,1.62784,-2.12575,0.392023,1.61989,-2.11563,0.183199,1.40993,-1.82205,-0.004188,1.47742,-1.89215,0.002015,1.50167,-1.9492,0.00453,1.48164,-2.00634,0.188948,1.40744,-2.08457,0.31979,1.20872,-1.75889,0.224584,1.10922,-1.78661,0.287424,1.05404,-1.80723,0.399585,1.01656,-1.79356,0.320708,0.853374,-1.78424,0.27582,0.793627,-1.79525,0.230794,0.920338,-1.79473,0.188484,0.863243,-1.80042,0.090844,0.6547,-1.81792,-0.029929,0.640406,-1.89439,0.205568,0.540397,-1.85563,0.157153,0.503443,-1.78828,0.087744,1.10787,-2.11871,0.072764,1.02603,-2.09771,-0.054593,1.13312,-2.10016,-0.066442,1.05233,-2.08521,-0.050578,0.90148,-2.07562,-0.106824,0.72005,-2.0593,-0.202283,0.77829,-2.0779,-0.235546,0.717341,-2.06697,-0.331827,0.503732,-2.02952,-0.439745,0.471129,-1.96922,-0.195789,0.37687,-1.99727,-0.247071,0.344716,-2.06086,0.101845,1.32491,-1.83796,0.10018,1.32603,-2.05318},
/*648*/{0.162266,1.9128,-1.72288,0.25923,1.84918,-1.85455,0.007851,1.81946,-1.6651,-0.113776,1.75238,-1.64186,0.020393,1.66522,-1.65751,0.089445,1.60855,-1.65074,0.233381,1.93424,-2.10127,0.282794,1.84892,-1.92863,0.088875,1.88157,-2.04234,0.125697,1.70233,-2.22267,0.188849,1.62252,-2.25616,0.331415,1.63538,-2.12289,0.395337,1.62859,-2.1119,0.184259,1.41464,-1.82258,-0.002036,1.48255,-1.89228,0.004073,1.50543,-1.95042,0.007065,1.48577,-2.00645,0.190314,1.40863,-2.08369,0.321118,1.21413,-1.7588,0.230556,1.11621,-1.78313,0.287753,1.05886,-1.80737,0.400111,1.02218,-1.79444,0.329195,0.852929,-1.78394,0.286749,0.790445,-1.79589,0.236041,0.914647,-1.79437,0.196446,0.855584,-1.80119,0.10789,0.641372,-1.81917,-0.010767,0.622002,-1.89375,0.231378,0.53518,-1.85645,0.186817,0.496296,-1.78868,0.083066,1.11009,-2.11711,0.064903,1.02946,-2.09623,-0.057958,1.14059,-2.10119,-0.073025,1.05989,-2.0851,-0.062305,0.908878,-2.07545,-0.119751,0.726933,-2.06018,-0.215913,0.786438,-2.07827,-0.249463,0.725285,-2.06756,-0.343485,0.510828,-2.03082,-0.452766,0.483563,-1.96775,-0.218209,0.377065,-1.99723,-0.269322,0.345992,-2.0607,0.102634,1.32985,-1.83661,0.100977,1.32839,-2.05184},
/*649*/{0.160796,1.91642,-1.72305,0.259819,1.85282,-1.85374,0.005032,1.82512,-1.66698,-0.117727,1.75902,-1.64558,0.016665,1.67091,-1.65906,0.08448,1.61385,-1.65083,0.234865,1.9385,-2.10004,0.283146,1.8524,-1.92731,0.089886,1.8844,-2.04252,0.130561,1.70681,-2.22453,0.19482,1.62729,-2.25686,0.333072,1.64224,-2.11977,0.397327,1.63687,-2.10761,0.186218,1.41839,-1.82311,-0.000834,1.48726,-1.89218,0.005552,1.50934,-1.9512,0.009154,1.48878,-2.00657,0.191693,1.40912,-2.08295,0.320853,1.2192,-1.75923,0.229812,1.11816,-1.78187,0.287739,1.06374,-1.80715,0.398507,1.02564,-1.79455,0.338019,0.852282,-1.78483,0.298363,0.788473,-1.79593,0.240977,0.909495,-1.79466,0.203686,0.848377,-1.80213,0.128086,0.628863,-1.81973,0.009382,0.603032,-1.89395,0.255549,0.530778,-1.85826,0.212634,0.488677,-1.79056,0.078294,1.11252,-2.11584,0.057345,1.03251,-2.09471,-0.062256,1.14725,-2.101,-0.079607,1.06825,-2.08496,-0.073308,0.916852,-2.07601,-0.131253,0.735476,-2.06118,-0.228396,0.794291,-2.07787,-0.260205,0.731791,-2.06736,-0.358537,0.5161,-2.0306,-0.463998,0.497166,-1.96777,-0.239921,0.37748,-1.99748,-0.29349,0.346978,-2.06187,0.103497,1.33424,-1.8352,0.101421,1.33017,-2.05039},
/*650*/{0.158487,1.91931,-1.72344,0.264351,1.85389,-1.85044,0.002048,1.83033,-1.66922,-0.121349,1.76517,-1.64926,0.01332,1.67653,-1.65999,0.08037,1.61882,-1.65044,0.23644,1.94221,-2.09895,0.283548,1.85561,-1.92545,0.091275,1.88718,-2.04348,0.135701,1.71093,-2.22633,0.200373,1.63154,-2.25677,0.336279,1.65071,-2.11674,0.399242,1.64525,-2.10479,0.186798,1.42267,-1.82266,0.00148,1.49174,-1.89184,0.007421,1.51289,-1.95199,0.011732,1.49186,-2.00604,0.193402,1.4098,-2.08174,0.322479,1.22388,-1.75939,0.233153,1.1261,-1.78034,0.288802,1.06834,-1.80576,0.39684,1.0292,-1.79575,0.3454,0.851034,-1.78469,0.3092,0.785598,-1.79667,0.24608,0.904077,-1.79461,0.211643,0.841053,-1.80103,0.147771,0.617681,-1.82009,0.030529,0.584918,-1.8942,0.279859,0.527247,-1.85848,0.240308,0.481855,-1.79203,0.074109,1.11525,-2.11477,0.050661,1.03498,-2.09325,-0.065059,1.15362,-2.10072,-0.08556,1.07556,-2.08438,-0.084569,0.923629,-2.07616,-0.14342,0.743705,-2.06354,-0.240588,0.802333,-2.07829,-0.274333,0.740131,-2.06797,-0.365608,0.523994,-2.03181,-0.474207,0.51222,-1.96723,-0.260155,0.378048,-1.99857,-0.315391,0.348801,-2.06005,0.104183,1.33873,-1.83322,0.102405,1.33198,-2.04834},
/*651*/{0.157151,1.9224,-1.72397,0.259803,1.86069,-1.85081,-1.1e-005,1.83562,-1.67074,-0.125809,1.77082,-1.65353,0.008622,1.68124,-1.66113,0.076918,1.62385,-1.64995,0.237893,1.94576,-2.09708,0.283205,1.85991,-1.92489,0.092749,1.88888,-2.04385,0.140932,1.71579,-2.22782,0.205273,1.63558,-2.25717,0.336836,1.65642,-2.11422,0.400655,1.65203,-2.10078,0.188179,1.42654,-1.82254,0.003963,1.49649,-1.8912,0.009996,1.5173,-1.95228,0.012893,1.4953,-2.00625,0.194323,1.41122,-2.08102,0.323475,1.22811,-1.75973,0.229326,1.12827,-1.78,0.287308,1.07222,-1.8043,0.3947,1.03173,-1.79573,0.352307,0.84965,-1.78498,0.322112,0.783695,-1.79701,0.251058,0.897646,-1.795,0.220494,0.832583,-1.80047,0.167779,0.60657,-1.82039,0.051465,0.567915,-1.89464,0.304284,0.524074,-1.85936,0.267825,0.476708,-1.792,0.069035,1.11797,-2.11416,0.043015,1.04048,-2.09385,-0.06768,1.16085,-2.1005,-0.091531,1.08242,-2.08468,-0.094237,0.931561,-2.07712,-0.154386,0.750974,-2.06513,-0.2513,0.810828,-2.07861,-0.285457,0.74761,-2.06684,-0.37634,0.530677,-2.03298,-0.484311,0.52748,-1.96741,-0.278743,0.377818,-1.99966,-0.337191,0.351733,-2.0609,0.10505,1.34324,-1.83186,0.10263,1.33443,-2.0469},
/*652*/{0.156222,1.92495,-1.72433,0.259086,1.86412,-1.84986,-0.002271,1.84021,-1.67449,-0.129387,1.77586,-1.65824,0.005919,1.68576,-1.66222,0.073255,1.62792,-1.64939,0.237936,1.94831,-2.0963,0.283818,1.8627,-1.9233,0.093926,1.89169,-2.04438,0.14522,1.71878,-2.22839,0.209934,1.63995,-2.25763,0.339387,1.66155,-2.1122,0.402133,1.65897,-2.09781,0.18863,1.42981,-1.82229,0.006082,1.50054,-1.89096,0.011579,1.52059,-1.95264,0.015838,1.49806,-2.00543,0.19489,1.41208,-2.07996,0.324473,1.23129,-1.76042,0.228474,1.13154,-1.77866,0.286284,1.07471,-1.80319,0.392471,1.03367,-1.7964,0.359679,0.848489,-1.78451,0.332207,0.780854,-1.79691,0.255549,0.891362,-1.79521,0.22755,0.825568,-1.80167,0.188282,0.597005,-1.82141,0.073545,0.550621,-1.89525,0.328514,0.520578,-1.86006,0.293058,0.471423,-1.79281,0.065123,1.121,-2.11353,0.036261,1.0437,-2.09416,-0.071326,1.16657,-2.1,-0.095984,1.08971,-2.08324,-0.104186,0.939501,-2.07785,-0.164924,0.759818,-2.06703,-0.261296,0.818559,-2.07877,-0.295265,0.756668,-2.06713,-0.386176,0.53867,-2.03448,-0.492213,0.543233,-1.96666,-0.29667,0.378207,-2.00069,-0.357915,0.355622,-2.05916,0.105434,1.34694,-1.83034,0.102963,1.33625,-2.0453},
/*653*/{0.155546,1.92784,-1.72418,0.263964,1.86392,-1.84759,-0.004912,1.84457,-1.6767,-0.131758,1.78125,-1.66159,0.001567,1.69031,-1.66369,0.068502,1.63148,-1.64946,0.239199,1.95121,-2.09472,0.28357,1.86593,-1.92238,0.095676,1.89331,-2.04492,0.149736,1.72242,-2.2298,0.214434,1.64311,-2.25808,0.340427,1.66656,-2.11007,0.403832,1.66439,-2.09485,0.189364,1.43405,-1.82219,0.007835,1.50385,-1.8903,0.013525,1.52399,-1.95258,0.017899,1.50048,-2.00483,0.196112,1.4127,-2.07878,0.324372,1.23316,-1.76134,0.228325,1.13856,-1.77737,0.284023,1.07733,-1.8015,0.390898,1.03411,-1.79558,0.365728,0.846263,-1.78461,0.339226,0.775802,-1.79657,0.260338,0.884598,-1.79605,0.236421,0.816409,-1.80187,0.204059,0.586131,-1.82176,0.095435,0.533719,-1.89623,0.351565,0.518725,-1.86068,0.320266,0.467398,-1.7924,0.061521,1.12387,-2.11356,0.03089,1.04692,-2.09377,-0.074537,1.17264,-2.09953,-0.100262,1.0957,-2.0828,-0.112766,0.94635,-2.07877,-0.173572,0.767513,-2.06851,-0.270178,0.82693,-2.07873,-0.302979,0.764398,-2.06825,-0.397987,0.546468,-2.03731,-0.498609,0.559162,-1.96594,-0.315133,0.378624,-2.00208,-0.380591,0.361299,-2.05854,0.106522,1.35104,-1.8284,0.103792,1.33787,-2.04322},
/*654*/{0.154621,1.93015,-1.72436,0.260601,1.86958,-1.84826,-0.005586,1.84791,-1.67891,-0.134423,1.7863,-1.66554,-0.000955,1.69337,-1.66471,0.064983,1.63459,-1.64897,0.240506,1.95354,-2.09364,0.283941,1.8684,-1.92156,0.096669,1.89571,-2.04502,0.153796,1.72577,-2.2302,0.218734,1.64664,-2.25803,0.341937,1.67137,-2.10888,0.404714,1.67003,-2.09171,0.189679,1.43719,-1.82267,0.008446,1.50693,-1.88945,0.014899,1.52635,-1.95193,0.019438,1.50427,-2.00485,0.197035,1.41403,-2.07767,0.324419,1.23538,-1.76256,0.226588,1.14113,-1.77641,0.282204,1.07937,-1.79757,0.389679,1.03335,-1.79489,0.371858,0.843749,-1.78457,0.348493,0.772638,-1.79743,0.263531,0.875387,-1.79668,0.244317,0.80795,-1.80253,0.224119,0.574896,-1.82237,0.117283,0.517921,-1.89781,0.37451,0.516514,-1.85984,0.343522,0.462795,-1.7941,0.057428,1.12712,-2.11384,0.026356,1.051,-2.09436,-0.07704,1.17774,-2.09816,-0.103723,1.10136,-2.08182,-0.119705,0.952752,-2.07861,-0.181405,0.774923,-2.06996,-0.277929,0.834736,-2.07917,-0.311878,0.772559,-2.06952,-0.409297,0.554948,-2.0384,-0.505283,0.575051,-1.96682,-0.332436,0.3786,-2.00304,-0.401262,0.36735,-2.05735,0.106796,1.35407,-1.82756,0.104132,1.34021,-2.04233},
/*655*/{0.153917,1.93286,-1.72469,0.260503,1.87157,-1.84703,-0.007656,1.85195,-1.68096,-0.137057,1.79053,-1.66975,-0.003999,1.69782,-1.66569,0.062275,1.63786,-1.64909,0.242101,1.95601,-2.09308,0.284349,1.8711,-1.92007,0.098294,1.89731,-2.04541,0.158649,1.72848,-2.23129,0.222082,1.64933,-2.25884,0.342993,1.67542,-2.10729,0.405884,1.67409,-2.08939,0.189965,1.43969,-1.82241,0.010222,1.51043,-1.88813,0.015532,1.53005,-1.95214,0.020598,1.50714,-2.00471,0.197607,1.41487,-2.07697,0.324257,1.2364,-1.76379,0.224224,1.14026,-1.77437,0.279631,1.0793,-1.79742,0.387575,1.0316,-1.79387,0.377451,0.84101,-1.78346,0.359444,0.770025,-1.79608,0.268551,0.868639,-1.79749,0.249918,0.799972,-1.80502,0.243376,0.56527,-1.82351,0.139737,0.502391,-1.89947,0.395519,0.515193,-1.86009,0.368706,0.460693,-1.79204,0.054503,1.13022,-2.11386,0.022481,1.05422,-2.09516,-0.078619,1.18246,-2.09715,-0.10714,1.10719,-2.08117,-0.124545,0.958848,-2.07899,-0.188649,0.781003,-2.07178,-0.284398,0.842123,-2.07917,-0.318605,0.779838,-2.06999,-0.418487,0.564085,-2.0398,-0.509984,0.591128,-1.96825,-0.350167,0.379079,-2.00447,-0.421067,0.374257,-2.05606,0.106675,1.35724,-1.82646,0.103724,1.34223,-2.04115},
/*656*/{0.153622,1.93445,-1.72525,0.264353,1.87041,-1.84507,-0.009008,1.85545,-1.68356,-0.138625,1.79435,-1.6731,-0.006911,1.70043,-1.66677,0.059214,1.64096,-1.64891,0.243781,1.95823,-2.09203,0.28559,1.87227,-1.91881,0.099475,1.89945,-2.04603,0.162184,1.73148,-2.23188,0.225443,1.65208,-2.25936,0.34454,1.68014,-2.10648,0.406957,1.67737,-2.08684,0.189985,1.44186,-1.82196,0.010218,1.51434,-1.88819,0.016625,1.53319,-1.95187,0.021681,1.50971,-2.00311,0.197624,1.41708,-2.07593,0.32464,1.23672,-1.76485,0.222775,1.14212,-1.7716,0.277412,1.08027,-1.79669,0.385269,1.02949,-1.79309,0.381907,0.837486,-1.78279,0.365816,0.763645,-1.79521,0.272121,0.861049,-1.7991,0.256957,0.791019,-1.80571,0.261681,0.555771,-1.8245,0.162055,0.487819,-1.90131,0.417182,0.514177,-1.85828,0.391092,0.457257,-1.79308,0.051562,1.13399,-2.11518,0.018793,1.05782,-2.09704,-0.080365,1.18707,-2.09488,-0.110036,1.11161,-2.07983,-0.127615,0.96351,-2.07839,-0.195013,0.786287,-2.07258,-0.289379,0.849558,-2.07969,-0.324835,0.787299,-2.07046,-0.426817,0.572866,-2.04196,-0.515228,0.606782,-1.96961,-0.368616,0.377596,-2.00275,-0.442494,0.38242,-2.05419,0.106221,1.3601,-1.8256,0.103412,1.34479,-2.04027},
/*657*/{0.153591,1.93657,-1.72532,0.26106,1.87584,-1.84515,-0.009439,1.85879,-1.68528,-0.140585,1.79757,-1.6769,-0.008908,1.70377,-1.66862,0.057138,1.64253,-1.64822,0.244417,1.95966,-2.09115,0.285247,1.87513,-1.91865,0.100315,1.90105,-2.04603,0.165225,1.73367,-2.23247,0.227858,1.6544,-2.25971,0.346227,1.68169,-2.10547,0.407541,1.68048,-2.08515,0.1906,1.44501,-1.82205,0.011658,1.5174,-1.8879,0.0174,1.53565,-1.95122,0.02187,1.51345,-2.00306,0.198601,1.41881,-2.07526,0.321939,1.23703,-1.76631,0.22504,1.1455,-1.77214,0.274421,1.07949,-1.79515,0.382807,1.02708,-1.79184,0.385669,0.834503,-1.78222,0.369847,0.760483,-1.79522,0.275199,0.851476,-1.80059,0.263624,0.780976,-1.80688,0.279722,0.546897,-1.82491,0.183996,0.473961,-1.90292,0.436514,0.512195,-1.85802,0.413932,0.454788,-1.79269,0.04948,1.13691,-2.11589,0.016804,1.06032,-2.09761,-0.082061,1.19108,-2.09308,-0.111506,1.11572,-2.07889,-0.129059,0.967641,-2.07776,-0.200546,0.791697,-2.07297,-0.292947,0.855956,-2.07984,-0.329918,0.793999,-2.07108,-0.434561,0.582412,-2.04332,-0.520308,0.621748,-1.97246,-0.387346,0.376452,-2.00128,-0.460771,0.391503,-2.05261,0.106798,1.36327,-1.82491,0.103713,1.34728,-2.03953},
/*658*/{0.153974,1.93839,-1.72502,0.261848,1.87731,-1.84517,-0.011022,1.86158,-1.68806,-0.141779,1.79974,-1.68046,-0.010358,1.7058,-1.66966,0.05394,1.64426,-1.64766,0.245911,1.9614,-2.09045,0.285782,1.87662,-1.91779,0.101579,1.90286,-2.0459,0.16899,1.73612,-2.23315,0.230973,1.65507,-2.2603,0.34757,1.68398,-2.10449,0.408331,1.68258,-2.08323,0.191411,1.44784,-1.82196,0.012137,1.51944,-1.88662,0.018057,1.53859,-1.95026,0.022706,1.51562,-2.00241,0.198304,1.42104,-2.07457,0.320493,1.23454,-1.76645,0.220314,1.14428,-1.77188,0.270665,1.07845,-1.79401,0.378793,1.02413,-1.79065,0.388722,0.830765,-1.78115,0.379698,0.755328,-1.79373,0.277366,0.842953,-1.80219,0.269276,0.772337,-1.80808,0.295699,0.538584,-1.82538,0.205496,0.461653,-1.90516,0.455644,0.511333,-1.85801,0.434969,0.452996,-1.79239,0.048678,1.13987,-2.11647,0.011912,1.06264,-2.09692,-0.082848,1.19435,-2.09186,-0.112251,1.11825,-2.07776,-0.129921,0.96959,-2.07719,-0.204831,0.795098,-2.07369,-0.295523,0.862464,-2.08057,-0.334906,0.80105,-2.07311,-0.442725,0.591312,-2.04512,-0.525586,0.637287,-1.97489,-0.4085,0.378627,-1.99966,-0.479661,0.401232,-2.05036,0.107712,1.3659,-1.82405,0.10386,1.34957,-2.03863},
/*659*/{0.153896,1.93976,-1.72501,0.26579,1.87526,-1.84311,-0.010637,1.86321,-1.68921,-0.143309,1.80276,-1.68362,-0.011877,1.70802,-1.67046,0.052615,1.64677,-1.64753,0.246449,1.9623,-2.09028,0.286971,1.8777,-1.91662,0.102364,1.90517,-2.0463,0.171133,1.73752,-2.23362,0.233053,1.65673,-2.26045,0.348767,1.68557,-2.10425,0.409195,1.6835,-2.08105,0.191845,1.45057,-1.82222,0.012395,1.52199,-1.88545,0.017554,1.54099,-1.94976,0.023056,1.51854,-2.0012,0.198285,1.42261,-2.07411,0.318542,1.23255,-1.76702,0.218529,1.14327,-1.77158,0.266379,1.07722,-1.79309,0.374957,1.01987,-1.78982,0.389713,0.826712,-1.78068,0.384761,0.75133,-1.79315,0.278711,0.83419,-1.80357,0.275006,0.762989,-1.80996,0.314085,0.529272,-1.82599,0.226334,0.450495,-1.9073,0.473575,0.50899,-1.85646,0.454596,0.44957,-1.79132,0.047709,1.14218,-2.11634,0.015204,1.06538,-2.09885,-0.08277,1.19677,-2.09031,-0.113091,1.12039,-2.07624,-0.128847,0.97179,-2.07711,-0.208,0.797659,-2.0738,-0.29718,0.86707,-2.08102,-0.337578,0.808043,-2.07426,-0.451581,0.598672,-2.04698,-0.530389,0.651431,-1.97832,-0.429434,0.390111,-1.99643,-0.497942,0.411543,-2.04777,0.108108,1.36861,-1.82321,0.103453,1.35177,-2.03773},
/*660*/{0.154408,1.94094,-1.72494,0.265896,1.87562,-1.84256,-0.010796,1.86525,-1.6909,-0.144945,1.8042,-1.68733,-0.013896,1.70867,-1.67183,0.050696,1.64749,-1.6472,0.24724,1.96302,-2.08986,0.287423,1.87847,-1.91607,0.103641,1.90687,-2.04634,0.173993,1.73847,-2.23372,0.23481,1.65693,-2.26044,0.349215,1.68782,-2.10363,0.409524,1.68399,-2.07976,0.191872,1.45233,-1.82181,0.013105,1.52341,-1.8854,0.017677,1.5429,-1.94943,0.023494,1.51971,-1.99944,0.198364,1.42499,-2.07362,0.315819,1.22868,-1.76708,0.215599,1.14148,-1.76995,0.260457,1.07437,-1.79272,0.370746,1.01514,-1.78938,0.3911,0.823228,-1.77922,0.390395,0.747514,-1.79272,0.280032,0.825049,-1.80521,0.279817,0.754289,-1.81211,0.32921,0.522527,-1.82621,0.246634,0.440612,-1.9089,0.491297,0.510078,-1.85611,0.473996,0.448115,-1.79149,0.048265,1.14389,-2.11675,0.016281,1.06716,-2.09967,-0.081724,1.19794,-2.08871,-0.111665,1.12213,-2.07453,-0.128039,0.972435,-2.07674,-0.210815,0.79902,-2.07309,-0.298072,0.871311,-2.08196,-0.341162,0.813093,-2.075,-0.460415,0.608007,-2.04823,-0.537343,0.665632,-1.98175,-0.44684,0.399872,-1.99239,-0.512741,0.421548,-2.04459,0.108683,1.37022,-1.82276,0.103931,1.35363,-2.0373},
/*661*/{0.154779,1.94167,-1.72461,0.262576,1.88095,-1.84317,-0.01154,1.86729,-1.693,-0.145122,1.8063,-1.69012,-0.014397,1.70984,-1.67255,0.049113,1.64812,-1.64749,0.248906,1.96413,-2.08943,0.286883,1.88014,-1.91589,0.104521,1.90889,-2.04621,0.175511,1.73938,-2.23377,0.236399,1.65711,-2.26051,0.351035,1.68809,-2.10237,0.40986,1.68411,-2.07809,0.191673,1.45332,-1.82171,0.013487,1.52531,-1.88375,0.018349,1.54513,-1.94808,0.023411,1.52217,-1.99933,0.198909,1.42749,-2.07305,0.313198,1.22467,-1.76716,0.212052,1.13931,-1.76914,0.255916,1.07167,-1.7923,0.366046,1.00998,-1.7891,0.390758,0.819534,-1.7793,0.394869,0.744252,-1.79214,0.280687,0.81622,-1.80614,0.283388,0.74504,-1.81304,0.344503,0.516142,-1.8274,0.265613,0.431624,-1.91109,0.507075,0.509698,-1.85537,0.4913,0.446626,-1.79101,0.049646,1.14512,-2.11696,0.017522,1.0678,-2.10011,-0.081379,1.19911,-2.08811,-0.110879,1.12226,-2.07304,-0.125839,0.972461,-2.07615,-0.213513,0.800562,-2.07264,-0.298218,0.875333,-2.08297,-0.343141,0.818002,-2.07575,-0.467614,0.619334,-2.05021,-0.544501,0.680119,-1.98512,-0.464683,0.410699,-1.98868,-0.531596,0.435211,-2.04335,0.108531,1.37136,-1.82282,0.103905,1.35623,-2.03747},
/*662*/{0.156259,1.94296,-1.72389,0.264223,1.88153,-1.84301,-0.010908,1.86787,-1.69347,-0.14503,1.807,-1.69251,-0.015358,1.71105,-1.67385,0.048692,1.64734,-1.6469,0.249642,1.96435,-2.08914,0.287512,1.8812,-1.91547,0.104861,1.90975,-2.04632,0.177176,1.7396,-2.23278,0.237317,1.65686,-2.26005,0.351414,1.68644,-2.10122,0.410858,1.68294,-2.07729,0.191684,1.45528,-1.82176,0.01373,1.52619,-1.88322,0.018198,1.54676,-1.94719,0.023318,1.52353,-1.99717,0.198925,1.42897,-2.07245,0.311441,1.21937,-1.76664,0.207922,1.1362,-1.76891,0.250821,1.06781,-1.7927,0.359479,1.00423,-1.7882,0.39154,0.815668,-1.77865,0.39753,0.740352,-1.79218,0.281189,0.807875,-1.80507,0.288682,0.735241,-1.81312,0.360425,0.511085,-1.82707,0.283472,0.42377,-1.91381,0.521143,0.509657,-1.85505,0.506862,0.445386,-1.79119,0.051721,1.14574,-2.11665,0.02025,1.06843,-2.10012,-0.079546,1.19821,-2.08696,-0.107718,1.12237,-2.07336,-0.122802,0.971601,-2.07593,-0.215155,0.800557,-2.07159,-0.296954,0.878773,-2.08381,-0.344394,0.823265,-2.07709,-0.477376,0.629049,-2.05078,-0.551832,0.694355,-1.98856,-0.4816,0.422146,-1.98509,-0.543746,0.447625,-2.04112,0.109169,1.37291,-1.822,0.103939,1.35769,-2.03664},
/*663*/{0.156544,1.94323,-1.72346,0.263791,1.88162,-1.8423,-0.009956,1.86857,-1.69449,-0.144852,1.80758,-1.69475,-0.015988,1.71091,-1.67464,0.047637,1.64711,-1.64689,0.250707,1.96414,-2.08849,0.287949,1.88179,-1.91553,0.105855,1.91128,-2.04591,0.178183,1.73973,-2.23188,0.237755,1.65656,-2.25964,0.35187,1.68508,-2.10031,0.410966,1.68101,-2.07628,0.192032,1.45576,-1.82216,0.013177,1.52722,-1.88227,0.018046,1.54777,-1.94632,0.023567,1.52389,-1.99567,0.198933,1.43066,-2.07253,0.307625,1.21434,-1.76637,0.202746,1.13282,-1.76845,0.243106,1.06366,-1.79337,0.35336,0.998427,-1.78822,0.391768,0.811967,-1.77918,0.401364,0.737334,-1.79202,0.281938,0.798759,-1.80446,0.291797,0.72782,-1.81294,0.370728,0.505866,-1.82941,0.299361,0.4169,-1.91461,0.534463,0.509811,-1.85434,0.523331,0.445494,-1.79131,0.053916,1.14615,-2.11634,0.022697,1.06835,-2.09965,-0.077883,1.19733,-2.08633,-0.105821,1.12028,-2.07193,-0.119101,0.970276,-2.07559,-0.216814,0.800985,-2.07016,-0.295258,0.882212,-2.08522,-0.343369,0.829564,-2.07801,-0.485499,0.639063,-2.0514,-0.558741,0.707885,-1.99342,-0.496455,0.433992,-1.98221,-0.559097,0.460714,-2.04045,0.109764,1.37338,-1.82199,0.103949,1.35901,-2.03666},
/*664*/{0.157688,1.94332,-1.72263,0.264363,1.88155,-1.84189,-0.009273,1.86806,-1.69549,-0.14398,1.80734,-1.69724,-0.015962,1.70955,-1.67507,0.046769,1.64593,-1.64637,0.250713,1.96356,-2.08835,0.287991,1.88205,-1.91463,0.105715,1.91223,-2.0461,0.177198,1.73945,-2.23115,0.236693,1.65502,-2.25849,0.352371,1.68337,-2.10007,0.412894,1.67823,-2.07609,0.191704,1.45593,-1.82213,0.012981,1.52669,-1.88124,0.017972,1.54792,-1.94567,0.022795,1.52544,-1.99502,0.199016,1.4324,-2.07234,0.304929,1.2091,-1.76493,0.192062,1.12747,-1.77042,0.236461,1.05859,-1.79259,0.345992,0.992763,-1.7876,0.39242,0.808451,-1.77905,0.405226,0.734593,-1.79313,0.282833,0.79163,-1.80351,0.295082,0.721032,-1.81303,0.381775,0.501394,-1.82889,0.314463,0.410892,-1.91574,0.546202,0.51101,-1.85324,0.535776,0.444497,-1.79148,0.056053,1.14564,-2.11586,0.026213,1.06748,-2.09952,-0.075373,1.19529,-2.08534,-0.101937,1.11847,-2.07163,-0.114988,0.967969,-2.07464,-0.218705,0.801873,-2.06935,-0.294301,0.884461,-2.08547,-0.344007,0.834108,-2.07876,-0.491485,0.651058,-2.05265,-0.566428,0.721923,-1.9975,-0.510061,0.447392,-1.97907,-0.571087,0.473779,-2.03896,0.109802,1.37308,-1.82246,0.104086,1.36041,-2.03725},
/*665*/{0.159062,1.94361,-1.72198,0.267619,1.87814,-1.84056,-0.00871,1.86762,-1.69568,-0.143237,1.80588,-1.69826,-0.015405,1.70776,-1.67541,0.046094,1.64333,-1.64504,0.251037,1.96264,-2.08813,0.288752,1.88135,-1.91388,0.106811,1.91312,-2.04598,0.176644,1.73851,-2.22939,0.235914,1.65388,-2.25772,0.352312,1.68042,-2.09888,0.412517,1.67496,-2.07482,0.192382,1.45679,-1.82244,0.01251,1.52647,-1.88008,0.017,1.54758,-1.94411,0.022504,1.52573,-1.99423,0.19887,1.43342,-2.07226,0.299555,1.2029,-1.7649,0.188599,1.12649,-1.76999,0.230564,1.05451,-1.79238,0.338177,0.986961,-1.78783,0.393653,0.805607,-1.77965,0.4084,0.731822,-1.79303,0.283897,0.784457,-1.80299,0.298301,0.714303,-1.8114,0.391078,0.496738,-1.82937,0.326523,0.405428,-1.91701,0.556314,0.512299,-1.85317,0.547521,0.446158,-1.79292,0.059717,1.145,-2.11475,0.030747,1.06565,-2.09811,-0.073083,1.19283,-2.08441,-0.098975,1.11526,-2.0707,-0.111283,0.96531,-2.07409,-0.219021,0.802276,-2.06814,-0.293633,0.886159,-2.0844,-0.342593,0.839992,-2.07959,-0.50062,0.661284,-2.05192,-0.573224,0.736195,-2.00007,-0.523489,0.460529,-1.97574,-0.582524,0.487735,-2.03792,0.110965,1.37331,-1.82215,0.104339,1.36102,-2.03694},
/*666*/{0.15981,1.94328,-1.72121,0.264366,1.88144,-1.8417,-0.008659,1.86667,-1.6963,-0.141993,1.80462,-1.70057,-0.014528,1.70569,-1.67588,0.046241,1.64123,-1.6449,0.252186,1.96199,-2.08756,0.288258,1.88179,-1.9139,0.106999,1.91315,-2.04586,0.174855,1.73773,-2.22886,0.23362,1.65198,-2.25644,0.352173,1.67703,-2.09827,0.412068,1.67035,-2.07502,0.19172,1.45666,-1.82258,0.011959,1.52577,-1.8793,0.017101,1.54802,-1.94365,0.021959,1.52479,-1.9926,0.199326,1.43456,-2.07209,0.296098,1.19765,-1.76495,0.1819,1.12111,-1.77029,0.22298,1.05052,-1.79452,0.330397,0.981118,-1.78743,0.39381,0.801906,-1.7801,0.410325,0.728558,-1.79469,0.285108,0.778141,-1.80136,0.301396,0.708522,-1.81032,0.402625,0.494251,-1.83064,0.337092,0.399685,-1.91665,0.563408,0.512276,-1.85379,0.556936,0.446587,-1.79549,0.0632,1.14378,-2.11328,0.03508,1.0641,-2.09767,-0.069476,1.19036,-2.08392,-0.094469,1.11186,-2.06978,-0.10593,0.962095,-2.07246,-0.219927,0.80256,-2.06678,-0.288148,0.891782,-2.08769,-0.342397,0.845927,-2.07994,-0.506679,0.674095,-2.05218,-0.578385,0.751111,-2.00269,-0.536274,0.473874,-1.97396,-0.592652,0.501695,-2.03744,0.111236,1.3728,-1.82217,0.104713,1.36151,-2.03701},
/*667*/{0.16086,1.94229,-1.72094,0.264978,1.88138,-1.84235,-0.007305,1.86464,-1.69558,-0.140389,1.80246,-1.70142,-0.013285,1.7035,-1.67534,0.047003,1.63817,-1.64396,0.252763,1.96042,-2.08699,0.287309,1.88098,-1.91366,0.107029,1.91315,-2.04582,0.172126,1.73651,-2.22729,0.231525,1.6502,-2.25505,0.351841,1.67368,-2.09805,0.412124,1.66606,-2.07463,0.194276,1.45668,-1.82246,0.011611,1.52484,-1.87859,0.016141,1.54708,-1.94343,0.021573,1.52441,-1.99211,0.199221,1.43491,-2.07213,0.291233,1.18977,-1.76329,0.174273,1.11544,-1.77041,0.215934,1.04534,-1.79422,0.322784,0.974863,-1.78719,0.394451,0.799028,-1.78058,0.411668,0.727243,-1.79555,0.285972,0.772221,-1.80062,0.303307,0.702441,-1.80849,0.408899,0.491032,-1.83043,0.345926,0.395814,-1.91744,0.569688,0.512774,-1.85434,0.565666,0.447271,-1.79526,0.06786,1.1421,-2.11242,0.040944,1.06181,-2.09662,-0.066774,1.18561,-2.08324,-0.089717,1.10726,-2.06944,-0.100062,0.959106,-2.07144,-0.219961,0.804126,-2.06541,-0.284915,0.89481,-2.08775,-0.340093,0.851874,-2.08015,-0.509305,0.687299,-2.05286,-0.582003,0.766658,-2.00453,-0.548349,0.488742,-1.97278,-0.602658,0.517347,-2.03792,0.113136,1.37264,-1.82198,0.105416,1.36125,-2.03678},
/*668*/{0.162143,1.94126,-1.72052,0.26856,1.87643,-1.84033,-0.006407,1.86253,-1.69528,-0.1382,1.79967,-1.70173,-0.012786,1.69997,-1.67485,0.047716,1.63491,-1.64269,0.251885,1.95848,-2.08633,0.288693,1.87949,-1.91304,0.107091,1.91287,-2.04522,0.17015,1.73485,-2.22527,0.229916,1.64866,-2.25369,0.351885,1.66933,-2.09791,0.411184,1.6606,-2.07403,0.194587,1.45656,-1.82228,0.011231,1.52259,-1.87816,0.015518,1.54574,-1.94289,0.020442,1.52285,-1.99109,0.199616,1.43525,-2.07222,0.288055,1.18372,-1.76208,0.16854,1.11184,-1.77166,0.208789,1.0412,-1.7954,0.315381,0.969442,-1.78704,0.393572,0.795621,-1.78154,0.412013,0.722847,-1.79559,0.286164,0.76675,-1.79977,0.305013,0.698668,-1.80813,0.412035,0.487844,-1.83048,0.351531,0.392123,-1.91698,0.575363,0.512521,-1.8559,0.570988,0.44546,-1.79616,0.072163,1.13942,-2.1104,0.04644,1.05957,-2.09506,-0.063334,1.18192,-2.08306,-0.085758,1.10219,-2.06731,-0.093999,0.955357,-2.07049,-0.219438,0.805379,-2.06504,-0.280589,0.898716,-2.08759,-0.337997,0.857989,-2.07965,-0.511074,0.700213,-2.052,-0.584886,0.782613,-2.00627,-0.557966,0.503274,-1.97164,-0.609999,0.53384,-2.03839,0.114372,1.37164,-1.8219,0.10635,1.36066,-2.03671},
/*669*/{0.162577,1.93994,-1.71984,0.268707,1.87593,-1.84058,-0.006321,1.86019,-1.69532,-0.1353,1.7957,-1.70091,-0.011538,1.69541,-1.67327,0.048865,1.6308,-1.64098,0.252164,1.9567,-2.08617,0.288018,1.87807,-1.9131,0.10683,1.91114,-2.0441,0.166508,1.73365,-2.22431,0.227256,1.64663,-2.25219,0.351534,1.66427,-2.09802,0.411007,1.65432,-2.07441,0.191554,1.45486,-1.82271,0.010657,1.5203,-1.87798,0.014364,1.54407,-1.94216,0.020608,1.52119,-1.99122,0.19926,1.4349,-2.07212,0.282925,1.17669,-1.76079,0.166155,1.11015,-1.7712,0.202573,1.03648,-1.79562,0.308968,0.963564,-1.78705,0.392289,0.793294,-1.78194,0.412355,0.721104,-1.79644,0.284315,0.761749,-1.79934,0.304695,0.694075,-1.80746,0.41566,0.485273,-1.83097,0.356197,0.389723,-1.9174,0.578432,0.511282,-1.85696,0.576477,0.444141,-1.79711,0.076951,1.13672,-2.10901,0.0523,1.05695,-2.09319,-0.059962,1.17643,-2.0824,-0.080027,1.09778,-2.06778,-0.087318,0.951022,-2.06914,-0.219081,0.806745,-2.06451,-0.275342,0.903117,-2.08703,-0.334529,0.865087,-2.07947,-0.514852,0.714436,-2.05226,-0.585123,0.798649,-2.00584,-0.567621,0.518662,-1.9726,-0.620518,0.550991,-2.03917,0.112906,1.36924,-1.82262,0.106075,1.35988,-2.03754},
/*670*/{0.163561,1.93799,-1.71834,0.263521,1.87782,-1.8419,-0.005745,1.85662,-1.69423,-0.134033,1.79208,-1.70144,-0.009789,1.69177,-1.67289,0.049796,1.62643,-1.6396,0.252602,1.95456,-2.0864,0.286827,1.87781,-1.91366,0.106201,1.91028,-2.04304,0.162323,1.73186,-2.22241,0.223109,1.64432,-2.25065,0.350158,1.65928,-2.09836,0.409814,1.64808,-2.07511,0.191366,1.45342,-1.82269,0.010249,1.51768,-1.87744,0.014463,1.54167,-1.94179,0.019283,1.51973,-1.9907,0.198699,1.43379,-2.07164,0.279677,1.1709,-1.75979,0.158996,1.10529,-1.77163,0.19583,1.03245,-1.79562,0.30369,0.957793,-1.78664,0.389785,0.790502,-1.78227,0.410523,0.718405,-1.79642,0.282548,0.757749,-1.79967,0.30344,0.689992,-1.80838,0.417507,0.482288,-1.83053,0.35818,0.386203,-1.91656,0.580492,0.509675,-1.85796,0.578882,0.441876,-1.7984,0.081169,1.13405,-2.10789,0.058535,1.05323,-2.0914,-0.055299,1.17182,-2.08217,-0.074702,1.09215,-2.06691,-0.079433,0.946527,-2.06783,-0.216793,0.805982,-2.06319,-0.269807,0.906945,-2.08602,-0.330059,0.871035,-2.07776,-0.514078,0.725386,-2.05122,-0.584767,0.815629,-2.00574,-0.576365,0.534571,-1.97364,-0.626503,0.568618,-2.0402,0.113121,1.36731,-1.82252,0.105978,1.35834,-2.03745},
/*671*/{0.164148,1.9359,-1.71836,0.264161,1.87599,-1.84203,-0.004529,1.85216,-1.6929,-0.132369,1.78664,-1.69939,-0.00821,1.68757,-1.67082,0.051327,1.62224,-1.63831,0.251188,1.95209,-2.0859,0.286805,1.87583,-1.91375,0.105394,1.90938,-2.04226,0.158581,1.72923,-2.22056,0.219772,1.64177,-2.2489,0.34914,1.65284,-2.09796,0.408417,1.64079,-2.07566,0.190975,1.45138,-1.82288,0.009362,1.51525,-1.8766,0.013281,1.53864,-1.94147,0.019073,1.51656,-1.99065,0.199584,1.43263,-2.07147,0.274484,1.1658,-1.7591,0.15437,1.10287,-1.77208,0.190012,1.02926,-1.79749,0.298017,0.952453,-1.7875,0.386528,0.787264,-1.78307,0.407353,0.716385,-1.79745,0.279996,0.753649,-1.80002,0.301251,0.685223,-1.80861,0.418082,0.479567,-1.83069,0.358882,0.38244,-1.91639,0.57995,0.507682,-1.85974,0.579735,0.439429,-1.80014,0.086469,1.13057,-2.10648,0.064896,1.04997,-2.0907,-0.051251,1.16582,-2.08154,-0.06894,1.08568,-2.06609,-0.071398,0.941981,-2.06658,-0.21505,0.810253,-2.06378,-0.263876,0.910678,-2.08534,-0.325051,0.877707,-2.07696,-0.520824,0.74527,-2.05481,-0.582801,0.831664,-2.00429,-0.584899,0.551033,-1.9769,-0.634419,0.587782,-2.04215,0.113551,1.36482,-1.82259,0.10688,1.3564,-2.03756},
/*672*/{0.165084,1.9334,-1.71762,0.263988,1.8743,-1.84226,-0.003202,1.84849,-1.6912,-0.13012,1.78163,-1.69856,-0.007025,1.68169,-1.66899,0.052767,1.6171,-1.6364,0.250714,1.94952,-2.08584,0.286275,1.87338,-1.91342,0.104944,1.90694,-2.0413,0.154718,1.7266,-2.21855,0.2158,1.63893,-2.24722,0.347928,1.64738,-2.09869,0.406271,1.63278,-2.07634,0.19092,1.44885,-1.82247,0.009119,1.51223,-1.87619,0.012783,1.53627,-1.94169,0.018224,1.51347,-1.99044,0.199416,1.43083,-2.07108,0.272084,1.15947,-1.7566,0.149328,1.09919,-1.77283,0.18496,1.02529,-1.79814,0.294276,0.948166,-1.78712,0.383534,0.783933,-1.78308,0.405302,0.711951,-1.79695,0.276697,0.74923,-1.80059,0.298364,0.680896,-1.80915,0.418103,0.474506,-1.8305,0.357848,0.378381,-1.91621,0.579259,0.504491,-1.86078,0.580289,0.436166,-1.80181,0.091368,1.1267,-2.10537,0.071951,1.04601,-2.08896,-0.046746,1.15931,-2.08083,-0.063111,1.07972,-2.06447,-0.064002,0.936468,-2.06559,-0.212194,0.81165,-2.06386,-0.255992,0.915043,-2.08411,-0.320294,0.884133,-2.07622,-0.520819,0.758774,-2.05481,-0.5792,0.848555,-2.00304,-0.590286,0.568597,-1.97937,-0.64086,0.607465,-2.04384,0.11362,1.36222,-1.82249,0.107044,1.35403,-2.03747},
/*673*/{0.165112,1.93042,-1.71723,0.263505,1.87187,-1.84221,-0.002714,1.84394,-1.6898,-0.128742,1.77572,-1.69646,-0.0041,1.67682,-1.66747,0.055239,1.61192,-1.63513,0.250141,1.94638,-2.08604,0.286187,1.87094,-1.91281,0.104385,1.90513,-2.0409,0.150656,1.72407,-2.21726,0.211125,1.63578,-2.24605,0.345173,1.64079,-2.09857,0.404824,1.62462,-2.07755,0.190505,1.44624,-1.82149,0.008176,1.50983,-1.87586,0.012179,1.53301,-1.94118,0.018396,1.50973,-1.99036,0.199736,1.42951,-2.07059,0.26809,1.15525,-1.75415,0.146007,1.09598,-1.77319,0.181549,1.02182,-1.79874,0.292904,0.945573,-1.78681,0.379203,0.779613,-1.783,0.401535,0.708383,-1.79768,0.27202,0.745319,-1.80127,0.294718,0.677448,-1.80967,0.415572,0.470029,-1.83083,0.354807,0.37413,-1.91717,0.577877,0.50165,-1.86259,0.577926,0.43327,-1.80428,0.097087,1.123,-2.1048,0.078841,1.04055,-2.08755,-0.041955,1.15326,-2.08022,-0.057114,1.07298,-2.06423,-0.056269,0.931289,-2.06494,-0.208639,0.813815,-2.06401,-0.248207,0.918581,-2.08229,-0.312767,0.890132,-2.07456,-0.520433,0.775422,-2.05554,-0.573744,0.86525,-2.00045,-0.597872,0.583414,-1.98498,-0.646104,0.627503,-2.04552,0.113683,1.35945,-1.82221,0.107919,1.35173,-2.03723},
/*674*/{0.164781,1.92672,-1.71688,0.263537,1.86854,-1.84238,-0.001936,1.83891,-1.68821,-0.126549,1.76913,-1.69371,-0.002995,1.67123,-1.66512,0.057849,1.60639,-1.63284,0.248973,1.94288,-2.08643,0.285899,1.86818,-1.91283,0.103277,1.90216,-2.03935,0.145856,1.72177,-2.21555,0.207012,1.63236,-2.24441,0.342693,1.63419,-2.0993,0.40212,1.61597,-2.07907,0.188832,1.44354,-1.8215,0.008226,1.50584,-1.87531,0.011963,1.52934,-1.94078,0.017835,1.50651,-1.99064,0.200198,1.42694,-2.06953,0.265182,1.15162,-1.75161,0.144062,1.0906,-1.77301,0.17926,1.0192,-1.79979,0.29218,0.944415,-1.78663,0.374554,0.775504,-1.78375,0.397658,0.703483,-1.79722,0.268197,0.740449,-1.80125,0.291202,0.67295,-1.80983,0.409206,0.466793,-1.83282,0.350079,0.370088,-1.91735,0.571895,0.496688,-1.86503,0.575522,0.428821,-1.80566,0.101463,1.11837,-2.1044,0.084998,1.03673,-2.08633,-0.037794,1.14621,-2.07855,-0.051312,1.06667,-2.0635,-0.048072,0.925681,-2.06402,-0.20429,0.815453,-2.06396,-0.239753,0.92246,-2.08071,-0.306134,0.894618,-2.07249,-0.517563,0.790642,-2.05593,-0.566771,0.881339,-1.99842,-0.600688,0.60128,-1.98658,-0.646546,0.648109,-2.04729,0.113244,1.35606,-1.82203,0.108429,1.34879,-2.03709},
/*675*/{0.165389,1.92316,-1.71597,0.263456,1.86557,-1.84255,-0.001158,1.83261,-1.68514,-0.125729,1.76205,-1.69155,-0.000424,1.66497,-1.66293,0.060498,1.60047,-1.63131,0.24801,1.93972,-2.08643,0.285235,1.86528,-1.91237,0.101864,1.89913,-2.03842,0.141443,1.71829,-2.21356,0.201546,1.62877,-2.24276,0.340216,1.62648,-2.10006,0.399648,1.60699,-2.08063,0.187281,1.43997,-1.82085,0.006977,1.50213,-1.87554,0.011574,1.52646,-1.94079,0.017353,1.50266,-1.99071,0.200202,1.42522,-2.06896,0.262212,1.14792,-1.75015,0.141332,1.08917,-1.77354,0.176173,1.0153,-1.8003,0.291732,0.942839,-1.78644,0.370635,0.770325,-1.78402,0.392092,0.698572,-1.79741,0.263809,0.736159,-1.80199,0.285881,0.667737,-1.81082,0.407074,0.463371,-1.83365,0.343735,0.365431,-1.91764,0.56672,0.491055,-1.8662,0.567052,0.422889,-1.80724,0.10689,1.11422,-2.10336,0.092096,1.03248,-2.08573,-0.033177,1.13939,-2.07799,-0.045394,1.05937,-2.06144,-0.040129,0.92025,-2.06337,-0.199155,0.816375,-2.06408,-0.230946,0.925218,-2.07927,-0.297111,0.901511,-2.07213,-0.514937,0.806445,-2.05508,-0.559651,0.896677,-1.99632,-0.604223,0.617566,-1.99096,-0.645135,0.667518,-2.05064,0.112179,1.35233,-1.8224,0.108737,1.34628,-2.03752},
/*676*/{0.165792,1.91899,-1.71537,0.261774,1.86176,-1.84304,0.000138,1.82717,-1.68402,-0.12456,1.75465,-1.68736,0.001816,1.65836,-1.66012,0.063978,1.5944,-1.62935,0.247041,1.93531,-2.08768,0.284786,1.86169,-1.91308,0.101347,1.89579,-2.03791,0.136692,1.71512,-2.21197,0.196339,1.62492,-2.24192,0.33718,1.61897,-2.10058,0.397271,1.5982,-2.08321,0.186594,1.43667,-1.81999,0.006796,1.49812,-1.87495,0.011041,1.52265,-1.94079,0.016698,1.49843,-1.99091,0.200041,1.42236,-2.06828,0.258958,1.14534,-1.74922,0.138173,1.08536,-1.77388,0.174605,1.01278,-1.79974,0.290606,0.940267,-1.78722,0.366273,0.765128,-1.7842,0.388152,0.693022,-1.79803,0.259223,0.731646,-1.80221,0.281207,0.663768,-1.81108,0.397301,0.455827,-1.83333,0.335969,0.360888,-1.9185,0.559236,0.483422,-1.86767,0.5607,0.414708,-1.80832,0.111524,1.10975,-2.10307,0.098522,1.02797,-2.08487,-0.028009,1.13246,-2.07679,-0.039189,1.05192,-2.0613,-0.032218,0.914248,-2.06286,-0.19352,0.817411,-2.06416,-0.221331,0.927751,-2.07781,-0.289194,0.904362,-2.07188,-0.508791,0.819502,-2.05506,-0.549397,0.910738,-1.99281,-0.606129,0.633841,-1.99565,-0.65077,0.686577,-2.05278,0.112021,1.34877,-1.82199,0.109092,1.34278,-2.03712},
/*677*/{0.166209,1.9141,-1.71463,0.262761,1.85873,-1.8432,0.000655,1.82067,-1.68169,-0.122679,1.74744,-1.68356,0.005235,1.65112,-1.6573,0.067659,1.58802,-1.62763,0.24491,1.93108,-2.08788,0.28435,1.85833,-1.91341,0.100213,1.89173,-2.03747,0.131596,1.71123,-2.2111,0.191676,1.6212,-2.24068,0.333453,1.61081,-2.10163,0.393965,1.58798,-2.08582,0.186277,1.43351,-1.81886,0.005315,1.49409,-1.87529,0.010218,1.51854,-1.94041,0.016212,1.49354,-1.99142,0.20019,1.41944,-2.06692,0.258384,1.14163,-1.747,0.136437,1.08119,-1.77428,0.172593,1.01008,-1.79964,0.288886,0.937128,-1.78747,0.361724,0.759404,-1.78438,0.382754,0.687329,-1.79904,0.253805,0.726802,-1.80256,0.275119,0.658924,-1.81129,0.390033,0.45174,-1.83484,0.326929,0.35618,-1.91943,0.551632,0.476918,-1.86907,0.552854,0.408163,-1.80963,0.116767,1.10613,-2.10241,0.104455,1.02342,-2.08426,-0.024596,1.12552,-2.07667,-0.032894,1.04451,-2.05993,-0.023835,0.908191,-2.0623,-0.187412,0.818319,-2.06509,-0.211443,0.92923,-2.0757,-0.279767,0.909789,-2.07094,-0.500643,0.83213,-2.05644,-0.538452,0.924274,-1.99248,-0.605844,0.65006,-1.99893,-0.648457,0.706328,-2.05741,0.111818,1.34534,-1.82125,0.109993,1.339,-2.03639},
/*678*/{0.165848,1.90881,-1.71411,0.261179,1.85439,-1.843,0.002147,1.81406,-1.67929,-0.120492,1.73914,-1.67932,0.006712,1.64446,-1.65472,0.07196,1.58194,-1.6257,0.24436,1.92648,-2.08864,0.283662,1.85415,-1.9132,0.098778,1.88725,-2.03643,0.126941,1.70741,-2.20944,0.186264,1.61645,-2.23944,0.330948,1.60302,-2.10305,0.390555,1.57779,-2.08764,0.185262,1.43082,-1.81769,0.004657,1.48944,-1.87552,0.009655,1.51428,-1.94023,0.015201,1.48878,-1.99122,0.200301,1.41658,-2.06629,0.256182,1.13807,-1.7465,0.135035,1.0812,-1.77547,0.17049,1.00662,-1.80088,0.286473,0.931839,-1.78714,0.356004,0.753447,-1.78472,0.376279,0.681209,-1.7997,0.247999,0.722975,-1.8025,0.26895,0.654484,-1.81203,0.379878,0.44423,-1.83551,0.316562,0.350644,-1.92189,0.54254,0.46803,-1.86966,0.541397,0.398582,-1.81041,0.121031,1.1017,-2.10207,0.111716,1.019,-2.08396,-0.019306,1.11846,-2.07549,-0.026987,1.03722,-2.05937,-0.01506,0.902242,-2.06223,-0.181097,0.818723,-2.06533,-0.200334,0.929324,-2.07318,-0.269032,0.911979,-2.0684,-0.492109,0.843774,-2.05563,-0.527153,0.936954,-1.98999,-0.605225,0.665031,-2.00252,-0.645086,0.724945,-2.05876,0.111887,1.34192,-1.82058,0.110857,1.33524,-2.03571},
/*679*/{0.166061,1.90335,-1.71351,0.266331,1.84694,-1.84185,0.002843,1.80672,-1.67699,-0.118706,1.7301,-1.67437,0.010201,1.63647,-1.65103,0.075666,1.57497,-1.62391,0.24193,1.92178,-2.08932,0.283453,1.84983,-1.91315,0.097706,1.88356,-2.03488,0.122281,1.70348,-2.20869,0.180827,1.61173,-2.23863,0.326438,1.59291,-2.10408,0.386219,1.56662,-2.09006,0.184003,1.42751,-1.81685,0.003246,1.48542,-1.87628,0.008814,1.51088,-1.94038,0.014787,1.484,-1.99211,0.199854,1.41309,-2.06533,0.255397,1.13451,-1.74518,0.133249,1.07808,-1.77683,0.167316,1.00343,-1.80108,0.282882,0.926647,-1.78715,0.350319,0.746995,-1.78532,0.369903,0.673937,-1.80024,0.242322,0.718412,-1.80353,0.261291,0.649186,-1.81211,0.369354,0.438674,-1.83709,0.304561,0.345919,-1.92362,0.532611,0.459165,-1.86883,0.529831,0.38972,-1.81029,0.126448,1.09747,-2.10224,0.118537,1.01382,-2.08355,-0.013971,1.1108,-2.07484,-0.02019,1.02995,-2.05912,-0.006694,0.896132,-2.06173,-0.174799,0.817952,-2.06414,-0.189597,0.930315,-2.07259,-0.258797,0.915949,-2.06804,-0.479545,0.852756,-2.05413,-0.515157,0.948168,-1.98833,-0.601074,0.680366,-2.00612,-0.639926,0.740923,-2.06104,0.110742,1.33848,-1.82013,0.110953,1.33132,-2.03524},
/*680*/{0.16608,1.89745,-1.71221,0.265953,1.84234,-1.842,0.004864,1.79849,-1.67382,-0.115881,1.72161,-1.67007,0.013827,1.62862,-1.64855,0.07996,1.56786,-1.62251,0.241031,1.91653,-2.09018,0.28247,1.84504,-1.91387,0.096357,1.87887,-2.03438,0.117369,1.69854,-2.20778,0.174858,1.60737,-2.23775,0.321685,1.58319,-2.10591,0.381865,1.55582,-2.09291,0.182897,1.4242,-1.81535,0.003301,1.4822,-1.87633,0.008316,1.50596,-1.94023,0.013094,1.47936,-1.99254,0.200045,1.40943,-2.06443,0.25259,1.12926,-1.74481,0.131476,1.07552,-1.77787,0.165675,0.999469,-1.80154,0.278922,0.920248,-1.78687,0.344033,0.739518,-1.7858,0.361269,0.667287,-1.80084,0.235306,0.713426,-1.80303,0.253013,0.644221,-1.81313,0.357112,0.432437,-1.83707,0.287132,0.35149,-1.92512,0.519711,0.44873,-1.86974,0.515847,0.379673,-1.80956,0.131967,1.09297,-2.10185,0.125971,1.00998,-2.08384,-0.010084,1.10392,-2.07476,-0.013416,1.02261,-2.05821,0.002318,0.89015,-2.06187,-0.16717,0.817669,-2.06397,-0.178302,0.93108,-2.07108,-0.247808,0.918363,-2.06734,-0.473963,0.865324,-2.05569,-0.501472,0.959359,-1.98725,-0.598313,0.693156,-2.00937,-0.632068,0.756727,-2.06466,0.110202,1.33512,-1.8191,0.111212,1.32709,-2.03419},
/*681*/{0.166664,1.89115,-1.71121,0.266588,1.83622,-1.84145,0.005972,1.79045,-1.67094,-0.114262,1.71265,-1.66575,0.017664,1.62058,-1.64541,0.085246,1.56095,-1.62046,0.238525,1.91108,-2.09089,0.282886,1.84063,-1.91379,0.094828,1.87417,-2.03391,0.113436,1.69391,-2.20743,0.168958,1.60238,-2.23688,0.317317,1.57357,-2.10766,0.376869,1.54385,-2.09588,0.182749,1.42061,-1.8136,0.000373,1.47508,-1.87679,0.007625,1.50047,-1.94006,0.012969,1.47377,-1.99197,0.199943,1.40578,-2.06361,0.251267,1.12505,-1.74477,0.128693,1.07002,-1.77856,0.163505,0.996285,-1.80062,0.275289,0.914826,-1.78647,0.337534,0.732968,-1.78528,0.353259,0.661441,-1.80205,0.228043,0.709315,-1.80407,0.245087,0.639763,-1.81347,0.343294,0.430245,-1.83693,0.268885,0.351286,-1.92679,0.506223,0.43788,-1.86968,0.494819,0.368414,-1.80972,0.136559,1.08895,-2.1023,0.13169,1.00467,-2.08442,-0.004574,1.09595,-2.07367,-0.006394,1.01492,-2.05736,0.011315,0.884121,-2.06176,-0.158795,0.816915,-2.06411,-0.16652,0.930852,-2.07099,-0.236232,0.919997,-2.06653,-0.463572,0.874499,-2.05532,-0.488362,0.969171,-1.98674,-0.592036,0.705466,-2.01325,-0.625675,0.77021,-2.06651,0.110461,1.33036,-1.81844,0.112675,1.32245,-2.03352},
/*682*/{0.167338,1.88477,-1.70992,0.266257,1.83265,-1.84232,0.008678,1.78151,-1.66774,-0.112113,1.70179,-1.66087,0.021789,1.61341,-1.64212,0.091061,1.55341,-1.61887,0.237631,1.90601,-2.09172,0.281791,1.83545,-1.91431,0.093787,1.86891,-2.0331,0.107917,1.68951,-2.20718,0.162653,1.59693,-2.23638,0.31279,1.5647,-2.11007,0.371543,1.53199,-2.09868,0.181723,1.41698,-1.81234,-0.00022,1.47065,-1.87767,0.006274,1.49679,-1.94007,0.012786,1.47006,-1.99245,0.199103,1.40195,-2.06308,0.247787,1.1213,-1.74456,0.128552,1.06725,-1.77795,0.161684,0.992023,-1.80167,0.271001,0.909305,-1.78572,0.330047,0.726389,-1.78622,0.344849,0.653397,-1.80148,0.220818,0.704046,-1.80412,0.235768,0.634758,-1.81481,0.328033,0.424843,-1.83978,0.250664,0.353923,-1.92902,0.492633,0.424074,-1.87052,0.47651,0.356589,-1.81061,0.142665,1.08467,-2.10265,0.138917,1.00088,-2.08506,0.001353,1.08948,-2.07295,0.001361,1.00774,-2.0569,0.020373,0.878586,-2.06203,-0.149918,0.81652,-2.06434,-0.154841,0.930198,-2.06951,-0.225033,0.921262,-2.06625,-0.453277,0.882094,-2.05449,-0.476451,0.976597,-1.98534,-0.586257,0.716389,-2.01579,-0.615952,0.78256,-2.06905,0.109259,1.3266,-1.81816,0.112386,1.31857,-2.03322},
/*683*/{0.167564,1.87799,-1.70877,0.266307,1.8261,-1.84155,0.01051,1.77264,-1.66382,-0.108145,1.69233,-1.65561,0.02725,1.60436,-1.63889,0.096594,1.5461,-1.61718,0.235161,1.9006,-2.09212,0.281339,1.83019,-1.91498,0.091755,1.86372,-2.03224,0.10361,1.68427,-2.20625,0.156129,1.59168,-2.2361,0.307923,1.55396,-2.11197,0.36593,1.51994,-2.10218,0.18174,1.4131,-1.81035,-0.000598,1.46496,-1.87784,0.005679,1.49097,-1.93963,0.010772,1.46309,-1.9934,0.198615,1.39806,-2.06281,0.246504,1.11588,-1.74361,0.125328,1.06309,-1.77902,0.159689,0.987299,-1.80153,0.266467,0.903939,-1.78522,0.323018,0.72046,-1.7862,0.335359,0.645496,-1.80198,0.21275,0.699803,-1.80494,0.227583,0.630693,-1.8142,0.314663,0.420112,-1.84239,0.230889,0.355066,-1.92936,0.476167,0.409848,-1.87023,0.456349,0.343924,-1.81055,0.146911,1.07956,-2.10297,0.145485,0.995948,-2.08649,0.006803,1.08271,-2.07194,0.007827,1.00083,-2.05657,0.030196,0.872583,-2.06295,-0.141342,0.815577,-2.06446,-0.142541,0.929195,-2.06854,-0.213016,0.923256,-2.06562,-0.441643,0.890713,-2.05556,-0.463688,0.984593,-1.98561,-0.576063,0.726493,-2.01813,-0.604025,0.79304,-2.07133,0.109954,1.3222,-1.81731,0.113304,1.31331,-2.03234},
/*684*/{0.168492,1.87108,-1.70729,0.266264,1.82056,-1.84267,0.013101,1.76333,-1.66052,-0.104377,1.68136,-1.64965,0.031471,1.59525,-1.63618,0.102364,1.53889,-1.61567,0.23405,1.89529,-2.09349,0.281332,1.82526,-1.9153,0.090095,1.85881,-2.03082,0.099809,1.67787,-2.20605,0.150133,1.58613,-2.23583,0.302349,1.5438,-2.11473,0.359802,1.50763,-2.10568,0.179711,1.40773,-1.80813,-0.00266,1.46049,-1.87834,0.005163,1.48526,-1.93958,0.009089,1.45691,-1.99333,0.199055,1.39305,-2.06144,0.246585,1.10973,-1.74286,0.124677,1.05874,-1.77798,0.156581,0.982128,-1.80142,0.261034,0.898326,-1.78504,0.315048,0.713479,-1.78706,0.325921,0.639825,-1.80515,0.20421,0.696744,-1.80591,0.217153,0.626491,-1.81659,0.296432,0.417133,-1.84428,0.210131,0.355694,-1.92951,0.462281,0.40035,-1.87281,0.437271,0.336831,-1.81097,0.152827,1.07515,-2.10399,0.153011,0.991888,-2.08651,0.011153,1.07496,-2.07074,0.013995,0.994056,-2.05614,0.039648,0.867008,-2.0637,-0.132124,0.81435,-2.06571,-0.130198,0.928072,-2.06761,-0.199787,0.924042,-2.06463,-0.431189,0.897544,-2.05446,-0.451759,0.992261,-1.98669,-0.567092,0.734877,-2.0199,-0.592524,0.801763,-2.07351,0.107934,1.31709,-1.81621,0.113259,1.30789,-2.03118},
/*685*/{0.168981,1.86461,-1.70573,0.266384,1.8142,-1.84158,0.016073,1.75357,-1.65642,-0.099875,1.67097,-1.64373,0.036895,1.58712,-1.63265,0.108452,1.53198,-1.61501,0.231901,1.88972,-2.09471,0.281401,1.81944,-1.91573,0.08861,1.85339,-2.02981,0.096058,1.6735,-2.2056,0.143661,1.58078,-2.2356,0.296951,1.53225,-2.11719,0.353554,1.49559,-2.10899,0.179285,1.40426,-1.80622,-0.005678,1.4553,-1.8793,0.001962,1.48122,-1.94011,0.007995,1.45154,-1.99376,0.198085,1.38817,-2.06019,0.24263,1.10698,-1.74241,0.120654,1.0547,-1.77769,0.155429,0.978904,-1.80111,0.255205,0.892544,-1.78362,0.307316,0.709052,-1.78777,0.316593,0.635888,-1.80486,0.19698,0.695727,-1.80544,0.205939,0.625108,-1.8186,0.279628,0.417144,-1.84696,0.188577,0.356061,-1.92931,0.441778,0.396535,-1.87936,0.415653,0.339351,-1.81407,0.158113,1.07037,-2.10311,0.158935,0.986847,-2.08705,0.016426,1.06742,-2.07021,0.020567,0.98668,-2.05521,0.049712,0.860746,-2.06558,-0.122414,0.813222,-2.06587,-0.117042,0.928313,-2.07009,-0.187722,0.924445,-2.06439,-0.416925,0.904517,-2.05558,-0.43964,0.998987,-1.98532,-0.555009,0.741866,-2.02114,-0.580232,0.809415,-2.07525,0.106379,1.31351,-1.81498,0.112833,1.30288,-2.02985},
/*686*/{0.170309,1.8578,-1.7041,0.266299,1.80818,-1.84212,0.019204,1.74346,-1.65252,-0.095387,1.65993,-1.63758,0.043179,1.57805,-1.62916,0.115459,1.52456,-1.61276,0.230274,1.88507,-2.09542,0.281469,1.8142,-1.91648,0.087448,1.84847,-2.02815,0.090694,1.66816,-2.20571,0.136682,1.57542,-2.23548,0.290851,1.52196,-2.12032,0.346638,1.48358,-2.11242,0.17649,1.40003,-1.80464,-0.008219,1.45075,-1.87954,0.000412,1.47364,-1.93967,0.005656,1.44585,-1.99471,0.198187,1.38458,-2.05755,0.240755,1.10298,-1.73833,0.117711,1.05198,-1.77639,0.152284,0.977013,-1.80087,0.249104,0.885768,-1.78408,0.299638,0.706703,-1.78882,0.30714,0.632268,-1.80611,0.189128,0.698142,-1.80679,0.195786,0.627957,-1.81791,0.261239,0.418768,-1.85042,0.166551,0.356511,-1.9311,0.420663,0.394994,-1.88401,0.396015,0.340725,-1.81521,0.161472,1.06678,-2.1042,0.165942,0.982706,-2.08759,0.021433,1.06112,-2.06991,0.027824,0.979842,-2.05504,0.060133,0.853401,-2.06705,-0.110952,0.81183,-2.06656,-0.101491,0.925476,-2.06806,-0.173562,0.924794,-2.06472,-0.406265,0.910008,-2.0544,-0.427209,1.00548,-1.98741,-0.542642,0.747789,-2.02198,-0.566717,0.814459,-2.0764,0.10455,1.30879,-1.81387,0.113451,1.29809,-2.02865},
/*687*/{0.171321,1.85241,-1.70291,0.267003,1.80244,-1.84237,0.023576,1.73305,-1.64806,-0.090729,1.64889,-1.63153,0.050405,1.56964,-1.62654,0.122871,1.51833,-1.61159,0.228659,1.88081,-2.09648,0.281992,1.80857,-1.91685,0.084874,1.84473,-2.02624,0.086569,1.66354,-2.20525,0.130197,1.57062,-2.2353,0.285147,1.51132,-2.12331,0.338987,1.47153,-2.11609,0.173523,1.39601,-1.80371,-0.012088,1.44596,-1.88003,-0.002879,1.46865,-1.94204,0.000996,1.44005,-1.99415,0.196553,1.37939,-2.0575,0.236068,1.10216,-1.73505,0.113671,1.05129,-1.77644,0.148667,0.976097,-1.80091,0.244219,0.881726,-1.7843,0.29369,0.707102,-1.78904,0.297683,0.633739,-1.80796,0.182158,0.703763,-1.80661,0.18574,0.63263,-1.81939,0.238882,0.419578,-1.85255,0.143604,0.357593,-1.932,0.398722,0.392601,-1.88819,0.371371,0.341155,-1.81636,0.16702,1.06274,-2.10417,0.17183,0.979519,-2.08748,0.025885,1.05353,-2.06958,0.034803,0.972241,-2.05417,0.069953,0.848893,-2.06726,-0.099666,0.81031,-2.06706,-0.089557,0.924411,-2.06897,-0.1598,0.924053,-2.06362,-0.390769,0.914071,-2.05598,-0.414875,1.00944,-1.98874,-0.529268,0.752271,-2.02271,-0.553694,0.818739,-2.0787,0.101442,1.3048,-1.81321,0.111134,1.2927,-2.02789},
/*688*/{0.172703,1.84763,-1.70197,0.26749,1.79829,-1.84248,0.028476,1.72175,-1.64427,-0.084546,1.63696,-1.62425,0.057035,1.56132,-1.62266,0.131666,1.51145,-1.60995,0.226685,1.87598,-2.09781,0.282166,1.80386,-1.91801,0.084322,1.8418,-2.02267,0.081894,1.65944,-2.2054,0.122594,1.56587,-2.23475,0.277787,1.4997,-2.12641,0.329691,1.46001,-2.12015,0.170348,1.39201,-1.80187,-0.015484,1.44217,-1.88147,-0.006625,1.46398,-1.9432,0.002462,1.43298,-1.99766,0.194729,1.37411,-2.0568,0.232022,1.10106,-1.73149,0.111623,1.04999,-1.77598,0.148058,0.976041,-1.80096,0.24317,0.884214,-1.78303,0.288327,0.706845,-1.78909,0.287842,0.633066,-1.80843,0.17725,0.709783,-1.80548,0.17704,0.63814,-1.81786,0.218772,0.423084,-1.85394,0.121895,0.358739,-1.93332,0.376728,0.391548,-1.88808,0.349362,0.339663,-1.81667,0.170417,1.06051,-2.10396,0.178528,0.976688,-2.08798,0.030275,1.04586,-2.06877,0.04145,0.965614,-2.05337,0.07976,0.844169,-2.06733,-0.087182,0.808716,-2.06676,-0.075679,0.92243,-2.069,-0.145377,0.92354,-2.06412,-0.375906,0.917183,-2.05715,-0.402385,1.01338,-1.98922,-0.515724,0.754999,-2.02334,-0.539167,0.82105,-2.08006,0.098005,1.30096,-1.81251,0.110462,1.28704,-2.02693},
/*689*/{0.173612,1.84292,-1.70064,0.267988,1.79166,-1.84246,0.033628,1.71127,-1.64075,-0.07686,1.62626,-1.61812,0.065484,1.55327,-1.62024,0.140056,1.50498,-1.60926,0.226015,1.87242,-2.09913,0.283061,1.79925,-1.91881,0.08305,1.83947,-2.02106,0.077605,1.65561,-2.20519,0.116928,1.56231,-2.23397,0.270168,1.49025,-2.13017,0.320973,1.44909,-2.12403,0.167838,1.38986,-1.8,-0.019916,1.43831,-1.88318,-0.009772,1.4599,-1.94364,-0.00341,1.43031,-1.99728,0.193327,1.37072,-2.05493,0.231319,1.10231,-1.72794,0.110621,1.04968,-1.77592,0.148636,0.976363,-1.79864,0.24564,0.88912,-1.78038,0.280942,0.706379,-1.78932,0.277854,0.634107,-1.80887,0.170196,0.714356,-1.80446,0.166558,0.642754,-1.81789,0.199904,0.423745,-1.85433,0.100008,0.359762,-1.93435,0.355608,0.39008,-1.88704,0.327118,0.339096,-1.81714,0.174947,1.05864,-2.1032,0.185898,0.97563,-2.08786,0.035466,1.03948,-2.06823,0.048823,0.960142,-2.05336,0.091216,0.839902,-2.06639,-0.074641,0.807108,-2.06657,-0.061033,0.920513,-2.06714,-0.130994,0.9219,-2.06332,-0.363083,0.919488,-2.05724,-0.388125,1.01557,-1.99128,-0.499678,0.755718,-2.02315,-0.524332,0.821974,-2.08066,0.094578,1.29853,-1.81136,0.10842,1.28365,-2.02563},
/*690*/{0.174661,1.83893,-1.69985,0.267524,1.78886,-1.84321,0.039092,1.70182,-1.63769,-0.070508,1.61435,-1.61145,0.07493,1.54662,-1.61741,0.150043,1.49958,-1.60801,0.225544,1.86903,-2.09985,0.282865,1.79447,-1.92046,0.082336,1.83793,-2.01871,0.073376,1.65281,-2.20359,0.10955,1.55933,-2.23314,0.262263,1.48139,-2.13245,0.311537,1.43926,-2.12756,0.164758,1.38726,-1.79793,-0.022889,1.43434,-1.88481,-0.012011,1.45651,-1.94386,-0.006486,1.42443,-1.99971,0.190393,1.36674,-2.05439,0.227231,1.10239,-1.72723,0.108777,1.04962,-1.77624,0.14579,0.974615,-1.79925,0.250209,0.893371,-1.77855,0.272853,0.704867,-1.78967,0.266273,0.631957,-1.80765,0.161144,0.716651,-1.80273,0.154906,0.645182,-1.81739,0.18024,0.423945,-1.85407,0.078956,0.360653,-1.93422,0.334197,0.389148,-1.88735,0.304838,0.338448,-1.81669,0.178125,1.05902,-2.10291,0.192715,0.975949,-2.08772,0.039039,1.03536,-2.06941,0.057041,0.955335,-2.05406,0.103479,0.835618,-2.06557,-0.061074,0.804299,-2.06552,-0.045208,0.916613,-2.06724,-0.116505,0.921395,-2.06429,-0.344263,0.916833,-2.05609,-0.377168,1.01623,-1.9936,-0.484473,0.755791,-2.02376,-0.507045,0.820432,-2.08064,0.091452,1.29574,-1.81051,0.106594,1.27909,-2.02457},
/*691*/{0.17523,1.8357,-1.69917,0.266939,1.78426,-1.84443,0.045764,1.69433,-1.63478,-0.060726,1.60487,-1.6053,0.083464,1.53963,-1.61559,0.160386,1.49512,-1.60667,0.225177,1.86659,-2.09997,0.283312,1.79036,-1.92131,0.082401,1.83731,-2.01783,0.068826,1.65249,-2.20166,0.102454,1.55808,-2.23281,0.253879,1.4755,-2.1341,0.30267,1.43035,-2.13114,0.161931,1.38647,-1.79553,-0.026041,1.43112,-1.88745,-0.01346,1.45402,-1.94369,-0.009004,1.41913,-2.00074,0.188531,1.36371,-2.05354,0.223107,1.10097,-1.72819,0.106372,1.04724,-1.77527,0.145657,0.972766,-1.79796,0.256668,0.896,-1.7785,0.263263,0.703611,-1.78879,0.254092,0.630959,-1.80786,0.15153,0.718083,-1.8019,0.145008,0.648194,-1.81491,0.161063,0.425233,-1.85506,0.058055,0.361675,-1.93409,0.313507,0.388106,-1.88661,0.284937,0.338492,-1.81527,0.184507,1.05941,-2.10204,0.200071,0.976465,-2.08723,0.044003,1.03197,-2.06928,0.063744,0.951908,-2.0534,0.116744,0.834079,-2.06492,-0.047763,0.802542,-2.06442,-0.031436,0.915384,-2.06921,-0.101416,0.919183,-2.06416,-0.330459,0.917568,-2.05684,-0.364521,1.01574,-1.99503,-0.468073,0.7542,-2.02406,-0.492578,0.817926,-2.08231,0.088976,1.2944,-1.80903,0.105787,1.27544,-2.02277},
/*692*/{0.175854,1.83347,-1.69921,0.267686,1.77992,-1.84492,0.050902,1.68826,-1.63287,-0.049451,1.59652,-1.59998,0.094308,1.53521,-1.61382,0.17092,1.49126,-1.60536,0.224811,1.86331,-2.09938,0.282653,1.78672,-1.92264,0.082578,1.8358,-2.01767,0.062104,1.65483,-2.19949,0.095037,1.55825,-2.23201,0.24484,1.46937,-2.13582,0.292086,1.42269,-2.13436,0.15791,1.38553,-1.79305,-0.028472,1.42952,-1.88872,-0.014857,1.45336,-1.94508,-0.01149,1.41619,-2.0026,0.189297,1.36125,-2.05035,0.218343,1.0991,-1.72498,0.099962,1.04478,-1.77603,0.140901,0.970478,-1.79687,0.260349,0.895334,-1.77929,0.251784,0.701926,-1.78657,0.240334,0.629411,-1.8057,0.140806,0.719429,-1.80118,0.130355,0.648507,-1.81354,0.141425,0.425254,-1.85461,0.036516,0.362204,-1.934,0.292964,0.386979,-1.88524,0.263938,0.337452,-1.81524,0.188865,1.05973,-2.10153,0.208188,0.977664,-2.08639,0.051414,1.02817,-2.06999,0.072814,0.949095,-2.0547,0.131053,0.834184,-2.06424,-0.032765,0.800122,-2.06312,-0.015509,0.912573,-2.06928,-0.08631,0.916929,-2.06477,-0.315859,0.915595,-2.05701,-0.351659,1.01489,-1.99789,-0.451354,0.750378,-2.02372,-0.474891,0.813014,-2.08262,0.08481,1.29363,-1.80746,0.105402,1.27309,-2.02072},
/*693*/{0.1769,1.83131,-1.6997,0.266329,1.77703,-1.84587,0.056205,1.68401,-1.6313,-0.041592,1.58921,-1.59495,0.105043,1.53081,-1.61249,0.182327,1.48905,-1.6038,0.224954,1.86102,-2.09893,0.282356,1.78382,-1.92281,0.082211,1.83472,-2.01753,0.057164,1.65541,-2.19666,0.087477,1.55946,-2.23056,0.235771,1.46514,-2.13813,0.281538,1.41687,-2.13767,0.155009,1.38422,-1.79053,-0.029242,1.42798,-1.88942,-0.016391,1.45249,-1.94493,-0.013423,1.41496,-2.003,0.186173,1.35931,-2.04967,0.215908,1.09787,-1.72444,0.0967,1.04294,-1.77528,0.133918,0.968277,-1.79702,0.25504,0.891001,-1.77836,0.239725,0.699081,-1.78465,0.226835,0.625485,-1.80347,0.128771,0.71937,-1.80036,0.117099,0.649146,-1.81257,0.121058,0.4251,-1.85344,0.015134,0.362716,-1.93347,0.271359,0.387094,-1.88534,0.242434,0.336618,-1.81487,0.196076,1.06084,-2.10111,0.216906,0.979611,-2.08576,0.057679,1.02574,-2.07111,0.082039,0.946638,-2.05524,0.145732,0.833374,-2.06317,-0.018708,0.798491,-2.06107,-0.002319,0.910072,-2.06966,-0.070432,0.915703,-2.06467,-0.301248,0.911705,-2.05774,-0.340059,1.01214,-1.99964,-0.434595,0.745545,-2.02271,-0.457915,0.805982,-2.08269,0.081684,1.29242,-1.80663,0.103036,1.27129,-2.01976},
/*694*/{0.177756,1.82969,-1.70005,0.266755,1.77534,-1.84607,0.062013,1.68097,-1.62903,-0.03102,1.58373,-1.59008,0.115836,1.5279,-1.61053,0.194825,1.48759,-1.6035,0.225539,1.85915,-2.09884,0.282023,1.78262,-1.9234,0.082022,1.834,-2.01759,0.051193,1.6579,-2.1936,0.080067,1.56154,-2.2299,0.226624,1.46182,-2.14009,0.271177,1.4129,-2.14084,0.152578,1.38353,-1.78829,-0.031457,1.42729,-1.89057,-0.018436,1.45234,-1.94526,-0.015129,1.41426,-2.00315,0.184904,1.35776,-2.04956,0.208662,1.09228,-1.7246,0.090339,1.04083,-1.77605,0.128692,0.964931,-1.7978,0.244654,0.886383,-1.77714,0.225767,0.694397,-1.78351,0.211843,0.623323,-1.80227,0.116485,0.718085,-1.79985,0.103053,0.648533,-1.81299,0.100393,0.423692,-1.85163,-0.006193,0.362822,-1.93286,0.24998,0.385885,-1.88433,0.21986,0.336298,-1.81412,0.203605,1.06256,-2.10074,0.226431,0.981521,-2.08524,0.066249,1.02283,-2.07156,0.091306,0.945591,-2.05699,0.161739,0.833049,-2.06118,-0.003419,0.795654,-2.05784,0.01232,0.90879,-2.06987,-0.056994,0.914172,-2.06597,-0.291292,0.910559,-2.06008,-0.329484,1.00796,-2.00297,-0.415469,0.739896,-2.02176,-0.442681,0.798759,-2.08387,0.078654,1.29191,-1.80606,0.101221,1.2702,-2.019},
/*695*/{0.178893,1.82873,-1.70049,0.266696,1.77333,-1.84728,0.067096,1.67825,-1.62709,-0.02127,1.57894,-1.58574,0.127611,1.52632,-1.6101,0.207082,1.48773,-1.60286,0.22463,1.85739,-2.0988,0.280701,1.77941,-1.92291,0.081592,1.83406,-2.01809,0.045657,1.66183,-2.19089,0.071586,1.56477,-2.22955,0.217668,1.46128,-2.1417,0.260215,1.4094,-2.14355,0.149028,1.3826,-1.78659,-0.031936,1.4273,-1.89002,-0.019975,1.45139,-1.94518,-0.015946,1.41413,-2.00334,0.182169,1.3567,-2.04874,0.202992,1.08846,-1.72373,0.082655,1.03951,-1.77733,0.120493,0.963622,-1.79786,0.232989,0.881456,-1.77533,0.212455,0.690719,-1.78279,0.194343,0.618109,-1.80147,0.103365,0.717182,-1.79839,0.087584,0.647634,-1.81281,0.079004,0.424637,-1.85214,-0.028449,0.364139,-1.93264,0.228281,0.385495,-1.88434,0.198931,0.336267,-1.81331,0.211451,1.06514,-2.09965,0.236484,0.985214,-2.08447,0.075177,1.0235,-2.07442,0.102591,0.944281,-2.05816,0.177494,0.836081,-2.0604,0.010829,0.795303,-2.05678,0.026604,0.907577,-2.07025,-0.042269,0.912173,-2.06629,-0.277135,0.906149,-2.06051,-0.318818,1.00368,-2.00566,-0.395847,0.731036,-2.01934,-0.425209,0.789612,-2.08413,0.075519,1.29118,-1.80534,0.098959,1.26929,-2.01817},
/*696*/{0.180483,1.828,-1.7003,0.26592,1.77357,-1.84736,0.072228,1.67612,-1.62516,-0.011703,1.57434,-1.58109,0.138488,1.52534,-1.60826,0.219491,1.48898,-1.60313,0.223796,1.85643,-2.09851,0.280057,1.77909,-1.92329,0.080967,1.83399,-2.01834,0.040247,1.66657,-2.18773,0.063039,1.56851,-2.22953,0.207318,1.4593,-2.14394,0.249371,1.40777,-2.14605,0.148044,1.38244,-1.78558,-0.034312,1.42638,-1.89048,-0.02145,1.45027,-1.94501,-0.017821,1.41453,-2.00274,0.181749,1.35692,-2.04852,0.194824,1.08453,-1.72341,0.077832,1.03794,-1.77603,0.112289,0.960384,-1.79913,0.22054,0.87637,-1.77472,0.197774,0.685773,-1.78229,0.17895,0.615277,-1.80227,0.089152,0.715616,-1.79836,0.07126,0.646212,-1.81232,0.058826,0.424937,-1.8509,-0.0492,0.363891,-1.93151,0.20734,0.385611,-1.88323,0.17799,0.336156,-1.81218,0.219728,1.06815,-2.09946,0.247101,0.988979,-2.08389,0.084627,1.02191,-2.07476,0.113741,0.943715,-2.05919,0.192709,0.837278,-2.05942,0.02538,0.795328,-2.05645,0.040826,0.906,-2.07019,-0.02872,0.909732,-2.06842,-0.265798,0.899947,-2.05911,-0.309508,0.998155,-2.00795,-0.376742,0.722485,-2.01885,-0.407387,0.778387,-2.08451,0.074357,1.29068,-1.80523,0.098395,1.26939,-2.01806},
/*697*/{0.181831,1.82778,-1.7003,0.264802,1.77259,-1.84839,0.077129,1.67533,-1.62322,-0.002534,1.57094,-1.57673,0.149776,1.52555,-1.60687,0.232313,1.49176,-1.60332,0.223678,1.8561,-2.0985,0.279508,1.77816,-1.92351,0.080651,1.83414,-2.0183,0.034069,1.67186,-2.18482,0.055195,1.5729,-2.22946,0.198399,1.45974,-2.1463,0.238757,1.40732,-2.14867,0.145212,1.38178,-1.78341,-0.035519,1.4264,-1.88945,-0.02247,1.45059,-1.94438,-0.019249,1.41479,-2.00102,0.180254,1.35786,-2.0485,0.189301,1.07935,-1.72335,0.071037,1.03574,-1.77542,0.101237,0.959332,-1.79893,0.207745,0.871629,-1.77387,0.18293,0.681534,-1.78254,0.161772,0.610043,-1.80185,0.075005,0.712784,-1.79857,0.056437,0.644664,-1.81251,0.038672,0.425129,-1.85095,-0.069462,0.36447,-1.93127,0.186151,0.384763,-1.88315,0.156951,0.33566,-1.81131,0.227942,1.07226,-2.09866,0.258417,0.994501,-2.08317,0.094523,1.021,-2.07653,0.126547,0.944511,-2.05928,0.207824,0.839877,-2.0589,0.039844,0.795662,-2.05589,0.05389,0.905606,-2.07054,-0.014611,0.908153,-2.06814,-0.250026,0.894341,-2.06019,-0.301029,0.990925,-2.00967,-0.356343,0.712628,-2.01864,-0.387949,0.766903,-2.08494,0.072292,1.29008,-1.80474,0.096909,1.27002,-2.01762},
/*698*/{0.182778,1.82778,-1.70086,0.264802,1.77259,-1.84839,0.082465,1.67465,-1.62146,0.007657,1.56738,-1.57253,0.160622,1.527,-1.60533,0.245301,1.49528,-1.60432,0.222995,1.85602,-2.09867,0.278255,1.7773,-1.92396,0.079706,1.83473,-2.01844,0.027658,1.67803,-2.18236,0.046788,1.57824,-2.22919,0.188722,1.46228,-2.14866,0.227818,1.40868,-2.15177,0.143068,1.3822,-1.78273,-0.037794,1.42668,-1.88965,-0.024461,1.45028,-1.94383,-0.02092,1.41605,-2.00033,0.179177,1.35896,-2.04811,0.181459,1.07666,-1.72122,0.061241,1.03531,-1.77637,0.093127,0.957652,-1.79943,0.194575,0.865554,-1.77384,0.166863,0.67714,-1.78296,0.146312,0.606659,-1.80218,0.06026,0.711,-1.79815,0.040449,0.642786,-1.81259,0.016816,0.424983,-1.8507,-0.090612,0.364597,-1.93129,0.165737,0.384666,-1.88192,0.135167,0.335242,-1.81157,0.234902,1.07839,-2.09954,0.268596,1.00075,-2.0824,0.103582,1.02152,-2.0773,0.138169,0.948416,-2.06126,0.222135,0.842685,-2.05839,0.056838,0.79336,-2.05759,0.068167,0.905441,-2.07062,-0.002623,0.90683,-2.06825,-0.234269,0.886109,-2.05977,-0.292699,0.982375,-2.01107,-0.335563,0.701503,-2.01774,-0.368435,0.754733,-2.08576,0.07043,1.29025,-1.80465,0.095728,1.27101,-2.01753},
/*699*/{0.184842,1.82869,-1.70059,0.26459,1.77069,-1.84803,0.086561,1.67496,-1.61981,0.017037,1.56552,-1.56888,0.17115,1.52919,-1.60424,0.257086,1.50005,-1.6054,0.22154,1.8562,-2.09861,0.27802,1.77738,-1.92425,0.078823,1.836,-2.01797,0.021413,1.68365,-2.18033,0.038604,1.58358,-2.22902,0.17924,1.46383,-2.1506,0.21731,1.41046,-2.1539,0.142035,1.382,-1.78274,-0.039066,1.42679,-1.88934,-0.026247,1.45053,-1.94411,-0.022153,1.41649,-1.99948,0.178127,1.36046,-2.0481,0.173555,1.07526,-1.72084,0.050497,1.03667,-1.77791,0.081977,0.957745,-1.79864,0.18055,0.860032,-1.77415,0.151395,0.673021,-1.78333,0.131829,0.604989,-1.80271,0.04507,0.70832,-1.79859,0.024734,0.640689,-1.81365,-0.002093,0.425291,-1.85055,-0.111423,0.365417,-1.93173,0.144648,0.384341,-1.88298,0.113964,0.335191,-1.81181,0.24269,1.08443,-2.09899,0.278556,1.00808,-2.08122,0.113379,1.02289,-2.07796,0.151715,0.951254,-2.06243,0.2368,0.846375,-2.05857,0.072757,0.793582,-2.05709,0.080829,0.90593,-2.07102,0.010369,0.905537,-2.06869,-0.223068,0.880612,-2.06115,-0.283826,0.97265,-2.01183,-0.31362,0.690815,-2.0179,-0.347367,0.740902,-2.08574,0.069553,1.29011,-1.80507,0.094895,1.27201,-2.01804},
/*700*/{0.186147,1.83013,-1.70058,0.264978,1.77178,-1.84951,0.091148,1.67571,-1.61804,0.027309,1.56309,-1.56473,0.181342,1.53189,-1.60371,0.268553,1.50551,-1.60675,0.219644,1.85739,-2.09844,0.277507,1.77833,-1.92466,0.077322,1.83736,-2.01691,0.017096,1.6903,-2.17872,0.029671,1.59024,-2.22945,0.170183,1.46891,-2.15231,0.207249,1.41405,-2.15575,0.140128,1.38072,-1.78164,-0.039929,1.42714,-1.88918,-0.026015,1.45139,-1.94376,-0.02327,1.41764,-1.99905,0.177579,1.36271,-2.04759,0.165922,1.07331,-1.72132,0.044425,1.03661,-1.7767,0.070182,0.958471,-1.80022,0.166199,0.85496,-1.77426,0.135891,0.670608,-1.78401,0.111935,0.600471,-1.80324,0.029026,0.707322,-1.79648,0.008682,0.64013,-1.8137,-0.022712,0.425964,-1.85061,-0.131925,0.366317,-1.93125,0.124701,0.384093,-1.88226,0.093874,0.335561,-1.81151,0.249298,1.09106,-2.09915,0.288371,1.01587,-2.08129,0.122367,1.0255,-2.07885,0.161195,0.954645,-2.06341,0.251213,0.851047,-2.0579,0.088602,0.793398,-2.0548,0.092704,0.907002,-2.07203,0.022572,0.904746,-2.06971,-0.205563,0.871641,-2.05851,-0.275937,0.961971,-2.01204,-0.291144,0.680547,-2.01762,-0.327133,0.727481,-2.08603,0.06792,1.28923,-1.80584,0.094389,1.27365,-2.01887},
/*701*/{0.188492,1.83203,-1.70083,0.264423,1.77369,-1.85033,0.09662,1.67715,-1.61621,0.03754,1.56253,-1.56133,0.191575,1.53545,-1.60361,0.279039,1.51173,-1.60882,0.216781,1.85842,-2.09819,0.275332,1.77991,-1.92585,0.076565,1.83876,-2.01556,0.011053,1.69681,-2.17743,0.021347,1.59623,-2.22962,0.161717,1.47406,-2.15402,0.19737,1.4184,-2.15756,0.139368,1.38084,-1.78168,-0.040008,1.42879,-1.88843,-0.027184,1.45281,-1.9428,-0.024646,1.41799,-1.99857,0.176736,1.36521,-2.0476,0.159342,1.07292,-1.7226,0.036244,1.03729,-1.77616,0.059806,0.957812,-1.79966,0.150652,0.852112,-1.77463,0.119361,0.668751,-1.78458,0.09533,0.599758,-1.80416,0.013481,0.706773,-1.79924,-0.008672,0.639701,-1.8124,-0.042547,0.426708,-1.85111,-0.152537,0.366788,-1.93143,0.102644,0.383765,-1.88237,0.072287,0.335782,-1.8106,0.256145,1.09738,-2.0986,0.29709,1.02418,-2.08119,0.131038,1.02797,-2.07892,0.172469,0.958585,-2.06334,0.265292,0.85602,-2.05769,0.1041,0.794152,-2.05452,0.1053,0.907649,-2.07301,0.034719,0.903404,-2.07063,-0.19709,0.863357,-2.06019,-0.268937,0.950575,-2.01215,-0.268138,0.667003,-2.01737,-0.305874,0.713205,-2.08713,0.067542,1.28978,-1.80613,0.093579,1.27543,-2.0193},
/*702*/{0.19105,1.83416,-1.70101,0.263714,1.77565,-1.85088,0.102674,1.67839,-1.61437,0.046783,1.56319,-1.55792,0.201316,1.54028,-1.60355,0.289823,1.51896,-1.61083,0.214648,1.86062,-2.09845,0.274252,1.78137,-1.92692,0.074794,1.84074,-2.01508,0.004897,1.70325,-2.17688,0.012457,1.60326,-2.22981,0.151687,1.47916,-2.15532,0.187085,1.42321,-2.15941,0.138414,1.38023,-1.78165,-0.04085,1.42993,-1.8884,-0.027695,1.45365,-1.94284,-0.024708,1.41868,-1.99819,0.176423,1.36682,-2.04751,0.15194,1.07179,-1.72415,0.023975,1.03851,-1.77839,0.049442,0.957669,-1.79811,0.132959,0.849693,-1.77526,0.102417,0.667359,-1.78527,0.076875,0.598044,-1.80472,-0.001854,0.707515,-1.79988,-0.025129,0.641297,-1.81324,-0.063169,0.426631,-1.85073,-0.173155,0.367717,-1.93195,0.08269,0.383707,-1.88181,0.051957,0.335778,-1.81115,0.261076,1.10567,-2.09882,0.305327,1.03344,-2.08105,0.139032,1.03192,-2.07914,0.182657,0.962857,-2.06355,0.279602,0.86214,-2.05792,0.119467,0.795405,-2.05354,0.116898,0.909196,-2.07405,0.046636,0.902603,-2.07192,-0.184727,0.854253,-2.05923,-0.261217,0.93662,-2.01075,-0.244257,0.654133,-2.01831,-0.284964,0.698649,-2.08751,0.066563,1.28966,-1.80677,0.093128,1.2767,-2.01996},
/*703*/{0.193192,1.83646,-1.70163,0.263398,1.77744,-1.85207,0.108433,1.6803,-1.61347,0.055981,1.56373,-1.55554,0.21086,1.54483,-1.60401,0.299789,1.52686,-1.61396,0.212012,1.86314,-2.09886,0.274338,1.78328,-1.92774,0.073111,1.84191,-2.01226,-0.00151,1.70973,-2.17621,0.00499,1.6107,-2.22965,0.143093,1.48477,-2.15644,0.178103,1.42925,-2.1608,0.138218,1.38022,-1.78186,-0.040023,1.43245,-1.88766,-0.028116,1.45485,-1.94163,-0.025448,1.42011,-1.99811,0.174059,1.36777,-2.04764,0.142979,1.06854,-1.72574,0.016647,1.04098,-1.77704,0.037861,0.958941,-1.79743,0.115995,0.847726,-1.7768,0.086541,0.66675,-1.78575,0.060159,0.597758,-1.8051,-0.017999,0.708241,-1.80096,-0.04293,0.642297,-1.81515,-0.082806,0.427234,-1.85083,-0.193615,0.368721,-1.93219,0.062376,0.383638,-1.88237,0.031392,0.335802,-1.81136,0.26691,1.11264,-2.09846,0.312201,1.04274,-2.08098,0.146547,1.03622,-2.07953,0.19257,0.969704,-2.06311,0.293825,0.8708,-2.05812,0.135283,0.797834,-2.05346,0.127297,0.91132,-2.07393,0.058042,0.901216,-2.07269,-0.171229,0.844007,-2.05879,-0.252861,0.923052,-2.01004,-0.220175,0.641015,-2.01944,-0.262547,0.68426,-2.08849,0.06579,1.29045,-1.8068,0.09101,1.27772,-2.02017},
/*704*/{0.195703,1.83961,-1.70192,0.265057,1.78021,-1.85277,0.11441,1.68239,-1.61199,0.06678,1.56512,-1.55351,0.219808,1.55143,-1.60481,0.308145,1.53535,-1.6164,0.208925,1.86579,-2.09908,0.273154,1.78581,-1.92926,0.072006,1.8444,-2.01142,-0.007708,1.71643,-2.17573,-0.003792,1.6175,-2.22959,0.134505,1.49154,-2.15778,0.168651,1.43583,-2.16245,0.13795,1.38031,-1.78147,-0.041163,1.43319,-1.88735,-0.028699,1.45684,-1.94122,-0.025237,1.42244,-1.99808,0.174023,1.3703,-2.04699,0.134831,1.06691,-1.72717,0.009012,1.0431,-1.77582,0.027553,0.960635,-1.79647,0.100677,0.847575,-1.77798,0.069885,0.666473,-1.78733,0.042313,0.598223,-1.80615,-0.033475,0.708708,-1.80191,-0.059381,0.644456,-1.81444,-0.102676,0.428947,-1.85123,-0.213492,0.369534,-1.93191,0.042159,0.383693,-1.88296,0.011172,0.336098,-1.81156,0.27162,1.12125,-2.09835,0.319609,1.05192,-2.08074,0.154101,1.03978,-2.07863,0.201446,0.975346,-2.06253,0.305839,0.880569,-2.05766,0.150142,0.799338,-2.05382,0.137997,0.911403,-2.07422,0.068673,0.898838,-2.0724,-0.160124,0.83467,-2.05749,-0.245552,0.906943,-2.00837,-0.19484,0.627997,-2.02054,-0.24064,0.668101,-2.08899,0.065022,1.2908,-1.80753,0.09099,1.28013,-2.02093},
/*705*/{0.197713,1.84294,-1.70268,0.263835,1.78227,-1.8538,0.120734,1.68484,-1.61104,0.074368,1.56676,-1.55074,0.228026,1.5572,-1.60663,0.31714,1.54449,-1.62006,0.205824,1.86902,-2.09921,0.272649,1.78807,-1.92979,0.070473,1.84576,-2.00868,-0.015068,1.72333,-2.17498,-0.01086,1.62491,-2.22923,0.125663,1.49775,-2.15859,0.159779,1.44092,-2.16331,0.13826,1.38083,-1.78164,-0.041483,1.43558,-1.88664,-0.028332,1.45843,-1.94071,-0.025361,1.42443,-1.99774,0.174246,1.37244,-2.04623,0.12696,1.066,-1.7295,-4.6e-005,1.0449,-1.77564,0.015656,0.962073,-1.7977,0.085731,0.848409,-1.7799,0.052568,0.66623,-1.78821,0.024089,0.597967,-1.80695,-0.050165,0.710692,-1.80246,-0.076473,0.645447,-1.81529,-0.12277,0.429023,-1.85132,-0.233746,0.371758,-1.93169,0.02254,0.382681,-1.88268,-0.008774,0.335827,-1.81129,0.2762,1.12939,-2.09759,0.32554,1.06161,-2.08053,0.160639,1.04478,-2.07872,0.210158,0.980648,-2.0628,0.317419,0.89066,-2.05802,0.164939,0.801788,-2.05349,0.147627,0.912757,-2.07482,0.078993,0.897415,-2.07321,-0.145904,0.823192,-2.05554,-0.236224,0.889693,-2.0066,-0.168992,0.614982,-2.02235,-0.216576,0.654045,-2.09091,0.064815,1.29189,-1.80768,0.090824,1.28219,-2.02112},
/*706*/{0.200149,1.847,-1.70315,0.265004,1.78574,-1.85433,0.12811,1.68723,-1.60961,0.084315,1.56922,-1.54874,0.236611,1.56456,-1.60786,0.325029,1.55356,-1.62335,0.201297,1.87263,-2.09892,0.271829,1.79096,-1.93113,0.068637,1.84819,-2.00693,-0.02018,1.73017,-2.1743,-0.018694,1.6321,-2.22886,0.117805,1.50481,-2.15974,0.152772,1.44992,-2.16541,0.13805,1.38072,-1.7796,-0.040475,1.43741,-1.8854,-0.028076,1.46076,-1.93893,-0.02496,1.42625,-1.99649,0.173432,1.37469,-2.04557,0.118759,1.06535,-1.73151,-0.008331,1.04819,-1.77478,0.005071,0.965502,-1.79743,0.071901,0.849344,-1.78147,0.035363,0.667017,-1.78954,0.008033,0.600219,-1.80826,-0.066782,0.713232,-1.80287,-0.094066,0.64746,-1.81536,-0.141139,0.431403,-1.85042,-0.25391,0.373664,-1.93105,0.002026,0.382288,-1.88302,-0.028969,0.336578,-1.81027,0.280442,1.13703,-2.09767,0.331769,1.07106,-2.08045,0.167263,1.04938,-2.07829,0.218117,0.986925,-2.06257,0.329541,0.901663,-2.05808,0.179473,0.804397,-2.05329,0.157259,0.913539,-2.07554,0.08929,0.89605,-2.07335,-0.134147,0.812182,-2.0546,-0.228183,0.872125,-2.00318,-0.142694,0.603102,-2.02456,-0.193603,0.638733,-2.09147,0.064344,1.29249,-1.80721,0.090268,1.28426,-2.02072},
/*707*/{0.202867,1.85116,-1.70371,0.265712,1.78967,-1.85585,0.134481,1.69024,-1.60874,0.093827,1.57225,-1.54696,0.243875,1.57092,-1.60889,0.332312,1.56288,-1.62609,0.198394,1.87664,-2.0988,0.271893,1.79485,-1.93263,0.066587,1.85069,-2.00527,-0.026179,1.73662,-2.17373,-0.02597,1.63963,-2.2283,0.110404,1.51276,-2.16009,0.144934,1.45735,-2.16681,0.138728,1.38169,-1.7794,-0.039973,1.43986,-1.88498,-0.028115,1.46347,-1.93761,-0.02528,1.4297,-1.99684,0.173414,1.37775,-2.04453,0.112173,1.06502,-1.73231,-0.014302,1.04926,-1.77274,-0.005393,0.967348,-1.79609,0.05793,0.850794,-1.78283,0.018111,0.668049,-1.79061,-0.012189,0.600789,-1.809,-0.084089,0.713061,-1.80483,-0.111836,0.64956,-1.81806,-0.162265,0.432765,-1.8503,-0.273918,0.377296,-1.93105,-0.018494,0.382224,-1.88303,-0.050347,0.336207,-1.81131,0.284527,1.14496,-2.09766,0.337555,1.08019,-2.08026,0.173654,1.05456,-2.07728,0.225984,0.993855,-2.06152,0.33979,0.912272,-2.05767,0.193157,0.807043,-2.0537,0.167102,0.913641,-2.07524,0.09831,0.894203,-2.07315,-0.120309,0.799849,-2.05438,-0.218063,0.853001,-2.00228,-0.115573,0.590999,-2.02692,-0.168862,0.624322,-2.09307,0.064178,1.29404,-1.80763,0.090102,1.28737,-2.0212},
/*708*/{0.205157,1.85566,-1.7044,0.266591,1.79318,-1.85639,0.141761,1.69394,-1.60821,0.102176,1.57545,-1.54545,0.250423,1.57868,-1.61115,0.338253,1.57227,-1.62992,0.195072,1.88071,-2.09902,0.271534,1.7982,-1.93308,0.065259,1.85296,-2.00203,-0.030366,1.74367,-2.17266,-0.033136,1.64715,-2.22758,0.102691,1.52004,-2.16026,0.137623,1.46543,-2.16804,0.139213,1.3823,-1.77802,-0.039323,1.44187,-1.88389,-0.027584,1.46567,-1.93631,-0.024347,1.43275,-1.99653,0.174371,1.38175,-2.04312,0.107969,1.06734,-1.73429,-0.025215,1.05308,-1.7751,-0.016508,0.971402,-1.79691,0.046524,0.852141,-1.78459,0.000184,0.670134,-1.79189,-0.029641,0.602929,-1.80982,-0.101358,0.715853,-1.80505,-0.130143,0.651488,-1.81813,-0.182061,0.434979,-1.84953,-0.293295,0.381804,-1.93071,-0.038067,0.382137,-1.88325,-0.071887,0.336232,-1.81252,0.287871,1.15256,-2.09759,0.342846,1.08953,-2.08009,0.178856,1.06036,-2.0775,0.233239,1.00072,-2.06177,0.34982,0.923351,-2.05764,0.20725,0.810277,-2.05382,0.174846,0.914532,-2.07518,0.10749,0.892362,-2.07253,-0.103095,0.786629,-2.05391,-0.207391,0.834239,-2.00028,-0.088155,0.580523,-2.02983,-0.143554,0.609809,-2.09387,0.06455,1.29507,-1.80786,0.091371,1.29086,-2.02138},
/*709*/{0.207826,1.86092,-1.70553,0.26665,1.7964,-1.85753,0.14847,1.69788,-1.6081,0.109856,1.57887,-1.54416,0.256566,1.58665,-1.61275,0.344428,1.58239,-1.63329,0.191757,1.88487,-2.09869,0.271392,1.80241,-1.93449,0.064467,1.85574,-2.00064,-0.035908,1.7507,-2.17216,-0.039936,1.65439,-2.22624,0.09457,1.5282,-2.16122,0.129939,1.4729,-2.1696,0.139372,1.38321,-1.77662,-0.038533,1.44501,-1.88356,-0.026465,1.46865,-1.93492,-0.025272,1.43688,-1.99544,0.173684,1.38485,-2.04183,0.099675,1.06631,-1.73616,-0.03212,1.05923,-1.77513,-0.025705,0.974913,-1.79701,0.035102,0.853973,-1.78668,-0.016367,0.672438,-1.79302,-0.046562,0.60638,-1.81136,-0.118153,0.719213,-1.8064,-0.146536,0.655544,-1.81931,-0.200152,0.437168,-1.84892,-0.313427,0.387237,-1.92979,-0.058029,0.381988,-1.8835,-0.091571,0.337311,-1.81204,0.292718,1.16112,-2.09751,0.347865,1.09753,-2.07944,0.184266,1.06596,-2.07718,0.239976,1.00605,-2.06143,0.358373,0.933656,-2.05806,0.219998,0.813738,-2.05442,0.180433,0.919309,-2.07674,0.116149,0.890552,-2.07193,-0.083767,0.771505,-2.05113,-0.196198,0.814256,-1.99798,-0.060511,0.568271,-2.03179,-0.117669,0.596014,-2.0959,0.063761,1.29688,-1.80772,0.090583,1.29411,-2.02126},
/*710*/{0.209469,1.86632,-1.70649,0.267534,1.80109,-1.8595,0.153915,1.70266,-1.6078,0.118965,1.58402,-1.5433,0.262651,1.5934,-1.6139,0.349997,1.59212,-1.63669,0.189349,1.88913,-2.0982,0.271555,1.8061,-1.93605,0.063544,1.85781,-1.99856,-0.041246,1.75871,-2.17155,-0.046882,1.66201,-2.22488,0.088965,1.53607,-2.16086,0.123596,1.48049,-2.17069,0.14029,1.38415,-1.77554,-0.036596,1.44714,-1.88199,-0.025921,1.47168,-1.93251,-0.023134,1.4404,-1.99512,0.174326,1.38846,-2.04064,0.094164,1.06751,-1.73908,-0.0402,1.06313,-1.77526,-0.034862,0.979089,-1.79756,0.023171,0.857086,-1.78936,-0.032434,0.67585,-1.79405,-0.062789,0.609925,-1.81156,-0.133999,0.723514,-1.80753,-0.163564,0.65963,-1.8194,-0.218628,0.443504,-1.84966,-0.332561,0.393472,-1.92887,-0.077109,0.380426,-1.8827,-0.112297,0.336759,-1.81237,0.295011,1.16898,-2.09736,0.351205,1.10817,-2.08051,0.189682,1.07269,-2.07686,0.246089,1.01393,-2.06092,0.366142,0.944271,-2.05812,0.232847,0.817272,-2.05524,0.18734,0.920034,-2.07544,0.125025,0.887136,-2.07072,-0.070671,0.760807,-2.05015,-0.181897,0.793195,-1.99356,-0.032063,0.557009,-2.03327,-0.091915,0.582646,-2.0982,0.0646,1.29823,-1.80775,0.09161,1.29766,-2.02128},
/*711*/{0.212293,1.8714,-1.70761,0.26893,1.80508,-1.86029,0.160345,1.70743,-1.608,0.12496,1.58819,-1.54253,0.267231,1.60116,-1.61538,0.354403,1.60193,-1.6402,0.186813,1.89317,-2.09772,0.271462,1.8101,-1.93722,0.06235,1.86099,-1.99611,-0.044393,1.76453,-2.17065,-0.052981,1.66987,-2.22344,0.082022,1.54382,-2.16108,0.117033,1.48864,-2.17175,0.140807,1.38516,-1.7744,-0.035822,1.44984,-1.88166,-0.024945,1.47464,-1.9312,-0.021123,1.44458,-1.99445,0.174912,1.39229,-2.03929,0.086765,1.06888,-1.7414,-0.045257,1.06954,-1.77449,-0.046109,0.98558,-1.79724,0.009107,0.860527,-1.79094,-0.049242,0.680095,-1.79453,-0.08072,0.612933,-1.81186,-0.149987,0.728829,-1.80772,-0.179794,0.664898,-1.81956,-0.23762,0.446944,-1.84845,-0.350468,0.40058,-1.92836,-0.097492,0.379311,-1.88299,-0.132251,0.337917,-1.81269,0.298146,1.17686,-2.09736,0.354953,1.11674,-2.07959,0.19367,1.07937,-2.07707,0.251725,1.02109,-2.06052,0.373385,0.954445,-2.0579,0.245635,0.820521,-2.05648,0.194034,0.920734,-2.07534,0.133454,0.885054,-2.06956,-0.054473,0.746775,-2.04891,-0.169226,0.771687,-1.99224,-0.003508,0.547476,-2.03614,-0.062733,0.569935,-2.09916,0.064638,1.29985,-1.8081,0.092583,1.30149,-2.0215},
/*712*/{0.214089,1.87713,-1.70897,0.26971,1.80941,-1.86144,0.16554,1.71246,-1.60782,0.131092,1.59257,-1.54076,0.272047,1.60948,-1.61746,0.358817,1.61237,-1.64323,0.184443,1.89752,-2.09751,0.271435,1.8146,-1.93844,0.061507,1.86456,-1.99487,-0.04751,1.77131,-2.16908,-0.058481,1.67778,-2.22125,0.075571,1.55046,-2.16016,0.110917,1.49594,-2.17285,0.141874,1.38598,-1.77336,-0.035397,1.45348,-1.88022,-0.023516,1.47817,-1.92868,-0.02101,1.45005,-1.99401,0.175537,1.39675,-2.03799,0.082099,1.07025,-1.74328,-0.053324,1.07565,-1.77576,-0.054377,0.991143,-1.79853,-0.005466,0.865011,-1.79158,-0.06511,0.684732,-1.79498,-0.097645,0.617834,-1.81168,-0.166133,0.733548,-1.80875,-0.196123,0.670388,-1.82078,-0.255251,0.450873,-1.84652,-0.368749,0.408662,-1.92746,-0.116282,0.378464,-1.88282,-0.153286,0.337202,-1.81176,0.300361,1.18493,-2.09691,0.358537,1.12652,-2.07953,0.197886,1.08571,-2.07712,0.256653,1.02864,-2.06005,0.377915,0.96477,-2.05732,0.256249,0.82397,-2.05659,0.198887,0.920875,-2.0741,0.141014,0.881883,-2.06852,-0.039583,0.735007,-2.0473,-0.154423,0.749333,-1.98949,0.026463,0.537424,-2.03769,-0.036698,0.557554,-2.10105,0.064606,1.3017,-1.80859,0.092692,1.30623,-2.02194},
/*713*/{0.215923,1.88217,-1.71016,0.269335,1.81389,-1.86315,0.170082,1.71774,-1.60785,0.138088,1.5982,-1.54064,0.275714,1.61685,-1.61896,0.362133,1.62135,-1.64673,0.181902,1.90127,-2.097,0.271446,1.81925,-1.93934,0.060532,1.86782,-1.9933,-0.052085,1.77743,-2.16763,-0.064248,1.68501,-2.21965,0.069699,1.55746,-2.16013,0.104667,1.50308,-2.1739,0.142932,1.38697,-1.77253,-0.031972,1.45663,-1.87871,-0.02275,1.48192,-1.9269,-0.019739,1.45441,-1.99369,0.175903,1.40108,-2.0369,0.074936,1.07146,-1.74525,-0.058756,1.0808,-1.77556,-0.064037,0.998337,-1.79992,-0.021362,0.869272,-1.79151,-0.080506,0.689802,-1.79575,-0.114015,0.623766,-1.81297,-0.181158,0.739511,-1.80879,-0.212101,0.676086,-1.82091,-0.272181,0.45691,-1.84652,-0.386062,0.417824,-1.92681,-0.135549,0.377447,-1.8837,-0.174585,0.338337,-1.81332,0.303092,1.19321,-2.09673,0.362036,1.13471,-2.07893,0.201872,1.09217,-2.07761,0.258692,1.03539,-2.06032,0.381585,0.973331,-2.0568,0.267298,0.827597,-2.05808,0.2046,0.920485,-2.07323,0.148081,0.877839,-2.06729,-0.026227,0.723117,-2.04928,-0.1402,0.729353,-1.98795,0.055872,0.52907,-2.04027,-0.008884,0.545444,-2.10276,0.065442,1.30363,-1.80902,0.093357,1.31047,-2.02233},
/*714*/{0.216675,1.88805,-1.71199,0.269937,1.81806,-1.86391,0.174354,1.72321,-1.60828,0.143254,1.60272,-1.53989,0.279735,1.6252,-1.62142,0.365439,1.63031,-1.65,0.180399,1.90444,-2.09681,0.270952,1.82295,-1.94045,0.060089,1.87153,-1.99244,-0.054441,1.78353,-2.16538,-0.069972,1.6928,-2.21743,0.064256,1.56491,-2.16002,0.098982,1.51078,-2.17425,0.145155,1.38808,-1.77256,-0.03111,1.46035,-1.87777,-0.022051,1.48558,-1.92536,-0.018587,1.45974,-1.99217,0.176107,1.40547,-2.03616,0.070304,1.07386,-1.74786,-0.063161,1.08664,-1.77589,-0.07158,1.0041,-1.79919,-0.036584,0.876257,-1.79168,-0.095313,0.695679,-1.79532,-0.128571,0.630273,-1.81118,-0.196148,0.745849,-1.80916,-0.225902,0.68244,-1.8189,-0.289716,0.463253,-1.84553,-0.403534,0.426801,-1.92596,-0.154589,0.376601,-1.88344,-0.195037,0.338769,-1.81345,0.305121,1.20114,-2.09689,0.364845,1.14487,-2.07767,0.205246,1.09956,-2.07761,0.262346,1.04255,-2.06019,0.384294,0.983035,-2.05725,0.276354,0.829292,-2.05805,0.209553,0.920236,-2.07141,0.154585,0.872934,-2.06559,-0.005248,0.70758,-2.04453,-0.123514,0.706597,-1.98578,0.084705,0.521551,-2.04272,0.019442,0.535055,-2.10426,0.066228,1.3058,-1.80979,0.093477,1.31518,-2.02309},
/*715*/{0.217996,1.89277,-1.71338,0.270252,1.82256,-1.86551,0.178498,1.72874,-1.60822,0.148399,1.60839,-1.53943,0.282837,1.63221,-1.62329,0.367618,1.63917,-1.65309,0.180314,1.90859,-2.09672,0.270048,1.8271,-1.94203,0.060128,1.87535,-1.99187,-0.057212,1.79053,-2.16364,-0.074799,1.70042,-2.21534,0.059253,1.57207,-2.15945,0.093541,1.51748,-2.17484,0.146059,1.38842,-1.77218,-0.029756,1.46378,-1.877,-0.020343,1.48941,-1.92299,-0.017777,1.46428,-1.99143,0.175662,1.40989,-2.03544,0.064298,1.0759,-1.74833,-0.069614,1.09443,-1.77668,-0.079348,1.01038,-1.80088,-0.050231,0.882468,-1.7925,-0.109566,0.701774,-1.79494,-0.143898,0.635953,-1.81125,-0.209935,0.753435,-1.80906,-0.241256,0.690128,-1.82019,-0.304154,0.467228,-1.84331,-0.41984,0.437109,-1.92455,-0.174396,0.376233,-1.88384,-0.215413,0.339155,-1.81397,0.306664,1.20914,-2.09708,0.366822,1.15189,-2.07715,0.207933,1.10565,-2.07727,0.265801,1.05007,-2.05899,0.386447,0.991123,-2.0568,0.284475,0.830277,-2.05848,0.21392,0.919038,-2.07031,0.163142,0.868924,-2.06429,0.01196,0.694528,-2.04333,-0.105776,0.683413,-1.98222,0.114436,0.515216,-2.04541,0.046873,0.524905,-2.10549,0.066293,1.30741,-1.81077,0.09325,1.31966,-2.02396},
/*716*/{0.220143,1.89877,-1.7145,0.271611,1.82687,-1.86717,0.181596,1.73376,-1.6087,0.152397,1.6131,-1.53913,0.28596,1.63986,-1.62475,0.369599,1.64777,-1.65622,0.178921,1.91206,-2.0966,0.270558,1.83152,-1.94283,0.059566,1.87854,-1.99091,-0.060341,1.79686,-2.16072,-0.079123,1.70748,-2.21245,0.054375,1.57823,-2.15878,0.088644,1.52385,-2.17527,0.148882,1.38942,-1.77423,-0.027548,1.46729,-1.87532,-0.018587,1.49294,-1.92078,-0.016278,1.46947,-1.99042,0.176689,1.41501,-2.03524,0.061615,1.07838,-1.75052,-0.074313,1.09902,-1.77651,-0.08703,1.01738,-1.79975,-0.061827,0.889205,-1.79226,-0.123497,0.708775,-1.79419,-0.15787,0.643221,-1.80943,-0.222684,0.760135,-1.80918,-0.255024,0.697497,-1.82001,-0.321405,0.473349,-1.84243,-0.434736,0.447875,-1.92447,-0.193014,0.375657,-1.88389,-0.236664,0.339396,-1.81378,0.30837,1.21581,-2.09651,0.368823,1.15962,-2.07663,0.210175,1.11175,-2.07803,0.270156,1.05812,-2.05854,0.386961,0.999176,-2.05673,0.296931,0.834849,-2.05881,0.218022,0.915458,-2.06861,0.170605,0.863984,-2.06286,0.028957,0.679909,-2.04171,-0.085648,0.662063,-1.98028,0.144861,0.509952,-2.04742,0.076031,0.51558,-2.10685,0.068484,1.30923,-1.81255,0.09405,1.32496,-2.02568},
/*717*/{0.221319,1.90333,-1.71507,0.272682,1.83147,-1.86829,0.185092,1.73925,-1.60832,0.156389,1.6183,-1.53806,0.287595,1.64657,-1.62619,0.371382,1.65584,-1.65925,0.178063,1.91476,-2.09703,0.270566,1.83546,-1.94403,0.059513,1.88154,-1.98962,-0.06044,1.80413,-2.15746,-0.083503,1.7145,-2.20987,0.049815,1.5851,-2.15832,0.084271,1.53016,-2.17545,0.151673,1.38991,-1.7752,-0.025363,1.47111,-1.8746,-0.017037,1.4969,-1.91912,-0.014988,1.47433,-1.98893,0.176657,1.42018,-2.03505,0.05441,1.08165,-1.75286,-0.07527,1.10703,-1.77477,-0.094249,1.02609,-1.80069,-0.071699,0.895522,-1.79242,-0.136449,0.715908,-1.79317,-0.171131,0.651017,-1.80849,-0.235382,0.768158,-1.80973,-0.267809,0.705236,-1.81852,-0.335146,0.480091,-1.84001,-0.4499,0.459645,-1.9231,-0.211471,0.376332,-1.88335,-0.257305,0.339954,-1.81439,0.309345,1.22223,-2.09668,0.370499,1.16697,-2.07586,0.211942,1.11811,-2.07889,0.272597,1.06505,-2.05816,0.386898,1.00672,-2.05665,0.306792,0.836647,-2.05903,0.223282,0.914218,-2.06718,0.178768,0.857941,-2.06101,0.046876,0.666499,-2.04041,-0.065727,0.638638,-1.97717,0.17396,0.504059,-2.04851,0.104964,0.506683,-2.10743,0.070019,1.31113,-1.81424,0.094309,1.33013,-2.02725},
/*718*/{0.221956,1.90784,-1.7167,0.27273,1.8351,-1.86944,0.187643,1.74421,-1.60851,0.160332,1.62342,-1.53777,0.289327,1.65362,-1.62795,0.373258,1.66298,-1.66254,0.177073,1.9176,-2.09734,0.270518,1.839,-1.94484,0.059528,1.88494,-1.98958,-0.063078,1.81067,-2.1547,-0.087244,1.72164,-2.20764,0.045809,1.59089,-2.15781,0.079629,1.53631,-2.17578,0.153686,1.39155,-1.77544,-0.023132,1.47506,-1.87241,-0.015895,1.50052,-1.91677,-0.013648,1.47906,-1.98791,0.1775,1.42538,-2.03569,0.05211,1.08335,-1.75324,-0.080301,1.11425,-1.77564,-0.100033,1.03408,-1.80056,-0.08088,0.902029,-1.79192,-0.147908,0.723332,-1.79199,-0.183249,0.658635,-1.80597,-0.246513,0.776755,-1.80846,-0.279049,0.713466,-1.81716,-0.349112,0.48688,-1.8374,-0.4631,0.47212,-1.92196,-0.231059,0.375831,-1.88353,-0.277919,0.34061,-1.81461,0.309953,1.22881,-2.09614,0.371261,1.17344,-2.07532,0.213577,1.12347,-2.07847,0.272852,1.07087,-2.05809,0.385592,1.01332,-2.05703,0.314952,0.83777,-2.05918,0.22728,0.909495,-2.06527,0.186719,0.852315,-2.06009,0.065968,0.652458,-2.03873,-0.043795,0.618134,-1.974,0.202879,0.499952,-2.04946,0.133908,0.497461,-2.10697,0.071877,1.31359,-1.81521,0.094846,1.33529,-2.02812},
/*719*/{0.224586,1.91265,-1.71777,0.274375,1.84011,-1.8717,0.18983,1.74883,-1.60804,0.164533,1.62857,-1.53778,0.290542,1.65988,-1.62979,0.374008,1.67018,-1.66581,0.177384,1.92043,-2.09707,0.270914,1.84246,-1.94573,0.059973,1.88916,-1.98947,-0.0664,1.81937,-2.15067,-0.090997,1.72851,-2.20463,0.042508,1.59654,-2.15626,0.075663,1.54187,-2.1756,0.156262,1.39234,-1.77659,-0.021419,1.47831,-1.87085,-0.0152,1.50418,-1.91553,-0.012154,1.48445,-1.98649,0.177043,1.42982,-2.03593,0.048094,1.08653,-1.75427,-0.084745,1.12042,-1.77556,-0.105081,1.04118,-1.8008,-0.08923,0.908403,-1.7915,-0.158691,0.730698,-1.79055,-0.194389,0.664759,-1.80436,-0.256911,0.78458,-1.80796,-0.290695,0.721178,-1.81787,-0.362609,0.49378,-1.83622,-0.475439,0.485391,-1.91891,-0.25049,0.375468,-1.88324,-0.297934,0.34268,-1.81449,0.310519,1.23483,-2.09578,0.371743,1.17914,-2.0741,0.213134,1.12898,-2.07813,0.273002,1.07667,-2.05839,0.384962,1.01875,-2.0567,0.324849,0.838695,-2.06004,0.232708,0.90509,-2.06335,0.194632,0.846111,-2.05879,0.082793,0.638712,-2.0384,-0.022391,0.597978,-1.97259,0.231304,0.496031,-2.0492,0.162408,0.489651,-2.1067,0.073088,1.31556,-1.81679,0.094494,1.34017,-2.02954},
/*720*/{0.226185,1.9165,-1.71877,0.273943,1.84319,-1.87184,0.192119,1.75393,-1.60844,0.166667,1.63243,-1.53651,0.29224,1.66532,-1.63102,0.374437,1.67672,-1.66804,0.176659,1.92343,-2.0969,0.271408,1.84569,-1.94575,0.059938,1.89235,-1.98843,-0.067561,1.82534,-2.14652,-0.094108,1.7346,-2.20151,0.03822,1.6017,-2.15609,0.071866,1.54624,-2.17513,0.158984,1.39378,-1.77845,-0.019153,1.4823,-1.86974,-0.01333,1.50791,-1.91242,-0.010155,1.48904,-1.98526,0.177867,1.434,-2.03643,0.045076,1.08972,-1.75443,-0.085037,1.12875,-1.77613,-0.11017,1.0495,-1.80051,-0.096462,0.915342,-1.79008,-0.16848,0.738385,-1.78887,-0.204368,0.672932,-1.80258,-0.266479,0.791755,-1.80726,-0.299227,0.729562,-1.81567,-0.37482,0.500937,-1.83349,-0.485223,0.499636,-1.91744,-0.269224,0.37629,-1.88295,-0.318049,0.344797,-1.81479,0.311101,1.23971,-2.09495,0.371636,1.18409,-2.07358,0.213528,1.13478,-2.07898,0.272398,1.08206,-2.06049,0.383491,1.02297,-2.0562,0.332707,0.83881,-2.06013,0.237038,0.900107,-2.06215,0.203243,0.838199,-2.05597,0.102163,0.628031,-2.0408,0.001658,0.578153,-1.97124,0.2605,0.493271,-2.04771,0.191374,0.48231,-2.10514,0.075061,1.31783,-1.81806,0.094695,1.34491,-2.03068},
/*721*/{0.227341,1.91983,-1.71992,0.275837,1.84767,-1.87337,0.19328,1.7581,-1.60882,0.16873,1.6367,-1.5362,0.292793,1.66988,-1.63257,0.374892,1.6822,-1.6698,0.176898,1.92624,-2.09716,0.271661,1.84931,-1.94741,0.06004,1.89567,-1.98804,-0.068197,1.83101,-2.14199,-0.096617,1.74076,-2.19857,0.036017,1.60719,-2.15515,0.068353,1.55125,-2.17456,0.161093,1.3951,-1.77876,-0.017346,1.48576,-1.86808,-0.011424,1.51157,-1.91136,-0.008517,1.49422,-1.98361,0.177191,1.43849,-2.03621,0.04185,1.09201,-1.7535,-0.087048,1.13505,-1.77561,-0.114204,1.05628,-1.80083,-0.104692,0.922408,-1.79116,-0.176802,0.745212,-1.78762,-0.212914,0.680441,-1.79973,-0.274796,0.798977,-1.80612,-0.309289,0.736263,-1.81523,-0.38538,0.508784,-1.83119,-0.496153,0.514766,-1.91438,-0.28693,0.377481,-1.88216,-0.338197,0.347479,-1.81442,0.310864,1.24484,-2.0947,0.37189,1.18786,-2.07266,0.212875,1.1401,-2.07937,0.271599,1.08638,-2.06231,0.382867,1.02536,-2.05622,0.340218,0.838389,-2.06026,0.242513,0.894437,-2.06078,0.211363,0.83127,-2.05524,0.12397,0.614455,-2.03688,0.023905,0.558776,-1.96976,0.288953,0.490331,-2.04659,0.220382,0.475686,-2.10406,0.076129,1.32023,-1.81897,0.094545,1.34963,-2.03139},
/*722*/{0.22914,1.9235,-1.72054,0.276721,1.85083,-1.87413,0.196119,1.76281,-1.60871,0.170697,1.64081,-1.53602,0.2927,1.67459,-1.63429,0.375207,1.68731,-1.67272,0.175795,1.92836,-2.0963,0.271949,1.85228,-1.94744,0.060373,1.8976,-1.987,-0.068671,1.8361,-2.13875,-0.098932,1.74636,-2.19541,0.03373,1.61166,-2.15439,0.06573,1.55592,-2.17406,0.163272,1.39705,-1.78001,-0.015283,1.48891,-1.86582,-0.011734,1.51575,-1.90846,-0.007504,1.49811,-1.98209,0.178052,1.44273,-2.03699,0.038224,1.09594,-1.75236,-0.09045,1.14176,-1.77696,-0.116962,1.0638,-1.80011,-0.110865,0.929554,-1.79006,-0.184998,0.752234,-1.78609,-0.222793,0.686762,-1.79853,-0.281955,0.806856,-1.80449,-0.315641,0.743943,-1.81159,-0.396569,0.517081,-1.82847,-0.504542,0.529395,-1.91164,-0.304632,0.378859,-1.88183,-0.358216,0.35105,-1.81417,0.310629,1.24808,-2.09336,0.370545,1.19067,-2.0719,0.21137,1.14416,-2.08008,0.26977,1.09029,-2.06379,0.38085,1.02716,-2.05721,0.348198,0.838239,-2.05992,0.247363,0.889163,-2.06077,0.219367,0.824445,-2.05488,0.146128,0.602194,-2.0337,0.047106,0.541611,-1.96848,0.316942,0.488659,-2.04408,0.249838,0.469379,-2.10186,0.078003,1.3227,-1.8197,0.094413,1.35427,-2.03197},
/*723*/{0.230843,1.92703,-1.72106,0.27722,1.85415,-1.8749,0.197389,1.76616,-1.60875,0.173615,1.6444,-1.53525,0.293036,1.67849,-1.63491,0.374856,1.69168,-1.67523,0.176214,1.93097,-2.09629,0.273067,1.85558,-1.94782,0.062794,1.89897,-1.98629,-0.067264,1.83621,-2.13291,-0.100625,1.75162,-2.19279,0.031622,1.61558,-2.15272,0.063312,1.55978,-2.17359,0.165397,1.39897,-1.78075,-0.014201,1.49243,-1.86389,-0.011508,1.51909,-1.90703,-0.006468,1.50342,-1.98058,0.177417,1.44643,-2.03728,0.035285,1.09945,-1.75174,-0.091406,1.14721,-1.77527,-0.120141,1.06898,-1.80033,-0.115878,0.935456,-1.79001,-0.190353,0.758708,-1.78502,-0.227693,0.694753,-1.79731,-0.286876,0.814651,-1.80262,-0.32211,0.751906,-1.81042,-0.404602,0.524812,-1.82457,-0.51183,0.547736,-1.90915,-0.321616,0.380423,-1.88105,-0.378444,0.356214,-1.81403,0.31008,1.25118,-2.09295,0.369125,1.19311,-2.07155,0.209694,1.14766,-2.0809,0.267704,1.09331,-2.06454,0.379327,1.02812,-2.05763,0.354951,0.837541,-2.06069,0.252637,0.883989,-2.06088,0.22789,0.816642,-2.0534,0.163671,0.589414,-2.03293,0.072633,0.523664,-1.96648,0.343007,0.48795,-2.04091,0.278008,0.463306,-2.0988,0.078871,1.3254,-1.82027,0.093552,1.35863,-2.03242},
/*724*/{0.231963,1.92953,-1.72177,0.278222,1.85634,-1.87563,0.198707,1.76993,-1.60845,0.173814,1.64704,-1.53499,0.293467,1.68227,-1.63601,0.37445,1.69491,-1.67694,0.175981,1.93319,-2.09599,0.273882,1.85797,-1.94881,0.063607,1.90136,-1.98615,-0.06742,1.84088,-2.13,-0.102788,1.75632,-2.19012,0.02996,1.61927,-2.15143,0.060676,1.5627,-2.17335,0.16684,1.40106,-1.78206,-0.012946,1.4955,-1.86266,-0.010084,1.5231,-1.90514,-0.006347,1.50738,-1.97839,0.177084,1.44984,-2.0371,0.033462,1.10404,-1.75121,-0.09191,1.15168,-1.77502,-0.121725,1.0746,-1.80014,-0.118889,0.940622,-1.79037,-0.194966,0.764812,-1.78353,-0.233567,0.700638,-1.79494,-0.291291,0.820622,-1.80135,-0.327463,0.758389,-1.80754,-0.412214,0.533691,-1.82191,-0.518724,0.564446,-1.90472,-0.340166,0.383058,-1.88084,-0.397318,0.361662,-1.81481,0.309086,1.2527,-2.0916,0.367865,1.19448,-2.07121,0.207417,1.15047,-2.08099,0.26554,1.09504,-2.0648,0.377327,1.02859,-2.05902,0.362525,0.835865,-2.06096,0.256557,0.876577,-2.05961,0.234675,0.808646,-2.05228,0.182021,0.577936,-2.03156,0.094278,0.507399,-1.9664,0.368926,0.487276,-2.03727,0.306754,0.458725,-2.09551,0.079695,1.32797,-1.82062,0.092696,1.36261,-2.03265},
/*725*/{0.233899,1.93227,-1.72245,0.279366,1.86042,-1.87679,0.199921,1.77295,-1.60869,0.175425,1.6501,-1.53375,0.293731,1.68462,-1.63648,0.374377,1.69752,-1.67928,0.176057,1.93518,-2.09578,0.27432,1.86022,-1.9494,0.064349,1.90406,-1.98528,-0.067302,1.8439,-2.12551,-0.104106,1.7602,-2.18719,0.028466,1.62267,-2.15083,0.058555,1.56589,-2.17253,0.167858,1.40359,-1.78206,-0.011419,1.49865,-1.8602,-0.009093,1.52609,-1.90352,-0.004879,1.51053,-1.97614,0.177556,1.45382,-2.03732,0.033545,1.10622,-1.75053,-0.091122,1.15487,-1.77159,-0.121962,1.07841,-1.80176,-0.119529,0.944556,-1.7902,-0.199399,0.769845,-1.78329,-0.238158,0.705794,-1.79358,-0.294647,0.827752,-1.79846,-0.330663,0.76625,-1.80518,-0.419225,0.541893,-1.8178,-0.523084,0.582507,-1.89996,-0.358269,0.386643,-1.88215,-0.417129,0.367953,-1.81644,0.307551,1.25385,-2.09086,0.364931,1.19467,-2.07119,0.205383,1.1521,-2.08116,0.26286,1.09543,-2.06523,0.375083,1.02788,-2.05992,0.368275,0.833818,-2.06098,0.261098,0.869647,-2.05967,0.243021,0.801522,-2.05241,0.203852,0.568136,-2.03204,0.119035,0.491624,-1.96614,0.394886,0.487116,-2.03304,0.334218,0.453696,-2.0915,0.081211,1.33058,-1.82036,0.092995,1.36645,-2.03226},
/*726*/{0.235106,1.93427,-1.72275,0.279109,1.86256,-1.87662,0.200808,1.77586,-1.60834,0.175665,1.6519,-1.5333,0.293909,1.68702,-1.63756,0.374181,1.70006,-1.68098,0.175228,1.93698,-2.09558,0.274723,1.86248,-1.94945,0.06534,1.90577,-1.98401,-0.06778,1.84785,-2.12309,-0.105862,1.76351,-2.18501,0.027012,1.6252,-2.15003,0.057213,1.56844,-2.17204,0.169352,1.40592,-1.78314,-0.010226,1.5021,-1.85859,-0.008582,1.52951,-1.90266,-0.004555,1.5138,-1.97451,0.177228,1.45668,-2.03734,0.031122,1.11083,-1.74838,-0.090683,1.15845,-1.77564,-0.123828,1.08203,-1.80106,-0.119333,0.948285,-1.7906,-0.2021,0.774562,-1.78249,-0.243458,0.711739,-1.79145,-0.296169,0.833962,-1.7972,-0.334689,0.773809,-1.80254,-0.426192,0.550993,-1.81496,-0.527714,0.600652,-1.89334,-0.376196,0.392098,-1.88405,-0.436781,0.375622,-1.81845,0.305876,1.25346,-2.09045,0.362584,1.19344,-2.07153,0.202497,1.15307,-2.08143,0.258855,1.09661,-2.0667,0.371786,1.02626,-2.06125,0.374003,0.831538,-2.06144,0.265302,0.861555,-2.05821,0.250101,0.794692,-2.05267,0.222878,0.557691,-2.03319,0.141437,0.477423,-1.96529,0.418281,0.487599,-2.02816,0.360169,0.449769,-2.08693,0.082071,1.33336,-1.82026,0.092179,1.36969,-2.03216},
/*727*/{0.237265,1.93567,-1.7227,0.280944,1.86475,-1.87725,0.201299,1.7783,-1.60821,0.176673,1.65493,-1.53306,0.293646,1.68808,-1.63887,0.37383,1.70126,-1.68329,0.176522,1.93891,-2.0958,0.275372,1.86441,-1.95072,0.065417,1.90854,-1.98335,-0.068424,1.85067,-2.12119,-0.106252,1.76612,-2.18238,0.026483,1.62722,-2.14845,0.055497,1.57021,-2.17184,0.170794,1.40899,-1.78321,-0.010215,1.50467,-1.85739,-0.008814,1.53244,-1.90222,-0.004349,1.51718,-1.97282,0.177052,1.45924,-2.03694,0.031148,1.11428,-1.74892,-0.09354,1.16129,-1.77742,-0.123466,1.08518,-1.80102,-0.11846,0.950448,-1.79045,-0.203832,0.778058,-1.78212,-0.245923,0.7172,-1.79098,-0.297275,0.840341,-1.79483,-0.337067,0.781138,-1.79961,-0.432504,0.560518,-1.81273,-0.531284,0.618422,-1.88514,-0.394136,0.399848,-1.88609,-0.454008,0.383663,-1.8218,0.303109,1.25274,-2.09071,0.359779,1.19166,-2.07159,0.198782,1.15354,-2.08157,0.254322,1.09544,-2.06667,0.369364,1.02445,-2.06255,0.379228,0.829175,-2.06266,0.26843,0.854334,-2.05868,0.257049,0.785022,-2.05155,0.242381,0.547948,-2.02947,0.164148,0.463845,-1.96388,0.44012,0.48899,-2.02412,0.386526,0.446336,-2.08221,0.082889,1.33631,-1.81956,0.091918,1.37257,-2.03153},
/*728*/{0.237986,1.9372,-1.72301,0.280955,1.86681,-1.87784,0.201833,1.78045,-1.60826,0.176813,1.65661,-1.53229,0.293614,1.68937,-1.63946,0.3728,1.70187,-1.68491,0.176031,1.94089,-2.09585,0.275759,1.86621,-1.95094,0.066156,1.90937,-1.98305,-0.068002,1.8518,-2.11749,-0.106932,1.76833,-2.18052,0.025109,1.62881,-2.14736,0.055163,1.57144,-2.171,0.17047,1.41135,-1.78318,-0.008791,1.50719,-1.856,-0.008036,1.53561,-1.90057,-0.004552,1.51977,-1.97168,0.176388,1.46139,-2.03659,0.032716,1.116,-1.74881,-0.09347,1.16269,-1.777,-0.121447,1.08623,-1.80151,-0.117167,0.95165,-1.79149,-0.205169,0.782014,-1.78163,-0.249346,0.72049,-1.79088,-0.296732,0.845858,-1.79205,-0.337711,0.787661,-1.79676,-0.440322,0.569302,-1.81106,-0.534354,0.634656,-1.87538,-0.412203,0.408598,-1.89002,-0.472151,0.392088,-1.82556,0.300608,1.25051,-2.09049,0.356261,1.18857,-2.07183,0.195315,1.15296,-2.0818,0.249236,1.09437,-2.06701,0.366165,1.02163,-2.064,0.383354,0.826681,-2.06295,0.271565,0.84693,-2.0601,0.262898,0.778073,-2.05395,0.261688,0.539236,-2.0287,0.184616,0.453328,-1.96269,0.461111,0.490123,-2.01918,0.410554,0.44252,-2.07713,0.082854,1.33875,-1.81879,0.090896,1.37504,-2.0308},
/*729*/{0.239593,1.93796,-1.72319,0.282637,1.86935,-1.87903,0.202534,1.7821,-1.60812,0.176956,1.65778,-1.53184,0.29336,1.68972,-1.63986,0.372665,1.70238,-1.68618,0.176674,1.94203,-2.09599,0.276367,1.86766,-1.95123,0.066268,1.91214,-1.98303,-0.068263,1.85407,-2.11645,-0.107606,1.76979,-2.17889,0.02522,1.62989,-2.14682,0.054061,1.5728,-2.17075,0.171488,1.41419,-1.78315,-0.008767,1.50941,-1.85525,-0.007967,1.53799,-1.89993,-0.00444,1.5215,-1.96988,0.17634,1.46374,-2.03661,0.033199,1.11738,-1.74921,-0.091043,1.16349,-1.77673,-0.119776,1.08708,-1.80174,-0.11429,0.95218,-1.7909,-0.205398,0.783712,-1.78173,-0.251355,0.724088,-1.79112,-0.295133,0.85094,-1.78995,-0.337409,0.794546,-1.7938,-0.445527,0.577801,-1.80856,-0.537585,0.65139,-1.86651,-0.430335,0.418538,-1.89522,-0.490162,0.403687,-1.8284,0.297973,1.24771,-2.09053,0.352579,1.185,-2.07244,0.190053,1.15253,-2.08178,0.245067,1.09253,-2.06741,0.362831,1.01795,-2.06519,0.386932,0.824027,-2.06352,0.274678,0.838685,-2.06171,0.268506,0.769627,-2.05423,0.279061,0.530731,-2.02781,0.205938,0.441903,-1.96194,0.481611,0.490952,-2.01475,0.433877,0.43955,-2.07132,0.083929,1.34124,-1.81802,0.090882,1.37724,-2.03011},
/*730*/{0.240651,1.93888,-1.72322,0.282995,1.8704,-1.87884,0.202266,1.78334,-1.60838,0.176735,1.65879,-1.53183,0.293287,1.68955,-1.64066,0.372663,1.70002,-1.68713,0.1768,1.94389,-2.09613,0.277283,1.86826,-1.95186,0.067972,1.91349,-1.98193,-0.068635,1.8547,-2.11423,-0.107797,1.77064,-2.1769,0.025294,1.63066,-2.14616,0.054083,1.57316,-2.17037,0.171868,1.4169,-1.78251,-0.008019,1.51212,-1.85401,-0.008983,1.54065,-1.8993,-0.005286,1.5235,-1.96832,0.176513,1.46488,-2.0366,0.037122,1.11817,-1.74914,-0.087077,1.16483,-1.77579,-0.116485,1.08691,-1.80047,-0.110079,0.951941,-1.79203,-0.204931,0.785571,-1.78179,-0.252624,0.727436,-1.79152,-0.292535,0.855811,-1.78675,-0.336463,0.799383,-1.79059,-0.450885,0.588703,-1.80657,-0.543356,0.667597,-1.85722,-0.446105,0.432707,-1.90011,-0.502872,0.415592,-1.83137,0.294443,1.24354,-2.09147,0.348375,1.18091,-2.07278,0.18603,1.14973,-2.08206,0.239089,1.08973,-2.0674,0.359155,1.01391,-2.06568,0.389947,0.820599,-2.06319,0.276784,0.8312,-2.06491,0.275314,0.761577,-2.05555,0.295869,0.522827,-2.02693,0.225869,0.432561,-1.96018,0.499936,0.491874,-2.01076,0.45534,0.436984,-2.06681,0.08413,1.34399,-1.81646,0.090049,1.37877,-2.02878},
/*731*/{0.241274,1.9391,-1.7236,0.283724,1.87173,-1.87985,0.202557,1.78375,-1.60861,0.176552,1.65894,-1.53107,0.292992,1.6882,-1.6412,0.37193,1.69828,-1.68799,0.177576,1.94477,-2.09627,0.277948,1.86918,-1.95301,0.067535,1.91602,-1.98207,-0.069077,1.85499,-2.11308,-0.108139,1.77057,-2.17492,0.025018,1.63016,-2.14491,0.053649,1.57287,-2.16953,0.17223,1.41905,-1.78217,-0.007532,1.51273,-1.85259,-0.009577,1.54235,-1.89895,-0.005018,1.52476,-1.96756,0.176176,1.46644,-2.03613,0.04165,1.11797,-1.75107,-0.086171,1.16144,-1.77571,-0.112523,1.08543,-1.7994,-0.104865,0.951064,-1.7919,-0.203599,0.78573,-1.78317,-0.255245,0.729875,-1.79197,-0.289253,0.858779,-1.78474,-0.335307,0.805403,-1.78767,-0.456704,0.599557,-1.80511,-0.548608,0.682821,-1.84808,-0.461912,0.446481,-1.90392,-0.516105,0.42954,-1.83399,0.291651,1.24006,-2.09162,0.343948,1.17636,-2.07342,0.180479,1.14792,-2.08247,0.233076,1.08709,-2.06748,0.354531,1.00927,-2.06656,0.392135,0.818651,-2.06308,0.278458,0.824224,-2.06707,0.280206,0.752594,-2.05721,0.309395,0.514805,-2.02519,0.244471,0.4241,-1.95793,0.516232,0.492675,-2.00673,0.475478,0.434541,-2.0618,0.084867,1.34561,-1.81567,0.090141,1.38016,-2.02805},
/*732*/{0.242029,1.93862,-1.72382,0.28352,1.87236,-1.88082,0.202827,1.7842,-1.60858,0.176487,1.65941,-1.53091,0.292262,1.68719,-1.64162,0.371215,1.69566,-1.68873,0.177694,1.94579,-2.09651,0.27827,1.8704,-1.95285,0.068779,1.91562,-1.98194,-0.069203,1.85499,-2.11123,-0.107822,1.77066,-2.17446,0.025697,1.62971,-2.14444,0.054353,1.57149,-2.16908,0.172736,1.42077,-1.78161,-0.007539,1.51422,-1.85189,-0.009434,1.54387,-1.89863,-0.005139,1.52497,-1.96689,0.176073,1.46669,-2.03595,0.048113,1.11713,-1.75062,-0.082164,1.16178,-1.7747,-0.107957,1.08281,-1.79799,-0.099277,0.949074,-1.79252,-0.203031,0.785735,-1.78412,-0.25593,0.732471,-1.7938,-0.284424,0.863221,-1.78187,-0.333496,0.812091,-1.78596,-0.462708,0.610916,-1.80428,-0.554054,0.697422,-1.8393,-0.4743,0.461319,-1.90946,-0.526462,0.442958,-1.83615,0.287618,1.23593,-2.09181,0.339329,1.17066,-2.07386,0.175211,1.1457,-2.08082,0.227891,1.08327,-2.067,0.349605,1.00349,-2.06692,0.394657,0.815895,-2.06201,0.281144,0.815982,-2.06808,0.285895,0.746193,-2.05832,0.32624,0.509658,-2.02479,0.263694,0.416547,-1.95582,0.53099,0.49459,-2.00381,0.493612,0.433195,-2.05712,0.085221,1.34724,-1.8143,0.089842,1.38043,-2.02691},
/*733*/{0.243823,1.93848,-1.7233,0.283962,1.87342,-1.8812,0.202855,1.7841,-1.60871,0.175366,1.65916,-1.53044,0.291955,1.68498,-1.64237,0.370137,1.6925,-1.68921,0.178642,1.9464,-2.09638,0.278726,1.87073,-1.95308,0.069944,1.9177,-1.98079,-0.069185,1.85489,-2.11083,-0.107495,1.76995,-2.17186,0.025994,1.6285,-2.14359,0.054874,1.57088,-2.16873,0.173196,1.42277,-1.78143,-0.007713,1.51459,-1.85176,-0.008567,1.54484,-1.89912,-0.005303,1.52495,-1.9664,0.1761,1.46737,-2.03535,0.053163,1.11527,-1.75208,-0.077105,1.15983,-1.77305,-0.102249,1.07959,-1.79703,-0.091991,0.946785,-1.79275,-0.200549,0.786141,-1.78482,-0.257533,0.735715,-1.79448,-0.279085,0.867205,-1.77951,-0.330536,0.817347,-1.78245,-0.467313,0.622321,-1.80293,-0.559712,0.712387,-1.83167,-0.48612,0.478438,-1.91246,-0.535766,0.458146,-1.83873,0.283861,1.23068,-2.09251,0.334994,1.16502,-2.07412,0.170488,1.14282,-2.08044,0.221463,1.07877,-2.06617,0.344601,0.998791,-2.06709,0.397294,0.8138,-2.06046,0.283105,0.80851,-2.06958,0.29052,0.739027,-2.05885,0.339808,0.503784,-2.02324,0.279007,0.410042,-1.95782,0.545022,0.49559,-2.00033,0.51002,0.431732,-2.05317,0.086064,1.34857,-1.81341,0.090436,1.38074,-2.02618},
/*734*/{0.244451,1.93762,-1.72333,0.28384,1.87345,-1.88121,0.20232,1.78355,-1.60859,0.173444,1.6584,-1.5313,0.290428,1.68301,-1.64262,0.370007,1.68868,-1.68985,0.178729,1.94667,-2.09637,0.278812,1.87075,-1.95322,0.070323,1.9181,-1.98091,-0.067924,1.85363,-2.10991,-0.106362,1.76883,-2.1712,0.027406,1.62786,-2.14319,0.055191,1.56826,-2.16893,0.173156,1.42366,-1.78103,-0.007914,1.51498,-1.85206,-0.008634,1.54536,-1.89941,-0.005481,1.52478,-1.96605,0.176267,1.46751,-2.03481,0.058436,1.11344,-1.75481,-0.072306,1.15509,-1.77141,-0.096812,1.07598,-1.79588,-0.084279,0.943111,-1.794,-0.199626,0.786013,-1.78582,-0.257575,0.738797,-1.79543,-0.272688,0.870872,-1.77579,-0.327392,0.823794,-1.77988,-0.474138,0.634549,-1.80267,-0.564476,0.727755,-1.82497,-0.496724,0.494692,-1.91273,-0.544022,0.472708,-1.83997,0.279715,1.22562,-2.09292,0.330181,1.15878,-2.07492,0.165106,1.13942,-2.07922,0.214449,1.07502,-2.06588,0.338601,0.993162,-2.06723,0.398397,0.811249,-2.05829,0.286139,0.801305,-2.07137,0.295616,0.733202,-2.0607,0.35109,0.498397,-2.02216,0.291002,0.404168,-1.95259,0.556412,0.497542,-1.99728,0.522499,0.430805,-2.0492,0.086119,1.34927,-1.81277,0.090714,1.38075,-2.02564},
/*735*/{0.244714,1.93713,-1.72345,0.283723,1.8736,-1.8814,0.201641,1.78276,-1.60917,0.172588,1.65833,-1.53187,0.290055,1.6799,-1.64307,0.369342,1.684,-1.69046,0.17918,1.94672,-2.09646,0.278899,1.87074,-1.95335,0.070566,1.91824,-1.98146,-0.067185,1.85319,-2.10929,-0.10529,1.76719,-2.16993,0.029702,1.62488,-2.14237,0.05575,1.56646,-2.1682,0.173207,1.42465,-1.78072,-0.008051,1.51461,-1.85207,-0.008634,1.54536,-1.89941,-0.006162,1.52366,-1.96594,0.17674,1.4672,-2.03409,0.063532,1.11144,-1.75663,-0.06684,1.15136,-1.76922,-0.090813,1.07237,-1.79447,-0.075975,0.939295,-1.79477,-0.198051,0.786842,-1.78631,-0.258139,0.742338,-1.796,-0.266931,0.874847,-1.77333,-0.32305,0.830254,-1.7779,-0.480152,0.648699,-1.80131,-0.567988,0.743747,-1.82058,-0.504907,0.511491,-1.91455,-0.55299,0.488462,-1.84026,0.275938,1.22004,-2.09348,0.325048,1.15285,-2.07526,0.15973,1.13531,-2.07904,0.20901,1.07096,-2.06525,0.33162,0.987397,-2.06694,0.399361,0.808198,-2.05534,0.287999,0.794955,-2.07277,0.29913,0.727197,-2.06136,0.360847,0.495132,-2.02122,0.303472,0.400981,-1.94995,0.565866,0.497258,-1.99474,0.534918,0.429812,-2.04584,0.086659,1.34966,-1.81181,0.091304,1.38012,-2.02483},
/*736*/{0.245032,1.93619,-1.72353,0.283661,1.87314,-1.88146,0.20052,1.78188,-1.60907,0.170203,1.6573,-1.53165,0.28875,1.67641,-1.64343,0.36782,1.67896,-1.69089,0.179349,1.94672,-2.09643,0.278389,1.8701,-1.95308,0.071156,1.91854,-1.98208,-0.066216,1.85114,-2.10886,-0.103605,1.76461,-2.16942,0.030991,1.62238,-2.14248,0.057107,1.56368,-2.16794,0.173409,1.42511,-1.78063,-0.007786,1.51387,-1.85158,-0.008567,1.54484,-1.89912,-0.006292,1.52246,-1.96545,0.177107,1.4666,-2.03368,0.072452,1.11048,-1.75886,-0.060902,1.14519,-1.76679,-0.084817,1.06752,-1.79565,-0.068114,0.935328,-1.79595,-0.195725,0.788419,-1.78708,-0.258788,0.746813,-1.79604,-0.260941,0.879103,-1.77154,-0.318649,0.837311,-1.77604,-0.48461,0.663816,-1.79841,-0.56949,0.760919,-1.81748,-0.513512,0.527859,-1.91312,-0.561477,0.505707,-1.83909,0.27205,1.21434,-2.0939,0.320298,1.14685,-2.07592,0.15494,1.13193,-2.07828,0.202876,1.06599,-2.06396,0.325906,0.981822,-2.06644,0.400339,0.805777,-2.05247,0.290019,0.789717,-2.07278,0.302808,0.722118,-2.06165,0.368726,0.490785,-2.02169,0.310429,0.399145,-1.95025,0.57302,0.498238,-1.99431,0.544436,0.429117,-2.04338,0.087431,1.34954,-1.81099,0.091762,1.3793,-2.02411},
/*737*/{0.245648,1.93421,-1.72348,0.283361,1.87249,-1.88182,0.199412,1.78046,-1.60958,0.169317,1.65587,-1.53171,0.28773,1.67315,-1.64327,0.36675,1.67397,-1.69066,0.179528,1.94653,-2.09638,0.27826,1.86921,-1.9535,0.071816,1.91857,-1.98249,-0.065238,1.84871,-2.10772,-0.102522,1.76194,-2.1686,0.031938,1.61934,-2.14187,0.058044,1.56048,-2.16841,0.173861,1.42512,-1.77975,-0.007959,1.51268,-1.85183,-0.008736,1.54379,-1.89897,-0.006565,1.52054,-1.96583,0.177855,1.46605,-2.03339,0.078624,1.1084,-1.76117,-0.055664,1.14037,-1.76437,-0.077779,1.06229,-1.7945,-0.059288,0.930856,-1.79716,-0.192752,0.790216,-1.78695,-0.258604,0.751275,-1.79659,-0.254539,0.88333,-1.77049,-0.315008,0.844945,-1.77509,-0.487768,0.678666,-1.79576,-0.56923,0.779075,-1.81632,-0.520739,0.54286,-1.91013,-0.571056,0.524158,-1.83743,0.268756,1.20889,-2.09428,0.31562,1.14077,-2.07639,0.150089,1.1281,-2.07735,0.197462,1.06237,-2.06306,0.319525,0.976455,-2.06523,0.400132,0.803396,-2.05033,0.289564,0.785408,-2.07244,0.30328,0.717607,-2.06094,0.374058,0.487711,-2.01909,0.319705,0.390881,-1.94891,0.578691,0.497823,-1.99182,0.551555,0.427943,-2.04248,0.088309,1.34906,-1.81032,0.092917,1.37815,-2.02353},
/*738*/{0.244657,1.93215,-1.72372,0.282331,1.87218,-1.8824,0.198363,1.77897,-1.60992,0.166673,1.65353,-1.53235,0.286146,1.66791,-1.64386,0.365525,1.66739,-1.69028,0.179311,1.94556,-2.09636,0.278003,1.86888,-1.95324,0.071544,1.91837,-1.98302,-0.065539,1.84597,-2.10793,-0.100736,1.75851,-2.16831,0.033313,1.61623,-2.14257,0.059562,1.55667,-2.1685,0.173783,1.42493,-1.7791,-0.008351,1.51173,-1.85276,-0.008721,1.54245,-1.89945,-0.006553,1.5186,-1.9663,0.177678,1.46418,-2.03274,0.084552,1.10598,-1.763,-0.050041,1.13462,-1.76347,-0.070935,1.05719,-1.79295,-0.050449,0.926616,-1.79824,-0.189576,0.792364,-1.78668,-0.256126,0.756421,-1.79526,-0.247044,0.888614,-1.76968,-0.308768,0.851679,-1.77398,-0.488768,0.694415,-1.79412,-0.567326,0.797757,-1.81625,-0.526514,0.558978,-1.90635,-0.578685,0.542059,-1.83365,0.265489,1.20334,-2.09453,0.310987,1.13481,-2.07698,0.14566,1.12436,-2.07622,0.191678,1.05777,-2.06221,0.313711,0.971658,-2.0649,0.39794,0.801343,-2.04901,0.28785,0.781448,-2.06972,0.302741,0.713832,-2.05891,0.378106,0.484091,-2.01866,0.324515,0.387959,-1.94742,0.583033,0.497937,-1.99214,0.555385,0.426134,-2.04064,0.088242,1.34855,-1.80934,0.093261,1.37609,-2.02274},
/*739*/{0.244291,1.93008,-1.72395,0.282714,1.87078,-1.88219,0.197199,1.77704,-1.61039,0.164508,1.65198,-1.5334,0.283934,1.66354,-1.64376,0.363531,1.66096,-1.69018,0.179771,1.94462,-2.09628,0.277326,1.86807,-1.9534,0.071173,1.91744,-1.98362,-0.06431,1.84387,-2.10788,-0.099471,1.75508,-2.16825,0.034485,1.61261,-2.1425,0.061428,1.55274,-2.16859,0.174202,1.42408,-1.77914,-0.009057,1.50992,-1.85319,-0.008202,1.54079,-1.89921,-0.006843,1.51638,-1.96636,0.177622,1.46307,-2.03206,0.092122,1.10347,-1.76416,-0.04218,1.13113,-1.76262,-0.06239,1.05174,-1.79315,-0.041395,0.922208,-1.79876,-0.186064,0.795843,-1.78548,-0.253867,0.762181,-1.79449,-0.240324,0.894379,-1.7698,-0.302152,0.86017,-1.77345,-0.489588,0.709811,-1.79034,-0.56308,0.816603,-1.81729,-0.530964,0.574462,-1.90153,-0.58556,0.561375,-1.82929,0.262966,1.19786,-2.09502,0.306895,1.12823,-2.0787,0.141807,1.12162,-2.07556,0.187229,1.05442,-2.06021,0.307112,0.966284,-2.06331,0.395252,0.798455,-2.04804,0.284448,0.777425,-2.06654,0.30024,0.71038,-2.05602,0.378751,0.48098,-2.01826,0.328989,0.384476,-1.94574,0.584914,0.497128,-1.99304,0.558603,0.425318,-2.0412,0.088822,1.34726,-1.80905,0.093861,1.37453,-2.02249},
/*740*/{0.24415,1.92767,-1.7236,0.282209,1.86972,-1.88209,0.194833,1.77485,-1.61035,0.161371,1.65081,-1.5345,0.28161,1.65882,-1.64373,0.36224,1.65358,-1.68981,0.179653,1.94284,-2.09619,0.277279,1.86738,-1.95338,0.07121,1.91711,-1.98396,-0.063322,1.84061,-2.1083,-0.097501,1.75077,-2.16861,0.035876,1.60798,-2.1432,0.063301,1.54867,-2.16892,0.17442,1.4233,-1.77901,-0.008443,1.50799,-1.85251,-0.007947,1.53878,-1.89895,-0.006927,1.51452,-1.96737,0.17829,1.46077,-2.03236,0.098567,1.10077,-1.76463,-0.037022,1.12599,-1.76193,-0.055979,1.04656,-1.7918,-0.033298,0.918015,-1.79942,-0.181912,0.799255,-1.78399,-0.251896,0.768121,-1.791,-0.232529,0.899545,-1.77002,-0.296177,0.868149,-1.77329,-0.489985,0.724721,-1.78729,-0.558705,0.834394,-1.81896,-0.534403,0.588921,-1.89571,-0.59161,0.580885,-1.82592,0.259521,1.19269,-2.09629,0.303494,1.12283,-2.07941,0.138259,1.11844,-2.07399,0.182519,1.05077,-2.05892,0.301672,0.962025,-2.06217,0.390321,0.795301,-2.0477,0.279492,0.77318,-2.06324,0.296276,0.706262,-2.05268,0.380088,0.478901,-2.01639,0.330854,0.38179,-1.94264,0.585613,0.495735,-1.99305,0.558802,0.424531,-2.04178,0.089512,1.34596,-1.80847,0.094316,1.37229,-2.02204},
/*741*/{0.243788,1.92538,-1.72388,0.280898,1.86757,-1.88201,0.193506,1.77282,-1.61069,0.15757,1.64759,-1.53505,0.279891,1.65261,-1.64352,0.360879,1.64645,-1.6894,0.178986,1.9412,-2.09589,0.275854,1.86507,-1.9535,0.070745,1.91489,-1.98478,-0.063286,1.83633,-2.10885,-0.095776,1.746,-2.16928,0.037825,1.60353,-2.14438,0.065542,1.54389,-2.16939,0.174835,1.42131,-1.77844,-0.008592,1.50528,-1.8528,-0.008535,1.53621,-1.89958,-0.00712,1.51141,-1.968,0.178362,1.45811,-2.03268,0.103516,1.09855,-1.76556,-0.031567,1.12063,-1.76147,-0.048524,1.0402,-1.79042,-0.025217,0.913961,-1.79954,-0.177514,0.802814,-1.78224,-0.248371,0.774197,-1.78918,-0.223857,0.904952,-1.77078,-0.288392,0.875384,-1.77335,-0.488974,0.739936,-1.78469,-0.551261,0.851846,-1.82017,-0.536676,0.603454,-1.88934,-0.596268,0.599965,-1.82125,0.257736,1.18771,-2.09684,0.300529,1.11645,-2.08023,0.135291,1.11558,-2.07228,0.178522,1.04778,-2.0577,0.296148,0.957422,-2.06085,0.385023,0.7921,-2.04765,0.274316,0.768941,-2.05978,0.292461,0.702236,-2.04879,0.378918,0.475903,-2.01437,0.329568,0.374499,-1.94422,0.584959,0.492996,-1.9927,0.557686,0.423011,-2.0424,0.089869,1.34381,-1.80818,0.094702,1.36934,-2.02184},
/*742*/{0.24249,1.92206,-1.72315,0.281193,1.86576,-1.88188,0.190574,1.76993,-1.61078,0.155785,1.6463,-1.53663,0.277503,1.64772,-1.64348,0.358543,1.63847,-1.6881,0.179459,1.93915,-2.09586,0.275823,1.86409,-1.95344,0.07007,1.9136,-1.98598,-0.062855,1.83272,-2.10991,-0.094098,1.74048,-2.16977,0.039868,1.59832,-2.14506,0.06743,1.53919,-2.16997,0.176367,1.42009,-1.77999,-0.008765,1.50285,-1.85353,-0.007785,1.53374,-1.90037,-0.006418,1.50851,-1.96899,0.17808,1.45502,-2.03354,0.110093,1.09638,-1.76564,-0.025769,1.11542,-1.7611,-0.042345,1.03456,-1.79134,-0.016639,0.910446,-1.79945,-0.172473,0.806399,-1.78094,-0.243453,0.780498,-1.78637,-0.215071,0.91089,-1.77173,-0.281399,0.88396,-1.77219,-0.486605,0.755761,-1.78254,-0.54364,0.868924,-1.82318,-0.538104,0.617704,-1.88331,-0.598462,0.618912,-1.81621,0.255794,1.18311,-2.09807,0.297505,1.11138,-2.08115,0.132655,1.11347,-2.07151,0.174856,1.04497,-2.05649,0.291886,0.953573,-2.06006,0.379334,0.788378,-2.04821,0.269869,0.76304,-2.05218,0.287894,0.698063,-2.04596,0.375089,0.47204,-2.01159,0.328724,0.372236,-1.93771,0.581764,0.490132,-1.9931,0.552933,0.420318,-2.04301,0.09114,1.34207,-1.80837,0.094955,1.36625,-2.02221},
/*743*/{0.242475,1.91989,-1.72269,0.281059,1.86416,-1.88193,0.1892,1.76727,-1.61038,0.150658,1.64352,-1.53847,0.274766,1.64135,-1.64313,0.356281,1.63021,-1.68736,0.178484,1.93632,-2.09574,0.275286,1.86153,-1.95324,0.070041,1.91106,-1.98623,-0.061304,1.82712,-2.11117,-0.092428,1.73499,-2.17059,0.04193,1.59313,-2.14595,0.069889,1.53348,-2.17096,0.1766,1.41795,-1.77998,-0.008976,1.49967,-1.85372,-0.00817,1.53053,-1.90011,-0.007167,1.50614,-1.97024,0.177304,1.45168,-2.03447,0.11609,1.0932,-1.76528,-0.020339,1.10995,-1.76047,-0.035096,1.02927,-1.7907,-0.008278,0.906828,-1.79869,-0.166949,0.810299,-1.7787,-0.238554,0.785346,-1.78478,-0.205737,0.915283,-1.77312,-0.272702,0.890887,-1.77329,-0.481233,0.770714,-1.78123,-0.534901,0.884143,-1.82517,-0.537375,0.631982,-1.87748,-0.597928,0.637625,-1.81108,0.254254,1.17873,-2.09893,0.294648,1.10692,-2.08238,0.130506,1.11133,-2.07072,0.172314,1.04197,-2.05458,0.288505,0.94973,-2.05869,0.374133,0.784008,-2.04717,0.264394,0.759035,-2.05107,0.285122,0.694038,-2.04246,0.369527,0.467717,-2.00917,0.323577,0.36963,-1.93374,0.57663,0.485755,-1.99337,0.547459,0.41689,-2.04324,0.091226,1.33958,-1.80839,0.094387,1.36306,-2.02232},
/*744*/{0.241187,1.91693,-1.72219,0.281192,1.86153,-1.88201,0.18616,1.76404,-1.61031,0.147667,1.63975,-1.53877,0.271923,1.63499,-1.64264,0.353214,1.62124,-1.68596,0.177292,1.93322,-2.09578,0.274731,1.86019,-1.95354,0.068905,1.90809,-1.98687,-0.061387,1.82158,-2.1124,-0.090963,1.72875,-2.17165,0.044526,1.58754,-2.14761,0.072574,1.52807,-2.1716,0.177131,1.41595,-1.78038,-0.008679,1.4966,-1.85476,-0.007583,1.52731,-1.9003,-0.006602,1.50245,-1.97101,0.177189,1.44908,-2.03533,0.120601,1.0895,-1.76495,-0.014188,1.10461,-1.76059,-0.027967,1.02429,-1.79023,-0.000616,0.903256,-1.79784,-0.161605,0.813367,-1.77689,-0.233391,0.791458,-1.78229,-0.196789,0.919761,-1.77379,-0.264057,0.898219,-1.77288,-0.477049,0.785507,-1.77793,-0.525496,0.899002,-1.82682,-0.536104,0.644529,-1.87151,-0.597311,0.65422,-1.8065,0.251849,1.17469,-2.09971,0.291916,1.10221,-2.08251,0.128038,1.10901,-2.0688,0.169105,1.03934,-2.05394,0.285694,0.946621,-2.058,0.370002,0.779493,-2.04627,0.259254,0.754479,-2.04906,0.277294,0.689098,-2.04164,0.364312,0.464284,-2.00683,0.31819,0.365442,-1.93086,0.570753,0.480508,-1.9923,0.540191,0.411141,-2.04162,0.092306,1.33704,-1.80869,0.095121,1.35995,-2.02268},
/*745*/{0.239731,1.91376,-1.72147,0.280471,1.85809,-1.88133,0.183968,1.76069,-1.61024,0.144167,1.63749,-1.5401,0.269134,1.62806,-1.64284,0.351204,1.61236,-1.68466,0.176876,1.93,-2.09591,0.2749,1.85788,-1.95303,0.068199,1.90466,-1.98841,-0.060252,1.81558,-2.11421,-0.089453,1.72169,-2.17266,0.046692,1.58175,-2.14911,0.075055,1.52237,-2.17287,0.177658,1.41335,-1.781,-0.007808,1.49306,-1.85472,-0.008104,1.52377,-1.90042,-0.007116,1.49967,-1.971,0.176301,1.44623,-2.03573,0.126025,1.08707,-1.76432,-0.010763,1.1002,-1.76096,-0.022679,1.01771,-1.78926,0.006889,0.899532,-1.79713,-0.154493,0.816348,-1.77493,-0.227407,0.796783,-1.78099,-0.186888,0.924161,-1.77516,-0.255277,0.904805,-1.77446,-0.469711,0.79945,-1.77652,-0.516087,0.912118,-1.82835,-0.532204,0.657752,-1.86529,-0.593703,0.670279,-1.80088,0.250827,1.1708,-2.10089,0.289987,1.09829,-2.08343,0.125624,1.10676,-2.06776,0.165671,1.03659,-2.05287,0.283693,0.943141,-2.05669,0.364305,0.773642,-2.04544,0.254461,0.75011,-2.04809,0.271682,0.684523,-2.0401,0.354064,0.458835,-2.00339,0.310535,0.359839,-1.92795,0.56419,0.472287,-1.99085,0.532084,0.404427,-2.03991,0.093032,1.3341,-1.80897,0.094822,1.35692,-2.02298},
/*746*/{0.238399,1.91023,-1.72073,0.280919,1.855,-1.88096,0.181246,1.75726,-1.61002,0.139853,1.63494,-1.54141,0.265787,1.62073,-1.64234,0.347554,1.60283,-1.68319,0.175564,1.92646,-2.09618,0.274444,1.85484,-1.95233,0.065894,1.90148,-1.98894,-0.061239,1.80883,-2.11517,-0.087914,1.71462,-2.17394,0.049466,1.57533,-2.15046,0.078847,1.5164,-2.17335,0.17855,1.41058,-1.78203,-0.007686,1.48956,-1.85524,-0.008311,1.52033,-1.9009,-0.007468,1.49503,-1.97075,0.175575,1.44332,-2.03623,0.129647,1.08476,-1.76326,-0.006248,1.0931,-1.76126,-0.016564,1.01256,-1.79107,0.014658,0.896353,-1.79579,-0.147675,0.819765,-1.77294,-0.221594,0.802204,-1.77743,-0.17711,0.928476,-1.77657,-0.245177,0.909569,-1.77571,-0.46255,0.812459,-1.77503,-0.506331,0.924864,-1.83038,-0.528201,0.669304,-1.8606,-0.58901,0.685253,-1.79563,0.248981,1.16746,-2.10082,0.287249,1.09339,-2.08406,0.123269,1.10422,-2.06754,0.163808,1.03324,-2.05193,0.281756,0.939632,-2.05605,0.359501,0.768072,-2.0445,0.248148,0.747169,-2.05089,0.265936,0.680447,-2.03853,0.347537,0.453606,-2.00147,0.299837,0.357058,-1.92359,0.555233,0.464087,-1.98991,0.522186,0.394909,-2.03708,0.094161,1.33101,-1.80923,0.094874,1.35336,-2.0233},
/*747*/{0.237085,1.90589,-1.7199,0.280648,1.85231,-1.88046,0.178044,1.75318,-1.60953,0.135214,1.63173,-1.54269,0.261696,1.61406,-1.64169,0.344352,1.59337,-1.68152,0.174961,1.92214,-2.09641,0.27427,1.85163,-1.95249,0.065264,1.8976,-1.98924,-0.061181,1.80134,-2.11824,-0.086238,1.70729,-2.17602,0.052707,1.56899,-2.15217,0.082621,1.51009,-2.17448,0.178626,1.40805,-1.78258,-0.008475,1.48609,-1.85531,-0.008127,1.51623,-1.90122,-0.008488,1.49168,-1.971,0.174744,1.44019,-2.03667,0.134186,1.08234,-1.7638,-0.000914,1.08742,-1.76188,-0.009337,1.00773,-1.79015,0.022894,0.893403,-1.79416,-0.139501,0.822964,-1.77113,-0.213614,0.806676,-1.77607,-0.165847,0.931964,-1.77793,-0.234931,0.915077,-1.77599,-0.453841,0.822261,-1.773,-0.495942,0.936131,-1.83174,-0.521488,0.680138,-1.85536,-0.582489,0.698953,-1.79071,0.247764,1.16333,-2.10145,0.28599,1.0894,-2.08405,0.121498,1.10101,-2.06721,0.160573,1.03002,-2.05196,0.28044,0.936209,-2.05457,0.354849,0.76258,-2.04351,0.243338,0.742702,-2.0501,0.259735,0.675182,-2.03759,0.337972,0.447945,-1.99907,0.288595,0.354808,-1.92159,0.545467,0.454834,-1.9866,0.512511,0.385891,-2.03353,0.094477,1.32798,-1.80938,0.09455,1.34995,-2.02349},
/*748*/{0.236127,1.90236,-1.71885,0.280567,1.84898,-1.8792,0.175911,1.74891,-1.60947,0.130711,1.62802,-1.54314,0.258219,1.6064,-1.64061,0.340296,1.58397,-1.67987,0.174318,1.91803,-2.09723,0.273872,1.84831,-1.95237,0.06415,1.89237,-1.98988,-0.061095,1.79378,-2.1196,-0.084529,1.69866,-2.1772,0.056868,1.56191,-2.15349,0.086042,1.50353,-2.17581,0.179036,1.40523,-1.78299,-0.008677,1.4817,-1.85476,-0.008135,1.51176,-1.9012,-0.008947,1.48612,-1.96992,0.174802,1.43772,-2.03749,0.139524,1.07788,-1.7602,0.00229,1.08307,-1.76326,-0.002602,1.00196,-1.79064,0.031232,0.889975,-1.7918,-0.131616,0.825186,-1.76837,-0.205815,0.811979,-1.77217,-0.154744,0.934608,-1.7791,-0.225845,0.920439,-1.77809,-0.445727,0.831968,-1.77184,-0.485283,0.946459,-1.83338,-0.515005,0.690219,-1.85074,-0.575022,0.711243,-1.78584,0.245164,1.15928,-2.10142,0.284512,1.08398,-2.0828,0.119738,1.09819,-2.06722,0.15862,1.02696,-2.05184,0.278215,0.932207,-2.05429,0.350151,0.756128,-2.04168,0.237148,0.73787,-2.04906,0.251797,0.669776,-2.03701,0.327255,0.440949,-1.9967,0.276136,0.3492,-1.91819,0.536169,0.444078,-1.98263,0.500869,0.375342,-2.02944,0.096248,1.32431,-1.80945,0.095371,1.34636,-2.02355},
/*749*/{0.234138,1.89754,-1.7176,0.279557,1.84428,-1.87884,0.173017,1.74424,-1.60954,0.126846,1.62435,-1.54377,0.254652,1.59892,-1.64027,0.336615,1.57372,-1.67772,0.174036,1.91352,-2.09766,0.273408,1.84498,-1.9528,0.06247,1.88777,-1.99089,-0.059688,1.78551,-2.1212,-0.082481,1.69053,-2.1791,0.060105,1.55463,-2.15516,0.090565,1.49651,-2.1769,0.180763,1.402,-1.78388,-0.009097,1.47729,-1.85499,-0.008212,1.5071,-1.90102,-0.009819,1.48199,-1.96984,0.174538,1.43489,-2.03815,0.141825,1.07587,-1.75775,0.007032,1.07768,-1.7633,0.002677,0.9962,-1.79132,0.038935,0.886483,-1.78972,-0.12238,0.826656,-1.76711,-0.19688,0.814569,-1.77066,-0.142978,0.936784,-1.78079,-0.213795,0.924679,-1.77933,-0.434669,0.844624,-1.77122,-0.475445,0.955591,-1.83396,-0.507845,0.698482,-1.84647,-0.566871,0.722554,-1.78049,0.244005,1.15517,-2.1015,0.281719,1.08016,-2.08314,0.117533,1.09343,-2.06659,0.155949,1.02243,-2.0518,0.274624,0.926924,-2.05381,0.343411,0.749506,-2.04048,0.230234,0.73303,-2.04862,0.245335,0.665002,-2.03605,0.315534,0.437128,-1.99496,0.26081,0.350249,-1.91517,0.523219,0.434449,-1.97968,0.487706,0.365504,-2.02523,0.097933,1.32058,-1.81011,0.095835,1.34293,-2.02418},
/*750*/{0.233036,1.8939,-1.71721,0.280186,1.83961,-1.8777,0.169878,1.73946,-1.60925,0.121586,1.62037,-1.54356,0.250298,1.59104,-1.63936,0.331917,1.56366,-1.676,0.172584,1.90854,-2.09785,0.27385,1.84124,-1.95185,0.061881,1.88236,-1.99264,-0.06073,1.7769,-2.12362,-0.080522,1.68196,-2.18098,0.063243,1.54711,-2.15647,0.094792,1.48975,-2.17782,0.180594,1.39863,-1.78469,-0.008272,1.47254,-1.85368,-0.007536,1.5027,-1.90019,-0.010977,1.47695,-1.96838,0.174406,1.43186,-2.03907,0.147653,1.07284,-1.75534,0.011453,1.07362,-1.76595,0.009279,0.991465,-1.79205,0.047267,0.88349,-1.78685,-0.112866,0.829066,-1.76345,-0.188349,0.819305,-1.76723,-0.130895,0.938504,-1.78166,-0.201103,0.927994,-1.78037,-0.425782,0.852611,-1.76939,-0.464382,0.9637,-1.83486,-0.499239,0.707191,-1.84131,-0.556504,0.732338,-1.77557,0.242354,1.15089,-2.10133,0.280328,1.07637,-2.08274,0.115532,1.08926,-2.06616,0.154398,1.01766,-2.05129,0.272118,0.921383,-2.05339,0.337754,0.742622,-2.03992,0.223514,0.727903,-2.0486,0.236918,0.659794,-2.03569,0.304141,0.433506,-1.99284,0.239785,0.355138,-1.91698,0.509541,0.422137,-1.97387,0.469887,0.35506,-2.02092,0.099416,1.31644,-1.81025,0.095815,1.33924,-2.02425},
/*751*/{0.23128,1.88865,-1.71579,0.280092,1.83565,-1.87715,0.166788,1.73465,-1.60923,0.115933,1.61432,-1.54343,0.246358,1.58363,-1.63847,0.327203,1.55391,-1.67382,0.172267,1.90359,-2.09832,0.27404,1.83768,-1.95127,0.060154,1.87613,-1.99307,-0.059988,1.76726,-2.12695,-0.078177,1.67297,-2.18273,0.06768,1.53937,-2.15822,0.099767,1.48212,-2.17861,0.180914,1.39522,-1.78572,-0.008747,1.46722,-1.85329,-0.00964,1.49803,-1.90074,-0.010657,1.47185,-1.96806,0.174361,1.42865,-2.03976,0.151986,1.06869,-1.75195,0.015354,1.06681,-1.76577,0.015387,0.986235,-1.79187,0.05656,0.880445,-1.7847,-0.103657,0.830124,-1.76152,-0.178459,0.821419,-1.76611,-0.118451,0.940251,-1.78303,-0.189939,0.930898,-1.78034,-0.414067,0.861007,-1.76942,-0.453518,0.970762,-1.83603,-0.489539,0.714283,-1.83734,-0.547123,0.74137,-1.77187,0.240559,1.14688,-2.10144,0.278797,1.072,-2.08295,0.113862,1.08504,-2.06651,0.152317,1.01353,-2.05138,0.268333,0.914896,-2.05345,0.329762,0.735263,-2.03897,0.21643,0.722787,-2.04827,0.227885,0.654552,-2.03535,0.29133,0.428506,-1.99217,0.220627,0.354542,-1.91365,0.494541,0.405426,-1.96975,0.451718,0.343531,-2.01755,0.100562,1.31226,-1.81088,0.096404,1.33543,-2.02483},
/*752*/{0.229535,1.88419,-1.71509,0.279444,1.83057,-1.87573,0.163817,1.72946,-1.60937,0.112411,1.61166,-1.54366,0.242369,1.57595,-1.63702,0.322533,1.54402,-1.67163,0.172651,1.89837,-2.09904,0.273893,1.83352,-1.95148,0.059447,1.87034,-1.99388,-0.059833,1.75756,-2.12939,-0.075332,1.66391,-2.18529,0.073042,1.53226,-2.15934,0.105196,1.47452,-2.1796,0.181808,1.39123,-1.78695,-0.008284,1.46166,-1.85292,-0.008359,1.49249,-1.90015,-0.011991,1.4668,-1.96697,0.174047,1.42561,-2.04075,0.155195,1.06528,-1.74927,0.02032,1.06183,-1.76721,0.020825,0.979414,-1.79372,0.065188,0.876921,-1.78196,-0.09266,0.830782,-1.75919,-0.168639,0.823619,-1.76377,-0.105572,0.940225,-1.78408,-0.177139,0.932324,-1.78146,-0.402653,0.867234,-1.7685,-0.441625,0.976758,-1.83726,-0.479327,0.719879,-1.8336,-0.535375,0.748837,-1.76664,0.238905,1.14209,-2.10117,0.277554,1.06769,-2.08334,0.111875,1.0808,-2.06718,0.150749,1.00926,-2.05178,0.264346,0.908358,-2.05339,0.32228,0.728097,-2.03766,0.209682,0.717633,-2.04779,0.219717,0.649537,-2.035,0.27347,0.422383,-1.98776,0.199756,0.355015,-1.9139,0.480598,0.393589,-1.96074,0.432018,0.340907,-2.01522,0.102604,1.30747,-1.81181,0.09677,1.33158,-2.02561},
/*753*/{0.227715,1.87916,-1.71403,0.280056,1.82547,-1.87542,0.161066,1.72467,-1.60947,0.106982,1.60813,-1.54492,0.237364,1.56834,-1.63598,0.317731,1.53564,-1.67068,0.173425,1.89315,-2.10028,0.273898,1.82849,-1.95024,0.05885,1.86379,-1.99531,-0.05846,1.74746,-2.13087,-0.071967,1.65428,-2.18731,0.076811,1.52404,-2.16057,0.110421,1.46762,-2.18063,0.181663,1.3863,-1.78726,-0.00881,1.45582,-1.8515,-0.010105,1.48713,-1.89967,-0.013132,1.46179,-1.96613,0.17352,1.42201,-2.04224,0.157223,1.06231,-1.74783,0.023434,1.05562,-1.76886,0.026958,0.973751,-1.79284,0.073845,0.872757,-1.77977,-0.082085,0.830959,-1.75704,-0.157218,0.823931,-1.76114,-0.092579,0.939814,-1.78492,-0.164187,0.933584,-1.78138,-0.390409,0.872994,-1.76703,-0.429821,0.981291,-1.83849,-0.467993,0.725188,-1.82959,-0.522692,0.755342,-1.7633,0.236443,1.13809,-2.10209,0.274936,1.06382,-2.08474,0.109907,1.07685,-2.06743,0.148774,1.0056,-2.05203,0.260066,0.90248,-2.05359,0.314583,0.720899,-2.03503,0.202297,0.71352,-2.04747,0.210393,0.644737,-2.03341,0.256246,0.420933,-1.98122,0.177075,0.35287,-1.9134,0.459491,0.388159,-1.95322,0.409865,0.343004,-2.01497,0.103131,1.30219,-1.81263,0.096182,1.32753,-2.02625},
/*754*/{0.226262,1.87449,-1.71296,0.280959,1.82054,-1.87379,0.158213,1.72002,-1.60889,0.103445,1.60381,-1.54416,0.232997,1.56097,-1.63466,0.311379,1.52679,-1.66756,0.17321,1.88806,-2.1007,0.274652,1.82366,-1.95018,0.057164,1.85778,-1.99577,-0.056461,1.73783,-2.13402,-0.068731,1.64439,-2.1894,0.082571,1.51624,-2.16227,0.116782,1.46025,-2.18157,0.181087,1.38203,-1.7883,-0.010318,1.45115,-1.85114,-0.011253,1.48155,-1.89905,-0.014743,1.45715,-1.96528,0.171919,1.41776,-2.0436,0.161147,1.05945,-1.74505,0.027193,1.05082,-1.76975,0.033226,0.967057,-1.79283,0.084466,0.870906,-1.77641,-0.070579,0.830586,-1.75481,-0.146479,0.825931,-1.75863,-0.079952,0.938743,-1.78517,-0.150676,0.934189,-1.78214,-0.376719,0.878307,-1.76685,-0.417281,0.98524,-1.83953,-0.455472,0.729453,-1.82506,-0.510608,0.76098,-1.75842,0.233553,1.1344,-2.10405,0.271903,1.05956,-2.08704,0.107545,1.07294,-2.06762,0.146285,1.00206,-2.05269,0.255711,0.89679,-2.05404,0.307805,0.713839,-2.03031,0.195408,0.709767,-2.04656,0.201269,0.641241,-2.03116,0.238171,0.422846,-1.97582,0.15434,0.353714,-1.91118,0.433171,0.388052,-1.95493,0.385361,0.343499,-2.01472,0.102937,1.29752,-1.81316,0.094569,1.32311,-2.02671},
/*755*/{0.225661,1.86987,-1.71168,0.280935,1.81482,-1.87276,0.155003,1.71507,-1.60925,0.098302,1.60103,-1.54555,0.22743,1.55377,-1.63374,0.305729,1.51906,-1.66586,0.17427,1.88273,-2.10151,0.274493,1.81827,-1.94958,0.056665,1.85116,-1.99693,-0.054377,1.72801,-2.13762,-0.064066,1.63488,-2.1919,0.088436,1.50949,-2.16403,0.123715,1.45273,-2.18265,0.182051,1.37706,-1.79047,-0.012575,1.44575,-1.84997,-0.012501,1.4765,-1.89839,-0.01711,1.45295,-1.96537,0.170621,1.413,-2.04518,0.164612,1.05475,-1.74207,0.032174,1.04221,-1.77032,0.039859,0.960954,-1.7934,0.095146,0.86697,-1.77292,-0.058886,0.829874,-1.75226,-0.135399,0.825204,-1.75783,-0.064499,0.937833,-1.78569,-0.137413,0.934497,-1.7824,-0.36527,0.881518,-1.76644,-0.404995,0.988088,-1.84052,-0.44263,0.732456,-1.82064,-0.4975,0.76545,-1.75667,0.229707,1.13097,-2.10786,0.268054,1.05659,-2.09047,0.103822,1.07225,-2.06851,0.142466,1.00103,-2.05211,0.250031,0.891052,-2.05444,0.302179,0.709481,-2.02549,0.190027,0.708794,-2.04451,0.191654,0.64067,-2.02724,0.213754,0.423903,-1.97209,0.130828,0.354613,-1.90983,0.410441,0.385396,-1.94833,0.362829,0.343148,-2.0132,0.102936,1.29244,-1.81439,0.092515,1.31869,-2.02777},
/*756*/{0.223703,1.86528,-1.71111,0.28122,1.81025,-1.87192,0.15118,1.71037,-1.6092,0.09282,1.59779,-1.54615,0.221786,1.54801,-1.63178,0.299718,1.51173,-1.66329,0.175244,1.87784,-2.10268,0.276215,1.81332,-1.94922,0.056467,1.84699,-1.99753,-0.051941,1.71799,-2.14154,-0.05923,1.62438,-2.19405,0.094561,1.50163,-2.16536,0.130456,1.44562,-2.18271,0.181609,1.37197,-1.79146,-0.012832,1.44083,-1.84953,-0.013753,1.47009,-1.89718,-0.020455,1.4499,-1.96477,0.167486,1.40845,-2.04665,0.170372,1.05221,-1.73908,0.03811,1.03765,-1.77066,0.04923,0.953496,-1.79297,0.105612,0.863702,-1.76963,-0.04615,0.827889,-1.75058,-0.121797,0.825295,-1.75476,-0.051069,0.935792,-1.78382,-0.122669,0.933836,-1.78006,-0.351447,0.884239,-1.76685,-0.392127,0.989845,-1.84184,-0.429013,0.734397,-1.81723,-0.483631,0.768576,-1.75329,0.226666,1.12886,-2.11192,0.264002,1.054,-2.09441,0.101084,1.07185,-2.06784,0.139518,1.00033,-2.05199,0.244016,0.888098,-2.05451,0.295272,0.706284,-2.02058,0.183156,0.711766,-2.04108,0.181437,0.644273,-2.02332,0.192705,0.424411,-1.96832,0.107572,0.354763,-1.90759,0.38907,0.383076,-1.94966,0.339556,0.343856,-2.01177,0.102264,1.28726,-1.81542,0.089484,1.31432,-2.02857},
/*757*/{0.222752,1.86085,-1.70985,0.282619,1.80486,-1.87078,0.148961,1.7058,-1.60937,0.086435,1.59509,-1.54607,0.216349,1.54305,-1.63101,0.292505,1.50517,-1.66098,0.175733,1.87317,-2.10422,0.276321,1.80791,-1.94793,0.056673,1.84416,-1.99707,-0.046712,1.70785,-2.14609,-0.053131,1.61417,-2.196,0.101563,1.49384,-2.16651,0.138141,1.43929,-2.18356,0.180438,1.36718,-1.79383,-0.01429,1.43578,-1.84907,-0.016099,1.46515,-1.89605,-0.023052,1.44585,-1.96402,0.165369,1.40682,-2.04807,0.174629,1.04899,-1.7371,0.042079,1.03181,-1.77187,0.055755,0.948371,-1.79336,0.117769,0.860807,-1.76711,-0.033324,0.826559,-1.74865,-0.109179,0.825114,-1.75285,-0.036941,0.934158,-1.78216,-0.109244,0.932513,-1.77904,-0.338018,0.886445,-1.76516,-0.379029,0.990399,-1.84328,-0.414418,0.734551,-1.81304,-0.468948,0.769355,-1.74975,0.222879,1.12639,-2.1154,0.261229,1.05196,-2.09645,0.098592,1.07109,-2.06735,0.137237,0.999532,-2.05111,0.23936,0.886814,-2.05481,0.286181,0.705921,-2.01863,0.174826,0.716238,-2.03803,0.169665,0.648347,-2.02148,0.175832,0.427258,-1.9665,0.084377,0.356271,-1.90583,0.367338,0.383149,-1.94546,0.317411,0.343925,-2.01037,0.101896,1.28219,-1.81791,0.087476,1.31203,-2.03058},
/*758*/{0.222055,1.8568,-1.70838,0.282247,1.80069,-1.86971,0.146247,1.7023,-1.60914,0.07947,1.5927,-1.54634,0.209792,1.53857,-1.62873,0.286148,1.4999,-1.65885,0.176945,1.8688,-2.10485,0.277279,1.80376,-1.94759,0.057117,1.84281,-1.99671,-0.040239,1.69806,-2.15033,-0.046472,1.60434,-2.1988,0.109149,1.48723,-2.1669,0.146212,1.43293,-2.18355,0.180017,1.36292,-1.79686,-0.017518,1.43218,-1.84812,-0.019074,1.46067,-1.89544,-0.0265,1.44276,-1.96386,0.163557,1.40493,-2.04945,0.17828,1.04724,-1.73525,0.047914,1.02516,-1.77157,0.064347,0.942927,-1.79379,0.130013,0.857821,-1.7628,-0.019705,0.824209,-1.74689,-0.095676,0.823591,-1.75345,-0.023178,0.932093,-1.78055,-0.094847,0.931283,-1.77794,-0.32326,0.886953,-1.76395,-0.366483,0.989343,-1.84341,-0.398875,0.734405,-1.81018,-0.453126,0.769892,-1.74682,0.219684,1.12511,-2.11638,0.25804,1.05099,-2.09687,0.095788,1.06953,-2.067,0.134597,0.99841,-2.0503,0.237557,0.887232,-2.05432,0.276007,0.704706,-2.01852,0.164602,0.720461,-2.03728,0.156294,0.652707,-2.02108,0.151078,0.425137,-1.96259,0.064081,0.356818,-1.90435,0.3453,0.380583,-1.94664,0.294739,0.343789,-2.00968,0.100924,1.27802,-1.82023,0.08479,1.30996,-2.03247},
/*759*/{0.222119,1.85314,-1.70697,0.283606,1.79777,-1.86862,0.142105,1.69961,-1.60921,0.072107,1.59186,-1.54674,0.203302,1.5352,-1.6278,0.279439,1.49477,-1.65601,0.177688,1.86501,-2.10595,0.278779,1.79963,-1.94604,0.057435,1.84066,-1.99605,-0.034677,1.6881,-2.15641,-0.038443,1.59444,-2.20091,0.117564,1.48155,-2.16723,0.15539,1.42804,-2.18367,0.178302,1.35861,-1.79787,-0.019088,1.42751,-1.84711,-0.021503,1.45845,-1.89603,-0.02918,1.43945,-1.96209,0.161001,1.40269,-2.05107,0.182951,1.04769,-1.73419,0.052829,1.01998,-1.77298,0.073403,0.937839,-1.79276,0.142662,0.854612,-1.76154,-0.006441,0.821708,-1.7458,-0.082329,0.820797,-1.75154,-0.008598,0.930592,-1.7787,-0.079778,0.929897,-1.77533,-0.312006,0.885196,-1.76737,-0.354763,0.987334,-1.84447,-0.382231,0.732435,-1.80654,-0.436755,0.768354,-1.74374,0.214759,1.12379,-2.11596,0.254412,1.0499,-2.09725,0.09188,1.06733,-2.06589,0.131285,0.996382,-2.04958,0.238075,0.887417,-2.05391,0.264076,0.703739,-2.02081,0.153109,0.723888,-2.03646,0.142855,0.654759,-2.02048,0.135166,0.42796,-1.96302,0.042234,0.358365,-1.90293,0.325008,0.380738,-1.9448,0.272875,0.343534,-2.00888,0.099261,1.27393,-1.82176,0.081835,1.30759,-2.03363},
/*760*/{0.222891,1.84946,-1.70559,0.282261,1.79426,-1.86693,0.138025,1.69813,-1.60915,0.065113,1.5913,-1.54707,0.196563,1.53273,-1.62632,0.271519,1.49198,-1.6535,0.179402,1.86205,-2.1062,0.279005,1.79624,-1.94564,0.057677,1.83909,-1.99489,-0.030267,1.67969,-2.16028,-0.030239,1.58528,-2.2025,0.126484,1.4764,-2.16767,0.165287,1.42278,-2.1832,0.177081,1.35482,-1.80008,-0.021507,1.42361,-1.84529,-0.021612,1.45678,-1.89445,-0.03129,1.43693,-1.95941,0.158607,1.4021,-2.05256,0.189056,1.04996,-1.73349,0.059972,1.01639,-1.7715,0.082655,0.935822,-1.79131,0.156155,0.852135,-1.75919,0.006955,0.819731,-1.74523,-0.068796,0.818322,-1.75169,0.006137,0.92955,-1.77531,-0.066883,0.928576,-1.77478,-0.294397,0.883021,-1.7629,-0.343413,0.984579,-1.84489,-0.365277,0.729206,-1.8038,-0.420908,0.764693,-1.7407,0.210374,1.12224,-2.11608,0.24974,1.04787,-2.09795,0.087808,1.06586,-2.0647,0.12729,0.995254,-2.0489,0.238656,0.887752,-2.0524,0.251713,0.70124,-2.02335,0.141389,0.725366,-2.03628,0.129066,0.657136,-2.02097,0.115816,0.428594,-1.96294,0.022347,0.357354,-1.90302,0.303001,0.379153,-1.94535,0.251151,0.343481,-2.00892,0.098392,1.27015,-1.8238,0.078875,1.30685,-2.03498},
/*761*/{0.222792,1.84575,-1.70341,0.282855,1.78967,-1.86613,0.133247,1.6974,-1.6089,0.05782,1.59203,-1.54843,0.189394,1.53178,-1.62491,0.264713,1.4884,-1.65119,0.180547,1.85943,-2.10529,0.279029,1.79323,-1.94401,0.058079,1.83753,-1.99497,-0.024731,1.67296,-2.16382,-0.020503,1.57717,-2.20483,0.136762,1.47231,-2.16693,0.176757,1.42049,-2.18221,0.174069,1.35191,-1.8006,-0.022877,1.42092,-1.84393,-0.023656,1.45646,-1.89382,-0.033394,1.43566,-1.95785,0.156513,1.40172,-2.05389,0.195057,1.05285,-1.73218,0.068108,1.01366,-1.76904,0.093037,0.933584,-1.78847,0.169789,0.850947,-1.75806,0.020963,0.81809,-1.74407,-0.053975,0.817842,-1.75144,0.019406,0.927811,-1.77291,-0.051375,0.92839,-1.77235,-0.284832,0.884404,-1.76473,-0.332741,0.979724,-1.8454,-0.34858,0.724835,-1.80143,-0.403891,0.759377,-1.73869,0.205914,1.1198,-2.11605,0.244333,1.04508,-2.09879,0.082921,1.0639,-2.06337,0.121767,0.993005,-2.048,0.237863,0.887564,-2.05013,0.239103,0.69926,-2.02625,0.128392,0.724748,-2.03766,0.115502,0.657099,-2.0197,0.093406,0.428365,-1.96238,-0.001835,0.360314,-1.9036,0.280407,0.378714,-1.94579,0.229229,0.343027,-2.00903,0.095977,1.26756,-1.82513,0.075887,1.30654,-2.03585},
/*762*/{0.223948,1.84357,-1.7031,0.283625,1.7879,-1.86519,0.128457,1.69741,-1.6088,0.051158,1.59426,-1.5492,0.183095,1.53121,-1.62376,0.257562,1.48646,-1.64948,0.181603,1.85736,-2.10407,0.279238,1.79068,-1.94375,0.058498,1.83634,-1.99455,-0.018483,1.6664,-2.1656,-0.011558,1.57111,-2.20578,0.146811,1.46923,-2.16629,0.188062,1.41775,-2.1812,0.172782,1.3492,-1.80286,-0.025105,1.41976,-1.84229,-0.025193,1.45593,-1.89427,-0.033841,1.43456,-1.9547,0.154936,1.4011,-2.05526,0.203252,1.05553,-1.7318,0.07654,1.01282,-1.76698,0.104381,0.932521,-1.787,0.184633,0.852322,-1.75768,0.034841,0.817621,-1.74319,-0.039847,0.816001,-1.75061,0.033055,0.92751,-1.77106,-0.037908,0.927496,-1.77082,-0.269052,0.878345,-1.76398,-0.322829,0.974163,-1.84499,-0.329754,0.718879,-1.79946,-0.38494,0.752591,-1.73619,0.200017,1.11645,-2.11637,0.23735,1.04137,-2.09893,0.077071,1.06029,-2.0614,0.115217,0.991454,-2.04715,0.23137,0.886145,-2.04959,0.226204,0.69508,-2.0271,0.115559,0.724271,-2.03852,0.101287,0.657859,-2.02087,0.077227,0.429352,-1.96323,-0.023041,0.361187,-1.90328,0.26011,0.37759,-1.94531,0.207134,0.342744,-2.00984,0.094381,1.26537,-1.82657,0.073015,1.30627,-2.0368},
/*763*/{0.224504,1.8416,-1.70238,0.283483,1.78643,-1.86453,0.125146,1.69842,-1.60877,0.044125,1.59684,-1.54954,0.17538,1.5314,-1.62369,0.251147,1.48588,-1.64662,0.183496,1.85642,-2.1029,0.278948,1.78838,-1.9423,0.05917,1.83504,-1.99428,-0.011679,1.66189,-2.16653,-0.003664,1.56665,-2.20585,0.157922,1.46767,-2.16499,0.199708,1.4175,-2.17999,0.170931,1.34628,-1.80237,-0.025723,1.41925,-1.84226,-0.026629,1.45521,-1.89333,-0.035843,1.43406,-1.9537,0.152997,1.40072,-2.05641,0.209603,1.05877,-1.73223,0.084948,1.0115,-1.76503,0.114226,0.932593,-1.78409,0.198605,0.854181,-1.7573,0.049467,0.81812,-1.7414,-0.024367,0.815727,-1.74998,0.045335,0.92765,-1.76942,-0.025717,0.927255,-1.76994,-0.253064,0.872547,-1.76262,-0.314094,0.967801,-1.84483,-0.310408,0.712578,-1.79779,-0.366478,0.744076,-1.73315,0.193723,1.11346,-2.11668,0.230356,1.03708,-2.09985,0.070997,1.05885,-2.06131,0.108254,0.986905,-2.04519,0.221071,0.882392,-2.05133,0.212205,0.690841,-2.02666,0.103629,0.72227,-2.03998,0.086481,0.656899,-2.02197,0.057323,0.430339,-1.96366,-0.045134,0.360825,-1.90499,0.238123,0.377374,-1.94595,0.185533,0.342979,-2.01046,0.092079,1.2635,-1.82745,0.070352,1.30597,-2.03733},
/*764*/{0.224891,1.84008,-1.70193,0.283047,1.7843,-1.86322,0.120291,1.7002,-1.60865,0.03768,1.60117,-1.55129,0.168538,1.53288,-1.62255,0.243791,1.48611,-1.64528,0.185039,1.85543,-2.10231,0.279699,1.78708,-1.94108,0.060037,1.83468,-1.99435,-0.006488,1.65791,-2.16632,0.004143,1.5627,-2.20657,0.168443,1.46751,-2.16397,0.212036,1.41925,-2.17808,0.169155,1.34446,-1.801,-0.027518,1.41884,-1.84198,-0.027693,1.455,-1.89354,-0.036204,1.43419,-1.95263,0.151311,1.4003,-2.05693,0.216787,1.06176,-1.732,0.09427,1.01211,-1.76273,0.125363,0.933163,-1.78232,0.213687,0.85763,-1.75743,0.063183,0.817984,-1.74213,-0.01044,0.816946,-1.75015,0.057097,0.928205,-1.76788,-0.013881,0.92486,-1.76878,-0.2399,0.867188,-1.76399,-0.305231,0.959649,-1.84403,-0.290524,0.704894,-1.79669,-0.346458,0.734807,-1.73084,0.188668,1.11044,-2.11738,0.222963,1.03313,-2.10048,0.064302,1.05867,-2.0611,0.100449,0.985065,-2.04555,0.210882,0.877018,-2.05217,0.198683,0.686514,-2.02641,0.08951,0.718795,-2.04092,0.072008,0.652742,-2.02198,0.035808,0.43082,-1.96455,-0.066491,0.361798,-1.90542,0.216758,0.377148,-1.947,0.16301,0.341826,-2.01088,0.089723,1.2624,-1.8275,0.068544,1.30573,-2.03726},
/*765*/{0.224129,1.83918,-1.70108,0.281646,1.78358,-1.86196,0.115317,1.70225,-1.60862,0.030615,1.60575,-1.55279,0.16206,1.53459,-1.62135,0.235723,1.48715,-1.6436,0.187326,1.85449,-2.10143,0.278956,1.78603,-1.93943,0.060315,1.83454,-1.99468,-0.001049,1.65537,-2.16599,0.01259,1.55966,-2.20662,0.178574,1.46802,-2.16202,0.223073,1.4209,-2.17594,0.168053,1.34314,-1.80046,-0.028253,1.42014,-1.84052,-0.029137,1.45495,-1.89315,-0.036783,1.4348,-1.95233,0.150827,1.40021,-2.05705,0.223363,1.06867,-1.7319,0.103031,1.01264,-1.76122,0.137522,0.936242,-1.78042,0.228223,0.861215,-1.75652,0.077238,0.818875,-1.74176,0.003186,0.814583,-1.74982,0.06901,0.929327,-1.76554,-0.003363,0.924563,-1.7676,-0.227309,0.86104,-1.76473,-0.297399,0.950143,-1.8443,-0.269105,0.697175,-1.79604,-0.325111,0.724225,-1.7294,0.182133,1.1075,-2.11834,0.215778,1.02918,-2.1008,0.057718,1.05694,-2.0613,0.092282,0.983757,-2.04614,0.199324,0.87246,-2.0529,0.184853,0.681678,-2.0255,0.078102,0.717686,-2.04127,0.058026,0.65265,-2.02361,0.014402,0.430654,-1.96572,-0.087642,0.362428,-1.90693,0.195425,0.377152,-1.94734,0.143507,0.342633,-2.01122,0.087938,1.26204,-1.82731,0.067009,1.30595,-2.03697},
/*766*/{0.223707,1.83961,-1.70022,0.281639,1.78297,-1.86079,0.111304,1.70506,-1.60914,0.02481,1.61124,-1.55421,0.154843,1.53736,-1.62002,0.228586,1.48871,-1.64198,0.189398,1.85429,-2.10032,0.279333,1.78577,-1.93794,0.061273,1.83487,-1.99476,0.003667,1.65339,-2.1655,0.020799,1.55714,-2.20731,0.188964,1.46919,-2.16008,0.235147,1.42493,-2.1737,0.165727,1.34268,-1.79879,-0.028301,1.42021,-1.84031,-0.029518,1.45504,-1.89264,-0.037237,1.43546,-1.95277,0.152086,1.40003,-2.05701,0.231649,1.07377,-1.73186,0.110658,1.01498,-1.76076,0.148939,0.938544,-1.77859,0.242293,0.86644,-1.75714,0.09174,0.819561,-1.74087,0.016609,0.812034,-1.75023,0.079846,0.93084,-1.76392,0.008282,0.923384,-1.76507,-0.212498,0.853019,-1.76394,-0.288924,0.940033,-1.84359,-0.24859,0.687814,-1.79597,-0.303931,0.713967,-1.72733,0.17637,1.10358,-2.11808,0.207795,1.02537,-2.10085,0.049785,1.0583,-2.06278,0.081763,0.983528,-2.04714,0.187068,0.868572,-2.05329,0.169741,0.676922,-2.02514,0.063942,0.715387,-2.0412,0.04194,0.651069,-2.0245,-0.005545,0.431841,-1.96639,-0.108077,0.362861,-1.90655,0.174552,0.376777,-1.94871,0.12212,0.342078,-2.01174,0.086309,1.26176,-1.82685,0.067111,1.30611,-2.03659},
/*767*/{0.222327,1.84038,-1.70011,0.279721,1.78256,-1.85981,0.106698,1.70833,-1.60872,0.01698,1.61566,-1.55539,0.14849,1.54029,-1.61974,0.221748,1.49128,-1.64015,0.191931,1.85517,-2.09977,0.279281,1.78566,-1.93692,0.062097,1.83464,-1.99506,0.008523,1.65122,-2.16453,0.028796,1.55583,-2.20748,0.199563,1.47408,-2.15838,0.246721,1.43021,-2.17105,0.165408,1.34356,-1.79778,-0.029445,1.42069,-1.84169,-0.029343,1.45525,-1.89336,-0.037484,1.43609,-1.95317,0.151529,1.3992,-2.05733,0.238565,1.07905,-1.73089,0.119868,1.0155,-1.75875,0.159775,0.942338,-1.77708,0.255903,0.872442,-1.75628,0.105562,0.821273,-1.74237,0.032052,0.812524,-1.75048,0.090495,0.931844,-1.7625,0.019565,0.922457,-1.76295,-0.198988,0.844016,-1.76345,-0.281245,0.92811,-1.84327,-0.226869,0.679925,-1.79431,-0.28157,0.701381,-1.72574,0.170045,1.10116,-2.11779,0.199107,1.02166,-2.1009,0.042386,1.05933,-2.06417,0.072721,0.983519,-2.04868,0.17403,0.86468,-2.05269,0.154134,0.671712,-2.02333,0.049416,0.713316,-2.04145,0.025955,0.649666,-2.02503,-0.029089,0.431117,-1.96688,-0.130571,0.364671,-1.90916,0.153233,0.376003,-1.94889,0.099277,0.341733,-2.01285,0.085547,1.26251,-1.82618,0.066866,1.30554,-2.03624},
/*768*/{0.220107,1.84177,-1.69924,0.280331,1.78292,-1.85834,0.101734,1.71254,-1.60918,0.010959,1.62117,-1.55626,0.142316,1.54408,-1.61911,0.214814,1.49434,-1.63867,0.193872,1.85664,-2.09935,0.279222,1.78575,-1.93542,0.063031,1.83426,-1.99593,0.012733,1.64959,-2.16395,0.036752,1.55515,-2.20719,0.209731,1.47816,-2.15557,0.258291,1.43636,-2.1679,0.163609,1.34495,-1.79552,-0.02941,1.4215,-1.84222,-0.029834,1.45565,-1.89364,-0.03762,1.43654,-1.95482,0.149417,1.39811,-2.05817,0.246116,1.08582,-1.72991,0.130461,1.02088,-1.75551,0.170765,0.947534,-1.77544,0.268528,0.878535,-1.75667,0.119393,0.823123,-1.7424,0.045232,0.810438,-1.75047,0.100847,0.932577,-1.76078,0.029893,0.920615,-1.76173,-0.18509,0.83588,-1.76431,-0.272533,0.915944,-1.84358,-0.204577,0.670484,-1.79388,-0.258552,0.689999,-1.72445,0.163584,1.09873,-2.11741,0.19067,1.0186,-2.10056,0.034355,1.05971,-2.06371,0.06335,0.982862,-2.04919,0.159962,0.860479,-2.05225,0.138163,0.668388,-2.02231,0.032925,0.710688,-2.04125,0.010237,0.648237,-2.02447,-0.050078,0.431736,-1.96678,-0.151824,0.364925,-1.90918,0.131464,0.376054,-1.9489,0.077204,0.341577,-2.01307,0.084157,1.2637,-1.82472,0.065788,1.30448,-2.03526},
/*769*/{0.218539,1.84414,-1.69816,0.279644,1.78348,-1.85639,0.097009,1.71683,-1.60922,0.00347,1.62575,-1.55806,0.135677,1.54827,-1.61775,0.207657,1.49805,-1.6374,0.196397,1.85848,-2.09813,0.279016,1.78698,-1.93366,0.063382,1.83648,-1.9974,0.018243,1.64943,-2.16309,0.044124,1.55501,-2.20744,0.218596,1.48329,-2.15271,0.268955,1.4447,-2.16495,0.163076,1.34677,-1.79465,-0.030279,1.42239,-1.84275,-0.029553,1.4567,-1.8946,-0.037511,1.43755,-1.95497,0.150575,1.39819,-2.05726,0.252288,1.09417,-1.72958,0.138157,1.02544,-1.75555,0.180455,0.95262,-1.77464,0.281818,0.886056,-1.75585,0.132758,0.824235,-1.74236,0.05991,0.809557,-1.75,0.110203,0.933284,-1.75947,0.040255,0.91923,-1.76024,-0.170865,0.826733,-1.76498,-0.263268,0.901086,-1.84345,-0.181922,0.660787,-1.79351,-0.236552,0.678313,-1.72335,0.15755,1.09652,-2.11688,0.181954,1.01577,-2.09962,0.027367,1.06063,-2.06421,0.051275,0.985928,-2.05026,0.145171,0.856612,-2.05156,0.120589,0.667869,-2.02234,0.017232,0.709651,-2.04034,-0.007289,0.647177,-2.0234,-0.070633,0.433867,-1.96702,-0.171863,0.365237,-1.90611,0.110466,0.376488,-1.94955,0.056507,0.341807,-2.01283,0.083756,1.26512,-1.8237,0.066705,1.30484,-2.03455},
/*770*/{0.215682,1.84709,-1.69737,0.278892,1.78543,-1.85485,0.091925,1.7213,-1.60937,-0.002383,1.63166,-1.55856,0.129238,1.55399,-1.61752,0.200504,1.5027,-1.63589,0.19748,1.8607,-2.0971,0.279058,1.78905,-1.93187,0.064593,1.83731,-1.99763,0.023922,1.64865,-2.16265,0.05034,1.55557,-2.20728,0.227887,1.48988,-2.15017,0.279481,1.45249,-2.16145,0.161556,1.34906,-1.79273,-0.030476,1.42356,-1.84454,-0.029545,1.45807,-1.89616,-0.03713,1.43919,-1.95582,0.151092,1.39817,-2.05736,0.258666,1.10076,-1.72946,0.144818,1.02942,-1.75485,0.189835,0.957752,-1.77337,0.293034,0.892573,-1.75621,0.147145,0.826162,-1.74282,0.07328,0.808929,-1.75058,0.119009,0.934498,-1.75859,0.048948,0.917006,-1.75992,-0.156553,0.817627,-1.76645,-0.254314,0.886602,-1.84377,-0.158877,0.651243,-1.79254,-0.213502,0.666204,-1.72165,0.15035,1.09463,-2.11614,0.171918,1.01325,-2.09894,0.018801,1.06293,-2.06451,0.040565,0.986539,-2.05084,0.129774,0.853223,-2.05106,0.103601,0.665175,-2.02107,0.001437,0.710259,-2.04009,-0.024745,0.647438,-2.02364,-0.087077,0.434729,-1.96616,-0.191103,0.36713,-1.90707,0.089088,0.37613,-1.95026,0.035655,0.342206,-2.01316,0.082689,1.26703,-1.8227,0.067409,1.30511,-2.03398},
/*771*/{0.212882,1.84913,-1.69637,0.277949,1.78737,-1.8526,0.087151,1.72603,-1.60922,-0.009071,1.6366,-1.55998,0.123687,1.5585,-1.61681,0.193776,1.50762,-1.63514,0.199677,1.86418,-2.09608,0.27926,1.79053,-1.92986,0.065299,1.83827,-1.99805,0.027678,1.64838,-2.16107,0.05771,1.55707,-2.20792,0.236339,1.49724,-2.14745,0.289042,1.46183,-2.1575,0.160879,1.35109,-1.79171,-0.030839,1.42539,-1.84546,-0.029804,1.4598,-1.89665,-0.036827,1.44071,-1.95759,0.151334,1.39804,-2.05735,0.264413,1.10879,-1.7297,0.153083,1.03427,-1.75328,0.198783,0.963121,-1.77396,0.304389,0.90058,-1.75615,0.160174,0.828207,-1.74293,0.087062,0.80799,-1.75113,0.127673,0.935512,-1.75722,0.057916,0.914982,-1.75922,-0.145826,0.810123,-1.76662,-0.24437,0.870598,-1.84395,-0.134947,0.641659,-1.79143,-0.190818,0.653594,-1.72132,0.142827,1.09329,-2.11496,0.162799,1.01101,-2.09772,0.010716,1.06474,-2.06397,0.030556,0.988524,-2.05137,0.112583,0.851647,-2.05018,0.086617,0.664874,-2.01854,-0.01563,0.710848,-2.03907,-0.041663,0.647739,-2.0218,-0.108118,0.436536,-1.96707,-0.212731,0.368903,-1.90621,0.068873,0.376289,-1.94997,0.015101,0.341839,-2.01351,0.081751,1.26901,-1.82179,0.067528,1.30546,-2.03344},
/*772*/{0.210546,1.85238,-1.6952,0.277601,1.79007,-1.85043,0.081832,1.73064,-1.60939,-0.016324,1.64224,-1.56108,0.116957,1.56464,-1.61698,0.188022,1.5134,-1.63391,0.201095,1.86728,-2.09508,0.279808,1.79315,-1.92885,0.065985,1.83949,-1.9984,0.03229,1.64832,-2.1595,0.064176,1.55923,-2.20805,0.244119,1.50594,-2.1449,0.298756,1.47224,-2.15374,0.161387,1.3539,-1.79113,-0.030937,1.42739,-1.84611,-0.029378,1.46127,-1.89695,-0.035453,1.44251,-1.95849,0.151996,1.39791,-2.057,0.269687,1.11686,-1.72771,0.160277,1.03659,-1.75237,0.207451,0.97003,-1.77378,0.315099,0.909246,-1.75606,0.173256,0.830371,-1.74355,0.102481,0.806846,-1.75127,0.135924,0.935948,-1.75582,0.067627,0.912017,-1.75901,-0.128518,0.796551,-1.76551,-0.234172,0.853317,-1.84523,-0.111351,0.631675,-1.79096,-0.168008,0.640513,-1.72069,0.135868,1.09164,-2.11333,0.152834,1.009,-2.09534,0.001715,1.06808,-2.06484,0.020359,0.988196,-2.04893,0.095746,0.85187,-2.04909,0.068882,0.665295,-2.01792,-0.032977,0.712912,-2.03781,-0.060226,0.650467,-2.02158,-0.130182,0.437665,-1.96923,-0.233553,0.369073,-1.90853,0.047698,0.376326,-1.9498,-0.006014,0.342407,-2.01323,0.081992,1.27139,-1.82053,0.068306,1.30588,-2.03254},
/*773*/{0.20714,1.8556,-1.69452,0.277218,1.79367,-1.84897,0.077292,1.73562,-1.60962,-0.022373,1.64834,-1.56231,0.110775,1.5708,-1.61679,0.181574,1.51885,-1.6332,0.202165,1.87107,-2.09386,0.280611,1.79678,-1.92633,0.066989,1.84142,-1.99952,0.036749,1.65033,-2.15831,0.070713,1.56172,-2.20857,0.251453,1.51371,-2.1418,0.307296,1.48252,-2.1499,0.161531,1.35693,-1.78972,-0.02962,1.42973,-1.84733,-0.027783,1.46379,-1.89902,-0.035249,1.44426,-1.95984,0.153908,1.39768,-2.05607,0.274489,1.12404,-1.72786,0.167837,1.0432,-1.75182,0.21631,0.975592,-1.77313,0.325147,0.917713,-1.75601,0.185987,0.832284,-1.74403,0.115255,0.805,-1.75241,0.143414,0.935887,-1.75551,0.074795,0.909432,-1.75962,-0.114077,0.785114,-1.76623,-0.223055,0.836249,-1.84683,-0.088585,0.62199,-1.79042,-0.144744,0.628353,-1.71974,0.128613,1.09094,-2.1114,0.142828,1.0075,-2.09301,-0.007257,1.07031,-2.06344,0.00939,0.990222,-2.04885,0.079402,0.852705,-2.04804,0.050233,0.666759,-2.01712,-0.050275,0.715117,-2.03655,-0.079016,0.652189,-2.02035,-0.150701,0.439458,-1.96757,-0.25438,0.371725,-1.90888,0.026593,0.375985,-1.94983,-0.027955,0.342363,-2.01315,0.082023,1.27431,-1.81891,0.069871,1.30617,-2.03143},
/*774*/{0.203752,1.85978,-1.69419,0.276672,1.7966,-1.84653,0.072579,1.74048,-1.60982,-0.027411,1.65473,-1.56327,0.104376,1.5765,-1.6172,0.176021,1.52508,-1.63225,0.203752,1.87495,-2.09269,0.280989,1.79974,-1.92413,0.068245,1.84333,-2.00094,0.041544,1.65199,-2.15826,0.077526,1.56439,-2.20899,0.259515,1.52282,-2.139,0.316239,1.49347,-2.14592,0.160803,1.35972,-1.78883,-0.02918,1.43273,-1.84889,-0.026657,1.4657,-1.9001,-0.033193,1.44694,-1.96141,0.15516,1.39786,-2.05574,0.28012,1.13105,-1.72727,0.173976,1.0465,-1.75246,0.223729,0.981971,-1.77394,0.335477,0.927653,-1.75647,0.198312,0.83477,-1.7439,0.128994,0.803592,-1.75182,0.150779,0.935878,-1.75548,0.082856,0.907919,-1.76013,-0.09902,0.773831,-1.76698,-0.211134,0.818249,-1.84777,-0.063909,0.612995,-1.78882,-0.121986,0.615592,-1.71963,0.121947,1.08953,-2.10924,0.132467,1.0067,-2.09073,-0.015716,1.07457,-2.0633,-0.001212,0.993574,-2.04832,0.063009,0.853798,-2.04614,0.032739,0.667547,-2.01542,-0.068251,0.717257,-2.03532,-0.098435,0.655807,-2.01973,-0.171252,0.441696,-1.96714,-0.275303,0.375742,-1.90821,0.006029,0.375936,-1.94948,-0.046919,0.342604,-2.01276,0.08132,1.27699,-1.81801,0.07093,1.30711,-2.03088},
/*775*/{0.200875,1.86337,-1.69362,0.275905,1.80072,-1.84445,0.068289,1.7457,-1.60969,-0.032972,1.66111,-1.56474,0.099171,1.58247,-1.61744,0.169961,1.53125,-1.63159,0.206178,1.87969,-2.09166,0.281607,1.80391,-1.92262,0.068808,1.84597,-2.00101,0.045463,1.65442,-2.15827,0.084224,1.56832,-2.20954,0.265684,1.53133,-2.13557,0.323776,1.50487,-2.14153,0.161865,1.36362,-1.78837,-0.028985,1.43581,-1.85055,-0.025436,1.46815,-1.90068,-0.031764,1.45008,-1.96264,0.155815,1.3978,-2.05574,0.283536,1.13893,-1.72686,0.179946,1.05076,-1.75268,0.230466,0.987817,-1.77432,0.34371,0.937509,-1.75709,0.209445,0.83676,-1.74394,0.142677,0.802633,-1.75199,0.158456,0.935647,-1.75487,0.09332,0.901589,-1.75923,-0.084618,0.763081,-1.7679,-0.197942,0.799954,-1.84904,-0.040071,0.602818,-1.78891,-0.097259,0.603719,-1.71872,0.114604,1.08929,-2.107,0.122455,1.00548,-2.08777,-0.022787,1.07866,-2.0632,-0.012921,0.99662,-2.04655,0.0471,0.855807,-2.04431,0.014729,0.670388,-2.01441,-0.085804,0.720505,-2.03395,-0.11404,0.658117,-2.01787,-0.190201,0.445913,-1.96587,-0.296422,0.379796,-1.90896,-0.015143,0.375754,-1.9494,-0.069221,0.34261,-2.0131,0.081602,1.28054,-1.81677,0.071594,1.30803,-2.03001},
/*776*/{0.197365,1.86762,-1.69305,0.276049,1.80484,-1.84304,0.064339,1.75108,-1.61069,-0.039012,1.66674,-1.56575,0.093896,1.58968,-1.61744,0.164083,1.53761,-1.63057,0.207411,1.88396,-2.09,0.282382,1.80764,-1.9204,0.07008,1.84884,-2.00193,0.049724,1.65676,-2.15904,0.091321,1.57207,-2.21057,0.272399,1.54122,-2.13222,0.330729,1.51611,-2.13727,0.162212,1.36733,-1.78792,-0.028296,1.43958,-1.85069,-0.024092,1.47105,-1.90223,-0.029219,1.45233,-1.96366,0.157726,1.39768,-2.05528,0.28647,1.14653,-1.72704,0.18771,1.05844,-1.75226,0.238831,0.995376,-1.77439,0.351577,0.946549,-1.75679,0.221354,0.839019,-1.74324,0.156667,0.801487,-1.75218,0.164368,0.934921,-1.75574,0.102372,0.897487,-1.75923,-0.069447,0.750828,-1.76875,-0.184348,0.780753,-1.84979,-0.015431,0.594125,-1.78783,-0.074064,0.590921,-1.71814,0.107308,1.08926,-2.1039,0.112847,1.00539,-2.08499,-0.031457,1.08197,-2.06159,-0.023916,1.00138,-2.04496,0.03291,0.857665,-2.04164,-0.003074,0.673454,-2.01297,-0.102995,0.723734,-2.03236,-0.13277,0.660996,-2.01634,-0.20986,0.449638,-1.96732,-0.315409,0.384983,-1.90804,-0.036079,0.376094,-1.94975,-0.090145,0.342918,-2.01245,0.081783,1.28415,-1.81506,0.072869,1.30881,-2.02869},
/*777*/{0.194315,1.87215,-1.69216,0.276441,1.80755,-1.84095,0.060188,1.75638,-1.61102,-0.045008,1.67364,-1.56792,0.088966,1.59621,-1.61809,0.159394,1.54397,-1.63012,0.209539,1.88868,-2.08874,0.282655,1.81193,-1.91835,0.071316,1.85117,-2.00245,0.056187,1.66063,-2.16077,0.097428,1.57603,-2.21123,0.277357,1.55058,-2.12864,0.337493,1.52808,-2.13224,0.163116,1.37184,-1.78797,-0.025835,1.44318,-1.85253,-0.022675,1.47389,-1.90388,-0.027101,1.45494,-1.96466,0.158977,1.39733,-2.05512,0.289173,1.15529,-1.72727,0.191901,1.06353,-1.75243,0.243797,1.00095,-1.77455,0.358862,0.956488,-1.75757,0.23271,0.841264,-1.7432,0.168474,0.800275,-1.75288,0.170712,0.934448,-1.75611,0.111406,0.894312,-1.75997,-0.054114,0.739577,-1.7702,-0.169825,0.761937,-1.85056,0.009316,0.585489,-1.78721,-0.049408,0.578999,-1.71849,0.100396,1.08992,-2.1012,0.103985,1.0058,-2.0815,-0.038292,1.08788,-2.06076,-0.033483,1.0057,-2.04417,0.018524,0.860424,-2.03834,-0.020613,0.67664,-2.01124,-0.119379,0.728375,-2.03112,-0.149651,0.665115,-2.01518,-0.226172,0.453358,-1.96588,-0.336244,0.391231,-1.90979,-0.057341,0.376243,-1.94878,-0.111154,0.342575,-2.01241,0.082691,1.28828,-1.81357,0.074066,1.3094,-2.02759},
/*778*/{0.191379,1.87651,-1.69203,0.275601,1.8121,-1.83884,0.055968,1.76184,-1.6114,-0.049186,1.68041,-1.56943,0.083469,1.60253,-1.61784,0.154301,1.54973,-1.62895,0.212324,1.89371,-2.08742,0.282881,1.81587,-1.9166,0.072942,1.85472,-2.00363,0.059938,1.66473,-2.16363,0.103686,1.581,-2.21278,0.28304,1.56144,-2.12507,0.342916,1.54007,-2.12799,0.165394,1.37621,-1.78797,-0.024902,1.44748,-1.85329,-0.020888,1.47679,-1.90558,-0.024556,1.45832,-1.96624,0.161064,1.39734,-2.05497,0.293284,1.16173,-1.72728,0.196367,1.06994,-1.75157,0.250035,1.00863,-1.77357,0.365124,0.965985,-1.75793,0.243093,0.843112,-1.74315,0.181158,0.799474,-1.75205,0.176189,0.933135,-1.75691,0.118231,0.890228,-1.76156,-0.036894,0.726719,-1.76914,-0.154488,0.742953,-1.8513,0.034654,0.577274,-1.78649,-0.024188,0.567205,-1.71776,0.094259,1.09105,-2.09805,0.094811,1.00617,-2.07753,-0.045279,1.09252,-2.05958,-0.043004,1.01051,-2.04317,0.004427,0.864029,-2.03581,-0.037055,0.68106,-2.0098,-0.136223,0.733055,-2.02965,-0.166944,0.670459,-2.01477,-0.247215,0.458311,-1.96667,-0.354223,0.398535,-1.90998,-0.077703,0.377156,-1.94873,-0.13181,0.343658,-2.01245,0.083853,1.29265,-1.81217,0.075652,1.31056,-2.0265},
/*779*/{0.188462,1.88073,-1.69194,0.274913,1.81814,-1.83751,0.052538,1.76777,-1.61243,-0.055052,1.68663,-1.57076,0.078341,1.60896,-1.61912,0.149198,1.55635,-1.62826,0.213544,1.89842,-2.08613,0.283374,1.82093,-1.91475,0.073919,1.8581,-2.00482,0.064944,1.66812,-2.1656,0.110357,1.58535,-2.2132,0.28683,1.57069,-2.12167,0.348737,1.55198,-2.12334,0.166703,1.38039,-1.78825,-0.022715,1.45172,-1.8545,-0.018332,1.48061,-1.90696,-0.022162,1.46172,-1.96752,0.163414,1.39735,-2.05477,0.296403,1.16867,-1.72705,0.198802,1.07619,-1.75236,0.254113,1.01493,-1.77545,0.370473,0.973951,-1.75976,0.253313,0.845207,-1.74275,0.194485,0.798201,-1.75181,0.182077,0.931705,-1.75723,0.127707,0.88464,-1.76261,-0.019846,0.711983,-1.76847,-0.138596,0.723817,-1.85188,0.060464,0.568529,-1.78654,0.001426,0.55631,-1.71794,0.088131,1.09196,-2.09447,0.085632,1.00773,-2.07403,-0.051601,1.09775,-2.05862,-0.052881,1.01652,-2.04228,-0.00947,0.868901,-2.03286,-0.054022,0.685564,-2.00846,-0.152721,0.738545,-2.02821,-0.182979,0.675991,-2.01402,-0.263683,0.463718,-1.965,-0.371426,0.406645,-1.90939,-0.098281,0.377857,-1.94881,-0.153643,0.343634,-2.01186,0.084655,1.29693,-1.81099,0.07703,1.31195,-2.02557},
/*780*/{0.186325,1.88507,-1.69175,0.27416,1.82242,-1.83524,0.049562,1.77326,-1.61275,-0.058836,1.69328,-1.57314,0.074474,1.61563,-1.61897,0.14531,1.56224,-1.62858,0.216121,1.90328,-2.08421,0.284564,1.82547,-1.91281,0.07616,1.86204,-2.00507,0.070307,1.67482,-2.16972,0.116806,1.59032,-2.2149,0.290949,1.58009,-2.11828,0.352972,1.56374,-2.11898,0.16918,1.38455,-1.78841,-0.020331,1.45605,-1.85416,-0.016272,1.48427,-1.90839,-0.018751,1.46449,-1.96844,0.16515,1.39756,-2.05437,0.298848,1.17693,-1.72745,0.203305,1.08249,-1.75135,0.259604,1.02186,-1.7752,0.374807,0.983257,-1.75823,0.263242,0.84664,-1.74268,0.206878,0.796426,-1.7516,0.188739,0.929655,-1.75946,0.136143,0.882033,-1.76202,-0.000449,0.701777,-1.76961,-0.121372,0.703978,-1.85178,0.085366,0.560934,-1.78626,0.027938,0.545674,-1.71739,0.082583,1.09262,-2.09128,0.076864,1.00917,-2.07074,-0.057788,1.1033,-2.05741,-0.060988,1.02198,-2.04132,-0.023797,0.874168,-2.0314,-0.070817,0.690811,-2.00706,-0.168341,0.744271,-2.02724,-0.200169,0.683302,-2.01336,-0.284087,0.472052,-1.97144,-0.391142,0.415258,-1.90967,-0.119661,0.376865,-1.9481,-0.174774,0.344466,-2.01196,0.086371,1.30131,-1.80937,0.078496,1.31319,-2.02413},
/*781*/{0.183992,1.88934,-1.69179,0.275446,1.82688,-1.83304,0.046219,1.77859,-1.61358,-0.064398,1.70053,-1.5753,0.069391,1.62172,-1.61965,0.140471,1.56851,-1.62774,0.218731,1.90856,-2.08299,0.285804,1.82968,-1.91052,0.076965,1.86542,-2.00596,0.075573,1.68161,-2.17255,0.123473,1.59563,-2.21603,0.293988,1.5898,-2.11491,0.356434,1.57522,-2.11497,0.170469,1.38901,-1.78904,-0.019822,1.46135,-1.85537,-0.014838,1.48782,-1.91048,-0.016028,1.46772,-1.96889,0.167262,1.39751,-2.05416,0.301994,1.18361,-1.72707,0.209253,1.08759,-1.74984,0.262636,1.02853,-1.7742,0.378048,0.990991,-1.75899,0.273737,0.847734,-1.74265,0.219274,0.79524,-1.75117,0.19385,0.927254,-1.76034,0.143049,0.876053,-1.76346,0.017252,0.688417,-1.76933,-0.103625,0.683131,-1.85147,0.111763,0.554052,-1.78714,0.055586,0.535827,-1.71831,0.077296,1.09435,-2.08839,0.069221,1.01155,-2.06738,-0.062704,1.11014,-2.05677,-0.069643,1.02934,-2.04057,-0.038885,0.879131,-2.03054,-0.085924,0.696211,-2.00636,-0.183272,0.751456,-2.02651,-0.215465,0.689766,-2.01258,-0.306229,0.475415,-1.96601,-0.406191,0.423324,-1.90754,-0.141228,0.376839,-1.94704,-0.195799,0.344256,-2.01123,0.086769,1.30609,-1.80797,0.079442,1.31459,-2.02291},
/*782*/{0.181928,1.89378,-1.69157,0.274115,1.83063,-1.83211,0.042715,1.78431,-1.61486,-0.066808,1.70673,-1.57672,0.065612,1.62752,-1.61997,0.136851,1.57465,-1.62711,0.220633,1.913,-2.0811,0.286766,1.83414,-1.90845,0.078939,1.86922,-2.00642,0.081158,1.68448,-2.17545,0.129716,1.60092,-2.21736,0.296943,1.59936,-2.11127,0.359525,1.58584,-2.1111,0.171458,1.39279,-1.78906,-0.01622,1.46639,-1.85571,-0.012493,1.49223,-1.91199,-0.012818,1.47121,-1.9696,0.169178,1.39725,-2.0535,0.303645,1.19026,-1.72678,0.208772,1.09227,-1.74991,0.266351,1.03562,-1.7734,0.38068,0.998805,-1.75939,0.28297,0.849142,-1.74293,0.231932,0.793607,-1.75138,0.199551,0.923647,-1.76172,0.152531,0.870112,-1.76397,0.034838,0.675337,-1.7697,-0.084472,0.663784,-1.85144,0.138122,0.547242,-1.78817,0.083376,0.525308,-1.71825,0.071848,1.09588,-2.08492,0.060829,1.01378,-2.06402,-0.067999,1.11604,-2.05548,-0.077139,1.03593,-2.03969,-0.053262,0.884606,-2.03009,-0.10088,0.703674,-2.00667,-0.198758,0.75898,-2.02626,-0.23103,0.698493,-2.01287,-0.315236,0.483894,-1.9653,-0.423823,0.434499,-1.90593,-0.162627,0.376384,-1.94699,-0.216346,0.345456,-2.01001,0.087232,1.31059,-1.80636,0.0802,1.31603,-2.02141},
/*783*/{0.180335,1.89753,-1.69139,0.273533,1.837,-1.8309,0.039232,1.78989,-1.61561,-0.072139,1.71253,-1.57936,0.06246,1.63368,-1.62062,0.132148,1.57942,-1.62593,0.222569,1.91754,-2.0798,0.286368,1.83862,-1.90717,0.080471,1.87259,-2.00745,0.085645,1.68962,-2.17923,0.135351,1.60635,-2.21904,0.30023,1.60912,-2.10823,0.362508,1.59619,-2.1074,0.172586,1.39687,-1.78918,-0.014663,1.47173,-1.85528,-0.009838,1.49581,-1.91348,-0.010038,1.47459,-1.96988,0.171491,1.39679,-2.05264,0.305539,1.19738,-1.72733,0.21091,1.09834,-1.74908,0.26833,1.04095,-1.77342,0.381914,1.00534,-1.75962,0.29243,0.849406,-1.74291,0.243828,0.79129,-1.75145,0.204098,0.920617,-1.76169,0.160203,0.863495,-1.76527,0.052523,0.660967,-1.76984,-0.065884,0.643832,-1.85017,0.164501,0.541111,-1.78808,0.11139,0.51514,-1.7188,0.067105,1.09809,-2.08226,0.052821,1.01652,-2.06064,-0.072977,1.12394,-2.05549,-0.085232,1.04241,-2.03848,-0.065806,0.890623,-2.0294,-0.115524,0.71057,-2.00688,-0.212998,0.766946,-2.02516,-0.245041,0.70451,-2.01192,-0.330165,0.491529,-1.96581,-0.438772,0.444807,-1.90592,-0.183553,0.376733,-1.94697,-0.236967,0.345841,-2.00981,0.087688,1.31522,-1.80435,0.081,1.31735,-2.01947},
/*784*/{0.178802,1.90144,-1.69149,0.273509,1.8423,-1.82958,0.037078,1.79542,-1.61736,-0.075192,1.71902,-1.58165,0.058998,1.63873,-1.62101,0.128828,1.58451,-1.62578,0.225491,1.92239,-2.07863,0.287255,1.84275,-1.90507,0.082497,1.87579,-2.00844,0.091272,1.69451,-2.18307,0.141847,1.61111,-2.22047,0.302042,1.61798,-2.10517,0.365229,1.6063,-2.10345,0.175779,1.40172,-1.79001,-0.012422,1.4768,-1.85514,-0.007579,1.49961,-1.91532,-0.006627,1.47812,-1.96992,0.172957,1.397,-2.05159,0.307868,1.20334,-1.72731,0.213276,1.10565,-1.74833,0.272095,1.0481,-1.7723,0.382632,1.01094,-1.75975,0.301844,0.849794,-1.74307,0.257068,0.789539,-1.75139,0.211534,0.91543,-1.76303,0.168965,0.857589,-1.76586,0.072695,0.648402,-1.7692,-0.045451,0.624332,-1.84942,0.190879,0.535584,-1.79068,0.140469,0.506314,-1.72069,0.062143,1.1008,-2.07988,0.045025,1.01963,-2.05783,-0.076954,1.12993,-2.0546,-0.092112,1.05041,-2.03819,-0.077664,0.898468,-2.02893,-0.129883,0.717929,-2.00725,-0.226897,0.774719,-2.02467,-0.259321,0.712825,-2.01154,-0.35365,0.495907,-1.96582,-0.453829,0.45779,-1.90507,-0.205742,0.376803,-1.94659,-0.260292,0.346476,-2.01025,0.089758,1.3205,-1.80248,0.082198,1.31893,-2.01758},
/*785*/{0.177657,1.90534,-1.6911,0.273118,1.8464,-1.82841,0.034251,1.8013,-1.61889,-0.079183,1.72483,-1.584,0.055347,1.64436,-1.62179,0.126699,1.58992,-1.62599,0.226638,1.92667,-2.07688,0.286974,1.84663,-1.90399,0.083885,1.87875,-2.00907,0.096278,1.69983,-2.18622,0.146916,1.61623,-2.22182,0.303707,1.62646,-2.10209,0.367148,1.61628,-2.10001,0.17816,1.40623,-1.79036,-0.010314,1.48195,-1.85636,-0.005426,1.50355,-1.91566,-0.004346,1.48152,-1.97019,0.175613,1.39707,-2.05044,0.309293,1.20917,-1.72727,0.214668,1.11169,-1.74751,0.272981,1.0533,-1.77152,0.382461,1.01684,-1.75967,0.310063,0.849248,-1.74305,0.268907,0.786761,-1.75118,0.216082,0.910444,-1.76392,0.177423,0.849977,-1.76636,0.092617,0.634876,-1.76895,-0.024672,0.604986,-1.848,0.217132,0.530041,-1.79225,0.169394,0.498009,-1.72259,0.058204,1.10315,-2.07719,0.037774,1.02312,-2.05528,-0.079633,1.13763,-2.05413,-0.097916,1.05797,-2.03715,-0.089983,0.905479,-2.02858,-0.143044,0.726513,-2.00825,-0.240636,0.784262,-2.02448,-0.272514,0.721065,-2.01154,-0.363326,0.504652,-1.96803,-0.471939,0.474657,-1.90457,-0.227191,0.376634,-1.94683,-0.28166,0.347859,-2.01074,0.091189,1.32556,-1.80064,0.083543,1.32063,-2.01568},
/*786*/{0.176123,1.90857,-1.69154,0.273548,1.84966,-1.8272,0.031751,1.80612,-1.62004,-0.082144,1.72967,-1.58673,0.052801,1.64947,-1.62233,0.123622,1.59475,-1.62522,0.228173,1.93056,-2.07578,0.287791,1.8509,-1.90232,0.085373,1.88257,-2.00966,0.103901,1.70561,-2.18861,0.152185,1.62116,-2.22317,0.305106,1.63418,-2.09969,0.369146,1.62552,-2.09668,0.178605,1.41018,-1.79019,-0.0082,1.48718,-1.8549,-0.003302,1.50782,-1.91673,-0.001977,1.48492,-1.97041,0.177567,1.39793,-2.04948,0.311391,1.21463,-1.72738,0.215942,1.11602,-1.74558,0.274076,1.05881,-1.76957,0.382287,1.02048,-1.76033,0.319224,0.848759,-1.74277,0.280027,0.783374,-1.75169,0.22244,0.904742,-1.76397,0.186728,0.84197,-1.7668,0.113378,0.622868,-1.7701,-0.002781,0.586051,-1.84673,0.243667,0.525779,-1.79477,0.200095,0.490592,-1.72344,0.053848,1.10587,-2.07518,0.031909,1.02711,-2.05295,-0.083592,1.14504,-2.05397,-0.10353,1.06663,-2.03667,-0.10015,0.913568,-2.0282,-0.153386,0.735486,-2.01105,-0.252945,0.792533,-2.02372,-0.286414,0.730164,-2.01014,-0.372511,0.512824,-1.96754,-0.479695,0.485533,-1.90321,-0.24803,0.376775,-1.94743,-0.303952,0.348545,-2.00913,0.091527,1.33016,-1.79893,0.084151,1.32293,-2.01392},
/*787*/{0.175089,1.9123,-1.69161,0.273966,1.85482,-1.82658,0.029804,1.81107,-1.62195,-0.08458,1.73501,-1.58957,0.049865,1.65331,-1.62242,0.120638,1.59891,-1.6247,0.2301,1.93427,-2.07435,0.288169,1.85466,-1.90092,0.087053,1.88528,-2.01011,0.108205,1.7103,-2.19136,0.157215,1.6263,-2.22506,0.306327,1.64149,-2.09807,0.369555,1.63346,-2.09339,0.180124,1.41424,-1.79005,-0.005332,1.49076,-1.85609,-0.001096,1.51091,-1.91813,0.001483,1.48771,-1.97089,0.179934,1.39857,-2.04814,0.3133,1.21941,-1.72747,0.217543,1.11915,-1.74289,0.274765,1.06241,-1.7686,0.381413,1.02345,-1.76014,0.326927,0.847046,-1.74337,0.294861,0.781891,-1.75108,0.227954,0.898899,-1.76441,0.194682,0.833338,-1.76665,0.134206,0.611939,-1.77033,0.019146,0.567819,-1.84559,0.26971,0.521426,-1.79753,0.228155,0.482917,-1.72669,0.051103,1.10878,-2.07319,0.02659,1.02958,-2.05103,-0.085022,1.15251,-2.05348,-0.108403,1.07433,-2.0368,-0.110464,0.922125,-2.02903,-0.167182,0.743767,-2.01163,-0.264748,0.80149,-2.02357,-0.298169,0.738225,-2.00881,-0.388037,0.519543,-1.96774,-0.491121,0.501439,-1.90143,-0.269515,0.376798,-1.9486,-0.326872,0.350541,-2.00909,0.092943,1.33434,-1.7976,0.086318,1.32449,-2.0125},
/*788*/{0.174395,1.91521,-1.69147,0.27341,1.85712,-1.82546,0.027977,1.81614,-1.62374,-0.087844,1.73975,-1.59248,0.047812,1.65785,-1.62272,0.11791,1.60274,-1.62423,0.232005,1.9381,-2.07314,0.288458,1.85797,-1.89971,0.088657,1.88765,-2.0103,0.112637,1.71441,-2.19321,0.161246,1.63091,-2.22655,0.307523,1.64779,-2.09665,0.370536,1.64166,-2.09025,0.181347,1.41967,-1.78975,-0.00311,1.49622,-1.85503,0.001379,1.51489,-1.91835,0.003684,1.49118,-1.97027,0.181612,1.39967,-2.04746,0.31409,1.22321,-1.72792,0.217102,1.12712,-1.74253,0.273228,1.06645,-1.76731,0.379806,1.02602,-1.76021,0.334958,0.845886,-1.74323,0.302491,0.776874,-1.75134,0.233157,0.891004,-1.76481,0.203332,0.826048,-1.76562,0.154415,0.599168,-1.77095,0.041887,0.549852,-1.845,0.295311,0.5177,-1.79967,0.25687,0.475232,-1.72874,0.047764,1.11119,-2.07204,0.01929,1.03495,-2.05013,-0.086771,1.15881,-2.05279,-0.111957,1.08173,-2.03632,-0.120063,0.930805,-2.0296,-0.177422,0.75257,-2.01346,-0.276241,0.80889,-2.02279,-0.30857,0.747855,-2.00905,-0.399424,0.52731,-1.96922,-0.499517,0.516798,-1.89901,-0.289865,0.377234,-1.95072,-0.349157,0.352632,-2.00828,0.094481,1.33987,-1.79532,0.087205,1.32689,-2.01004},
/*789*/{0.17354,1.91795,-1.69168,0.273433,1.86019,-1.82444,0.026002,1.82085,-1.62501,-0.089786,1.74411,-1.59446,0.045761,1.66217,-1.62416,0.115832,1.60588,-1.62416,0.233497,1.94145,-2.07165,0.289057,1.86156,-1.89852,0.090541,1.89073,-2.01182,0.116911,1.71893,-2.19551,0.16605,1.63542,-2.22871,0.308118,1.6539,-2.09512,0.371627,1.64764,-2.08745,0.181565,1.4229,-1.78939,-0.000994,1.50019,-1.85547,0.004106,1.51794,-1.91916,0.005899,1.49433,-1.97048,0.182942,1.40107,-2.04578,0.31577,1.22675,-1.7284,0.217747,1.12933,-1.73854,0.272464,1.06936,-1.76495,0.378944,1.0268,-1.75938,0.341526,0.843748,-1.7422,0.314892,0.774653,-1.75122,0.238547,0.884977,-1.76374,0.21244,0.817851,-1.76604,0.176166,0.586595,-1.77046,0.065684,0.532677,-1.84448,0.320354,0.514048,-1.8018,0.286263,0.46944,-1.72986,0.045777,1.1141,-2.07105,0.014612,1.03809,-2.04839,-0.088338,1.16558,-2.05271,-0.115697,1.08975,-2.03598,-0.128712,0.939159,-2.03069,-0.187417,0.761258,-2.01565,-0.286115,0.817843,-2.02185,-0.317497,0.756076,-2.00845,-0.409474,0.53638,-1.97034,-0.506869,0.532649,-1.89716,-0.308645,0.378067,-1.95242,-0.371957,0.356175,-2.00698,0.094623,1.34356,-1.79419,0.088193,1.32904,-2.00883},
/*790*/{0.17283,1.92045,-1.69207,0.266698,1.86597,-1.82589,0.024618,1.82472,-1.62657,-0.093011,1.74778,-1.59674,0.04454,1.66564,-1.62407,0.115481,1.6097,-1.62233,0.235205,1.94453,-2.07055,0.289231,1.86521,-1.898,0.09139,1.89379,-2.01247,0.121405,1.72301,-2.19708,0.16939,1.63916,-2.23033,0.308971,1.65928,-2.09371,0.372671,1.65388,-2.08546,0.183838,1.42708,-1.78792,0.001087,1.50424,-1.85481,0.006399,1.52149,-1.91917,0.008446,1.4969,-1.97029,0.185012,1.40245,-2.04494,0.315516,1.22914,-1.72913,0.218325,1.13476,-1.7373,0.270524,1.07298,-1.76229,0.375711,1.02642,-1.75941,0.348751,0.840826,-1.74206,0.324629,0.769692,-1.7505,0.243355,0.876839,-1.76341,0.221066,0.808745,-1.76504,0.197372,0.575654,-1.77118,0.089085,0.51612,-1.84428,0.345244,0.51099,-1.80303,0.312131,0.462826,-1.73282,0.042355,1.11723,-2.07058,0.010785,1.04254,-2.04921,-0.089379,1.17063,-2.05198,-0.11898,1.09567,-2.03508,-0.13663,0.947135,-2.03122,-0.195929,0.768955,-2.01791,-0.293367,0.826495,-2.02158,-0.32557,0.765033,-2.00817,-0.42059,0.54468,-1.97129,-0.513715,0.55034,-1.89561,-0.328474,0.377931,-1.95374,-0.394271,0.36137,-2.00538,0.096553,1.34796,-1.79224,0.090035,1.33115,-2.00672},
/*791*/{0.172181,1.92262,-1.69204,0.267475,1.86889,-1.82462,0.023247,1.82849,-1.62755,-0.093808,1.75121,-1.59874,0.042702,1.66843,-1.62381,0.113543,1.61181,-1.62073,0.236813,1.94719,-2.06978,0.289839,1.86829,-1.89694,0.093425,1.89596,-2.01239,0.124612,1.72722,-2.19883,0.172267,1.64333,-2.23138,0.310325,1.6637,-2.09325,0.37326,1.658,-2.08105,0.182925,1.43034,-1.78687,0.002141,1.5076,-1.85415,0.008035,1.52466,-1.91903,0.010895,1.49978,-1.96983,0.186802,1.40442,-2.04365,0.316162,1.23126,-1.72986,0.218712,1.13814,-1.73568,0.269253,1.07457,-1.75951,0.374907,1.02697,-1.75774,0.355336,0.838539,-1.74153,0.335011,0.766168,-1.75032,0.24841,0.86897,-1.76318,0.229779,0.799401,-1.76552,0.217838,0.564089,-1.77164,0.112789,0.500947,-1.84542,0.369272,0.508004,-1.80396,0.339988,0.457043,-1.73566,0.040499,1.12047,-2.07065,0.006901,1.04477,-2.04853,-0.091645,1.17565,-2.05062,-0.121292,1.10064,-2.0338,-0.142696,0.954311,-2.03142,-0.203752,0.776632,-2.01954,-0.300291,0.835316,-2.02091,-0.333433,0.773814,-2.00892,-0.429095,0.554067,-1.97249,-0.518804,0.566794,-1.8935,-0.345714,0.377738,-1.95419,-0.416228,0.367518,-2.00274,0.096282,1.35114,-1.79105,0.091212,1.33377,-2.00552},
/*792*/{0.172212,1.92489,-1.6922,0.273837,1.8672,-1.82205,0.022226,1.83153,-1.6301,-0.097215,1.7536,-1.60111,0.040887,1.67118,-1.62483,0.112689,1.61443,-1.62027,0.238736,1.94992,-2.06877,0.291032,1.86988,-1.89555,0.094738,1.89886,-2.01307,0.128642,1.73074,-2.20039,0.176291,1.64637,-2.23342,0.311834,1.66751,-2.09291,0.373736,1.66324,-2.08146,0.186168,1.43361,-1.78683,0.004036,1.51152,-1.85377,0.009673,1.5274,-1.91845,0.01159,1.50292,-1.96983,0.187679,1.40625,-2.04311,0.31808,1.23289,-1.73074,0.215528,1.14118,-1.73526,0.267799,1.07677,-1.75795,0.372371,1.02561,-1.75663,0.361363,0.835606,-1.74055,0.344164,0.762192,-1.74987,0.252588,0.860729,-1.76349,0.237076,0.789864,-1.76558,0.237832,0.553943,-1.77243,0.136511,0.486364,-1.84633,0.39183,0.505316,-1.80614,0.365419,0.452172,-1.73763,0.038565,1.12377,-2.07169,0.004516,1.04916,-2.0505,-0.092524,1.18075,-2.04906,-0.122802,1.10471,-2.03329,-0.146012,0.95982,-2.03113,-0.21013,0.782855,-2.02067,-0.306115,0.843502,-2.01976,-0.339433,0.781075,-2.00908,-0.440162,0.563007,-1.97302,-0.52419,0.584866,-1.89353,-0.363187,0.379038,-1.95482,-0.437719,0.375788,-2.00069,0.098543,1.35495,-1.79001,0.092014,1.33609,-2.00432},
/*793*/{0.171979,1.92665,-1.69202,0.275606,1.86934,-1.82099,0.021223,1.83453,-1.63139,-0.097638,1.75602,-1.60291,0.039726,1.67342,-1.62486,0.111796,1.61639,-1.61955,0.239657,1.95242,-2.06755,0.291749,1.87248,-1.89457,0.096098,1.90058,-2.01307,0.133019,1.73418,-2.20111,0.179071,1.64937,-2.23486,0.311849,1.66965,-2.09236,0.373843,1.66685,-2.08018,0.186245,1.43683,-1.7864,0.00579,1.51454,-1.85354,0.010779,1.53048,-1.91822,0.014253,1.50571,-1.96897,0.188815,1.40872,-2.04237,0.315054,1.23295,-1.73146,0.212582,1.14187,-1.73383,0.264322,1.07792,-1.75718,0.369012,1.02354,-1.75517,0.366529,0.832981,-1.73946,0.353256,0.757833,-1.74868,0.257271,0.851564,-1.76326,0.245214,0.780115,-1.76507,0.25749,0.544634,-1.77296,0.159791,0.472532,-1.84805,0.414298,0.503237,-1.80769,0.390486,0.447146,-1.73963,0.036688,1.12731,-2.07241,0.002645,1.0522,-2.05151,-0.09314,1.18398,-2.04778,-0.124016,1.1086,-2.0322,-0.146632,0.963543,-2.03104,-0.216305,0.788562,-2.02151,-0.310249,0.850176,-2.02023,-0.344588,0.789714,-2.00896,-0.449204,0.572644,-1.97395,-0.528206,0.602064,-1.89453,-0.381918,0.379596,-1.95331,-0.457867,0.38513,-1.99847,0.099225,1.35803,-1.78926,0.093196,1.33882,-2.00355},
/*794*/{0.172093,1.92807,-1.69181,0.275814,1.87134,-1.82055,0.020543,1.83708,-1.63231,-0.098247,1.75841,-1.60445,0.039013,1.67482,-1.62491,0.1111,1.61803,-1.61816,0.240912,1.95424,-2.06693,0.292548,1.87459,-1.89401,0.096721,1.90334,-2.01289,0.131257,1.73764,-2.20277,0.181553,1.65209,-2.23601,0.312468,1.67209,-2.09151,0.374526,1.6686,-2.07793,0.186496,1.43954,-1.78601,0.006991,1.51701,-1.85296,0.010959,1.5343,-1.9189,0.015051,1.50895,-1.96851,0.189461,1.41079,-2.04163,0.314815,1.23317,-1.73177,0.21123,1.1431,-1.73319,0.261299,1.07707,-1.75568,0.366395,1.02112,-1.75321,0.370632,0.829125,-1.73753,0.361919,0.753549,-1.74784,0.261316,0.841878,-1.76174,0.252111,0.770645,-1.76528,0.278245,0.53469,-1.77373,0.183256,0.45981,-1.8501,0.436656,0.501419,-1.80838,0.415058,0.443129,-1.74179,0.035512,1.13067,-2.07377,0.000198,1.05411,-2.05193,-0.09347,1.18759,-2.0462,-0.124179,1.11217,-2.03127,-0.146228,0.96567,-2.0307,-0.220113,0.792741,-2.02213,-0.312777,0.856529,-2.02008,-0.348707,0.797223,-2.00892,-0.453134,0.58452,-1.97589,-0.534333,0.617702,-1.89456,-0.400146,0.377706,-1.94988,-0.476365,0.395395,-1.99561,0.099198,1.36101,-1.78875,0.09339,1.3415,-2.00302},
/*795*/{0.173085,1.92964,-1.69102,0.276984,1.87295,-1.81965,0.02053,1.83862,-1.63326,-0.098631,1.7608,-1.60569,0.038762,1.67635,-1.62463,0.110791,1.61928,-1.61715,0.241525,1.95672,-2.0663,0.292605,1.8764,-1.89353,0.098607,1.90498,-2.01294,0.133322,1.74035,-2.20345,0.183702,1.65437,-2.23681,0.313605,1.67403,-2.0914,0.375591,1.67055,-2.07689,0.185729,1.44194,-1.78573,0.008184,1.51941,-1.8527,0.01229,1.53638,-1.91783,0.015935,1.51196,-1.9684,0.190315,1.41346,-2.04131,0.312795,1.23152,-1.73219,0.208384,1.14247,-1.73266,0.257606,1.07606,-1.75405,0.362662,1.01747,-1.75178,0.375004,0.825056,-1.73682,0.369493,0.750595,-1.74727,0.264249,0.832172,-1.7612,0.259142,0.760741,-1.7651,0.296362,0.526098,-1.77361,0.206022,0.448651,-1.85147,0.456847,0.499045,-1.80814,0.438588,0.440809,-1.74349,0.035949,1.13377,-2.07424,0.001627,1.0585,-2.05377,-0.09392,1.19027,-2.04588,-0.124233,1.11439,-2.02988,-0.144334,0.967451,-2.02998,-0.223635,0.795531,-2.02215,-0.313443,0.862201,-2.02006,-0.35196,0.803496,-2.00991,-0.461194,0.595415,-1.97687,-0.539959,0.634332,-1.89724,-0.420959,0.382231,-1.94688,-0.495215,0.405892,-1.9914,0.099234,1.36309,-1.78868,0.094028,1.34427,-2.00303},
/*796*/{0.172886,1.93047,-1.69086,0.277976,1.87239,-1.81844,0.020159,1.84005,-1.63442,-0.099791,1.76129,-1.607,0.038247,1.67683,-1.6246,0.111216,1.61966,-1.61566,0.242443,1.95821,-2.06544,0.294147,1.87826,-1.8921,0.099248,1.9079,-2.0131,0.135439,1.74285,-2.2039,0.185172,1.65603,-2.23826,0.313832,1.67494,-2.09122,0.376022,1.67082,-2.07584,0.190057,1.44411,-1.78529,0.008514,1.52201,-1.85271,0.012648,1.53932,-1.91631,0.016203,1.51448,-1.96792,0.190707,1.41608,-2.04065,0.311886,1.2283,-1.73098,0.20857,1.14295,-1.73132,0.252947,1.07435,-1.75235,0.35908,1.01314,-1.74993,0.378355,0.821216,-1.73557,0.376953,0.745677,-1.74653,0.267092,0.822117,-1.75874,0.266333,0.751755,-1.76491,0.316139,0.5185,-1.77427,0.227231,0.437892,-1.85328,0.475618,0.498281,-1.80868,0.460098,0.437365,-1.74438,0.036338,1.13584,-2.07501,0.004158,1.06066,-2.05641,-0.093649,1.19198,-2.04402,-0.122359,1.11544,-2.02817,-0.142734,0.968097,-2.02954,-0.225036,0.797767,-2.02153,-0.313521,0.867903,-2.02146,-0.354778,0.809605,-2.01008,-0.467733,0.604844,-1.97703,-0.546008,0.651905,-1.90059,-0.441485,0.394016,-1.94142,-0.514576,0.41827,-1.98936,0.101692,1.36588,-1.78802,0.094918,1.34675,-2.0023},
/*797*/{0.173285,1.93186,-1.69006,0.278166,1.87527,-1.81806,0.020695,1.84107,-1.63439,-0.100936,1.76049,-1.60805,0.038484,1.6773,-1.62455,0.111173,1.61963,-1.61446,0.243318,1.95974,-2.06451,0.294498,1.87996,-1.8917,0.1003,1.90936,-2.01268,0.136857,1.74509,-2.20435,0.185637,1.6582,-2.23887,0.31455,1.6751,-2.09057,0.376626,1.67057,-2.07535,0.190882,1.447,-1.78514,0.007924,1.5238,-1.8524,0.013688,1.54145,-1.91607,0.016476,1.51677,-1.96702,0.191873,1.41843,-2.04103,0.310035,1.22521,-1.73093,0.202508,1.14104,-1.73077,0.247898,1.07243,-1.75151,0.354423,1.00791,-1.7487,0.381072,0.816702,-1.73451,0.383575,0.741098,-1.74646,0.270125,0.813092,-1.75709,0.273097,0.741104,-1.76275,0.334901,0.512766,-1.77544,0.248746,0.42859,-1.85467,0.49485,0.499376,-1.8099,0.480517,0.435603,-1.74611,0.037876,1.13825,-2.07582,0.005989,1.06134,-2.05714,-0.091168,1.19234,-2.04306,-0.119951,1.11594,-2.02762,-0.138626,0.96833,-2.02867,-0.226715,0.798432,-2.02052,-0.313266,0.872042,-2.02212,-0.355342,0.816347,-2.01137,-0.476498,0.615679,-1.97819,-0.553492,0.666448,-1.90316,-0.459984,0.40502,-1.9381,-0.530001,0.431215,-1.98597,0.102798,1.36822,-1.78781,0.095968,1.3491,-2.00208},
/*798*/{0.17449,1.93237,-1.68955,0.279211,1.8761,-1.81793,0.021484,1.84105,-1.63423,-0.100588,1.76016,-1.60901,0.039763,1.67702,-1.6241,0.112504,1.61926,-1.61235,0.243685,1.96084,-2.06384,0.294788,1.88126,-1.8914,0.101171,1.91175,-2.01228,0.138511,1.74666,-2.20449,0.185473,1.65866,-2.23872,0.316446,1.67556,-2.09038,0.377121,1.6692,-2.07474,0.190179,1.4472,-1.78554,0.010064,1.5253,-1.85193,0.014074,1.54388,-1.91588,0.017416,1.51899,-1.96659,0.191844,1.4212,-2.04076,0.30662,1.22025,-1.73098,0.199044,1.1392,-1.72946,0.242961,1.06994,-1.75066,0.350369,1.00254,-1.74691,0.384049,0.812649,-1.7344,0.390886,0.73921,-1.74668,0.272857,0.803681,-1.75513,0.27928,0.732326,-1.76123,0.349649,0.506054,-1.7756,0.26854,0.419796,-1.85648,0.511858,0.499551,-1.81103,0.500759,0.435509,-1.74717,0.040408,1.13975,-2.07638,0.009136,1.06305,-2.05819,-0.090385,1.19239,-2.04292,-0.117666,1.11574,-2.02696,-0.134435,0.967341,-2.02776,-0.228442,0.799365,-2.01922,-0.311159,0.87564,-2.02307,-0.356459,0.82199,-2.0119,-0.489683,0.627597,-1.97781,-0.562311,0.684201,-1.90661,-0.476383,0.416713,-1.93284,-0.54631,0.44442,-1.98379,0.102434,1.36886,-1.78865,0.095858,1.35166,-2.0031},
/*799*/{0.175661,1.93295,-1.68865,0.280195,1.87667,-1.81705,0.021629,1.84061,-1.63425,-0.09931,1.75948,-1.60944,0.040229,1.67656,-1.62337,0.112939,1.61852,-1.61063,0.244284,1.96169,-2.06348,0.295844,1.88252,-1.89056,0.101362,1.91253,-2.01196,0.13809,1.74825,-2.20366,0.185943,1.65982,-2.239,0.317546,1.67495,-2.09038,0.377022,1.6666,-2.07462,0.19239,1.44924,-1.78558,0.010954,1.52545,-1.85085,0.014498,1.54437,-1.9148,0.017964,1.52,-1.96532,0.19267,1.42371,-2.04055,0.303652,1.21549,-1.72945,0.196976,1.13636,-1.72899,0.236848,1.06549,-1.75115,0.345411,0.996427,-1.74622,0.387565,0.808903,-1.73364,0.396204,0.734206,-1.74725,0.275871,0.795087,-1.75246,0.286165,0.723739,-1.75871,0.365156,0.500763,-1.77601,0.28708,0.41269,-1.85715,0.52753,0.501278,-1.81117,0.517457,0.43558,-1.74854,0.042762,1.13987,-2.07707,0.013552,1.06211,-2.05871,-0.087025,1.19141,-2.04217,-0.113872,1.11435,-2.02623,-0.129522,0.965738,-2.02661,-0.228978,0.799848,-2.01768,-0.308972,0.880259,-2.02346,-0.356051,0.827936,-2.01276,-0.495052,0.639796,-1.97916,-0.569765,0.70008,-1.90937,-0.493332,0.430139,-1.92861,-0.560137,0.458505,-1.98113,0.105258,1.37001,-1.7883,0.097692,1.3532,-2.00274},
/*800*/{0.176472,1.93314,-1.68789,0.280004,1.87716,-1.8166,0.02276,1.84005,-1.63425,-0.099212,1.7583,-1.60923,0.042145,1.67561,-1.62264,0.113921,1.61734,-1.60851,0.244829,1.96195,-2.06308,0.296255,1.8841,-1.89086,0.102134,1.91382,-2.01066,0.137893,1.74888,-2.20284,0.184717,1.6604,-2.2387,0.317019,1.67222,-2.09055,0.377708,1.66435,-2.07475,0.192503,1.45014,-1.78523,0.010901,1.5262,-1.85098,0.013979,1.54588,-1.9146,0.018086,1.5216,-1.96481,0.193169,1.42586,-2.04067,0.298615,1.21063,-1.72977,0.186448,1.1309,-1.72996,0.230281,1.06148,-1.75093,0.338728,0.990788,-1.74501,0.39029,0.805866,-1.73346,0.401478,0.731964,-1.74678,0.279493,0.78731,-1.74928,0.290806,0.716956,-1.75663,0.379119,0.495553,-1.77587,0.304348,0.40669,-1.85781,0.541518,0.503488,-1.80976,0.534542,0.435599,-1.74891,0.046055,1.13968,-2.07699,0.017116,1.06249,-2.05851,-0.08452,1.1899,-2.04184,-0.110679,1.11314,-2.02625,-0.123954,0.96328,-2.02572,-0.229581,0.799993,-2.01535,-0.305632,0.883127,-2.02415,-0.355408,0.833574,-2.01402,-0.503048,0.652046,-1.97925,-0.577493,0.716724,-1.91323,-0.508496,0.443712,-1.92406,-0.571505,0.473646,-1.97927,0.105338,1.37082,-1.78872,0.098179,1.35507,-2.00326},
/*801*/{0.177626,1.93333,-1.68688,0.280024,1.87947,-1.8165,0.023848,1.83874,-1.6335,-0.096577,1.75717,-1.60904,0.042891,1.67344,-1.62086,0.115592,1.61559,-1.60651,0.245181,1.96222,-2.06262,0.296372,1.88447,-1.89046,0.101878,1.91485,-2.01007,0.136197,1.7499,-2.20123,0.183363,1.66072,-2.23839,0.316389,1.6697,-2.09011,0.377996,1.66114,-2.07523,0.194491,1.45105,-1.78567,0.011237,1.52623,-1.8499,0.013536,1.54717,-1.91392,0.017938,1.52259,-1.9643,0.193972,1.42773,-2.04056,0.295296,1.20447,-1.72772,0.184319,1.12885,-1.72952,0.224164,1.05661,-1.75086,0.331679,0.985905,-1.74461,0.392227,0.803281,-1.734,0.406991,0.73002,-1.74751,0.282308,0.780713,-1.74741,0.296551,0.711047,-1.75583,0.390001,0.492612,-1.77559,0.31954,0.401381,-1.85808,0.553504,0.505858,-1.80985,0.548649,0.436146,-1.74931,0.050168,1.13915,-2.07708,0.021978,1.06094,-2.05858,-0.081247,1.18765,-2.04174,-0.105781,1.11023,-2.02517,-0.117886,0.960349,-2.02499,-0.229675,0.799954,-2.0136,-0.302098,0.887414,-2.02557,-0.35337,0.840167,-2.0149,-0.511123,0.665422,-1.97799,-0.584034,0.73314,-1.91578,-0.520736,0.457615,-1.91932,-0.582147,0.488844,-1.97737,0.10711,1.37149,-1.78889,0.099152,1.35652,-2.00346},
/*802*/{0.178275,1.93308,-1.68564,0.28079,1.88035,-1.81642,0.024707,1.83697,-1.63244,-0.095472,1.75473,-1.60892,0.045064,1.6715,-1.61959,0.117798,1.61302,-1.60398,0.245233,1.96206,-2.0617,0.296211,1.88486,-1.88952,0.102597,1.91575,-2.00964,0.134033,1.75066,-2.19945,0.182335,1.66092,-2.23746,0.316002,1.66647,-2.0907,0.378153,1.65686,-2.07676,0.194472,1.45127,-1.78569,0.011394,1.52566,-1.84936,0.014028,1.54748,-1.91268,0.018516,1.52304,-1.96311,0.194477,1.42924,-2.04083,0.291962,1.19844,-1.72645,0.177091,1.1237,-1.73024,0.217113,1.05272,-1.75092,0.326613,0.980027,-1.74466,0.393447,0.800337,-1.73479,0.409074,0.726745,-1.74717,0.283512,0.775135,-1.7466,0.299533,0.705993,-1.75576,0.40154,0.488383,-1.77433,0.333476,0.396476,-1.85798,0.563271,0.507865,-1.80924,0.561114,0.43801,-1.74974,0.053801,1.13775,-2.07663,0.026969,1.0592,-2.05852,-0.077379,1.18435,-2.04144,-0.10156,1.10594,-2.02454,-0.112341,0.957475,-2.02356,-0.229779,0.800982,-2.01144,-0.297195,0.891565,-2.02633,-0.352013,0.846326,-2.01469,-0.517617,0.679678,-1.97803,-0.589108,0.749945,-1.9175,-0.532826,0.472705,-1.91587,-0.592109,0.504485,-1.97597,0.107882,1.37111,-1.78922,0.099899,1.35759,-2.00388},
/*803*/{0.179062,1.93252,-1.68499,0.280906,1.88066,-1.81604,0.026303,1.83502,-1.63137,-0.092817,1.75309,-1.60818,0.047189,1.66806,-1.61802,0.119639,1.61064,-1.60188,0.245123,1.96135,-2.06072,0.296145,1.8848,-1.88917,0.102838,1.91608,-2.00866,0.13128,1.75126,-2.19752,0.17949,1.66113,-2.23601,0.318017,1.66452,-2.09206,0.378335,1.65218,-2.07734,0.194449,1.45113,-1.78626,0.011128,1.52527,-1.84907,0.013844,1.54718,-1.91273,0.019077,1.52216,-1.96298,0.195014,1.42985,-2.04096,0.287421,1.19177,-1.7256,0.170994,1.12054,-1.72996,0.21073,1.04803,-1.75045,0.319244,0.974672,-1.74427,0.393731,0.798719,-1.73531,0.412083,0.725512,-1.74696,0.285074,0.769458,-1.74582,0.303395,0.700156,-1.75329,0.409742,0.485418,-1.77272,0.344254,0.392733,-1.85701,0.573562,0.510129,-1.80957,0.57186,0.439126,-1.74979,0.058461,1.13626,-2.07574,0.032501,1.05755,-2.05813,-0.073441,1.1813,-2.04111,-0.096194,1.10149,-2.02427,-0.105489,0.95503,-2.02277,-0.229335,0.802062,-2.01014,-0.292199,0.895149,-2.02647,-0.348864,0.852936,-2.01629,-0.52109,0.693789,-1.97797,-0.592974,0.767408,-1.92172,-0.545323,0.489287,-1.9122,-0.603232,0.522541,-1.97631,0.108418,1.37066,-1.78959,0.10064,1.35766,-2.00429},
/*804*/{0.180599,1.93199,-1.68395,0.280906,1.88066,-1.81604,0.027767,1.83264,-1.63007,-0.090524,1.74934,-1.60709,0.049531,1.66534,-1.61598,0.122219,1.60711,-1.59951,0.245236,1.9608,-2.05972,0.296039,1.88453,-1.88916,0.102304,1.91623,-2.00677,0.129464,1.75027,-2.19518,0.177097,1.66096,-2.23463,0.31714,1.66051,-2.09329,0.377437,1.64676,-2.07798,0.194438,1.45082,-1.78695,0.011088,1.5229,-1.84835,0.014528,1.54561,-1.91193,0.018723,1.52159,-1.96203,0.19545,1.43022,-2.04092,0.28413,1.18532,-1.72468,0.166032,1.11689,-1.73139,0.203194,1.04315,-1.75191,0.31276,0.969097,-1.74352,0.392797,0.796495,-1.73579,0.413373,0.72435,-1.74734,0.284781,0.764488,-1.74688,0.305038,0.695559,-1.75339,0.416504,0.484354,-1.77244,0.352755,0.388962,-1.85532,0.579824,0.509067,-1.80853,0.580863,0.439615,-1.74912,0.063829,1.13421,-2.07475,0.039131,1.05451,-2.05697,-0.070308,1.17676,-2.04016,-0.090765,1.09805,-2.02314,-0.098689,0.951025,-2.02195,-0.228269,0.803571,-2.008,-0.286858,0.899181,-2.02656,-0.345052,0.861904,-2.01769,-0.525783,0.709117,-1.97713,-0.594462,0.785864,-1.92283,-0.556184,0.506067,-1.91044,-0.611404,0.539295,-1.97409,0.109582,1.36926,-1.78994,0.101555,1.35738,-2.0047},
/*805*/{0.181753,1.93092,-1.68313,0.28122,1.87986,-1.81589,0.029197,1.82971,-1.62889,-0.087087,1.74554,-1.60503,0.053952,1.66251,-1.6147,0.125147,1.60353,-1.59729,0.245036,1.95957,-2.05945,0.295937,1.88316,-1.88858,0.102069,1.91575,-2.0063,0.1254,1.74994,-2.1931,0.174314,1.66104,-2.23291,0.315992,1.65615,-2.09417,0.376622,1.64127,-2.07979,0.196649,1.45019,-1.78769,0.011038,1.52166,-1.84827,0.013868,1.54474,-1.9125,0.018388,1.52036,-1.96149,0.196083,1.4303,-2.04116,0.279163,1.17851,-1.72311,0.160662,1.11359,-1.73141,0.196294,1.0386,-1.75295,0.306237,0.963923,-1.74387,0.390493,0.794297,-1.73518,0.412931,0.72294,-1.74695,0.283546,0.760297,-1.74841,0.306371,0.692088,-1.75397,0.423678,0.481668,-1.7713,0.360296,0.386034,-1.85463,0.586042,0.510313,-1.80832,0.587609,0.439816,-1.7483,0.068997,1.13146,-2.07373,0.044772,1.05105,-2.05629,-0.065248,1.17117,-2.03969,-0.085257,1.09222,-2.02283,-0.091661,0.946299,-2.02082,-0.225249,0.805383,-2.00707,-0.281136,0.903683,-2.02701,-0.341342,0.865868,-2.01505,-0.528433,0.723738,-1.97773,-0.594926,0.803292,-1.92472,-0.566169,0.523082,-1.90931,-0.618861,0.557808,-1.97349,0.111409,1.36856,-1.79033,0.102554,1.3568,-2.00506},
/*806*/{0.182466,1.92959,-1.68223,0.282749,1.87771,-1.81524,0.03122,1.82666,-1.62715,-0.084564,1.74131,-1.6033,0.055641,1.65817,-1.61124,0.128618,1.6005,-1.59478,0.243975,1.95801,-2.05863,0.296114,1.8826,-1.88849,0.101763,1.91485,-2.00534,0.121403,1.75083,-2.19132,0.171368,1.6604,-2.23113,0.316151,1.65037,-2.09492,0.3758,1.63503,-2.08171,0.195576,1.44871,-1.78822,0.011712,1.51863,-1.84702,0.014089,1.54264,-1.91168,0.018279,1.51813,-1.96097,0.19674,1.43009,-2.04133,0.275925,1.17203,-1.72102,0.15478,1.10743,-1.73191,0.189135,1.03485,-1.75527,0.299046,0.957636,-1.74277,0.388279,0.792651,-1.73529,0.410624,0.72088,-1.74618,0.28151,0.755643,-1.74913,0.30499,0.688476,-1.75495,0.42625,0.481398,-1.77103,0.365401,0.383326,-1.85282,0.58816,0.509744,-1.80904,0.591635,0.440319,-1.74781,0.074177,1.12842,-2.0727,0.05262,1.04806,-2.05421,-0.060381,1.16606,-2.03921,-0.079279,1.08681,-2.02228,-0.084176,0.940985,-2.02006,-0.224201,0.807227,-2.00644,-0.27477,0.907733,-2.02637,-0.336666,0.873088,-2.01416,-0.523184,0.738229,-1.97718,-0.593817,0.822112,-1.92513,-0.574449,0.540206,-1.90794,-0.625005,0.576196,-1.97209,0.112187,1.36606,-1.79082,0.103491,1.35576,-2.00564},
/*807*/{0.183638,1.92819,-1.68124,0.281922,1.87789,-1.81519,0.032833,1.8227,-1.62522,-0.080303,1.73655,-1.60097,0.059064,1.6542,-1.6083,0.132119,1.59638,-1.59216,0.243547,1.95648,-2.05745,0.295888,1.88148,-1.88831,0.1009,1.91425,-2.00339,0.117914,1.75031,-2.18904,0.167302,1.65995,-2.22972,0.315399,1.64592,-2.09652,0.376089,1.62697,-2.08296,0.198315,1.44737,-1.78774,0.011024,1.51669,-1.84718,0.014541,1.541,-1.91158,0.018831,1.51592,-1.96117,0.196896,1.42948,-2.04148,0.273426,1.16567,-1.71967,0.150833,1.10534,-1.73268,0.185867,1.02991,-1.75429,0.292586,0.95159,-1.74275,0.384244,0.78975,-1.73457,0.409892,0.718611,-1.74545,0.279174,0.751695,-1.7496,0.303219,0.683426,-1.75624,0.428348,0.477766,-1.77013,0.368523,0.379444,-1.85277,0.59138,0.509082,-1.80811,0.594081,0.439517,-1.74723,0.079401,1.12503,-2.07207,0.058399,1.04468,-2.054,-0.057173,1.16017,-2.03886,-0.073435,1.0805,-2.02125,-0.07543,0.936675,-2.01959,-0.220946,0.809516,-2.0061,-0.267005,0.911782,-2.02418,-0.330209,0.880059,-2.01311,-0.528013,0.755638,-1.97919,-0.590225,0.840435,-1.92577,-0.581189,0.558005,-1.90804,-0.633313,0.596155,-1.97253,0.114018,1.36467,-1.79089,0.104791,1.35433,-2.00568},
/*808*/{0.184275,1.92559,-1.68069,0.282171,1.87555,-1.81505,0.035396,1.81898,-1.62315,-0.077044,1.7323,-1.59836,0.062493,1.64923,-1.60556,0.136302,1.59218,-1.58941,0.243041,1.95471,-2.05725,0.295224,1.87886,-1.88791,0.100104,1.91285,-2.0028,0.114654,1.74744,-2.18582,0.163635,1.6588,-2.22832,0.313643,1.64059,-2.09797,0.372991,1.62106,-2.08671,0.196431,1.44504,-1.78847,0.01191,1.51371,-1.84651,0.013959,1.5374,-1.91171,0.01859,1.51286,-1.96099,0.198359,1.42769,-2.04146,0.268759,1.16089,-1.71815,0.146487,1.09865,-1.73298,0.179673,1.02586,-1.75584,0.288086,0.947012,-1.7427,0.381052,0.78586,-1.73364,0.406924,0.716126,-1.74514,0.275978,0.74756,-1.75047,0.30077,0.680349,-1.75826,0.42915,0.475066,-1.7699,0.369607,0.376203,-1.85271,0.590877,0.506523,-1.80695,0.594215,0.43829,-1.74637,0.084559,1.12104,-2.07102,0.065659,1.04072,-2.05277,-0.052027,1.15423,-2.03747,-0.067651,1.0743,-2.02034,-0.068317,0.932106,-2.0194,-0.217939,0.811151,-2.00571,-0.259274,0.915468,-2.02384,-0.324265,0.886699,-2.01203,-0.529045,0.770991,-1.97871,-0.585982,0.857871,-1.92443,-0.587746,0.574977,-1.90837,-0.638708,0.616153,-1.97277,0.114118,1.36159,-1.79127,0.105747,1.35203,-2.00613},
/*809*/{0.185828,1.92336,-1.67945,0.282082,1.87189,-1.81506,0.037128,1.81422,-1.6211,-0.07271,1.72664,-1.59505,0.066491,1.6441,-1.60214,0.139778,1.58749,-1.58667,0.241184,1.95253,-2.05686,0.294217,1.87687,-1.88776,0.099228,1.91063,-2.00154,0.110792,1.74646,-2.18346,0.159323,1.65727,-2.22607,0.310758,1.63359,-2.09886,0.371194,1.61348,-2.08869,0.197679,1.4423,-1.78737,0.011267,1.51137,-1.84669,0.014233,1.53425,-1.91148,0.01904,1.50967,-1.96071,0.198225,1.42611,-2.04135,0.267403,1.15546,-1.71554,0.143865,1.09822,-1.73324,0.176886,1.02236,-1.75622,0.286387,0.944332,-1.74212,0.378178,0.78295,-1.73244,0.403751,0.711883,-1.74467,0.273418,0.742992,-1.7505,0.299617,0.675748,-1.756,0.427706,0.472953,-1.77101,0.36892,0.373225,-1.85272,0.590263,0.504489,-1.80739,0.59372,0.436426,-1.74673,0.090176,1.11786,-2.071,0.073058,1.03631,-2.05146,-0.046911,1.14793,-2.03647,-0.061649,1.0678,-2.0194,-0.059563,0.925825,-2.01842,-0.213679,0.813214,-2.00547,-0.251582,0.919235,-2.02326,-0.316524,0.893941,-2.01173,-0.526569,0.787401,-1.98157,-0.579232,0.875329,-1.92438,-0.593602,0.593636,-1.91022,-0.643475,0.63628,-1.97281,0.114869,1.35897,-1.7911,0.106551,1.34962,-2.00597},
/*810*/{0.18664,1.92027,-1.67892,0.282905,1.86989,-1.81506,0.039343,1.80996,-1.6181,-0.069774,1.72082,-1.59176,0.070196,1.63822,-1.5988,0.14396,1.58356,-1.58374,0.240148,1.95017,-2.0565,0.294508,1.87476,-1.88722,0.098465,1.90819,-1.99938,0.106845,1.74488,-2.1815,0.155274,1.65532,-2.22453,0.308921,1.62715,-2.10038,0.36899,1.60512,-2.09169,0.198736,1.43916,-1.78718,0.011305,1.50753,-1.84611,0.014404,1.53098,-1.91119,0.018821,1.50688,-1.96165,0.199295,1.42404,-2.04121,0.264254,1.15068,-1.71252,0.141593,1.09451,-1.73323,0.174342,1.01937,-1.75634,0.286014,0.942824,-1.74136,0.375381,0.7788,-1.73209,0.401845,0.708199,-1.74428,0.270316,0.738455,-1.7506,0.29578,0.67242,-1.75781,0.423554,0.468355,-1.77095,0.366572,0.36963,-1.8541,0.58795,0.501733,-1.80749,0.59037,0.431561,-1.74599,0.094862,1.11366,-2.07013,0.079716,1.03176,-2.05014,-0.043342,1.14168,-2.03652,-0.055116,1.06171,-2.01826,-0.050659,0.920142,-2.01766,-0.208596,0.81536,-2.00545,-0.242436,0.921905,-2.02151,-0.308361,0.898055,-2.01142,-0.520177,0.801176,-1.98057,-0.571013,0.891696,-1.92339,-0.599476,0.610542,-1.91115,-0.643185,0.656369,-1.97258,0.115764,1.35556,-1.79158,0.107766,1.34712,-2.0065},
/*811*/{0.18769,1.91726,-1.6778,0.282205,1.8665,-1.81439,0.041453,1.80541,-1.61548,-0.065426,1.71496,-1.58772,0.074377,1.63395,-1.59563,0.148103,1.57848,-1.58114,0.239161,1.9472,-2.05647,0.29457,1.87171,-1.88735,0.097217,1.90596,-1.99852,0.102336,1.74273,-2.17897,0.150485,1.65287,-2.22391,0.306093,1.62128,-2.10228,0.366449,1.59616,-2.09536,0.196724,1.43517,-1.78703,0.010325,1.50382,-1.84665,0.014612,1.52801,-1.91102,0.019099,1.50293,-1.96142,0.199992,1.42156,-2.04078,0.261613,1.14755,-1.71051,0.138637,1.09145,-1.73387,0.172583,1.01616,-1.75794,0.286703,0.941635,-1.74107,0.372691,0.773876,-1.7322,0.398885,0.70355,-1.74395,0.268118,0.735378,-1.7505,0.292716,0.668707,-1.75829,0.421411,0.463698,-1.77113,0.361751,0.365762,-1.85556,0.584076,0.495781,-1.80719,0.585815,0.425732,-1.74762,0.100866,1.10929,-2.06937,0.086322,1.02758,-2.04892,-0.038562,1.13518,-2.03528,-0.04866,1.05477,-2.0174,-0.043201,0.914661,-2.01714,-0.203613,0.816379,-2.00561,-0.232495,0.925453,-2.02216,-0.300423,0.902724,-2.00996,-0.514954,0.81584,-1.98151,-0.562594,0.90713,-1.92178,-0.602094,0.626781,-1.91315,-0.647921,0.675593,-1.97284,0.114518,1.35143,-1.79205,0.108144,1.34428,-2.00707},
/*812*/{0.188491,1.91336,-1.67755,0.281822,1.86519,-1.81488,0.04432,1.80054,-1.61273,-0.061676,1.70882,-1.58362,0.078645,1.62843,-1.59207,0.153338,1.57379,-1.57775,0.236975,1.94419,-2.05628,0.293513,1.86892,-1.88769,0.095887,1.90276,-1.99706,0.098184,1.74052,-2.17712,0.145971,1.65003,-2.22191,0.303044,1.61307,-2.10368,0.363331,1.58736,-2.09888,0.198311,1.43237,-1.78643,0.011053,1.50018,-1.84607,0.014065,1.5245,-1.91105,0.018585,1.49949,-1.96198,0.200343,1.41911,-2.04039,0.260736,1.14466,-1.70864,0.137299,1.08894,-1.73393,0.172059,1.01354,-1.75733,0.28701,0.940035,-1.74049,0.369884,0.768902,-1.73158,0.394402,0.699123,-1.74465,0.264618,0.730997,-1.75048,0.289239,0.663204,-1.75704,0.414496,0.458558,-1.7714,0.35482,0.361729,-1.85641,0.578581,0.488076,-1.80669,0.580481,0.418528,-1.74767,0.10514,1.10561,-2.06857,0.093831,1.02352,-2.0478,-0.033074,1.12861,-2.03481,-0.041911,1.04798,-2.01681,-0.034498,0.90896,-2.01675,-0.197982,0.817221,-2.00509,-0.22206,0.92616,-2.01936,-0.29102,0.907499,-2.00983,-0.510133,0.829378,-1.98041,-0.551823,0.92245,-1.92125,-0.602939,0.643569,-1.91449,-0.645107,0.695389,-1.97392,0.115844,1.3485,-1.79183,0.109138,1.34119,-2.00683},
/*813*/{0.188561,1.90973,-1.6765,0.281957,1.86033,-1.81418,0.046613,1.79469,-1.61033,-0.056694,1.70196,-1.57945,0.083419,1.62315,-1.58808,0.158654,1.56811,-1.57521,0.234953,1.94092,-2.05651,0.293726,1.86622,-1.88756,0.09526,1.89953,-1.99512,0.094173,1.73729,-2.17504,0.141208,1.64697,-2.22052,0.300141,1.60673,-2.10571,0.359704,1.57799,-2.10262,0.197839,1.42836,-1.78555,0.011432,1.49654,-1.84624,0.013518,1.52061,-1.9111,0.018147,1.4948,-1.96201,0.200376,1.4162,-2.03933,0.258622,1.1412,-1.70748,0.136176,1.08638,-1.73529,0.169556,1.01096,-1.75749,0.286985,0.938059,-1.74078,0.366139,0.763606,-1.73174,0.390794,0.692483,-1.74396,0.260858,0.726735,-1.74946,0.284017,0.659368,-1.75718,0.407537,0.451926,-1.77119,0.347386,0.35727,-1.85783,0.570867,0.480412,-1.80746,0.572784,0.409827,-1.74791,0.111395,1.10167,-2.06739,0.100859,1.01947,-2.04732,-0.027806,1.12144,-2.03437,-0.03574,1.04121,-2.01633,-0.026337,0.903009,-2.01616,-0.190727,0.816443,-2.0021,-0.212476,0.92786,-2.01913,-0.280892,0.911502,-2.00977,-0.50117,0.840799,-1.98154,-0.540161,0.936386,-1.92079,-0.601543,0.659371,-1.9158,-0.645086,0.714238,-1.97519,0.115596,1.34465,-1.7915,0.109607,1.33749,-2.00653},
/*814*/{0.189318,1.90536,-1.67594,0.28225,1.85669,-1.81368,0.049615,1.78866,-1.60701,-0.052905,1.69499,-1.57405,0.0877,1.61708,-1.58434,0.163083,1.56371,-1.57238,0.233564,1.93747,-2.0565,0.293572,1.8628,-1.88747,0.093715,1.89555,-1.99485,0.088461,1.7363,-2.17475,0.136446,1.64368,-2.21959,0.296374,1.59797,-2.10834,0.355832,1.56789,-2.10659,0.195612,1.42521,-1.78545,0.00996,1.49221,-1.84675,0.014368,1.51661,-1.91064,0.01866,1.49248,-1.96294,0.201289,1.4132,-2.03871,0.255954,1.13876,-1.70687,0.135943,1.08333,-1.73525,0.169605,1.00788,-1.75722,0.285494,0.933246,-1.7407,0.36266,0.75825,-1.73219,0.385248,0.68654,-1.74512,0.256282,0.722195,-1.74917,0.279507,0.654694,-1.75662,0.402384,0.448308,-1.77326,0.337696,0.352889,-1.85805,0.563571,0.471479,-1.80605,0.566557,0.402868,-1.74608,0.117404,1.0979,-2.06691,0.108198,1.01494,-2.04681,-0.022068,1.11461,-2.03398,-0.028228,1.03367,-2.01598,-0.018247,0.89787,-2.01592,-0.184702,0.818122,-2.00462,-0.201357,0.929847,-2.01916,-0.270812,0.914957,-2.00955,-0.493347,0.852827,-1.98204,-0.528627,0.948384,-1.92076,-0.599,0.673869,-1.9176,-0.641003,0.730255,-1.97725,0.114242,1.34068,-1.79197,0.11031,1.33467,-2.00709},
/*815*/{0.190443,1.90057,-1.67465,0.282406,1.85404,-1.81414,0.051905,1.78256,-1.60434,-0.048944,1.68726,-1.56973,0.093085,1.61056,-1.57971,0.169476,1.55882,-1.5703,0.231678,1.93366,-2.05693,0.293225,1.85894,-1.88782,0.092414,1.89114,-1.99229,0.08409,1.73286,-2.17301,0.131322,1.63989,-2.21797,0.293101,1.59051,-2.11154,0.35162,1.55802,-2.11082,0.193117,1.42074,-1.78314,0.010075,1.48714,-1.84663,0.013678,1.51287,-1.91039,0.018346,1.48562,-1.96289,0.201007,1.41007,-2.03805,0.256324,1.13577,-1.70592,0.133994,1.0805,-1.7366,0.168054,1.00455,-1.75843,0.283777,0.927716,-1.74041,0.358265,0.752348,-1.7324,0.38131,0.680428,-1.7445,0.251566,0.718156,-1.74894,0.27326,0.65018,-1.75598,0.389845,0.441862,-1.77315,0.326593,0.348561,-1.85948,0.555324,0.463716,-1.80637,0.553894,0.394104,-1.7467,0.12301,1.09347,-2.06775,0.116217,1.01069,-2.04706,-0.017129,1.10811,-2.03398,-0.022199,1.02647,-2.01465,-0.009237,0.892737,-2.01563,-0.177172,0.817776,-2.0044,-0.191154,0.929856,-2.01857,-0.259773,0.917977,-2.00978,-0.483983,0.862942,-1.98191,-0.515926,0.959507,-1.92081,-0.595084,0.687292,-1.91948,-0.635863,0.745215,-1.97778,0.113212,1.33596,-1.7913,0.110856,1.33026,-2.00644},
/*816*/{0.191029,1.89576,-1.67443,0.281672,1.84838,-1.81423,0.054828,1.77611,-1.60098,-0.04477,1.67986,-1.5652,0.097414,1.60422,-1.57591,0.174975,1.55367,-1.56714,0.229999,1.92919,-2.05713,0.293427,1.85559,-1.88796,0.091224,1.88735,-1.99158,0.081026,1.72795,-2.17142,0.126024,1.63659,-2.21713,0.288527,1.58124,-2.11458,0.346968,1.54741,-2.11576,0.195583,1.4173,-1.78373,0.009846,1.48256,-1.84613,0.013241,1.50878,-1.91051,0.018228,1.48051,-1.96364,0.201397,1.40657,-2.03712,0.256237,1.13262,-1.70485,0.133465,1.0773,-1.73733,0.167753,1.00218,-1.75831,0.280866,0.922817,-1.74024,0.354132,0.746104,-1.73217,0.373715,0.674508,-1.7457,0.24632,0.71425,-1.7489,0.266276,0.644903,-1.75673,0.377872,0.43625,-1.77305,0.310587,0.350531,-1.85916,0.543757,0.453456,-1.80569,0.54071,0.382135,-1.74886,0.129018,1.08905,-2.06784,0.123104,1.00585,-2.04757,-0.01082,1.10154,-2.03345,-0.014605,1.02007,-2.01418,-0.000547,0.887286,-2.01553,-0.169997,0.817304,-2.00425,-0.179083,0.92881,-2.01882,-0.24969,0.920807,-2.01075,-0.474872,0.872558,-1.98205,-0.503309,0.970134,-1.92021,-0.590459,0.700584,-1.92128,-0.63105,0.760126,-1.9791,0.115088,1.33237,-1.79103,0.112086,1.32604,-2.00615},
/*817*/{0.192214,1.89014,-1.67324,0.282598,1.84468,-1.81397,0.058775,1.76822,-1.59786,-0.040919,1.67155,-1.55959,0.103427,1.59849,-1.57229,0.181166,1.5484,-1.56436,0.228,1.92482,-2.05778,0.293182,1.8516,-1.88774,0.090389,1.88263,-1.99084,0.077563,1.72391,-2.17039,0.120704,1.63253,-2.21605,0.284102,1.57264,-2.11751,0.341591,1.53682,-2.12063,0.1948,1.41396,-1.782,0.008594,1.47849,-1.84644,0.013069,1.50398,-1.9094,0.017692,1.47492,-1.96354,0.201041,1.40307,-2.03671,0.253895,1.12866,-1.70427,0.132557,1.07313,-1.73804,0.166721,0.997894,-1.75851,0.278963,0.917125,-1.73972,0.347714,0.739765,-1.73168,0.366732,0.667922,-1.74586,0.239857,0.709631,-1.74949,0.259245,0.640578,-1.75668,0.365589,0.431818,-1.77325,0.292854,0.353344,-1.86039,0.529736,0.439561,-1.80536,0.522267,0.369107,-1.74795,0.134645,1.08489,-2.06807,0.130358,1.00173,-2.04793,-0.005104,1.09494,-2.03323,-0.006195,1.01317,-2.01396,0.008246,0.882623,-2.01601,-0.162195,0.816585,-2.0043,-0.168246,0.929805,-2.01863,-0.237805,0.921676,-2.01019,-0.463065,0.881761,-1.98214,-0.49073,0.979712,-1.9207,-0.583938,0.711489,-1.92429,-0.620917,0.771211,-1.98128,0.114965,1.32859,-1.79003,0.112564,1.32169,-2.00514},
/*818*/{0.192153,1.88495,-1.67328,0.281987,1.84098,-1.8147,0.061889,1.76169,-1.59417,-0.03645,1.66336,-1.5547,0.108994,1.59176,-1.56829,0.188109,1.54321,-1.5614,0.226226,1.92047,-2.05835,0.29309,1.84647,-1.88812,0.088905,1.87707,-1.98941,0.073727,1.71977,-2.16961,0.115064,1.62864,-2.21439,0.279604,1.56411,-2.12089,0.335789,1.5253,-2.12526,0.196911,1.40913,-1.78301,0.008446,1.47273,-1.84692,0.011932,1.49897,-1.90923,0.016794,1.46977,-1.96346,0.20113,1.39929,-2.03659,0.254873,1.12527,-1.70423,0.133376,1.06877,-1.73821,0.166458,0.994519,-1.75866,0.276195,0.912851,-1.73955,0.341769,0.732713,-1.73218,0.360317,0.660211,-1.7449,0.232969,0.705984,-1.74975,0.25124,0.637123,-1.75693,0.350936,0.425945,-1.77451,0.274786,0.353646,-1.86264,0.516567,0.425833,-1.80563,0.50152,0.356745,-1.74651,0.139875,1.07994,-2.06818,0.137836,0.997599,-2.04862,0.000534,1.08701,-2.03096,0.000465,1.00683,-2.0144,0.018456,0.876927,-2.01618,-0.153473,0.815839,-2.0048,-0.155665,0.929652,-2.02036,-0.226642,0.923183,-2.01069,-0.452652,0.888734,-1.9821,-0.478633,0.98773,-1.92162,-0.577123,0.721095,-1.92626,-0.611729,0.782359,-1.98367,0.116504,1.32362,-1.7907,0.113217,1.31724,-2.00581},
/*819*/{0.193888,1.87971,-1.67169,0.282885,1.83501,-1.81408,0.065739,1.75398,-1.59086,-0.031268,1.65553,-1.54911,0.114953,1.5851,-1.56485,0.1948,1.53853,-1.55941,0.22434,1.91547,-2.05889,0.293347,1.84236,-1.88857,0.087406,1.8724,-1.98785,0.068957,1.71581,-2.16902,0.109978,1.62474,-2.21385,0.274314,1.55511,-2.12494,0.329023,1.51415,-2.13036,0.196954,1.40535,-1.77933,0.007698,1.46772,-1.84724,0.011448,1.49355,-1.90856,0.016433,1.46417,-1.96379,0.202135,1.39531,-2.0331,0.253742,1.12007,-1.7043,0.132009,1.0654,-1.73817,0.166028,0.990139,-1.75813,0.272761,0.907675,-1.73863,0.334845,0.726807,-1.73187,0.353049,0.654891,-1.74555,0.225976,0.701505,-1.75032,0.242354,0.632636,-1.75787,0.335724,0.419883,-1.77563,0.2558,0.355547,-1.8655,0.501845,0.411767,-1.80559,0.480171,0.343582,-1.74591,0.146492,1.07639,-2.06824,0.144541,0.99301,-2.04848,0.005549,1.08232,-2.03033,0.007171,1.00032,-2.01361,0.027879,0.871545,-2.01639,-0.144105,0.814983,-2.0054,-0.143901,0.928648,-2.01895,-0.213331,0.924389,-2.01047,-0.441528,0.896841,-1.98312,-0.466265,0.9958,-1.92144,-0.567716,0.729317,-1.92792,-0.601211,0.791542,-1.98567,0.116217,1.3196,-1.78842,0.115258,1.3123,-2.00353},
/*820*/{0.194855,1.87399,-1.67105,0.283614,1.82994,-1.81401,0.069917,1.74629,-1.58718,-0.02348,1.64748,-1.54328,0.121711,1.57903,-1.56094,0.201468,1.53366,-1.55713,0.223158,1.91085,-2.05906,0.292838,1.83781,-1.88944,0.086573,1.86703,-1.98677,0.065624,1.71173,-2.16797,0.103581,1.62035,-2.21341,0.269312,1.54542,-2.12901,0.321973,1.50204,-2.13581,0.195584,1.40212,-1.77772,0.006309,1.46282,-1.84733,0.011079,1.48786,-1.9076,0.015175,1.45887,-1.9641,0.201658,1.39053,-2.03289,0.254538,1.1161,-1.70379,0.131487,1.0613,-1.73858,0.165409,0.986112,-1.75769,0.269262,0.903202,-1.73791,0.328803,0.719868,-1.73259,0.343877,0.647103,-1.74574,0.218692,0.699053,-1.75061,0.233808,0.628514,-1.75889,0.321091,0.419223,-1.77932,0.234648,0.355897,-1.86539,0.485808,0.39984,-1.80729,0.461157,0.336543,-1.74594,0.151757,1.07141,-2.06839,0.151843,0.988489,-2.04866,0.010749,1.07658,-2.03074,0.014852,0.993433,-2.01337,0.038528,0.865031,-2.01655,-0.134421,0.813699,-2.00629,-0.131299,0.927141,-2.01845,-0.201299,0.923774,-2.00959,-0.429333,0.902278,-1.98368,-0.454076,1.00178,-1.92124,-0.556884,0.736712,-1.92998,-0.59036,0.798235,-1.98762,0.115691,1.31559,-1.78725,0.115275,1.3072,-2.00232},
/*821*/{0.195397,1.86892,-1.67055,0.283417,1.82642,-1.81494,0.074118,1.7381,-1.58409,-0.018539,1.63871,-1.5389,0.128796,1.57284,-1.55781,0.208534,1.52876,-1.55505,0.222224,1.90644,-2.05964,0.292602,1.83301,-1.88996,0.085551,1.86141,-1.98591,0.061496,1.70765,-2.16731,0.097169,1.61632,-2.21328,0.263048,1.53572,-2.13307,0.31461,1.49039,-2.14055,0.194934,1.39764,-1.77652,0.004792,1.45805,-1.84777,0.009089,1.48194,-1.90697,0.01408,1.45342,-1.9637,0.200652,1.38614,-2.03238,0.25287,1.11122,-1.70353,0.130072,1.05697,-1.73768,0.16376,0.982118,-1.75833,0.265278,0.897641,-1.73738,0.320912,0.714406,-1.73363,0.333862,0.64068,-1.74776,0.210913,0.697233,-1.75142,0.222529,0.626302,-1.76009,0.301523,0.418103,-1.78255,0.212633,0.356599,-1.86453,0.466247,0.395482,-1.81388,0.440147,0.338322,-1.74758,0.155946,1.06843,-2.06935,0.158469,0.984583,-2.04969,0.01734,1.06712,-2.03021,0.021862,0.986807,-2.01341,0.048719,0.86002,-2.01906,-0.123938,0.812205,-2.00663,-0.117916,0.926115,-2.02031,-0.188626,0.924709,-2.01048,-0.420129,0.908012,-1.98202,-0.440716,1.00601,-1.92018,-0.544893,0.742964,-1.93225,-0.577176,0.805348,-1.99029,0.115032,1.31092,-1.78659,0.114902,1.30224,-2.00165},
/*822*/{0.196835,1.8638,-1.66936,0.284482,1.8194,-1.81501,0.078892,1.7295,-1.58088,-0.012693,1.62953,-1.5325,0.136257,1.56649,-1.55451,0.21613,1.52442,-1.55288,0.219712,1.90134,-2.06019,0.291066,1.82792,-1.89114,0.083725,1.85706,-1.98437,0.056375,1.70323,-2.16668,0.091425,1.61209,-2.21307,0.256627,1.52558,-2.13777,0.306104,1.47867,-2.14556,0.192902,1.39428,-1.77546,0.002022,1.45374,-1.84883,0.00762,1.47552,-1.90816,0.011941,1.44831,-1.96503,0.201909,1.38176,-2.0308,0.250929,1.10986,-1.70175,0.130364,1.05683,-1.73541,0.163755,0.980485,-1.75715,0.261285,0.891242,-1.7368,0.314865,0.711388,-1.73539,0.323182,0.63719,-1.75032,0.204493,0.699077,-1.75181,0.212698,0.627899,-1.76253,0.284586,0.419957,-1.78588,0.190392,0.357037,-1.86602,0.444084,0.393796,-1.8181,0.418285,0.341062,-1.74923,0.161403,1.06395,-2.06912,0.164843,0.980585,-2.05059,0.021549,1.06003,-2.03014,0.02805,0.980066,-2.01219,0.05966,0.852385,-2.01722,-0.112759,0.810209,-2.0075,-0.104656,0.92427,-2.01987,-0.175078,0.924459,-2.01079,-0.397499,0.908813,-1.98034,-0.427546,1.01072,-1.92114,-0.532811,0.74741,-1.93435,-0.564309,0.809782,-1.99204,0.113398,1.30705,-1.78584,0.115773,1.29735,-2.00084},
/*823*/{0.197894,1.8587,-1.66832,0.285424,1.81408,-1.81517,0.084746,1.72169,-1.57736,-0.004335,1.62135,-1.52673,0.143292,1.56071,-1.55156,0.223798,1.52032,-1.55132,0.219492,1.89772,-2.06146,0.292104,1.82302,-1.89171,0.083168,1.8537,-1.98286,0.052544,1.69943,-2.16631,0.085028,1.60796,-2.21263,0.249692,1.51531,-2.14243,0.297199,1.46754,-2.15061,0.190574,1.39162,-1.77533,-0.001543,1.44982,-1.84892,0.005371,1.47107,-1.90904,0.010167,1.44303,-1.96552,0.201051,1.37742,-2.02908,0.248112,1.10837,-1.69965,0.127201,1.05585,-1.73423,0.160848,0.980459,-1.75698,0.256214,0.885819,-1.73732,0.309363,0.711714,-1.73654,0.315422,0.637579,-1.75247,0.197771,0.704015,-1.753,0.203579,0.63254,-1.76353,0.262317,0.422857,-1.78881,0.167539,0.357638,-1.86734,0.422485,0.39193,-1.82154,0.396849,0.341135,-1.75025,0.165116,1.06086,-2.07005,0.17106,0.976757,-2.05043,0.026535,1.05307,-2.02997,0.034988,0.97321,-2.01216,0.069799,0.846736,-2.01857,-0.101094,0.808655,-2.00825,-0.09104,0.921922,-2.02096,-0.161337,0.923728,-2.01075,-0.389703,0.915828,-1.98494,-0.414712,1.01411,-1.92167,-0.519196,0.750712,-1.93614,-0.552769,0.818012,-1.99745,0.111311,1.30401,-1.78466,0.115001,1.29272,-1.99957},
/*824*/{0.199129,1.85427,-1.66698,0.285555,1.80991,-1.81596,0.090631,1.71327,-1.57378,0.003284,1.613,-1.52152,0.151476,1.55657,-1.55019,0.232326,1.51693,-1.55023,0.217993,1.89397,-2.06254,0.294621,1.81876,-1.89249,0.082851,1.85135,-1.98027,0.049687,1.69586,-2.16558,0.078911,1.60411,-2.21221,0.241854,1.5047,-2.14673,0.287906,1.45653,-2.15542,0.187167,1.38999,-1.77549,-0.004475,1.44569,-1.8495,0.002232,1.46591,-1.90962,0.007887,1.43746,-1.96634,0.200736,1.37291,-2.02774,0.246737,1.10916,-1.69625,0.125021,1.05404,-1.7342,0.160522,0.980798,-1.75678,0.254895,0.887674,-1.73748,0.305396,0.71224,-1.73824,0.307719,0.640014,-1.75376,0.193416,0.709992,-1.7533,0.195311,0.639352,-1.76415,0.242909,0.423615,-1.79002,0.145741,0.357976,-1.86943,0.400635,0.390707,-1.8228,0.372981,0.339769,-1.75107,0.170601,1.05702,-2.06856,0.178092,0.974084,-2.05125,0.031966,1.0465,-2.02962,0.042783,0.96597,-2.01161,0.080354,0.841321,-2.01896,-0.088003,0.806654,-2.00812,-0.077221,0.920194,-2.02145,-0.147156,0.921065,-2.01123,-0.374835,0.917844,-1.98569,-0.400326,1.01483,-1.92268,-0.505069,0.75255,-1.9379,-0.529643,0.812535,-1.99598,0.109361,1.30142,-1.78333,0.114557,1.28789,-1.99808},
/*825*/{0.200814,1.85026,-1.66585,0.286299,1.80453,-1.8162,0.096968,1.70499,-1.57152,0.012872,1.60574,-1.51653,0.160061,1.55197,-1.54789,0.241204,1.51464,-1.54871,0.217618,1.89025,-2.06351,0.29402,1.81428,-1.89374,0.082851,1.84894,-1.97878,0.046196,1.69297,-2.16494,0.0728,1.60112,-2.21214,0.234415,1.49636,-2.15103,0.278313,1.44626,-2.15954,0.183917,1.38763,-1.7736,-0.007925,1.44202,-1.85008,-0.001038,1.46193,-1.91126,0.004038,1.43236,-1.96717,0.198266,1.36939,-2.02635,0.24597,1.11007,-1.69496,0.125,1.05731,-1.73569,0.160871,0.980947,-1.75609,0.257587,0.893104,-1.73678,0.299395,0.711997,-1.73921,0.299462,0.639864,-1.75518,0.187057,0.715806,-1.75379,0.185085,0.644518,-1.76486,0.225108,0.427125,-1.79178,0.123559,0.3599,-1.86957,0.379402,0.389553,-1.8217,0.350725,0.339555,-1.75105,0.174558,1.05607,-2.06898,0.185968,0.973621,-2.05116,0.035048,1.03942,-2.02877,0.050411,0.959548,-2.01123,0.091147,0.836328,-2.01825,-0.074942,0.804523,-2.00746,-0.062591,0.917576,-2.02026,-0.131772,0.918988,-2.01133,-0.360916,0.919257,-1.98742,-0.387684,1.01766,-1.92367,-0.490346,0.752987,-1.94081,-0.518286,0.815435,-2.00053,0.106099,1.2989,-1.7821,0.112763,1.28365,-1.99669},
/*826*/{0.203052,1.84583,-1.66426,0.28726,1.80143,-1.81678,0.102679,1.69885,-1.57021,0.020957,1.59757,-1.51181,0.168942,1.548,-1.54615,0.250867,1.51228,-1.54756,0.21799,1.88744,-2.06509,0.295507,1.81122,-1.89448,0.082449,1.84883,-1.97731,0.042749,1.69047,-2.16367,0.067955,1.59868,-2.21088,0.225562,1.48663,-2.15404,0.267463,1.43713,-2.16324,0.181641,1.38572,-1.77157,-0.01143,1.4384,-1.85252,-0.002995,1.45872,-1.91149,0.001641,1.42741,-1.96703,0.197216,1.36631,-2.02508,0.242528,1.11064,-1.69342,0.124478,1.05597,-1.73406,0.161144,0.980424,-1.7553,0.262734,0.898523,-1.73575,0.291863,0.711771,-1.74012,0.287175,0.63798,-1.75541,0.179272,0.719742,-1.75193,0.175051,0.648739,-1.76318,0.205007,0.427548,-1.79219,0.101872,0.360982,-1.87065,0.358212,0.388647,-1.82163,0.328615,0.339049,-1.75138,0.179176,1.05619,-2.06845,0.192878,0.974122,-2.05121,0.040813,1.03405,-2.02852,0.058089,0.955476,-2.01075,0.103217,0.832468,-2.01697,-0.060379,0.801964,-2.00683,-0.048111,0.914927,-2.02157,-0.118056,0.917351,-2.01238,-0.347673,0.918599,-1.98673,-0.374657,1.01796,-1.92609,-0.473978,0.751784,-1.94229,-0.504878,0.814117,-2.00099,0.103777,1.29664,-1.78088,0.112238,1.27995,-1.9953},
/*827*/{0.203876,1.84265,-1.66316,0.287065,1.80013,-1.81787,0.107955,1.69397,-1.5696,0.03043,1.59287,-1.50883,0.178252,1.54555,-1.54591,0.260506,1.51093,-1.54745,0.219308,1.8853,-2.06509,0.29562,1.80811,-1.89534,0.082443,1.84823,-1.97623,0.038693,1.69071,-2.16115,0.062456,1.59774,-2.21014,0.216726,1.48112,-2.15604,0.257106,1.429,-2.16692,0.178831,1.38513,-1.76871,-0.013518,1.4363,-1.85373,-0.005043,1.45667,-1.91084,-0.00203,1.42265,-1.96942,0.195255,1.36283,-2.02389,0.240579,1.11085,-1.69324,0.121536,1.05237,-1.73498,0.160478,0.979151,-1.7557,0.270233,0.902644,-1.73643,0.282185,0.711707,-1.73914,0.275388,0.637215,-1.75463,0.169763,0.722466,-1.7511,0.162951,0.650961,-1.76114,0.18408,0.427682,-1.79234,0.08058,0.36173,-1.87005,0.336026,0.388271,-1.82195,0.307668,0.338733,-1.75065,0.18457,1.05742,-2.06783,0.200465,0.975354,-2.05062,0.046431,1.0314,-2.0294,0.065643,0.952672,-2.01174,0.117346,0.830516,-2.01623,-0.046921,0.800146,-2.00596,-0.03317,0.91227,-2.02223,-0.102421,0.915977,-2.01318,-0.33076,0.9175,-1.98935,-0.362461,1.01561,-1.92842,-0.456502,0.748414,-1.94417,-0.486453,0.810615,-2.00502,0.100945,1.29587,-1.77887,0.110645,1.27625,-1.99299},
/*828*/{0.204182,1.84067,-1.66335,0.287124,1.7975,-1.81837,0.112716,1.69034,-1.5693,0.039584,1.58777,-1.5053,0.188018,1.54376,-1.54526,0.270374,1.51063,-1.54741,0.219254,1.88312,-2.06446,0.295743,1.80541,-1.89586,0.082509,1.8482,-1.97635,0.035038,1.69195,-2.15729,0.056636,1.59884,-2.2088,0.207933,1.47693,-2.1579,0.246292,1.4225,-2.17024,0.176629,1.38478,-1.76553,-0.015618,1.43418,-1.85529,-0.006216,1.45647,-1.91169,-0.004296,1.4199,-1.96988,0.192223,1.36043,-2.02346,0.237685,1.10868,-1.69342,0.119339,1.05005,-1.73384,0.156665,0.977113,-1.75555,0.274875,0.903223,-1.73866,0.271371,0.71027,-1.73808,0.260694,0.635619,-1.75381,0.160077,0.725154,-1.7511,0.15255,0.653814,-1.76136,0.163297,0.427701,-1.79155,0.058727,0.362157,-1.86905,0.315638,0.387777,-1.82147,0.285183,0.338031,-1.74984,0.190702,1.05842,-2.06728,0.209811,0.977349,-2.04986,0.054153,1.02866,-2.03082,0.07475,0.95046,-2.01273,0.131983,0.829794,-2.01576,-0.031147,0.797425,-2.00432,-0.01765,0.907547,-2.02403,-0.087707,0.913966,-2.01592,-0.316864,0.914688,-1.98922,-0.349582,1.0128,-1.92836,-0.4406,0.743948,-1.94526,-0.469612,0.80508,-2.00664,0.098094,1.29545,-1.77751,0.108715,1.27384,-1.99139},
/*829*/{0.204916,1.83896,-1.66403,0.287589,1.79396,-1.81865,0.119542,1.68798,-1.56808,0.049887,1.58424,-1.50299,0.19679,1.54284,-1.54549,0.281198,1.51185,-1.54795,0.219611,1.88133,-2.06357,0.294896,1.80379,-1.89645,0.083166,1.84771,-1.97724,0.030746,1.69398,-2.15339,0.051023,1.60138,-2.20733,0.198452,1.47268,-2.15832,0.235165,1.41672,-2.17258,0.17373,1.38449,-1.76345,-0.016491,1.43295,-1.85627,-0.007772,1.45626,-1.911,-0.00601,1.41926,-1.97003,0.190911,1.35905,-2.02327,0.23408,1.10546,-1.69294,0.115429,1.04998,-1.73443,0.15266,0.975053,-1.75579,0.273064,0.899713,-1.73974,0.25972,0.7074,-1.73663,0.246999,0.633182,-1.75194,0.14898,0.725213,-1.75125,0.137343,0.654881,-1.76125,0.142727,0.427545,-1.7895,0.037052,0.363029,-1.86754,0.293799,0.386761,-1.82084,0.263242,0.337756,-1.74942,0.198072,1.06006,-2.06698,0.218699,0.979804,-2.04902,0.060776,1.02652,-2.03104,0.08418,0.948756,-2.01381,0.148565,0.830972,-2.01438,-0.015803,0.795493,-2.00366,-0.003154,0.906687,-2.02416,-0.071968,0.910768,-2.0143,-0.304387,0.912349,-1.99009,-0.33855,1.00973,-1.93173,-0.421734,0.737887,-1.94669,-0.452534,0.798259,-2.00839,0.095564,1.29491,-1.77676,0.107212,1.27283,-1.99054},
/*830*/{0.206141,1.83802,-1.66457,0.28707,1.79234,-1.81862,0.124917,1.68621,-1.56751,0.058101,1.58119,-1.50034,0.206856,1.54268,-1.54517,0.291404,1.51347,-1.5487,0.219977,1.88022,-2.06353,0.294101,1.80168,-1.89574,0.082834,1.84786,-1.97751,0.027207,1.69725,-2.14944,0.044329,1.6047,-2.20583,0.189804,1.47064,-2.15907,0.223839,1.41304,-2.17506,0.171854,1.38427,-1.76105,-0.018309,1.43288,-1.85558,-0.008741,1.45575,-1.91015,-0.007013,1.41955,-1.96959,0.188653,1.35868,-2.02283,0.228923,1.1018,-1.69271,0.109352,1.04811,-1.73668,0.147181,0.973255,-1.75727,0.264856,0.895325,-1.7387,0.246994,0.703,-1.73568,0.231553,0.629842,-1.75072,0.136735,0.725369,-1.75036,0.123016,0.654847,-1.76008,0.120905,0.426948,-1.78807,0.015296,0.363892,-1.86678,0.271962,0.386231,-1.81991,0.241939,0.337504,-1.74795,0.206636,1.06346,-2.06633,0.229989,0.983152,-2.04879,0.069189,1.02532,-2.0336,0.096237,0.947842,-2.01617,0.164858,0.833464,-2.01565,-0.000129,0.79392,-2.00178,0.012958,0.904326,-2.02425,-0.057676,0.908549,-2.01507,-0.282951,0.902806,-1.98795,-0.327703,1.00497,-1.933,-0.402959,0.730588,-1.94792,-0.433702,0.78834,-2.00915,0.093446,1.29465,-1.77575,0.105481,1.27257,-1.98951},
/*831*/{0.207685,1.83757,-1.66503,0.285997,1.79266,-1.81925,0.129219,1.68577,-1.56691,0.068582,1.58016,-1.49879,0.217008,1.5436,-1.54566,0.301357,1.51642,-1.55064,0.220724,1.87926,-2.06308,0.293192,1.80073,-1.89559,0.083269,1.84842,-1.97813,0.022274,1.70181,-2.14551,0.039194,1.60825,-2.20407,0.180462,1.46931,-2.15966,0.213295,1.41122,-2.17658,0.170487,1.38407,-1.75951,-0.018671,1.43304,-1.8544,-0.009966,1.45636,-1.90942,-0.007897,1.42016,-1.96915,0.187288,1.35948,-2.02233,0.223809,1.09808,-1.69179,0.103804,1.04586,-1.73733,0.140037,0.970061,-1.75766,0.254786,0.890417,-1.73761,0.233322,0.699789,-1.73494,0.216384,0.626358,-1.75013,0.124024,0.724232,-1.74995,0.108438,0.654584,-1.76001,0.101478,0.426749,-1.78743,-0.006343,0.364492,-1.86592,0.250353,0.386247,-1.81932,0.220494,0.337011,-1.74798,0.214813,1.06669,-2.06642,0.240669,0.98758,-2.04833,0.078872,1.0261,-2.03557,0.10785,0.947529,-2.01678,0.181546,0.837154,-2.01501,0.015714,0.791987,-2.00052,0.026805,0.902991,-2.02497,-0.043421,0.907362,-2.01671,-0.274304,0.901672,-1.99272,-0.318717,0.998488,-1.93516,-0.383283,0.722428,-1.94764,-0.412923,0.777476,-2.01037,0.092149,1.29455,-1.77527,0.104356,1.27323,-1.98909},
/*832*/{0.209104,1.8376,-1.66584,0.284848,1.79167,-1.8203,0.13427,1.68557,-1.56638,0.076175,1.57853,-1.49757,0.226531,1.54568,-1.54667,0.31153,1.52045,-1.5523,0.220766,1.87882,-2.06276,0.292905,1.80063,-1.89593,0.082703,1.84897,-1.97818,0.018748,1.70565,-2.1409,0.032416,1.61295,-2.20281,0.171386,1.46919,-2.16038,0.202468,1.41009,-2.1783,0.167928,1.38413,-1.75881,-0.01979,1.4335,-1.85345,-0.011618,1.45622,-1.90918,-0.010065,1.42211,-1.96733,0.186232,1.35994,-2.02237,0.218493,1.0936,-1.69225,0.098184,1.04436,-1.73818,0.132693,0.9682,-1.75889,0.24334,0.884858,-1.73668,0.219299,0.695299,-1.73435,0.200639,0.622873,-1.74986,0.110636,0.722568,-1.74843,0.092083,0.653191,-1.76052,0.079894,0.427689,-1.78575,-0.028104,0.365183,-1.86531,0.228588,0.385638,-1.81792,0.198555,0.337184,-1.74645,0.224556,1.07061,-2.06572,0.252178,0.993128,-2.04758,0.089314,1.02566,-2.03718,0.121057,0.948008,-2.01801,0.197573,0.840136,-2.01408,0.031863,0.791879,-2.00002,0.041325,0.902068,-2.02522,-0.028836,0.905382,-2.01653,-0.254938,0.893054,-1.98992,-0.309617,0.990741,-1.93797,-0.360782,0.711867,-1.9463,-0.395729,0.766195,-2.01201,0.090128,1.29453,-1.77499,0.102426,1.27407,-1.9889},
/*833*/{0.210543,1.83797,-1.66606,0.284785,1.79114,-1.82021,0.138178,1.6861,-1.56603,0.084109,1.5774,-1.49606,0.23495,1.54773,-1.54686,0.321261,1.52543,-1.55452,0.220133,1.87881,-2.06271,0.29229,1.79998,-1.89636,0.082126,1.84998,-1.9784,0.015517,1.7117,-2.13708,0.025912,1.61822,-2.2018,0.162889,1.47045,-2.16122,0.191319,1.41043,-2.17948,0.167311,1.38377,-1.7564,-0.020165,1.4333,-1.8529,-0.012477,1.45593,-1.90768,-0.011567,1.42324,-1.96624,0.184639,1.36229,-2.02243,0.213096,1.09025,-1.69223,0.091198,1.04355,-1.73869,0.124369,0.96586,-1.75878,0.231664,0.880022,-1.73671,0.205002,0.690506,-1.73449,0.184937,0.618936,-1.75007,0.096352,0.719908,-1.74848,0.078515,0.65086,-1.76012,0.059678,0.428332,-1.78565,-0.049088,0.366289,-1.86463,0.207401,0.385148,-1.81673,0.17722,0.33622,-1.74635,0.232355,1.07728,-2.06676,0.263371,0.998948,-2.04726,0.100105,1.02591,-2.03839,0.133365,0.949745,-2.0196,0.213554,0.844409,-2.01391,0.047268,0.790099,-1.99875,0.05532,0.901344,-2.02526,-0.015192,0.903758,-2.01709,-0.249665,0.888694,-1.99126,-0.299798,0.982186,-1.93994,-0.339374,0.701272,-1.94641,-0.375134,0.753576,-2.0133,0.08967,1.29401,-1.77498,0.101911,1.27554,-1.98907},
/*834*/{0.212161,1.8391,-1.66633,0.285134,1.79167,-1.82077,0.14171,1.6869,-1.56543,0.093824,1.57735,-1.49422,0.244749,1.55135,-1.54752,0.331113,1.53112,-1.55703,0.218929,1.87925,-2.06295,0.291931,1.8002,-1.8968,0.081305,1.85085,-1.97752,0.011223,1.71709,-2.13388,0.019276,1.62354,-2.20084,0.154133,1.47233,-2.16232,0.181611,1.41234,-2.18035,0.166498,1.38446,-1.75608,-0.020442,1.43324,-1.85225,-0.013624,1.45626,-1.90639,-0.012616,1.42387,-1.96432,0.183609,1.36418,-2.02235,0.206203,1.08621,-1.69268,0.083374,1.0415,-1.7388,0.113347,0.965493,-1.76014,0.219358,0.874888,-1.73683,0.189984,0.685733,-1.73503,0.168119,0.614289,-1.75064,0.082652,0.718307,-1.74834,0.063504,0.649383,-1.75973,0.039153,0.428337,-1.78493,-0.07069,0.366935,-1.86345,0.186031,0.385238,-1.81688,0.155464,0.336077,-1.74549,0.240854,1.08379,-2.06584,0.275195,1.00685,-2.04714,0.110709,1.02756,-2.0399,0.14614,0.952234,-2.02162,0.229044,0.848534,-2.01487,0.063551,0.790977,-1.99918,0.069128,0.902018,-2.02507,-0.001009,0.902839,-2.01862,-0.232278,0.881668,-1.9942,-0.292272,0.973261,-1.94135,-0.317048,0.690589,-1.94792,-0.354437,0.73954,-2.01418,0.08977,1.29428,-1.77475,0.101452,1.27684,-1.98896},
/*835*/{0.213101,1.84116,-1.66685,0.284189,1.79232,-1.82184,0.144789,1.68841,-1.56524,0.101114,1.57799,-1.49378,0.252337,1.55521,-1.54879,0.340551,1.53714,-1.56053,0.217338,1.88052,-2.06345,0.290642,1.80038,-1.89732,0.080737,1.85228,-1.97628,0.00694,1.72306,-2.13169,0.012806,1.62978,-2.20032,0.145329,1.47566,-2.16382,0.172043,1.41574,-2.1816,0.165507,1.38479,-1.75584,-0.021624,1.43314,-1.85171,-0.014434,1.45697,-1.90646,-0.013104,1.42455,-1.96306,0.182125,1.36599,-2.02293,0.200282,1.08306,-1.69317,0.075064,1.04347,-1.73974,0.104787,0.964264,-1.75843,0.205663,0.868442,-1.73702,0.17561,0.681723,-1.73655,0.152447,0.610421,-1.75153,0.067849,0.71594,-1.74872,0.047754,0.647498,-1.75824,0.017876,0.428058,-1.7835,-0.092014,0.367694,-1.86281,0.164113,0.384715,-1.81615,0.134115,0.336393,-1.74428,0.248779,1.0905,-2.0663,0.285396,1.01528,-2.04718,0.120051,1.02973,-2.04096,0.15722,0.958065,-2.02374,0.243578,0.852562,-2.01529,0.079585,0.791966,-1.99971,0.081587,0.903699,-2.02739,0.012045,0.901437,-2.01907,-0.219074,0.873268,-1.99433,-0.283163,0.961616,-1.94191,-0.293544,0.679149,-1.94827,-0.33356,0.726017,-2.01562,0.089287,1.29437,-1.77515,0.100724,1.27813,-1.98947},
/*836*/{0.214691,1.84327,-1.66748,0.284762,1.7937,-1.82273,0.148856,1.69135,-1.56466,0.108377,1.57792,-1.49331,0.260202,1.56002,-1.55044,0.348721,1.54423,-1.56401,0.215386,1.88162,-2.06349,0.289767,1.80103,-1.89828,0.079394,1.8539,-1.97583,0.003553,1.72954,-2.12956,0.005685,1.63557,-2.19963,0.135692,1.48007,-2.16498,0.166497,1.42008,-2.18191,0.164574,1.38415,-1.75534,-0.021844,1.43381,-1.84997,-0.014682,1.45771,-1.90517,-0.01481,1.426,-1.96242,0.181406,1.36821,-2.02341,0.196777,1.08271,-1.69248,0.069156,1.04444,-1.73928,0.093801,0.964668,-1.76063,0.191684,0.863147,-1.73686,0.159911,0.678905,-1.73767,0.1372,0.608722,-1.75276,0.052855,0.713945,-1.74847,0.030568,0.646617,-1.75908,-0.002561,0.429464,-1.78395,-0.113483,0.369031,-1.86244,0.143063,0.384642,-1.81595,0.112596,0.336036,-1.74371,0.25585,1.09784,-2.06648,0.294856,1.02372,-2.04758,0.12928,1.03276,-2.04157,0.169174,0.963194,-2.02486,0.258063,0.857529,-2.01599,0.096359,0.793503,-2.00017,0.09526,0.905228,-2.02643,0.0251,0.900759,-2.01944,-0.205368,0.86513,-1.99547,-0.273518,0.949983,-1.94492,-0.270805,0.666953,-1.94805,-0.310845,0.712319,-2.0167,0.088757,1.29393,-1.77574,0.099708,1.27995,-1.99024},
/*837*/{0.216534,1.84581,-1.66802,0.284679,1.79464,-1.82323,0.152757,1.69352,-1.56437,0.116044,1.57932,-1.49187,0.267617,1.56536,-1.55236,0.356916,1.55159,-1.56771,0.212762,1.88313,-2.06333,0.288732,1.80248,-1.89962,0.078525,1.85498,-1.97439,-0.002194,1.73564,-2.12889,-0.001053,1.64278,-2.19918,0.127299,1.48523,-2.16556,0.152407,1.42585,-2.18268,0.164888,1.38437,-1.75601,-0.022323,1.4359,-1.85003,-0.014415,1.45919,-1.90394,-0.01522,1.42776,-1.96143,0.18132,1.37105,-2.02431,0.189271,1.08066,-1.69534,0.061609,1.0454,-1.7387,0.084048,0.964074,-1.76029,0.175797,0.859409,-1.73874,0.143048,0.67739,-1.73801,0.118004,0.606779,-1.75368,0.036782,0.713644,-1.74791,0.014658,0.646193,-1.75914,-0.022904,0.429277,-1.78429,-0.13502,0.369615,-1.86239,0.121786,0.384159,-1.81547,0.089944,0.336169,-1.74465,0.262058,1.10628,-2.06651,0.304062,1.03318,-2.04776,0.1383,1.03635,-2.04292,0.179717,0.967567,-2.02593,0.272263,0.863295,-2.01649,0.112745,0.795486,-2.00138,0.107652,0.907302,-2.02699,0.037182,0.900187,-2.02155,-0.186947,0.852201,-1.99308,-0.266389,0.937219,-1.94314,-0.245775,0.654496,-1.94918,-0.288464,0.697155,-2.0185,0.089043,1.29455,-1.77675,0.099307,1.28241,-1.9914},
/*838*/{0.218705,1.84927,-1.66887,0.284379,1.79746,-1.82447,0.156926,1.69661,-1.56486,0.125333,1.58164,-1.49173,0.274702,1.57089,-1.55475,0.363771,1.55913,-1.57131,0.210582,1.88547,-2.06364,0.288286,1.80394,-1.90072,0.07731,1.8576,-1.97304,-0.008064,1.74204,-2.12843,-0.008251,1.64897,-2.19907,0.118369,1.49159,-2.16598,0.14351,1.43159,-2.18248,0.165249,1.3843,-1.75545,-0.021827,1.43748,-1.84923,-0.014322,1.46025,-1.90282,-0.014945,1.42856,-1.96105,0.180147,1.37371,-2.02416,0.178632,1.07714,-1.69653,0.052801,1.04712,-1.73869,0.072743,0.965473,-1.7598,0.160057,0.85722,-1.7388,0.126513,0.675583,-1.73896,0.100878,0.605667,-1.75401,0.021135,0.714039,-1.74935,-0.003289,0.646644,-1.75849,-0.044779,0.431416,-1.78445,-0.155852,0.371166,-1.86265,0.100206,0.38308,-1.81584,0.069425,0.336336,-1.74454,0.268278,1.11403,-2.06711,0.312353,1.04282,-2.04804,0.145702,1.04013,-2.04277,0.190384,0.97297,-2.02589,0.285552,0.8709,-2.01771,0.128725,0.797337,-2.00259,0.119404,0.910112,-2.02595,0.049779,0.899811,-2.02111,-0.177202,0.845411,-1.99663,-0.257902,0.922548,-1.94404,-0.221201,0.641739,-1.95054,-0.265698,0.682514,-2.01879,0.089348,1.29493,-1.77705,0.099103,1.28424,-1.99179},
/*839*/{0.221065,1.8524,-1.66973,0.284971,1.79961,-1.82559,0.160406,1.69912,-1.56547,0.133237,1.58426,-1.49126,0.282379,1.57742,-1.55724,0.370494,1.56805,-1.57596,0.207899,1.8882,-2.06461,0.288133,1.80666,-1.90192,0.075676,1.85868,-1.97206,-0.014261,1.74804,-2.12741,-0.016476,1.65594,-2.19885,0.110406,1.49802,-2.16597,0.134946,1.4379,-2.18237,0.166892,1.38428,-1.75637,-0.021737,1.43931,-1.8479,-0.01367,1.46236,-1.90216,-0.015581,1.43014,-1.96031,0.180228,1.37587,-2.02437,0.174919,1.07834,-1.69631,0.043057,1.04671,-1.73816,0.065231,0.96667,-1.758,0.142964,0.85593,-1.73965,0.110521,0.674362,-1.74011,0.082436,0.604679,-1.75465,0.005196,0.715047,-1.74946,-0.020091,0.64817,-1.75855,-0.064205,0.432086,-1.78432,-0.177809,0.373475,-1.86207,0.078324,0.383434,-1.8154,0.047239,0.336416,-1.74407,0.273716,1.12243,-2.06793,0.31919,1.05239,-2.04875,0.154003,1.04493,-2.04366,0.19949,0.979277,-2.02671,0.298736,0.879865,-2.01875,0.144699,0.800035,-2.00417,0.130387,0.911657,-2.02651,0.061938,0.898997,-2.02162,-0.16507,0.835386,-1.996,-0.249043,0.90752,-1.94423,-0.195778,0.629302,-1.95195,-0.241546,0.668083,-2.0203,0.090133,1.29561,-1.77769,0.09862,1.28629,-1.99256},
/*840*/{0.222716,1.85562,-1.67065,0.285962,1.80265,-1.82753,0.165647,1.70232,-1.5654,0.139223,1.58598,-1.49103,0.288184,1.58353,-1.56024,0.376915,1.57618,-1.5806,0.205287,1.89186,-2.06458,0.287818,1.8088,-1.90313,0.07413,1.86132,-1.96966,-0.020307,1.75438,-2.127,-0.023627,1.66303,-2.19799,0.102552,1.50446,-2.16537,0.127002,1.44513,-2.18182,0.167351,1.38393,-1.75621,-0.020738,1.4413,-1.84662,-0.014365,1.46436,-1.90112,-0.015475,1.43215,-1.95948,0.179539,1.3788,-2.0246,0.167211,1.07476,-1.69798,0.03563,1.05064,-1.73729,0.051866,0.967899,-1.75822,0.127207,0.855315,-1.74087,0.092583,0.674457,-1.74009,0.064859,0.60553,-1.75583,-0.011844,0.71628,-1.74923,-0.038343,0.650579,-1.75924,-0.087106,0.431484,-1.78224,-0.199408,0.375061,-1.86162,0.057391,0.38349,-1.81533,0.025988,0.336257,-1.74422,0.278474,1.13039,-2.06748,0.32645,1.06191,-2.0494,0.160917,1.05001,-2.04411,0.208658,0.985979,-2.02653,0.312116,0.890467,-2.01938,0.158945,0.802889,-2.00534,0.141586,0.913511,-2.02774,0.072427,0.898452,-2.02237,-0.149294,0.823972,-1.99637,-0.239241,0.891083,-1.94323,-0.170545,0.616811,-1.95365,-0.219739,0.652809,-2.02177,0.090236,1.29604,-1.77842,0.097944,1.28884,-1.9934},
/*841*/{0.22428,1.85979,-1.67179,0.285516,1.80544,-1.8288,0.170602,1.70523,-1.56518,0.146799,1.58954,-1.49173,0.293813,1.59016,-1.56336,0.381597,1.58534,-1.58497,0.20223,1.89481,-2.06437,0.287141,1.81162,-1.90553,0.072504,1.86281,-1.96757,-0.023801,1.76096,-2.12635,-0.030765,1.66959,-2.19723,0.094553,1.51074,-2.16473,0.119635,1.45277,-2.18141,0.168305,1.38509,-1.757,-0.019881,1.44382,-1.84653,-0.013574,1.46668,-1.89964,-0.014573,1.43479,-1.95891,0.180743,1.38177,-2.02478,0.157,1.07385,-1.70129,0.027472,1.05382,-1.73707,0.039747,0.970449,-1.75929,0.111669,0.855204,-1.74184,0.074735,0.674394,-1.74144,0.046044,0.606086,-1.75689,-0.02932,0.718099,-1.75069,-0.055628,0.65136,-1.76011,-0.108308,0.433249,-1.7821,-0.220422,0.378685,-1.86085,0.036302,0.383048,-1.81584,0.00384,0.335928,-1.74406,0.283379,1.13871,-2.06836,0.332897,1.07145,-2.05021,0.168061,1.05488,-2.04435,0.217578,0.991567,-2.02685,0.324156,0.901356,-2.02055,0.17449,0.805776,-2.00749,0.152007,0.914625,-2.0275,0.083447,0.897036,-2.02324,-0.135821,0.812874,-1.99777,-0.229849,0.873203,-1.9421,-0.144467,0.604398,-1.95601,-0.195808,0.637832,-2.02428,0.091211,1.29748,-1.77912,0.098576,1.2918,-1.99415},
/*842*/{0.226926,1.86374,-1.67258,0.286509,1.80849,-1.83052,0.17592,1.70882,-1.5655,0.152455,1.59252,-1.49153,0.299773,1.59712,-1.56662,0.386831,1.59389,-1.59019,0.198732,1.8984,-2.06468,0.287312,1.81506,-1.90681,0.070723,1.8656,-1.96585,-0.030087,1.76742,-2.12491,-0.037717,1.67664,-2.19633,0.087378,1.51853,-2.16324,0.112296,1.46046,-2.18048,0.168975,1.38523,-1.75674,-0.018886,1.44696,-1.84484,-0.012701,1.46935,-1.89838,-0.01433,1.43776,-1.95771,0.180208,1.38504,-2.0243,0.150437,1.07274,-1.70258,0.018469,1.05679,-1.73785,0.029521,0.973643,-1.75889,0.096717,0.856469,-1.74304,0.056759,0.675473,-1.74185,0.025719,0.606918,-1.75673,-0.046891,0.719549,-1.75143,-0.075639,0.654253,-1.76122,-0.128111,0.437177,-1.78261,-0.24154,0.382246,-1.85968,0.014651,0.383266,-1.81565,-0.017233,0.336009,-1.74499,0.287641,1.14637,-2.06824,0.339158,1.08101,-2.05084,0.174366,1.05939,-2.04418,0.225955,0.99741,-2.02647,0.335762,0.912586,-2.02171,0.189078,0.808419,-2.0093,0.161517,0.91554,-2.02786,0.09422,0.895463,-2.02321,-0.120325,0.799891,-1.99798,-0.219252,0.855741,-1.94113,-0.115538,0.593166,-1.95988,-0.1713,0.623424,-2.02578,0.091249,1.29863,-1.77941,0.097869,1.2949,-1.99451},
/*843*/{0.229055,1.86785,-1.67375,0.287032,1.81165,-1.83186,0.18151,1.71245,-1.56603,0.160157,1.5957,-1.49169,0.304257,1.60355,-1.5692,0.39106,1.60311,-1.5953,0.195354,1.90226,-2.06475,0.287657,1.819,-1.90852,0.070404,1.86752,-1.96419,-0.035913,1.77373,-2.12459,-0.044598,1.68365,-2.19526,0.080247,1.52613,-2.16199,0.104994,1.46832,-2.18009,0.170301,1.38591,-1.75657,-0.017412,1.44913,-1.84276,-0.011944,1.47164,-1.8974,-0.012885,1.4413,-1.95729,0.180871,1.38892,-2.0239,0.143382,1.07408,-1.7061,0.011104,1.05736,-1.73547,0.018556,0.977324,-1.75863,0.083334,0.858049,-1.74567,0.037968,0.677277,-1.74245,0.007698,0.608728,-1.75815,-0.064519,0.722843,-1.75201,-0.092852,0.657445,-1.76103,-0.148305,0.439652,-1.78182,-0.262151,0.387333,-1.8593,-0.006741,0.38204,-1.81596,-0.039892,0.336484,-1.74531,0.291823,1.15383,-2.06938,0.344349,1.09009,-2.05111,0.180503,1.0647,-2.04378,0.233116,1.00358,-2.02661,0.34646,0.923286,-2.02251,0.203267,0.811853,-2.01024,0.169121,0.919844,-2.02926,0.103332,0.893865,-2.02379,-0.103391,0.785756,-1.99614,-0.207647,0.836008,-1.94044,-0.088416,0.581194,-1.96292,-0.146282,0.608686,-2.02786,0.092351,1.29974,-1.78012,0.098685,1.29851,-1.99526},
/*844*/{0.231435,1.87277,-1.67491,0.288234,1.81606,-1.83354,0.188076,1.7163,-1.56691,0.167292,1.60014,-1.49181,0.30847,1.61103,-1.57203,0.395001,1.61192,-1.59933,0.192178,1.90566,-2.0647,0.286906,1.82247,-1.9101,0.068755,1.87042,-1.96212,-0.041248,1.78073,-2.12415,-0.051071,1.69056,-2.19415,0.073351,1.53467,-2.16096,0.098895,1.47632,-2.17858,0.171958,1.38622,-1.75615,-0.016377,1.45161,-1.84205,-0.011054,1.47426,-1.89588,-0.012081,1.44498,-1.95678,0.181586,1.3921,-2.02314,0.138795,1.07316,-1.70612,0.005098,1.06306,-1.73404,0.008279,0.979994,-1.75758,0.068489,0.86061,-1.74748,0.020332,0.679604,-1.74369,-0.011273,0.612204,-1.75844,-0.08217,0.725309,-1.75226,-0.110924,0.661225,-1.76017,-0.167654,0.442969,-1.78122,-0.282922,0.393753,-1.85811,-0.027085,0.382179,-1.81564,-0.061701,0.336321,-1.74598,0.295202,1.16199,-2.07048,0.349647,1.0972,-2.05172,0.186392,1.06997,-2.04399,0.240125,1.01113,-2.02691,0.355841,0.933697,-2.02355,0.217034,0.815286,-2.0132,0.177253,0.921451,-2.02983,0.112737,0.8929,-2.02393,-0.086994,0.773024,-1.99588,-0.196453,0.817484,-1.9404,-0.060384,0.571524,-1.96652,-0.121056,0.594847,-2.03052,0.092865,1.30089,-1.78066,0.099051,1.30182,-1.99581},
/*845*/{0.233283,1.8773,-1.67678,0.289178,1.82065,-1.83523,0.193282,1.72061,-1.5676,0.174217,1.60472,-1.4925,0.312831,1.61818,-1.57505,0.39798,1.62064,-1.60479,0.188984,1.91016,-2.06414,0.286796,1.82633,-1.91211,0.067962,1.87363,-1.96072,-0.044741,1.78724,-2.12311,-0.056643,1.69794,-2.19238,0.066762,1.54261,-2.15883,0.092055,1.48502,-2.17782,0.173048,1.38732,-1.75544,-0.014227,1.45431,-1.84106,-0.008888,1.47743,-1.89343,-0.010743,1.44796,-1.95585,0.182216,1.39616,-2.02236,0.131734,1.07331,-1.70904,-0.00462,1.06756,-1.73579,-0.001995,0.985445,-1.75627,0.057445,0.8635,-1.74813,0.002968,0.682894,-1.74378,-0.029182,0.614757,-1.75818,-0.099146,0.729292,-1.75316,-0.129315,0.664107,-1.76144,-0.186989,0.445865,-1.77997,-0.303219,0.400172,-1.85761,-0.047453,0.380788,-1.8156,-0.083675,0.336834,-1.74661,0.298887,1.16961,-2.07092,0.354168,1.10743,-2.05255,0.190901,1.07641,-2.04441,0.246787,1.01772,-2.02724,0.364155,0.944106,-2.02598,0.23031,0.818635,-2.01392,0.184905,0.922267,-2.03036,0.12146,0.890997,-2.02437,-0.071441,0.760629,-1.99518,-0.183164,0.79742,-1.93835,-0.033084,0.560144,-1.96964,-0.094557,0.581317,-2.03262,0.094076,1.30248,-1.7808,0.099971,1.30551,-1.99593},
/*846*/{0.235105,1.88249,-1.67809,0.28937,1.82461,-1.83733,0.199327,1.72504,-1.56867,0.179332,1.60762,-1.49198,0.315593,1.62464,-1.57862,0.400802,1.62965,-1.60954,0.186249,1.91427,-2.0642,0.286959,1.83055,-1.91381,0.06772,1.87555,-1.95814,-0.049794,1.79363,-2.12261,-0.062604,1.70451,-2.19049,0.060475,1.55098,-2.15684,0.086266,1.49275,-2.1769,0.174445,1.3889,-1.75501,-0.012266,1.45755,-1.84025,-0.007033,1.48225,-1.8923,-0.01005,1.45219,-1.95502,0.183603,1.39995,-2.02191,0.124793,1.0756,-1.71049,-0.011496,1.07472,-1.73508,-0.011088,0.990548,-1.7578,0.043371,0.866883,-1.74926,-0.014631,0.686863,-1.74418,-0.046469,0.620062,-1.75853,-0.116796,0.734129,-1.75303,-0.145883,0.669651,-1.76109,-0.206125,0.450881,-1.77946,-0.322312,0.407706,-1.85657,-0.068583,0.379333,-1.81615,-0.106262,0.337065,-1.74685,0.30215,1.17738,-2.07123,0.358156,1.11661,-2.05317,0.196235,1.08227,-2.04437,0.252523,1.02439,-2.02782,0.372109,0.953916,-2.02849,0.243793,0.821841,-2.01592,0.191619,0.92391,-2.03158,0.130736,0.88871,-2.02419,-0.056373,0.748813,-1.99581,-0.169964,0.777472,-1.93819,-0.004893,0.549747,-1.97259,-0.067536,0.568072,-2.03542,0.094753,1.30491,-1.78116,0.100508,1.30964,-1.99626},
/*847*/{0.236528,1.88718,-1.67975,0.29025,1.82922,-1.83924,0.20406,1.72946,-1.5695,0.185558,1.61238,-1.49277,0.319387,1.63227,-1.58151,0.403418,1.63785,-1.61447,0.184205,1.91792,-2.06368,0.287012,1.8354,-1.91583,0.067769,1.8786,-1.95601,-0.053426,1.79985,-2.12183,-0.06834,1.71172,-2.18899,0.055355,1.55912,-2.15551,0.080658,1.50093,-2.17612,0.176456,1.38938,-1.75462,-0.010537,1.46002,-1.83954,-0.006462,1.48411,-1.89082,-0.00789,1.45683,-1.95455,0.184197,1.40359,-2.02092,0.118647,1.07697,-1.71207,-0.016831,1.08086,-1.73474,-0.02173,0.99656,-1.75709,0.028984,0.870528,-1.74959,-0.031547,0.691416,-1.74359,-0.063806,0.624541,-1.75789,-0.133499,0.739742,-1.75375,-0.164796,0.675624,-1.7627,-0.224577,0.456231,-1.77804,-0.340648,0.415825,-1.85655,-0.089832,0.37854,-1.81733,-0.127461,0.337565,-1.74709,0.305074,1.18495,-2.07172,0.361932,1.12498,-2.05291,0.200843,1.08794,-2.04453,0.258168,1.03147,-2.02822,0.378012,0.964483,-2.02826,0.256625,0.826759,-2.01815,0.198458,0.924657,-2.0314,0.139729,0.884787,-2.02398,-0.040176,0.736344,-1.99592,-0.154139,0.756131,-1.93661,0.024684,0.539602,-1.97579,-0.040569,0.555649,-2.0384,0.095713,1.3061,-1.78193,0.101445,1.31338,-1.99696},
/*848*/{0.238343,1.89193,-1.68118,0.291929,1.8343,-1.84162,0.209273,1.73383,-1.57066,0.191242,1.61738,-1.49315,0.322365,1.63945,-1.58536,0.405524,1.64633,-1.61911,0.182318,1.92181,-2.06376,0.286447,1.83937,-1.91776,0.066763,1.88201,-1.95589,-0.056131,1.80709,-2.12135,-0.073351,1.71858,-2.18643,0.048933,1.56683,-2.15318,0.075373,1.50908,-2.17522,0.177993,1.39109,-1.75461,-0.007945,1.46336,-1.83854,-0.006143,1.48729,-1.88806,-0.006819,1.46112,-1.95479,0.185165,1.40808,-2.02028,0.111838,1.07799,-1.71405,-0.022167,1.08561,-1.73345,-0.03067,1.00267,-1.75715,0.013321,0.875374,-1.75012,-0.048494,0.69662,-1.74374,-0.081942,0.62988,-1.75782,-0.14983,0.745529,-1.75367,-0.180434,0.682259,-1.76149,-0.242985,0.460503,-1.77783,-0.359324,0.425703,-1.85688,-0.110654,0.377126,-1.81664,-0.150038,0.338086,-1.74636,0.307855,1.19248,-2.07336,0.365817,1.13325,-2.05399,0.204704,1.09488,-2.04498,0.262987,1.03742,-2.02883,0.382309,0.973741,-2.02633,0.266511,0.827954,-2.01914,0.204977,0.923802,-2.03037,0.147574,0.881448,-2.02424,-0.024637,0.723722,-1.99597,-0.137288,0.734445,-1.93583,0.05404,0.530208,-1.97915,-0.012315,0.543433,-2.04104,0.097036,1.30832,-1.78254,0.10229,1.31781,-1.9975},
/*849*/{0.239896,1.89671,-1.68326,0.292026,1.8378,-1.84297,0.213623,1.73861,-1.57213,0.196279,1.62175,-1.49431,0.324537,1.64606,-1.58901,0.407194,1.65408,-1.6238,0.18027,1.92617,-2.06375,0.286127,1.84395,-1.91946,0.066365,1.88578,-1.95394,-0.059227,1.81372,-2.11968,-0.078806,1.72561,-2.18406,0.044486,1.57454,-2.15154,0.069786,1.51728,-2.17463,0.179947,1.39172,-1.75467,-0.006418,1.46606,-1.8387,-0.003069,1.49087,-1.88653,-0.004683,1.46557,-1.95435,0.18687,1.41237,-2.01932,0.106456,1.07984,-1.7159,-0.028733,1.09263,-1.73323,-0.040349,1.00966,-1.75661,-0.001566,0.881108,-1.74929,-0.065038,0.703008,-1.74266,-0.100136,0.635525,-1.75562,-0.165584,0.752955,-1.75374,-0.197126,0.68935,-1.76162,-0.261171,0.466664,-1.77602,-0.377149,0.435823,-1.85577,-0.130729,0.377492,-1.81718,-0.171083,0.338341,-1.74729,0.311159,1.19937,-2.07252,0.369479,1.14147,-2.05395,0.208132,1.10096,-2.04611,0.268068,1.04462,-2.02899,0.387351,0.98276,-2.02665,0.277549,0.83104,-2.02104,0.210977,0.923426,-2.03048,0.155651,0.87701,-2.0243,-0.009482,0.709434,-1.99698,-0.118635,0.71425,-1.9339,0.08321,0.522464,-1.98335,0.01554,0.532205,-2.04403,0.098122,1.30981,-1.78379,0.103901,1.32223,-1.99859},
/*850*/{0.2407,1.90139,-1.68469,0.291922,1.84302,-1.84509,0.217286,1.74361,-1.57319,0.20133,1.62668,-1.49416,0.325684,1.65228,-1.59119,0.40749,1.66168,-1.62829,0.178613,1.92931,-2.06419,0.285789,1.84849,-1.92143,0.066281,1.88962,-1.95323,-0.062125,1.81965,-2.11885,-0.083539,1.73221,-2.18131,0.038877,1.58267,-2.14977,0.06507,1.52448,-2.17376,0.182037,1.39326,-1.75527,-0.004902,1.46947,-1.83733,-0.001464,1.49507,-1.88491,-0.002488,1.47046,-1.95425,0.187457,1.41613,-2.01891,0.103911,1.08507,-1.71686,-0.034547,1.10085,-1.73237,-0.047672,1.01671,-1.75635,-0.016431,0.888107,-1.74853,-0.080465,0.709573,-1.74181,-0.114931,0.643439,-1.75475,-0.181373,0.760604,-1.75433,-0.213504,0.696606,-1.76196,-0.278833,0.472942,-1.77463,-0.394533,0.445899,-1.85516,-0.151034,0.376818,-1.81704,-0.194275,0.338629,-1.74722,0.313283,1.20693,-2.0726,0.372946,1.14947,-2.05315,0.211797,1.10719,-2.04664,0.271778,1.05166,-2.02846,0.389797,0.990962,-2.02774,0.289388,0.83361,-2.02244,0.217081,0.920482,-2.03015,0.166182,0.872194,-2.02188,0.011112,0.696826,-1.99604,-0.102332,0.693933,-1.933,0.112496,0.514931,-1.98701,0.044027,0.521535,-2.04689,0.099075,1.31219,-1.78456,0.104233,1.32654,-1.99925},
/*851*/{0.242731,1.90599,-1.68639,0.292676,1.84769,-1.84737,0.221367,1.74831,-1.57426,0.204822,1.63124,-1.49481,0.328037,1.65862,-1.59466,0.409368,1.66898,-1.63291,0.177879,1.93285,-2.06436,0.285129,1.85245,-1.92308,0.066378,1.89268,-1.95262,-0.064633,1.82617,-2.11716,-0.087688,1.73887,-2.17795,0.034897,1.58953,-2.14755,0.060686,1.53126,-2.17269,0.184305,1.39501,-1.75576,-0.001449,1.47294,-1.83736,0.000317,1.49846,-1.88372,-0.000508,1.47502,-1.95317,0.187974,1.42045,-2.01811,0.094865,1.08488,-1.7179,-0.040233,1.10697,-1.7322,-0.055787,1.02461,-1.7563,-0.030545,0.895685,-1.74733,-0.095528,0.717202,-1.74025,-0.131416,0.650585,-1.75298,-0.195684,0.768782,-1.75422,-0.228024,0.705126,-1.76161,-0.295646,0.478952,-1.77298,-0.410279,0.457434,-1.85484,-0.171976,0.375962,-1.81713,-0.216601,0.339471,-1.74888,0.315299,1.21335,-2.07275,0.375395,1.15631,-2.05278,0.215212,1.11358,-2.04736,0.274923,1.05847,-2.02927,0.392506,0.998451,-2.02785,0.299726,0.836171,-2.02388,0.222258,0.918569,-2.02958,0.17385,0.86734,-2.02167,0.029688,0.682692,-1.99565,-0.08469,0.671468,-1.93232,0.142398,0.508137,-1.99033,0.072502,0.51147,-2.04963,0.100826,1.31464,-1.78534,0.105266,1.33085,-1.99992},
/*852*/{0.243326,1.90989,-1.6885,0.293722,1.8511,-1.84908,0.224084,1.75236,-1.57507,0.208867,1.63596,-1.49498,0.328893,1.66463,-1.59641,0.409656,1.67592,-1.63702,0.176435,1.93608,-2.06436,0.28547,1.85656,-1.9243,0.066992,1.89554,-1.95165,-0.065711,1.83206,-2.11521,-0.092142,1.74511,-2.17479,0.031556,1.59662,-2.14575,0.057018,1.53826,-2.17183,0.186852,1.39595,-1.7566,-0.000103,1.47616,-1.83641,0.003266,1.50217,-1.88278,0.000808,1.4799,-1.95277,0.189623,1.4245,-2.01861,0.089686,1.08758,-1.71925,-0.043635,1.11448,-1.73117,-0.063788,1.03248,-1.756,-0.042134,0.903031,-1.74735,-0.108991,0.724551,-1.73875,-0.144365,0.658615,-1.75104,-0.209067,0.776959,-1.75419,-0.242078,0.713482,-1.76128,-0.310275,0.487234,-1.77088,-0.425587,0.470067,-1.8547,-0.192796,0.375574,-1.81732,-0.23897,0.340879,-1.74893,0.317361,1.22039,-2.07328,0.377718,1.1634,-2.05309,0.217546,1.11897,-2.04754,0.278612,1.06468,-2.02906,0.392812,1.00525,-2.02872,0.309771,0.837253,-2.02521,0.22761,0.915167,-2.02943,0.182967,0.861891,-2.02129,0.047824,0.669146,-1.99555,-0.064182,0.649551,-1.93027,0.17124,0.502656,-1.99405,0.101241,0.502854,-2.05198,0.102225,1.31658,-1.78691,0.1061,1.33536,-2.00129},
/*853*/{0.244876,1.91422,-1.68978,0.294358,1.85555,-1.85098,0.22708,1.75658,-1.57642,0.213032,1.63982,-1.49529,0.330416,1.66998,-1.59873,0.409671,1.68203,-1.641,0.175644,1.93909,-2.06449,0.285722,1.86,-1.92607,0.067686,1.89876,-1.95059,-0.067934,1.83724,-2.11275,-0.095238,1.75118,-2.1716,0.027129,1.60244,-2.14451,0.052593,1.54504,-2.17142,0.188293,1.39738,-1.75737,0.003021,1.47987,-1.83609,0.005347,1.50583,-1.88108,0.003495,1.48484,-1.9531,0.191104,1.42858,-2.01852,0.084699,1.09059,-1.71929,-0.049218,1.12047,-1.73124,-0.070742,1.04091,-1.75499,-0.053214,0.910514,-1.74665,-0.122617,0.732769,-1.73688,-0.158208,0.667115,-1.74808,-0.221468,0.785508,-1.75365,-0.254847,0.721926,-1.76026,-0.325451,0.492426,-1.76912,-0.4395,0.483567,-1.8536,-0.2129,0.375461,-1.81769,-0.261412,0.342245,-1.74918,0.319248,1.22579,-2.07323,0.379271,1.16975,-2.0528,0.219612,1.12483,-2.04833,0.279575,1.07103,-2.02914,0.393659,1.01147,-2.02897,0.318938,0.838222,-2.02648,0.232727,0.9115,-2.02952,0.191126,0.855803,-2.02137,0.064289,0.657324,-1.99755,-0.042163,0.627843,-1.92922,0.200256,0.498307,-1.99701,0.130604,0.494845,-2.05484,0.103359,1.31884,-1.78824,0.107208,1.3399,-2.00241},
/*854*/{0.247232,1.91881,-1.69142,0.294318,1.85881,-1.85288,0.229673,1.76086,-1.5766,0.216144,1.64417,-1.49634,0.331369,1.6747,-1.60179,0.409623,1.6883,-1.64479,0.174387,1.94179,-2.06484,0.285516,1.8636,-1.92733,0.06813,1.90163,-1.95063,-0.069764,1.84342,-2.11045,-0.098897,1.75726,-2.16831,0.023659,1.60829,-2.14238,0.049389,1.55069,-2.17005,0.190739,1.39914,-1.75904,0.004506,1.48323,-1.83525,0.006458,1.50955,-1.8804,0.005406,1.48907,-1.95211,0.191867,1.43281,-2.01842,0.080163,1.09361,-1.72009,-0.050569,1.12804,-1.73076,-0.076556,1.04888,-1.75416,-0.063067,0.918031,-1.74537,-0.13475,0.740793,-1.735,-0.17124,0.674567,-1.74591,-0.233372,0.793498,-1.75281,-0.26689,0.730176,-1.75973,-0.339986,0.500695,-1.7667,-0.452772,0.49842,-1.85163,-0.233975,0.376057,-1.81675,-0.283216,0.344095,-1.74881,0.320417,1.23145,-2.07305,0.38134,1.17499,-2.0523,0.222191,1.12833,-2.0499,0.281277,1.07634,-2.0298,0.393504,1.01619,-2.02991,0.329072,0.83838,-2.02709,0.239223,0.907061,-2.02941,0.199735,0.849429,-2.02112,0.087401,0.643048,-1.99405,-0.020643,0.607418,-1.92741,0.230028,0.494295,-1.99905,0.159316,0.48651,-2.05624,0.104959,1.32128,-1.78951,0.10785,1.34436,-2.00348},
/*855*/{0.247879,1.92129,-1.69322,0.29502,1.86324,-1.85417,0.232364,1.76436,-1.57797,0.218159,1.64681,-1.49623,0.331918,1.67896,-1.60366,0.410448,1.69281,-1.64905,0.174871,1.9447,-2.06515,0.285569,1.86702,-1.92884,0.068619,1.90484,-1.95011,-0.068981,1.8485,-2.10764,-0.101648,1.76246,-2.16491,0.021607,1.61296,-2.14064,0.045811,1.55582,-2.16885,0.191943,1.40033,-1.75979,0.006861,1.48702,-1.83508,0.009096,1.51216,-1.87972,0.007495,1.49336,-1.95124,0.193292,1.43614,-2.01895,0.075139,1.09593,-1.71943,-0.053947,1.13549,-1.72973,-0.08267,1.05711,-1.754,-0.07142,0.925423,-1.74492,-0.145422,0.749058,-1.73362,-0.181343,0.6836,-1.74357,-0.243659,0.801499,-1.75278,-0.277127,0.738306,-1.7592,-0.352535,0.508271,-1.76473,-0.464426,0.513027,-1.84943,-0.252902,0.377052,-1.81582,-0.303413,0.346803,-1.74862,0.322145,1.23678,-2.07271,0.382451,1.17949,-2.05162,0.222551,1.13447,-2.05058,0.281977,1.0808,-2.03055,0.393527,1.01993,-2.03011,0.337923,0.837783,-2.02773,0.244093,0.901731,-2.02948,0.208181,0.841445,-2.02129,0.107534,0.630015,-1.99374,0.001607,0.587088,-1.92687,0.258372,0.49105,-2.00009,0.188386,0.47951,-2.0577,0.105925,1.3233,-1.79065,0.108609,1.34813,-2.00443},
/*856*/{0.250218,1.92455,-1.69404,0.296193,1.86581,-1.85613,0.234221,1.76819,-1.57868,0.22075,1.65035,-1.49704,0.332602,1.68317,-1.60651,0.410001,1.69765,-1.65244,0.175445,1.94731,-2.06541,0.28586,1.86992,-1.93008,0.069008,1.90649,-1.95033,-0.070314,1.85382,-2.10439,-0.104771,1.76794,-2.16095,0.018819,1.61853,-2.13895,0.043142,1.56112,-2.16751,0.194619,1.40187,-1.76119,0.009188,1.49042,-1.83438,0.010866,1.51607,-1.87936,0.009721,1.49818,-1.9513,0.193446,1.43928,-2.01942,0.070616,1.10064,-1.7192,-0.056989,1.14266,-1.73097,-0.086355,1.06394,-1.75418,-0.080373,0.932061,-1.7447,-0.154578,0.755849,-1.73224,-0.190965,0.690645,-1.74153,-0.252556,0.808969,-1.75146,-0.286673,0.745956,-1.75784,-0.363529,0.515591,-1.76232,-0.474555,0.530115,-1.84734,-0.27168,0.378596,-1.81536,-0.326263,0.350837,-1.74813,0.322892,1.24046,-2.0722,0.382435,1.18306,-2.05094,0.222394,1.13841,-2.05085,0.282346,1.0828,-2.03108,0.392953,1.02297,-2.03105,0.346324,0.836773,-2.02853,0.250323,0.895708,-2.02987,0.217395,0.833308,-2.0219,0.124112,0.616893,-1.99417,0.024587,0.567629,-1.92596,0.286648,0.488529,-2.00132,0.217417,0.473483,-2.05807,0.107185,1.32585,-1.79186,0.108649,1.35198,-2.0055},
/*857*/{0.251239,1.92714,-1.69586,0.296396,1.86958,-1.85769,0.236615,1.77178,-1.57977,0.224551,1.65378,-1.49688,0.333018,1.68679,-1.60785,0.409403,1.70123,-1.65651,0.174441,1.94986,-2.06505,0.287105,1.87293,-1.93135,0.069791,1.90907,-1.9498,-0.070073,1.85852,-2.10086,-0.106856,1.77306,-2.15754,0.016977,1.62292,-2.13729,0.040255,1.56553,-2.16604,0.196225,1.40378,-1.76192,0.01014,1.49391,-1.8339,0.01186,1.51983,-1.87779,0.011796,1.50249,-1.95117,0.193413,1.44232,-2.01948,0.067932,1.10343,-1.7179,-0.062195,1.1476,-1.73159,-0.091815,1.0707,-1.75356,-0.087584,0.939055,-1.74545,-0.162125,0.763101,-1.73093,-0.199325,0.697569,-1.73966,-0.259389,0.816525,-1.75038,-0.293678,0.75432,-1.75505,-0.373521,0.524093,-1.75839,-0.483099,0.546125,-1.8442,-0.291486,0.380556,-1.81444,-0.346549,0.354608,-1.74812,0.323215,1.24397,-2.0715,0.382581,1.18561,-2.0502,0.221367,1.14323,-2.05153,0.280311,1.08742,-2.03436,0.392744,1.02415,-2.0318,0.354091,0.835991,-2.02894,0.255606,0.889535,-2.03068,0.226308,0.825712,-2.02177,0.14481,0.605079,-1.99415,0.047156,0.550262,-1.92646,0.314446,0.486758,-2.00116,0.246043,0.467191,-2.05807,0.107689,1.32848,-1.79242,0.108447,1.35571,-2.00593},
/*858*/{0.253812,1.9303,-1.69712,0.298488,1.8729,-1.85898,0.237519,1.77458,-1.58016,0.224937,1.65565,-1.49761,0.333867,1.68999,-1.61072,0.40982,1.70465,-1.65857,0.17433,1.95233,-2.06532,0.287746,1.87524,-1.93202,0.07058,1.91057,-1.94887,-0.069477,1.86331,-2.09814,-0.108522,1.77787,-2.15392,0.015354,1.62694,-2.13603,0.038172,1.56999,-2.16451,0.197847,1.40533,-1.76257,0.012101,1.49673,-1.83264,0.013108,1.52294,-1.87659,0.013207,1.50624,-1.95035,0.195377,1.44525,-2.02003,0.064447,1.10686,-1.71594,-0.06373,1.15192,-1.733,-0.094499,1.07772,-1.75457,-0.091795,0.944798,-1.74511,-0.168426,0.769551,-1.73051,-0.205759,0.704553,-1.73876,-0.265528,0.824316,-1.74857,-0.300496,0.76216,-1.75314,-0.383809,0.533027,-1.75618,-0.490822,0.56282,-1.84016,-0.31036,0.382401,-1.81405,-0.367923,0.360146,-1.74865,0.323216,1.24703,-2.07104,0.382363,1.18777,-2.04996,0.22105,1.14613,-2.05232,0.279019,1.09021,-2.03579,0.391769,1.02476,-2.03328,0.36282,0.833925,-2.02902,0.260636,0.883512,-2.03144,0.234459,0.817848,-2.02157,0.163484,0.593006,-1.99341,0.070882,0.532361,-1.92414,0.341322,0.485338,-2.00003,0.274383,0.462402,-2.05773,0.109017,1.33056,-1.79308,0.10923,1.35926,-2.00639},
/*859*/{0.254655,1.93201,-1.69823,0.298206,1.87576,-1.85974,0.239931,1.77693,-1.58027,0.227146,1.65854,-1.49828,0.333722,1.69259,-1.61281,0.408621,1.70757,-1.66257,0.175002,1.95416,-2.06564,0.288205,1.87749,-1.93334,0.071374,1.9133,-1.94845,-0.069897,1.86586,-2.09471,-0.11019,1.78196,-2.15013,0.013587,1.63112,-2.13409,0.036786,1.5738,-2.1631,0.198755,1.40798,-1.76258,0.013395,1.50024,-1.83216,0.013511,1.52645,-1.87652,0.014173,1.51022,-1.94947,0.194294,1.44747,-2.02015,0.061852,1.11039,-1.71554,-0.066392,1.15899,-1.73409,-0.097608,1.08347,-1.75593,-0.094695,0.949391,-1.74591,-0.173544,0.775057,-1.73047,-0.21208,0.710718,-1.73679,-0.270539,0.831467,-1.74708,-0.307035,0.768787,-1.75138,-0.391443,0.542889,-1.75241,-0.496471,0.580526,-1.83551,-0.329637,0.385996,-1.81444,-0.389609,0.367165,-1.74862,0.322168,1.24797,-2.07049,0.380976,1.18838,-2.04965,0.219335,1.14842,-2.05274,0.277193,1.09199,-2.03709,0.390347,1.02458,-2.03437,0.369544,0.832342,-2.0301,0.26574,0.875934,-2.03218,0.243277,0.808724,-2.02236,0.185056,0.581993,-1.99345,0.094312,0.513855,-1.92466,0.367387,0.485116,-1.99877,0.302091,0.4579,-2.05614,0.109075,1.33376,-1.79268,0.108233,1.36206,-2.00604},
/*860*/{0.257063,1.93397,-1.6992,0.299326,1.87821,-1.861,0.241002,1.77977,-1.58215,0.228467,1.65981,-1.49824,0.334482,1.69358,-1.61383,0.408634,1.70958,-1.66557,0.175485,1.95696,-2.06596,0.289144,1.87998,-1.93437,0.072264,1.91479,-1.94801,-0.068842,1.8705,-2.09139,-0.111367,1.78552,-2.1469,0.012023,1.6344,-2.13253,0.035778,1.5774,-2.16156,0.198726,1.4101,-1.76352,0.014468,1.50348,-1.83191,0.014883,1.53023,-1.87554,0.014434,1.51396,-1.94841,0.19478,1.45026,-2.02014,0.059715,1.11485,-1.71494,-0.068443,1.16458,-1.73602,-0.099561,1.08769,-1.75787,-0.096834,0.953933,-1.74659,-0.177964,0.780186,-1.72996,-0.217025,0.716324,-1.73643,-0.273447,0.837663,-1.74523,-0.310306,0.776149,-1.74725,-0.399641,0.551065,-1.75002,-0.502359,0.59796,-1.82961,-0.34863,0.391628,-1.81495,-0.410033,0.374296,-1.75027,0.321746,1.24842,-2.0699,0.379399,1.18814,-2.05025,0.217201,1.14989,-2.05351,0.274541,1.09266,-2.03783,0.388639,1.02357,-2.03556,0.376967,0.829775,-2.03111,0.271921,0.86877,-2.0326,0.251305,0.800464,-2.02464,0.204076,0.57025,-1.99355,0.116603,0.497692,-1.92475,0.392192,0.485272,-1.99679,0.329222,0.453205,-2.05402,0.108938,1.33633,-1.79309,0.107743,1.36556,-2.00633},
/*861*/{0.257946,1.93558,-1.70058,0.29927,1.87993,-1.86142,0.243018,1.78204,-1.58277,0.229162,1.66103,-1.49858,0.33473,1.69571,-1.61564,0.408664,1.71064,-1.66815,0.175588,1.95875,-2.06612,0.289609,1.88164,-1.93554,0.073697,1.91694,-1.94827,-0.069504,1.87283,-2.08802,-0.112175,1.78862,-2.14317,0.01141,1.6368,-2.13076,0.034127,1.58009,-2.15994,0.199062,1.41239,-1.76373,0.015774,1.50608,-1.83069,0.014864,1.53241,-1.87581,0.014933,1.51759,-1.94819,0.194717,1.45237,-2.01963,0.059179,1.11773,-1.71482,-0.068863,1.16895,-1.73739,-0.099803,1.09118,-1.75858,-0.096804,0.956664,-1.748,-0.180424,0.784554,-1.73004,-0.220729,0.721489,-1.73539,-0.274816,0.843697,-1.74215,-0.313488,0.78399,-1.74465,-0.407612,0.560412,-1.74592,-0.50683,0.61549,-1.82208,-0.366733,0.3992,-1.81728,-0.427339,0.38292,-1.75251,0.320482,1.2482,-2.06972,0.376959,1.18712,-2.04962,0.21493,1.15011,-2.0537,0.271045,1.0925,-2.03809,0.385579,1.02182,-2.03667,0.3828,0.827098,-2.03195,0.275469,0.861241,-2.03343,0.257848,0.794751,-2.02485,0.223243,0.559376,-1.99276,0.140183,0.482828,-1.92426,0.416039,0.485834,-1.99421,0.355873,0.449362,-2.0515,0.109066,1.33879,-1.79289,0.107532,1.36809,-2.00611},
/*862*/{0.2603,1.93718,-1.70135,0.300812,1.88253,-1.86333,0.243715,1.78373,-1.58387,0.231485,1.66307,-1.4993,0.334392,1.69551,-1.61747,0.408248,1.71109,-1.671,0.175729,1.96013,-2.06616,0.290967,1.88323,-1.93596,0.075248,1.91881,-1.948,-0.068737,1.87435,-2.08445,-0.112848,1.79132,-2.14051,0.01016,1.63911,-2.12959,0.033711,1.5826,-2.15844,0.198934,1.41437,-1.76404,0.016837,1.50908,-1.83001,0.015656,1.53546,-1.8751,0.016073,1.51941,-1.94661,0.195547,1.45446,-2.01938,0.059236,1.11973,-1.71504,-0.068375,1.16747,-1.73684,-0.099761,1.09345,-1.75983,-0.096878,0.958397,-1.74878,-0.182169,0.787804,-1.73073,-0.22415,0.726072,-1.73586,-0.275099,0.850005,-1.74113,-0.31531,0.790587,-1.74206,-0.413637,0.570159,-1.74435,-0.510694,0.632647,-1.8126,-0.384885,0.407616,-1.82007,-0.445194,0.39258,-1.75537,0.318139,1.24639,-2.06895,0.373582,1.18546,-2.04995,0.211937,1.14968,-2.05381,0.267462,1.09105,-2.03903,0.382959,1.01967,-2.03849,0.389007,0.824555,-2.03323,0.2787,0.852984,-2.03456,0.263021,0.788253,-2.02463,0.24279,0.549763,-1.99297,0.162481,0.467246,-1.92438,0.43835,0.485804,-1.99156,0.381055,0.445107,-2.04847,0.109296,1.34102,-1.79243,0.107603,1.37048,-2.00564},
/*863*/{0.261429,1.93866,-1.70265,0.30236,1.88451,-1.86453,0.244398,1.78445,-1.58429,0.231517,1.66384,-1.49971,0.334211,1.69648,-1.61986,0.407947,1.71111,-1.67278,0.176608,1.96145,-2.06693,0.29139,1.88419,-1.93749,0.076111,1.92022,-1.94805,-0.068898,1.87627,-2.08099,-0.113776,1.79352,-2.13715,0.010001,1.6411,-2.12803,0.033286,1.58468,-2.15757,0.199432,1.41664,-1.76348,0.017175,1.51185,-1.8294,0.015956,1.53854,-1.87471,0.016627,1.52149,-1.94621,0.195036,1.45693,-2.019,0.058353,1.12178,-1.71511,-0.067669,1.1689,-1.7376,-0.099326,1.09413,-1.76097,-0.09508,0.959459,-1.74946,-0.182436,0.79006,-1.73209,-0.22875,0.728906,-1.73695,-0.27424,0.855305,-1.73755,-0.317044,0.795938,-1.73978,-0.421486,0.579354,-1.74259,-0.515854,0.649023,-1.80399,-0.405602,0.417309,-1.82453,-0.463758,0.40268,-1.75814,0.31515,1.2444,-2.06924,0.370804,1.18255,-2.05074,0.208389,1.14814,-2.05465,0.263315,1.08973,-2.03909,0.380373,1.01706,-2.03945,0.393598,0.821531,-2.03273,0.282149,0.845059,-2.03575,0.271414,0.775811,-2.02442,0.262972,0.539972,-1.99182,0.183505,0.455485,-1.92362,0.458626,0.486435,-1.98919,0.405251,0.441169,-2.04554,0.109455,1.34363,-1.79184,0.107402,1.37284,-2.00507},
/*864*/{0.263928,1.93961,-1.70295,0.302862,1.88573,-1.86574,0.244692,1.78574,-1.58533,0.231641,1.66365,-1.50045,0.334265,1.69627,-1.62157,0.408913,1.71157,-1.67529,0.177121,1.9619,-2.06788,0.292139,1.88561,-1.93839,0.077192,1.92212,-1.9473,-0.067904,1.87824,-2.07759,-0.114377,1.79496,-2.13455,0.011188,1.64342,-2.12634,0.033866,1.58596,-2.15623,0.199579,1.41918,-1.76352,0.017084,1.51388,-1.8298,0.016081,1.54083,-1.87532,0.016554,1.52369,-1.94584,0.195319,1.45809,-2.01837,0.061022,1.12216,-1.71571,-0.065889,1.16885,-1.73734,-0.096708,1.09367,-1.76156,-0.092166,0.959457,-1.74916,-0.183688,0.790936,-1.73252,-0.231563,0.731808,-1.73812,-0.272624,0.859958,-1.73614,-0.316968,0.801882,-1.73764,-0.427912,0.590172,-1.74112,-0.521724,0.664912,-1.79409,-0.423405,0.430134,-1.83021,-0.478216,0.415448,-1.76021,0.312432,1.24195,-2.06916,0.366936,1.17898,-2.05061,0.204498,1.14613,-2.05481,0.258232,1.08727,-2.03933,0.377214,1.0134,-2.04044,0.397542,0.818452,-2.03363,0.284497,0.836683,-2.03699,0.278557,0.766841,-2.02452,0.277502,0.529775,-1.99201,0.204449,0.445237,-1.92372,0.479121,0.485801,-1.9847,0.428506,0.43675,-2.04111,0.109346,1.34604,-1.79124,0.107457,1.37438,-2.00459},
/*865*/{0.264286,1.93942,-1.70299,0.303606,1.88694,-1.86676,0.246066,1.78602,-1.58519,0.231952,1.66369,-1.50157,0.333915,1.6959,-1.62366,0.406649,1.70798,-1.67753,0.178532,1.96342,-2.0682,0.292673,1.88583,-1.93943,0.079066,1.92254,-1.94909,-0.067649,1.87834,-2.07499,-0.11362,1.7958,-2.13191,0.011082,1.64381,-2.12517,0.033374,1.5868,-2.15478,0.199594,1.42145,-1.76357,0.01764,1.51558,-1.82956,0.015623,1.5431,-1.87538,0.016614,1.52465,-1.94512,0.194707,1.4598,-2.01797,0.063267,1.12193,-1.71715,-0.063733,1.16779,-1.7395,-0.093363,1.09336,-1.7622,-0.087891,0.958374,-1.75053,-0.183687,0.791872,-1.73326,-0.233305,0.734432,-1.73868,-0.26984,0.863991,-1.73391,-0.315297,0.809894,-1.73459,-0.433782,0.599567,-1.73991,-0.528243,0.680793,-1.78508,-0.438685,0.4437,-1.83379,-0.491451,0.428479,-1.763,0.308672,1.23814,-2.0692,0.363305,1.17494,-2.05106,0.199318,1.14529,-2.054,0.253249,1.08465,-2.03907,0.374131,1.00991,-2.04141,0.400952,0.815895,-2.03357,0.287375,0.828374,-2.03779,0.282638,0.75886,-2.02606,0.294607,0.521401,-1.99192,0.223761,0.434446,-1.92423,0.497193,0.485389,-1.98258,0.449641,0.432099,-2.03712,0.109659,1.34812,-1.79062,0.10723,1.37585,-2.00405},
/*866*/{0.265738,1.93985,-1.70505,0.303541,1.88754,-1.86711,0.245524,1.78639,-1.58698,0.231733,1.66364,-1.50203,0.333735,1.69423,-1.62479,0.406317,1.70559,-1.67933,0.180213,1.96385,-2.0694,0.294047,1.88651,-1.94007,0.080149,1.92445,-1.94911,-0.067897,1.87877,-2.0725,-0.113889,1.79615,-2.12932,0.010981,1.64432,-2.12362,0.034593,1.58707,-2.15343,0.199621,1.4232,-1.76374,0.017594,1.51716,-1.82881,0.016054,1.54517,-1.87541,0.016721,1.52672,-1.94499,0.194917,1.46067,-2.01793,0.066447,1.12182,-1.71876,-0.061037,1.16638,-1.74025,-0.08981,1.0907,-1.76293,-0.082859,0.956584,-1.75108,-0.182647,0.791963,-1.73488,-0.234857,0.737637,-1.73947,-0.265828,0.86819,-1.73215,-0.313721,0.814127,-1.73174,-0.442082,0.609649,-1.73993,-0.534727,0.695576,-1.77695,-0.453247,0.458619,-1.83882,-0.503092,0.44224,-1.76509,0.305961,1.23402,-2.0695,0.358598,1.16981,-2.05174,0.194997,1.14257,-2.05377,0.247713,1.08171,-2.0395,0.369135,1.00461,-2.04191,0.40355,0.812848,-2.03362,0.289649,0.820262,-2.03891,0.289802,0.751074,-2.02815,0.311771,0.515698,-1.99241,0.242419,0.426001,-1.92247,0.514364,0.485306,-1.97972,0.469018,0.428952,-2.03359,0.109476,1.34988,-1.79026,0.106895,1.37727,-2.00373},
/*867*/{0.267348,1.93965,-1.70522,0.303892,1.8878,-1.86833,0.245052,1.7864,-1.58777,0.230569,1.6627,-1.503,0.333647,1.69222,-1.62627,0.405214,1.70351,-1.68141,0.180835,1.96383,-2.07034,0.294593,1.88634,-1.94085,0.081591,1.9254,-1.94983,-0.065948,1.8787,-2.06919,-0.113523,1.7964,-2.12791,0.013468,1.64455,-2.12219,0.035061,1.58688,-2.15277,0.199189,1.4248,-1.76343,0.016813,1.51785,-1.82908,0.015106,1.54644,-1.87606,0.016653,1.52679,-1.94485,0.194487,1.46186,-2.01709,0.070657,1.12177,-1.721,-0.057966,1.16414,-1.73969,-0.086301,1.08741,-1.76284,-0.077236,0.953793,-1.75184,-0.182627,0.792167,-1.73591,-0.236247,0.73955,-1.74147,-0.262038,0.871599,-1.73021,-0.312518,0.822008,-1.73035,-0.448473,0.621592,-1.73964,-0.54092,0.71054,-1.76909,-0.466396,0.474622,-1.84284,-0.513665,0.455576,-1.76732,0.301916,1.22974,-2.07108,0.353927,1.16453,-2.05224,0.190198,1.14033,-2.05407,0.242116,1.07828,-2.04005,0.364151,0.999153,-2.04174,0.405212,0.810675,-2.0329,0.291468,0.813737,-2.04054,0.294148,0.743719,-2.02918,0.326407,0.508886,-1.99229,0.259258,0.41901,-1.9223,0.530462,0.484937,-1.97687,0.487355,0.426531,-2.02963,0.109273,1.35117,-1.78977,0.107111,1.37801,-2.00332},
/*868*/{0.268703,1.93855,-1.70561,0.305071,1.88751,-1.86926,0.244914,1.78519,-1.58911,0.230804,1.66181,-1.50418,0.333168,1.69002,-1.62772,0.404753,1.69986,-1.68308,0.182037,1.96347,-2.07076,0.294861,1.88654,-1.94131,0.083305,1.92603,-1.95028,-0.065515,1.87802,-2.06643,-0.11277,1.79558,-2.12564,0.014367,1.6434,-2.12069,0.036251,1.58627,-2.15164,0.198838,1.42623,-1.76343,0.01607,1.51852,-1.82936,0.014724,1.54714,-1.87692,0.015203,1.52666,-1.94518,0.193828,1.46254,-2.0167,0.075918,1.11942,-1.72281,-0.053753,1.16181,-1.73908,-0.081079,1.08432,-1.76201,-0.070905,0.95064,-1.75267,-0.1817,0.791794,-1.73733,-0.239405,0.742935,-1.74232,-0.257078,0.875704,-1.72779,-0.310354,0.82731,-1.72719,-0.45436,0.634869,-1.73884,-0.546089,0.725639,-1.76279,-0.478158,0.490576,-1.84568,-0.524026,0.47017,-1.76958,0.297675,1.22459,-2.07032,0.349552,1.15917,-2.05248,0.185449,1.13729,-2.05397,0.236819,1.07231,-2.03947,0.359229,0.994229,-2.04182,0.407408,0.80807,-2.03191,0.293587,0.806292,-2.04111,0.298938,0.73675,-2.02924,0.339245,0.50282,-1.99133,0.275209,0.412232,-1.92127,0.543321,0.48521,-1.97407,0.504167,0.423983,-2.02665,0.109077,1.35234,-1.78937,0.106836,1.37825,-2.00303},
/*869*/{0.269517,1.9379,-1.70628,0.305038,1.88746,-1.86928,0.24471,1.78483,-1.59007,0.228255,1.66097,-1.50593,0.332851,1.68699,-1.62933,0.404825,1.69563,-1.68413,0.18266,1.96278,-2.07156,0.294829,1.88613,-1.94206,0.084001,1.9263,-1.95055,-0.06391,1.87649,-2.06393,-0.112347,1.7945,-2.12446,0.015256,1.64234,-2.11984,0.037626,1.58505,-2.15073,0.197712,1.42673,-1.76284,0.015558,1.51879,-1.82901,0.013695,1.54764,-1.87639,0.0146,1.52588,-1.94457,0.194738,1.46377,-2.01607,0.081875,1.11786,-1.72515,-0.048865,1.15794,-1.73863,-0.07517,1.08066,-1.76179,-0.063574,0.946714,-1.75387,-0.18066,0.792311,-1.73849,-0.24097,0.746323,-1.74512,-0.251354,0.87924,-1.72604,-0.306414,0.834371,-1.72642,-0.458929,0.648673,-1.73952,-0.550738,0.741741,-1.75695,-0.489996,0.508393,-1.84746,-0.533865,0.486632,-1.77055,0.294321,1.21918,-2.07081,0.344138,1.15311,-2.05323,0.180091,1.13306,-2.05261,0.230888,1.06818,-2.03967,0.35333,0.98841,-2.04158,0.408317,0.8054,-2.03027,0.295907,0.79953,-2.04227,0.303323,0.730914,-2.03051,0.350418,0.497489,-1.99086,0.287966,0.405649,-1.91881,0.555701,0.48575,-1.97158,0.518078,0.422582,-2.02357,0.108867,1.35257,-1.78905,0.107459,1.37894,-2.00266},
/*870*/{0.270467,1.93654,-1.70676,0.304933,1.88575,-1.86982,0.243672,1.78388,-1.59092,0.227315,1.65941,-1.50664,0.331895,1.68351,-1.63061,0.403847,1.69072,-1.68588,0.184614,1.96254,-2.0729,0.29537,1.88451,-1.94266,0.085409,1.92545,-1.95206,-0.062677,1.87475,-2.06137,-0.110757,1.79285,-2.1234,0.018196,1.6404,-2.11859,0.039907,1.58317,-2.14988,0.197838,1.4274,-1.7633,0.015086,1.51834,-1.82976,0.013559,1.54761,-1.87619,0.013917,1.52465,-1.9456,0.193869,1.46389,-2.01521,0.087699,1.11707,-1.72916,-0.043871,1.15418,-1.73692,-0.068634,1.07649,-1.76085,-0.055929,0.942645,-1.75522,-0.180168,0.793019,-1.73875,-0.242451,0.750094,-1.74523,-0.246934,0.883302,-1.7253,-0.303892,0.840657,-1.72495,-0.465319,0.663129,-1.73781,-0.552539,0.759227,-1.75572,-0.499931,0.524844,-1.8476,-0.543304,0.503651,-1.7701,0.290577,1.21409,-2.07096,0.339584,1.14769,-2.05347,0.174519,1.12995,-2.05294,0.223525,1.066,-2.03959,0.346543,0.982574,-2.04078,0.409215,0.802669,-2.02831,0.297272,0.79317,-2.04263,0.306475,0.724408,-2.0312,0.361079,0.493879,-1.98968,0.299987,0.400157,-1.91801,0.565849,0.486648,-1.9698,0.530577,0.42203,-2.02191,0.109158,1.35279,-1.78883,0.10757,1.37848,-2.00252},
/*871*/{0.27128,1.93511,-1.70735,0.304914,1.88548,-1.8702,0.242076,1.78188,-1.59201,0.224857,1.6574,-1.50809,0.330963,1.67969,-1.63157,0.403624,1.68543,-1.68693,0.185699,1.96117,-2.07338,0.296007,1.8841,-1.94231,0.086002,1.92568,-1.95303,-0.061535,1.87278,-2.06025,-0.108922,1.79058,-2.12189,0.019491,1.63814,-2.1174,0.041996,1.58099,-2.14927,0.197706,1.42773,-1.76295,0.01481,1.51729,-1.82991,0.013451,1.54725,-1.87611,0.013928,1.52328,-1.94634,0.194033,1.46382,-2.0146,0.091686,1.11468,-1.732,-0.038537,1.14957,-1.7357,-0.063483,1.07164,-1.76105,-0.047602,0.938347,-1.75701,-0.178192,0.794754,-1.73958,-0.243169,0.754888,-1.74577,-0.241117,0.887593,-1.72415,-0.300063,0.848809,-1.72526,-0.470216,0.678414,-1.73655,-0.553188,0.777617,-1.75475,-0.508729,0.541131,-1.84566,-0.553423,0.522134,-1.76851,0.286574,1.20893,-2.07171,0.33513,1.14176,-2.05385,0.170118,1.12634,-2.05296,0.21858,1.06099,-2.03865,0.340754,0.977286,-2.04045,0.409366,0.799724,-2.02579,0.298037,0.787635,-2.04258,0.308617,0.719292,-2.03158,0.368439,0.488439,-1.98961,0.309516,0.394351,-1.91933,0.574115,0.48728,-1.96804,0.539703,0.421862,-2.02042,0.109564,1.35258,-1.78849,0.108409,1.37788,-2.00223},
/*872*/{0.272133,1.93309,-1.7081,0.305509,1.88297,-1.87058,0.241437,1.78045,-1.5927,0.223854,1.65549,-1.51002,0.32917,1.67507,-1.63264,0.402296,1.67939,-1.68752,0.186158,1.95956,-2.07353,0.296825,1.88207,-1.94287,0.086736,1.92501,-1.9537,-0.059327,1.87078,-2.05851,-0.107633,1.78785,-2.12173,0.022372,1.63583,-2.11654,0.044365,1.57794,-2.14897,0.197667,1.42751,-1.76307,0.014339,1.51558,-1.8306,0.01262,1.54515,-1.87648,0.013009,1.52065,-1.94624,0.19455,1.46358,-2.0138,0.100681,1.11207,-1.73256,-0.033164,1.14462,-1.73536,-0.057016,1.0661,-1.76107,-0.038958,0.934055,-1.75832,-0.176576,0.796904,-1.73946,-0.242032,0.759674,-1.74573,-0.234655,0.892496,-1.72372,-0.294628,0.855404,-1.72479,-0.471721,0.694015,-1.73482,-0.551569,0.796617,-1.7564,-0.514022,0.556323,-1.84096,-0.563238,0.541088,-1.76636,0.283309,1.20361,-2.07164,0.330691,1.13544,-2.05518,0.165192,1.12231,-2.05185,0.212545,1.05705,-2.03736,0.334712,0.972002,-2.03993,0.40937,0.797174,-2.02379,0.297981,0.782336,-2.04202,0.310352,0.714317,-2.0307,0.373203,0.484565,-1.98969,0.317325,0.38972,-1.91655,0.579731,0.487589,-1.96827,0.547177,0.420665,-2.0196,0.110459,1.35154,-1.78835,0.109662,1.37664,-2.00211},
/*873*/{0.272107,1.93098,-1.7086,0.306137,1.88142,-1.87095,0.240208,1.77792,-1.59433,0.21987,1.65318,-1.51145,0.327865,1.67025,-1.63368,0.401875,1.67287,-1.68854,0.186811,1.95784,-2.07422,0.296746,1.88043,-1.94338,0.087787,1.92434,-1.9556,-0.057134,1.86678,-2.05605,-0.105176,1.78403,-2.12177,0.02445,1.63245,-2.11609,0.047058,1.57489,-2.14856,0.198021,1.42669,-1.76285,0.013811,1.51378,-1.83136,0.012826,1.54334,-1.8776,0.012023,1.51895,-1.94729,0.194146,1.46299,-2.01355,0.10613,1.1087,-1.73515,-0.027661,1.13937,-1.73441,-0.050124,1.06061,-1.76022,-0.030707,0.929726,-1.75961,-0.173047,0.800292,-1.73988,-0.240125,0.764367,-1.74435,-0.228263,0.897878,-1.72377,-0.290065,0.863651,-1.72541,-0.476407,0.710425,-1.73061,-0.548698,0.816031,-1.75934,-0.520879,0.571121,-1.83691,-0.572694,0.560693,-1.76313,0.281106,1.19882,-2.0727,0.32583,1.12982,-2.0564,0.161116,1.11957,-2.05182,0.207768,1.0534,-2.03672,0.328987,0.966556,-2.03937,0.408655,0.794837,-2.02217,0.296875,0.777652,-2.04066,0.310346,0.709919,-2.02952,0.378369,0.481363,-1.9884,0.322724,0.386101,-1.91856,0.584524,0.486581,-1.96817,0.551749,0.419473,-2.01969,0.110828,1.35043,-1.78865,0.110287,1.37531,-2.00244},
/*874*/{0.271981,1.92944,-1.70922,0.305925,1.87885,-1.8715,0.238612,1.77589,-1.59548,0.215976,1.64944,-1.51319,0.326119,1.6656,-1.63428,0.399517,1.66612,-1.68855,0.188095,1.95579,-2.0748,0.296512,1.87805,-1.94348,0.088068,1.92203,-1.95618,-0.055396,1.86322,-2.05605,-0.103304,1.78007,-2.12189,0.027514,1.6286,-2.11552,0.050121,1.57099,-2.14853,0.197996,1.42598,-1.76315,0.013176,1.51204,-1.83208,0.011971,1.54124,-1.87732,0.012591,1.51609,-1.94774,0.19346,1.46128,-2.01311,0.112449,1.1062,-1.73529,-0.022054,1.13419,-1.73412,-0.042954,1.05506,-1.76008,-0.022954,0.925283,-1.76106,-0.169218,0.803721,-1.73892,-0.238742,0.771042,-1.74417,-0.220773,0.903223,-1.72448,-0.284113,0.870598,-1.72535,-0.477104,0.726424,-1.7318,-0.544867,0.834449,-1.76282,-0.524698,0.587243,-1.83176,-0.579158,0.580536,-1.76007,0.277937,1.19354,-2.07269,0.322317,1.12347,-2.05643,0.157543,1.11687,-2.05115,0.203179,1.04998,-2.03651,0.322483,0.961548,-2.03874,0.40516,0.791765,-2.02136,0.293877,0.773437,-2.03862,0.308521,0.705208,-2.02716,0.379865,0.477893,-1.98727,0.327724,0.380791,-1.91749,0.586772,0.485626,-1.96902,0.55439,0.418313,-2.02018,0.111184,1.34914,-1.7882,0.110562,1.37313,-2.0021},
/*875*/{0.271803,1.92572,-1.71,0.306326,1.87643,-1.87164,0.236215,1.77279,-1.59619,0.212695,1.64713,-1.51506,0.324034,1.65965,-1.63515,0.398002,1.6581,-1.68897,0.18902,1.95364,-2.0754,0.296257,1.87573,-1.94365,0.088118,1.92103,-1.95686,-0.054321,1.85946,-2.05584,-0.10113,1.77519,-2.1227,0.030777,1.62453,-2.11545,0.053521,1.56684,-2.14884,0.198284,1.4246,-1.76284,0.012623,1.50905,-1.83288,0.012221,1.53882,-1.87695,0.012167,1.5132,-1.94821,0.193527,1.45944,-2.01374,0.11834,1.10446,-1.73773,-0.016329,1.12851,-1.73331,-0.036305,1.04869,-1.76045,-0.01466,0.921344,-1.76164,-0.165588,0.807573,-1.738,-0.235346,0.777801,-1.74278,-0.213066,0.908964,-1.72524,-0.277929,0.878748,-1.72614,-0.475754,0.742546,-1.72982,-0.53902,0.852964,-1.76708,-0.528417,0.602409,-1.82607,-0.584819,0.600849,-1.75539,0.275401,1.18896,-2.07369,0.319784,1.11991,-2.05886,0.154602,1.11455,-2.051,0.199013,1.04706,-2.03523,0.317186,0.957333,-2.03768,0.401533,0.789094,-2.02153,0.290345,0.76881,-2.0361,0.305762,0.701219,-2.02479,0.380759,0.47535,-1.9858,0.330409,0.379016,-1.91037,0.587839,0.483768,-1.9709,0.554338,0.416012,-2.0205,0.111931,1.34711,-1.78827,0.111196,1.37082,-2.00219},
/*876*/{0.272457,1.92261,-1.71056,0.306142,1.87332,-1.87156,0.234922,1.77013,-1.59664,0.209385,1.64512,-1.51726,0.32104,1.65388,-1.63511,0.396823,1.65045,-1.68895,0.189151,1.95101,-2.07618,0.296664,1.87348,-1.94366,0.087958,1.91866,-1.95815,-0.052396,1.85506,-2.05659,-0.098664,1.7701,-2.1236,0.033154,1.62009,-2.11589,0.057104,1.56191,-2.14891,0.19744,1.42273,-1.76284,0.011876,1.50672,-1.83373,0.011541,1.53617,-1.87836,0.011473,1.51062,-1.94973,0.193041,1.45669,-2.01457,0.125136,1.10108,-1.73718,-0.011461,1.12271,-1.7326,-0.030306,1.04334,-1.76053,-0.007417,0.91761,-1.7628,-0.161266,0.810235,-1.73733,-0.232479,0.782803,-1.74106,-0.204573,0.913848,-1.72739,-0.270703,0.886302,-1.72736,-0.475233,0.75817,-1.73076,-0.531874,0.870094,-1.77177,-0.530284,0.616689,-1.82005,-0.587823,0.621548,-1.75077,0.273594,1.18443,-2.07488,0.317147,1.11351,-2.0578,0.151666,1.11226,-2.05053,0.195137,1.04392,-2.03421,0.312092,0.953112,-2.03633,0.396862,0.785874,-2.02143,0.285854,0.764682,-2.03422,0.302337,0.697899,-2.02264,0.380177,0.471928,-1.98435,0.332378,0.373125,-1.90878,0.588185,0.481668,-1.9712,0.554485,0.414262,-2.02115,0.111188,1.34509,-1.78857,0.110886,1.36796,-2.00259},
/*877*/{0.272413,1.91966,-1.71045,0.306252,1.8696,-1.87152,0.231937,1.76669,-1.59705,0.205346,1.64207,-1.51922,0.318838,1.64749,-1.63539,0.393837,1.64222,-1.68781,0.189569,1.94818,-2.07667,0.296361,1.87022,-1.94401,0.087883,1.91614,-1.9602,-0.051066,1.85031,-2.05766,-0.095988,1.76406,-2.12507,0.037207,1.61505,-2.11666,0.060422,1.55678,-2.14987,0.19818,1.42107,-1.76331,0.011709,1.50412,-1.83396,0.01251,1.53258,-1.8796,0.011219,1.50749,-1.94964,0.192458,1.45407,-2.01508,0.130036,1.09823,-1.73723,-0.006017,1.11745,-1.73202,-0.023904,1.03718,-1.76055,0.000136,0.913759,-1.76307,-0.156348,0.814156,-1.7362,-0.228117,0.788534,-1.7397,-0.195881,0.919417,-1.72883,-0.262875,0.894775,-1.72889,-0.471973,0.7748,-1.72807,-0.524141,0.886774,-1.77623,-0.530541,0.63122,-1.81441,-0.589465,0.641329,-1.74636,0.271487,1.18021,-2.07586,0.313879,1.10862,-2.05888,0.148697,1.10963,-2.04931,0.191728,1.04127,-2.03339,0.307859,0.949488,-2.03622,0.392647,0.782118,-2.02169,0.281008,0.760288,-2.03235,0.299066,0.693348,-2.02036,0.377499,0.467599,-1.98206,0.329503,0.370879,-1.90657,0.584381,0.477298,-1.97216,0.551859,0.410572,-2.02097,0.112211,1.34293,-1.78848,0.111155,1.36483,-2.0026},
/*878*/{0.271378,1.91633,-1.71075,0.306034,1.86645,-1.87156,0.230259,1.76309,-1.59758,0.200855,1.63861,-1.52113,0.315238,1.64066,-1.63586,0.391941,1.63338,-1.68763,0.189764,1.94431,-2.07718,0.296957,1.8673,-1.94387,0.088363,1.91315,-1.9612,-0.051473,1.84438,-2.05965,-0.093942,1.75727,-2.1264,0.039823,1.60962,-2.11751,0.063972,1.5516,-2.1503,0.198915,1.41902,-1.76376,0.011323,1.50082,-1.83437,0.012717,1.52985,-1.87965,0.011802,1.50477,-1.95129,0.192619,1.45182,-2.01571,0.132338,1.09571,-1.73736,-0.00161,1.11263,-1.73209,-0.016456,1.03247,-1.75937,0.008424,0.909748,-1.7628,-0.150224,0.817514,-1.7349,-0.222273,0.795746,-1.73821,-0.186707,0.924446,-1.73021,-0.253322,0.90089,-1.73017,-0.465785,0.791943,-1.72633,-0.51549,0.901616,-1.78053,-0.529229,0.645409,-1.80884,-0.58823,0.659641,-1.74182,0.269786,1.17647,-2.07672,0.311099,1.10432,-2.05941,0.146302,1.10727,-2.04839,0.18851,1.03832,-2.03303,0.304903,0.945689,-2.0355,0.387992,0.77821,-2.02188,0.277434,0.754019,-2.02673,0.292972,0.688455,-2.0191,0.374861,0.464548,-1.98011,0.326168,0.367274,-1.90321,0.580783,0.472582,-1.97203,0.547258,0.405831,-2.02045,0.113015,1.34042,-1.78914,0.111963,1.36235,-2.00325},
/*879*/{0.27113,1.91319,-1.71097,0.30722,1.86257,-1.87192,0.226574,1.75885,-1.5982,0.196855,1.6353,-1.52234,0.31182,1.63371,-1.63588,0.388044,1.62402,-1.68644,0.189797,1.94038,-2.07806,0.297443,1.86388,-1.94392,0.088295,1.90969,-1.96235,-0.049795,1.83845,-2.06204,-0.091424,1.75004,-2.12886,0.042864,1.60332,-2.11942,0.06834,1.54566,-2.15126,0.198345,1.4163,-1.76395,0.010834,1.4976,-1.83491,0.012551,1.52665,-1.88008,0.011041,1.50159,-1.9513,0.191925,1.44893,-2.01646,0.138275,1.09309,-1.73876,0.002797,1.10571,-1.73287,-0.011006,1.02584,-1.76073,0.015939,0.905823,-1.76258,-0.144329,0.820778,-1.73487,-0.217166,0.800856,-1.73786,-0.176743,0.929342,-1.73266,-0.245159,0.909896,-1.72967,-0.460538,0.806752,-1.72594,-0.505879,0.91611,-1.78364,-0.526143,0.659057,-1.80369,-0.585405,0.677418,-1.73777,0.2688,1.17268,-2.07822,0.30858,1.09952,-2.06009,0.143723,1.10565,-2.04801,0.184958,1.03614,-2.03289,0.302673,0.942944,-2.03549,0.382874,0.773479,-2.02237,0.272688,0.749933,-2.02574,0.28852,0.68413,-2.01713,0.370268,0.459343,-1.97874,0.321051,0.364841,-1.90195,0.576406,0.46693,-1.97039,0.541348,0.399002,-2.01854,0.112757,1.33747,-1.78947,0.111487,1.35928,-2.00359},
/*880*/{0.269879,1.90858,-1.71096,0.30554,1.85802,-1.8716,0.22333,1.75475,-1.59847,0.19052,1.63177,-1.52401,0.307622,1.62638,-1.63644,0.385127,1.61404,-1.68533,0.190261,1.93603,-2.07935,0.297459,1.86,-1.94423,0.087498,1.90529,-1.96339,-0.050349,1.83084,-2.0646,-0.089575,1.74248,-2.1312,0.046097,1.59681,-2.12154,0.072239,1.53953,-2.15249,0.198897,1.41411,-1.76436,0.010296,1.49405,-1.835,0.011827,1.52278,-1.87991,0.010183,1.49776,-1.9509,0.19133,1.44597,-2.01703,0.144794,1.08842,-1.73599,0.006566,1.10124,-1.73348,-0.003939,1.01992,-1.76024,0.024316,0.902163,-1.76161,-0.137928,0.824461,-1.73316,-0.211292,0.807126,-1.73593,-0.167085,0.932919,-1.73488,-0.23683,0.915932,-1.73212,-0.453503,0.820353,-1.72561,-0.496544,0.928989,-1.78704,-0.522153,0.672467,-1.79856,-0.581133,0.693123,-1.7336,0.266227,1.16836,-2.07895,0.306975,1.09584,-2.06042,0.141374,1.1037,-2.0476,0.1817,1.03328,-2.03354,0.3004,0.939223,-2.03539,0.376604,0.768334,-2.02331,0.265184,0.74677,-2.02914,0.283165,0.679669,-2.01622,0.362241,0.453544,-1.97702,0.314309,0.3616,-1.89866,0.571404,0.459903,-1.96893,0.536641,0.392133,-2.01593,0.113676,1.33463,-1.78933,0.111398,1.35589,-2.0035},
/*881*/{0.269467,1.90439,-1.71004,0.306114,1.8542,-1.87183,0.221497,1.75056,-1.59774,0.185167,1.62781,-1.52603,0.303941,1.61924,-1.63631,0.381736,1.60477,-1.68469,0.190715,1.93152,-2.08033,0.297147,1.85558,-1.94367,0.08645,1.90177,-1.96581,-0.050127,1.82354,-2.06861,-0.087704,1.73415,-2.13361,0.049043,1.59021,-2.12367,0.076549,1.53301,-2.15366,0.198567,1.41153,-1.76457,0.010626,1.49014,-1.83511,0.011093,1.51894,-1.87969,0.009808,1.49387,-1.95116,0.191293,1.44293,-2.01786,0.1474,1.08686,-1.73755,0.012585,1.09687,-1.73333,0.001539,1.01461,-1.76012,0.032309,0.898378,-1.76083,-0.13015,0.827253,-1.73188,-0.204606,0.811722,-1.73429,-0.156219,0.936772,-1.73738,-0.225192,0.921,-1.73291,-0.444138,0.832109,-1.72708,-0.487064,0.941305,-1.79049,-0.517203,0.684662,-1.79439,-0.575401,0.708098,-1.72909,0.26482,1.16499,-2.07898,0.303742,1.0916,-2.06119,0.138739,1.10077,-2.04752,0.178642,1.03043,-2.03341,0.298052,0.935938,-2.03543,0.370884,0.762914,-2.02371,0.25922,0.742431,-2.02774,0.276671,0.675229,-2.0154,0.356542,0.448883,-1.97542,0.305978,0.358428,-1.89583,0.565881,0.452239,-1.96651,0.529059,0.381819,-2.01187,0.114294,1.33141,-1.7895,0.111638,1.3525,-2.00368},
/*882*/{0.268435,1.89991,-1.70957,0.305445,1.84865,-1.87067,0.218281,1.74642,-1.59782,0.179584,1.62474,-1.52675,0.298497,1.61137,-1.63566,0.377625,1.5944,-1.68277,0.190709,1.92643,-2.08152,0.297028,1.85141,-1.94403,0.086196,1.89707,-1.96675,-0.05012,1.81526,-2.07082,-0.085446,1.72567,-2.13649,0.052732,1.58267,-2.12599,0.081375,1.5259,-2.1547,0.198463,1.40846,-1.76426,0.009959,1.48551,-1.8354,0.010617,1.51493,-1.87981,0.008808,1.4896,-1.95071,0.190169,1.43941,-2.01848,0.150758,1.0841,-1.73446,0.015342,1.09015,-1.73517,0.006961,1.00889,-1.76113,0.040215,0.894657,-1.75909,-0.122844,0.82964,-1.73028,-0.196893,0.817069,-1.73257,-0.145371,0.939493,-1.7396,-0.216261,0.925949,-1.73657,-0.436257,0.844323,-1.72634,-0.477265,0.951959,-1.7926,-0.510831,0.694872,-1.79126,-0.567138,0.721184,-1.72586,0.262402,1.16139,-2.07999,0.3015,1.08686,-2.06098,0.136372,1.09785,-2.04824,0.175459,1.02708,-2.03377,0.294774,0.931715,-2.03507,0.365292,0.757091,-2.02414,0.253004,0.737893,-2.0279,0.26961,0.67006,-2.01451,0.348214,0.443298,-1.97472,0.296125,0.353943,-1.89256,0.558327,0.442666,-1.96352,0.520062,0.372363,-2.00784,0.114542,1.3278,-1.78942,0.111263,1.34856,-2.00363},
/*883*/{0.266929,1.89492,-1.70903,0.305979,1.84405,-1.87039,0.21416,1.74201,-1.5988,0.173476,1.62042,-1.52808,0.294344,1.60339,-1.63521,0.37308,1.58388,-1.68115,0.190931,1.92046,-2.08271,0.296834,1.84691,-1.94426,0.085671,1.89219,-1.9696,-0.048529,1.80699,-2.07445,-0.082957,1.71632,-2.13981,0.057457,1.57563,-2.12925,0.086006,1.51899,-2.15609,0.198376,1.40537,-1.76495,0.009482,1.48121,-1.83461,0.009955,1.51093,-1.87971,0.007997,1.48475,-1.9498,0.190029,1.43633,-2.01912,0.154973,1.08127,-1.73243,0.018899,1.08689,-1.73713,0.013188,1.00378,-1.76167,0.048307,0.891382,-1.75719,-0.114494,0.831505,-1.72912,-0.189255,0.820795,-1.73234,-0.134289,0.942255,-1.74199,-0.205124,0.930618,-1.73889,-0.426603,0.855033,-1.72682,-0.467575,0.961806,-1.79416,-0.502603,0.705399,-1.78797,-0.558713,0.733608,-1.72236,0.259224,1.15765,-2.08019,0.298752,1.08395,-2.06158,0.133818,1.09453,-2.04774,0.172902,1.02249,-2.03424,0.292108,0.927071,-2.03492,0.359046,0.751243,-2.02461,0.246804,0.732788,-2.02805,0.262882,0.665033,-2.01497,0.337602,0.435749,-1.97454,0.284864,0.351199,-1.8913,0.547912,0.433127,-1.96143,0.510602,0.361839,-2.00361,0.11539,1.3241,-1.7895,0.111254,1.34495,-2.00369},
/*884*/{0.26639,1.89051,-1.70887,0.306332,1.83895,-1.87,0.210503,1.73722,-1.59867,0.168078,1.61664,-1.52854,0.289401,1.59573,-1.63482,0.367788,1.57324,-1.67933,0.191501,1.91486,-2.08383,0.297489,1.84233,-1.94408,0.08571,1.8871,-1.97073,-0.048218,1.79722,-2.07874,-0.080531,1.70724,-2.14336,0.061144,1.56796,-2.13208,0.091378,1.5112,-2.15705,0.199081,1.4024,-1.76562,0.010365,1.47602,-1.83463,0.009799,1.50645,-1.87973,0.007347,1.47995,-1.94901,0.190001,1.4336,-2.01977,0.158367,1.07728,-1.73117,0.023153,1.0796,-1.73704,0.019371,0.998285,-1.76226,0.055998,0.887911,-1.75652,-0.105311,0.833412,-1.72835,-0.180645,0.823758,-1.72953,-0.122759,0.943486,-1.74457,-0.194045,0.933791,-1.74216,-0.415531,0.86239,-1.72883,-0.457834,0.970517,-1.79625,-0.493723,0.714055,-1.78419,-0.548239,0.744562,-1.71897,0.257399,1.15369,-2.08065,0.296173,1.0795,-2.06243,0.131221,1.08981,-2.04732,0.170627,1.01899,-2.03461,0.28734,0.921267,-2.03541,0.352955,0.744083,-2.02476,0.24047,0.727584,-2.028,0.254991,0.659404,-2.01518,0.325742,0.432,-1.97225,0.268647,0.356577,-1.89163,0.537253,0.420834,-1.95819,0.495881,0.351709,-1.99962,0.117298,1.32022,-1.78998,0.112105,1.34138,-2.00411},
/*885*/{0.265159,1.88561,-1.70819,0.305449,1.83394,-1.86931,0.205933,1.732,-1.59858,0.161307,1.61283,-1.52949,0.284222,1.58727,-1.6341,0.362047,1.56321,-1.67673,0.192598,1.90924,-2.08561,0.298142,1.83726,-1.9438,0.084816,1.88182,-1.97292,-0.047,1.78736,-2.08373,-0.077383,1.69734,-2.14714,0.065856,1.55946,-2.1345,0.096808,1.50356,-2.15862,0.199235,1.39863,-1.76632,0.010058,1.47146,-1.83399,0.010134,1.5022,-1.88006,0.006682,1.47489,-1.94853,0.190129,1.43022,-2.02105,0.164132,1.07302,-1.72781,0.026302,1.07401,-1.73953,0.024919,0.991745,-1.76431,0.065454,0.884274,-1.75439,-0.096053,0.834861,-1.72596,-0.171866,0.827471,-1.72885,-0.111121,0.94505,-1.7469,-0.181642,0.937272,-1.74382,-0.405673,0.871422,-1.72585,-0.447371,0.978273,-1.79812,-0.484853,0.722374,-1.7812,-0.537999,0.754312,-1.71544,0.254576,1.1495,-2.08112,0.293072,1.07535,-2.06401,0.128607,1.08519,-2.04763,0.168641,1.01416,-2.03417,0.282451,0.91501,-2.03565,0.346046,0.737283,-2.02369,0.233013,0.722245,-2.02822,0.247815,0.65372,-2.01529,0.318287,0.429446,-1.97155,0.248123,0.364252,-1.88985,0.524221,0.405755,-1.95403,0.47933,0.340886,-1.99755,0.118253,1.31606,-1.79052,0.11226,1.33748,-2.00461},
/*886*/{0.263134,1.88068,-1.70756,0.306697,1.8291,-1.86892,0.202578,1.7267,-1.59924,0.155802,1.60862,-1.52947,0.277693,1.57937,-1.63359,0.356806,1.55246,-1.67465,0.192738,1.90324,-2.08662,0.298229,1.83194,-1.94355,0.083989,1.8761,-1.97456,-0.046599,1.77773,-2.08804,-0.074297,1.68691,-2.15123,0.070376,1.55074,-2.13742,0.102843,1.49537,-2.16005,0.198697,1.39469,-1.76688,0.009859,1.46575,-1.83392,0.008845,1.49698,-1.88077,0.006052,1.47004,-1.94763,0.189818,1.42634,-2.02219,0.168609,1.06964,-1.72489,0.030722,1.06979,-1.7414,0.031985,0.986438,-1.7644,0.07381,0.881233,-1.75117,-0.086541,0.836681,-1.72441,-0.161809,0.830484,-1.72695,-0.098556,0.945866,-1.74918,-0.170021,0.939464,-1.74518,-0.393113,0.878827,-1.72607,-0.43601,0.985069,-1.79907,-0.473833,0.729096,-1.77912,-0.526637,0.762677,-1.71265,0.251223,1.14445,-2.08264,0.29037,1.07063,-2.06613,0.125957,1.08095,-2.04748,0.16544,1.0095,-2.03443,0.27775,0.909346,-2.0363,0.339416,0.730782,-2.0233,0.226142,0.716338,-2.02847,0.239785,0.648124,-2.01577,0.304912,0.422724,-1.97019,0.230701,0.358727,-1.8925,0.512715,0.392857,-1.94653,0.462064,0.337732,-1.996,0.118787,1.31138,-1.79116,0.112263,1.33319,-2.00519},
/*887*/{0.261529,1.87525,-1.70676,0.305814,1.82304,-1.86779,0.198101,1.72111,-1.59938,0.148978,1.60554,-1.53053,0.272379,1.57114,-1.63245,0.349897,1.54232,-1.67227,0.193877,1.89725,-2.0879,0.298102,1.82667,-1.94371,0.082767,1.87091,-1.97661,-0.045364,1.76709,-2.09297,-0.070832,1.67672,-2.15504,0.076954,1.54183,-2.13934,0.109565,1.48744,-2.1613,0.19917,1.39086,-1.76791,0.008925,1.46114,-1.83313,0.008851,1.49201,-1.88015,0.004056,1.46476,-1.94662,0.189895,1.42231,-2.02362,0.170907,1.06736,-1.72151,0.035607,1.06388,-1.74243,0.038721,0.979906,-1.76479,0.083086,0.878882,-1.7499,-0.075684,0.838137,-1.72303,-0.150659,0.832536,-1.72579,-0.085086,0.946724,-1.75001,-0.157138,0.941403,-1.74664,-0.382903,0.884598,-1.7248,-0.425282,0.990897,-1.80121,-0.462974,0.735383,-1.77682,-0.514503,0.769421,-1.71005,0.247247,1.13915,-2.08402,0.286713,1.06557,-2.06851,0.121829,1.07664,-2.04702,0.161654,1.00546,-2.0351,0.272643,0.903515,-2.03698,0.332235,0.72295,-2.0213,0.219643,0.711497,-2.02844,0.231183,0.642716,-2.01524,0.285746,0.419179,-1.96383,0.210414,0.353747,-1.88859,0.490273,0.388091,-1.93823,0.440323,0.340281,-1.99701,0.119828,1.30706,-1.79141,0.111766,1.32883,-2.00539},
/*888*/{0.260935,1.86993,-1.70543,0.305794,1.81674,-1.86709,0.194268,1.71644,-1.59964,0.141347,1.60171,-1.53143,0.266162,1.56365,-1.63102,0.343211,1.53316,-1.66986,0.195366,1.8919,-2.08943,0.299057,1.82089,-1.94236,0.082329,1.86396,-1.97858,-0.043382,1.75632,-2.09892,-0.066929,1.66616,-2.15913,0.083497,1.53404,-2.14162,0.116594,1.4793,-2.16267,0.198546,1.38645,-1.76854,0.007797,1.45546,-1.83343,0.007563,1.48639,-1.88008,0.002664,1.46083,-1.94633,0.188903,1.4184,-2.02489,0.171344,1.06474,-1.72077,0.039427,1.05674,-1.74313,0.043577,0.973295,-1.7645,0.09173,0.876292,-1.74756,-0.06434,0.838568,-1.72172,-0.139908,0.833733,-1.72536,-0.072485,0.945859,-1.75231,-0.144622,0.942721,-1.74834,-0.369967,0.89088,-1.72663,-0.413995,0.995739,-1.80317,-0.449911,0.740017,-1.77294,-0.502334,0.775014,-1.70794,0.242785,1.13427,-2.08735,0.281661,1.05994,-2.07194,0.117621,1.07365,-2.04732,0.156605,1.00182,-2.03554,0.266248,0.896724,-2.03829,0.324965,0.715488,-2.01718,0.212489,0.706578,-2.02817,0.222013,0.638265,-2.01329,0.267123,0.421088,-1.95622,0.187881,0.353185,-1.88532,0.467324,0.387681,-1.93869,0.416737,0.341538,-1.99627,0.11964,1.30209,-1.7925,0.110981,1.3248,-2.00636},
/*889*/{0.258971,1.86527,-1.70433,0.305099,1.8118,-1.86594,0.189916,1.71197,-1.60035,0.133802,1.59843,-1.53268,0.258768,1.55735,-1.62921,0.335889,1.52448,-1.66728,0.196201,1.88622,-2.09166,0.300204,1.8161,-1.94235,0.082115,1.85859,-1.98062,-0.040065,1.74635,-2.10453,-0.061717,1.65472,-2.16355,0.090077,1.52528,-2.1433,0.124529,1.47209,-2.16361,0.198814,1.38208,-1.76918,0.006461,1.45031,-1.83194,0.005727,1.48122,-1.87977,0.000105,1.45677,-1.94608,0.187409,1.41381,-2.02649,0.177892,1.05923,-1.71669,0.043382,1.04901,-1.74381,0.049919,0.966671,-1.76437,0.101654,0.873808,-1.74063,-0.053473,0.838297,-1.71985,-0.129829,0.835122,-1.72256,-0.059545,0.944373,-1.75433,-0.131069,0.943643,-1.74968,-0.357696,0.895612,-1.72701,-0.401312,0.998737,-1.8039,-0.43691,0.744002,-1.77078,-0.48849,0.779724,-1.70478,0.237685,1.13039,-2.09211,0.275421,1.05541,-2.07649,0.113108,1.07186,-2.04732,0.151642,1.00014,-2.03383,0.259212,0.889757,-2.03989,0.318199,0.709399,-2.01185,0.206158,0.704411,-2.02641,0.211669,0.636755,-2.00819,0.244583,0.421795,-1.94997,0.164364,0.353472,-1.88412,0.444373,0.385503,-1.932,0.394465,0.341709,-1.99448,0.119535,1.29749,-1.79294,0.109091,1.32031,-2.00671},
/*890*/{0.257703,1.8604,-1.70342,0.306371,1.80641,-1.86483,0.185783,1.70722,-1.60051,0.126734,1.59584,-1.53342,0.252757,1.55052,-1.62799,0.328347,1.51616,-1.66407,0.197777,1.88099,-2.09245,0.300634,1.81026,-1.94157,0.082042,1.85506,-1.9825,-0.037691,1.73574,-2.11137,-0.055793,1.64372,-2.16796,0.096148,1.51822,-2.14509,0.132833,1.46449,-2.16482,0.197961,1.37658,-1.77047,0.004512,1.44599,-1.83134,0.003708,1.47534,-1.87942,-0.002559,1.4526,-1.94585,0.183284,1.4093,-2.02749,0.182291,1.05644,-1.71551,0.04746,1.0451,-1.74554,0.056081,0.960891,-1.76663,0.11328,0.87191,-1.73747,-0.041414,0.836838,-1.71902,-0.117804,0.835005,-1.72163,-0.045486,0.943413,-1.75414,-0.117335,0.943714,-1.74944,-0.344997,0.899151,-1.72805,-0.389117,1.00093,-1.80628,-0.422521,0.746737,-1.76879,-0.474844,0.78299,-1.70298,0.232321,1.12782,-2.09839,0.269459,1.05214,-2.08211,0.108359,1.0714,-2.04631,0.146613,0.999639,-2.0331,0.251852,0.885516,-2.03985,0.311108,0.70782,-2.00736,0.198829,0.708026,-2.02212,0.200495,0.640351,-2.00334,0.225511,0.422551,-1.94689,0.1438,0.353399,-1.88221,0.424398,0.38221,-1.93236,0.371771,0.342062,-1.99279,0.117964,1.29232,-1.79391,0.105527,1.3157,-2.00751},
/*891*/{0.256568,1.85579,-1.7025,0.307079,1.80135,-1.86338,0.180691,1.70357,-1.60064,0.119572,1.59381,-1.53427,0.245267,1.54482,-1.62634,0.320948,1.5097,-1.66097,0.198254,1.87569,-2.09412,0.302304,1.80576,-1.94162,0.082591,1.85321,-1.98313,-0.032848,1.72491,-2.11816,-0.049028,1.63217,-2.17243,0.104868,1.51137,-2.14679,0.142039,1.4579,-2.16554,0.196982,1.37225,-1.77265,0.00228,1.44141,-1.83179,0.000854,1.47035,-1.87814,-0.007317,1.4495,-1.94586,0.181309,1.40627,-2.02959,0.185847,1.0531,-1.71287,0.052476,1.03841,-1.74597,0.064369,0.953173,-1.76685,0.12391,0.867756,-1.73779,-0.028873,0.83551,-1.71807,-0.104061,0.835011,-1.72069,-0.032028,0.941955,-1.75476,-0.103346,0.942852,-1.74931,-0.329749,0.899613,-1.72753,-0.377059,1.00196,-1.80832,-0.408768,0.74758,-1.76622,-0.459992,0.784638,-1.70216,0.226631,1.12506,-2.10306,0.26451,1.04985,-2.08589,0.105152,1.07222,-2.04459,0.143591,0.999697,-2.03186,0.246194,0.885899,-2.04012,0.301263,0.707891,-2.00519,0.188258,0.712991,-2.01753,0.188242,0.644974,-2.00065,0.209804,0.4257,-1.943,0.122324,0.355295,-1.87973,0.402269,0.382615,-1.92887,0.350401,0.342601,-1.99092,0.116833,1.28777,-1.796,0.102597,1.31272,-2.00931},
/*892*/{0.2556,1.8517,-1.70102,0.306707,1.79585,-1.86245,0.17669,1.70045,-1.60061,0.111208,1.59289,-1.53517,0.237281,1.54081,-1.62481,0.312433,1.50372,-1.6582,0.200164,1.87111,-2.09604,0.302684,1.80005,-1.93998,0.08362,1.85002,-1.98376,-0.026838,1.71362,-2.12547,-0.04119,1.62091,-2.17695,0.114214,1.50367,-2.14775,0.152604,1.45174,-2.16666,0.195978,1.36762,-1.77551,-0.000767,1.4369,-1.83019,-0.001993,1.46682,-1.87719,-0.010923,1.4469,-1.94449,0.177613,1.40372,-2.03166,0.189987,1.05208,-1.71131,0.058458,1.03212,-1.74676,0.07083,0.948757,-1.76779,0.135828,0.864471,-1.73631,-0.015895,0.834259,-1.71713,-0.09073,0.834355,-1.71989,-0.018197,0.940819,-1.75472,-0.089255,0.942003,-1.74928,-0.316356,0.901985,-1.72688,-0.364368,1.00152,-1.80933,-0.39253,0.747389,-1.76446,-0.445308,0.785764,-1.69988,0.221574,1.12374,-2.10486,0.260212,1.04923,-2.08649,0.101269,1.07146,-2.04371,0.139808,0.999248,-2.02974,0.242563,0.887979,-2.03994,0.289169,0.70798,-2.00578,0.176519,0.718158,-2.01554,0.174269,0.650093,-1.99897,0.186943,0.42607,-1.94022,0.100867,0.356918,-1.87577,0.382097,0.379939,-1.92749,0.328353,0.342848,-1.98921,0.115228,1.28323,-1.79821,0.098275,1.3104,-2.01105},
/*893*/{0.254396,1.84827,-1.69944,0.308396,1.7915,-1.8617,0.171795,1.69895,-1.60102,0.102404,1.59294,-1.53537,0.229715,1.53754,-1.62306,0.303816,1.49854,-1.65533,0.201715,1.86684,-2.09672,0.302989,1.79611,-1.93967,0.084445,1.84819,-1.98343,-0.022058,1.70282,-2.13461,-0.032043,1.60971,-2.18093,0.124127,1.49753,-2.14869,0.163345,1.44628,-2.16698,0.194045,1.36369,-1.77772,-0.002924,1.43359,-1.82867,-0.003668,1.46566,-1.87628,-0.013629,1.44497,-1.94253,0.174476,1.40221,-2.0341,0.193718,1.05245,-1.71134,0.062651,1.0276,-1.74753,0.079916,0.944685,-1.76799,0.147001,0.860274,-1.73878,-0.001753,0.832617,-1.71682,-0.076409,0.833163,-1.71855,-0.003325,0.94001,-1.75349,-0.075368,0.940934,-1.74841,-0.305105,0.902174,-1.72956,-0.352913,1.00033,-1.81042,-0.376595,0.746227,-1.76293,-0.429503,0.783975,-1.69851,0.21578,1.12307,-2.10433,0.255094,1.04903,-2.08716,0.097604,1.06758,-2.0408,0.135597,0.999006,-2.02793,0.240429,0.890104,-2.03952,0.27658,0.708133,-2.00832,0.163645,0.722024,-2.01465,0.158465,0.652055,-1.99686,0.170551,0.42719,-1.93767,0.081711,0.356569,-1.87411,0.360244,0.379757,-1.92717,0.306584,0.342386,-1.98809,0.113239,1.27966,-1.80025,0.094108,1.3092,-2.01259},
/*894*/{0.253997,1.84543,-1.69801,0.308075,1.78913,-1.85995,0.167319,1.69776,-1.60048,0.093334,1.59357,-1.53658,0.221312,1.53546,-1.62123,0.295329,1.49416,-1.65258,0.203264,1.86377,-2.09695,0.303302,1.79326,-1.93826,0.084553,1.84732,-1.9829,-0.016304,1.69344,-2.14091,-0.020741,1.59786,-2.18441,0.135342,1.49286,-2.15022,0.175138,1.44248,-2.16765,0.191509,1.3604,-1.77981,-0.004967,1.43162,-1.82677,-0.005692,1.46624,-1.87649,-0.016629,1.44417,-1.93968,0.171911,1.4021,-2.03685,0.199358,1.05519,-1.71189,0.068167,1.02516,-1.7482,0.089387,0.94281,-1.76733,0.160882,0.857732,-1.73852,0.012268,0.830834,-1.71748,-0.06427,0.830498,-1.72001,0.010894,0.938536,-1.7512,-0.060833,0.940239,-1.74752,-0.290243,0.900533,-1.72814,-0.341653,0.997742,-1.81055,-0.359815,0.744092,-1.76044,-0.413313,0.781175,-1.69699,0.210418,1.12251,-2.10437,0.248948,1.04735,-2.08864,0.092842,1.06745,-2.03854,0.130305,0.998298,-2.02633,0.239073,0.891461,-2.03909,0.263547,0.706656,-2.01129,0.150982,0.723549,-2.01504,0.144794,0.654762,-1.99611,0.152303,0.427721,-1.93643,0.058139,0.358765,-1.87356,0.340044,0.378599,-1.92578,0.285518,0.342873,-1.98726,0.110668,1.27712,-1.8025,0.089762,1.30943,-2.01426},
/*895*/{0.253813,1.84263,-1.69551,0.308095,1.78691,-1.85932,0.160231,1.69842,-1.60113,0.085984,1.59623,-1.53746,0.212321,1.53439,-1.62009,0.287084,1.49156,-1.64922,0.204499,1.8613,-2.09661,0.303403,1.7908,-1.93787,0.084244,1.84624,-1.98225,-0.013376,1.68628,-2.14804,-0.011516,1.59048,-2.18839,0.146935,1.48856,-2.15087,0.187774,1.43873,-2.1678,0.190349,1.35756,-1.78087,-0.007187,1.43039,-1.82444,-0.006128,1.46638,-1.87587,-0.017681,1.44441,-1.93736,0.168578,1.40216,-2.03912,0.204581,1.05849,-1.71264,0.07529,1.02382,-1.74673,0.09801,0.942031,-1.76584,0.17394,0.857984,-1.7381,0.025996,0.829671,-1.71711,-0.04909,0.83038,-1.72073,0.025109,0.938029,-1.75038,-0.045784,0.93942,-1.74644,-0.280215,0.900478,-1.72962,-0.330817,0.99383,-1.8117,-0.341788,0.739972,-1.7591,-0.395089,0.775326,-1.69579,0.204589,1.12038,-2.10472,0.241758,1.04476,-2.08922,0.085989,1.06753,-2.03777,0.123607,0.997759,-2.02574,0.238054,0.892563,-2.03905,0.250487,0.704674,-2.01358,0.138063,0.724666,-2.01528,0.130969,0.654456,-1.99516,0.128354,0.42742,-1.93752,0.037744,0.359346,-1.87238,0.31856,0.377353,-1.92444,0.26425,0.342882,-1.98629,0.108724,1.27509,-1.8041,0.085892,1.30983,-2.01528},
/*896*/{0.254324,1.84091,-1.69618,0.307776,1.78607,-1.85791,0.155711,1.69937,-1.60036,0.076143,1.59959,-1.5393,0.204269,1.53421,-1.61833,0.277211,1.48959,-1.64604,0.206085,1.8603,-2.09561,0.303927,1.78952,-1.93653,0.084789,1.84485,-1.98188,-0.005556,1.67921,-2.15232,-0.001255,1.58324,-2.19097,0.159323,1.48639,-2.15121,0.201594,1.43739,-2.16771,0.188904,1.35473,-1.78329,-0.007725,1.43069,-1.82235,-0.008854,1.46627,-1.87531,-0.019298,1.44485,-1.93448,0.166008,1.4021,-2.04139,0.211311,1.06173,-1.71354,0.084252,1.02278,-1.74441,0.10913,0.942298,-1.76477,0.186815,0.858919,-1.73773,0.040317,0.8284,-1.71869,-0.034781,0.828611,-1.72138,0.039197,0.938228,-1.74925,-0.03366,0.938862,-1.74675,-0.264269,0.896275,-1.73082,-0.320954,0.988501,-1.81226,-0.323858,0.734207,-1.75918,-0.377676,0.768865,-1.69432,0.198384,1.11772,-2.10509,0.235244,1.04207,-2.08983,0.08037,1.06749,-2.03671,0.116975,0.997509,-2.02473,0.231829,0.890728,-2.03938,0.238063,0.701811,-2.01442,0.126218,0.72461,-2.01638,0.118066,0.655253,-1.99696,0.106083,0.426324,-1.93709,0.016224,0.359897,-1.87439,0.297945,0.377331,-1.92503,0.242782,0.342445,-1.98661,0.106668,1.2734,-1.80587,0.081542,1.3104,-2.01641},
/*897*/{0.255314,1.8393,-1.69543,0.307595,1.78399,-1.85742,0.150723,1.70169,-1.60026,0.068752,1.60455,-1.5412,0.195702,1.5351,-1.61738,0.268521,1.48883,-1.64293,0.20742,1.85927,-2.09501,0.303261,1.78783,-1.93602,0.084985,1.84478,-1.98191,0.001758,1.67294,-2.15515,0.009525,1.5779,-2.19343,0.17084,1.48425,-2.15088,0.21536,1.43722,-2.16683,0.185606,1.35274,-1.78353,-0.008825,1.43185,-1.82184,-0.010344,1.46704,-1.87555,-0.020424,1.44552,-1.93333,0.163466,1.40272,-2.04289,0.218993,1.06558,-1.71396,0.092673,1.02327,-1.74322,0.120139,0.942987,-1.76367,0.203792,0.863186,-1.73782,0.05412,0.828411,-1.71936,-0.020361,0.830424,-1.72056,0.051168,0.939121,-1.74741,-0.01909,0.938345,-1.74525,-0.251599,0.890631,-1.73163,-0.313149,0.981587,-1.81135,-0.303966,0.728097,-1.7591,-0.357854,0.75981,-1.69394,0.192283,1.11571,-2.10533,0.228346,1.03929,-2.09044,0.073198,1.06632,-2.03633,0.109798,0.996384,-2.02458,0.22287,0.888357,-2.04095,0.226273,0.697383,-2.01418,0.115712,0.722178,-2.01907,0.103658,0.654831,-1.99774,0.089554,0.429292,-1.93827,-0.006297,0.362037,-1.87286,0.275812,0.377162,-1.92559,0.22181,0.342226,-1.98691,0.103296,1.2726,-1.80702,0.078103,1.31129,-2.01724},
/*898*/{0.255269,1.83877,-1.69485,0.306871,1.78322,-1.85706,0.146119,1.70459,-1.60032,0.059608,1.60983,-1.54312,0.188378,1.5367,-1.61584,0.259999,1.48846,-1.64004,0.208509,1.85858,-2.09347,0.302955,1.78676,-1.93448,0.085298,1.84476,-1.98155,0.010761,1.66883,-2.15693,0.019093,1.57269,-2.19475,0.183371,1.48395,-2.15091,0.229128,1.43865,-2.16591,0.184722,1.35229,-1.78443,-0.01012,1.43355,-1.82178,-0.012262,1.46789,-1.87522,-0.022087,1.44686,-1.93213,0.158997,1.40375,-2.04463,0.22651,1.07185,-1.71704,0.09989,1.0238,-1.74364,0.131236,0.944746,-1.76226,0.218184,0.868078,-1.73901,0.068787,0.829374,-1.72013,-0.005465,0.827552,-1.72503,0.064302,0.939867,-1.74714,-0.007026,0.938067,-1.74468,-0.238884,0.883552,-1.73263,-0.305021,0.973669,-1.8109,-0.283195,0.720892,-1.75893,-0.337172,0.749948,-1.69205,0.186957,1.11386,-2.10614,0.22175,1.03695,-2.09089,0.067292,1.06604,-2.03671,0.101778,0.995055,-2.02597,0.213806,0.884018,-2.04178,0.214355,0.69334,-2.01255,0.103852,0.721369,-2.02043,0.091056,0.652272,-1.99868,0.069291,0.429556,-1.9384,-0.027059,0.361589,-1.87495,0.255345,0.37733,-1.92583,0.199573,0.342062,-1.9877,0.10132,1.27306,-1.80803,0.074035,1.31239,-2.01787},
/*899*/{0.254913,1.83836,-1.69494,0.305539,1.78225,-1.85634,0.140362,1.70806,-1.60085,0.051478,1.61604,-1.54438,0.179618,1.53991,-1.61506,0.250629,1.49038,-1.63808,0.211309,1.85928,-2.09301,0.303106,1.78654,-1.9338,0.086045,1.8463,-1.98228,0.017675,1.66484,-2.15931,0.028996,1.56946,-2.19684,0.196896,1.48453,-2.14962,0.243151,1.44129,-2.16432,0.182044,1.35323,-1.78478,-0.01081,1.43495,-1.8206,-0.013652,1.46812,-1.87579,-0.022889,1.44772,-1.93281,0.15921,1.40407,-2.04567,0.233807,1.07734,-1.71736,0.110537,1.02496,-1.74137,0.143415,0.947451,-1.76197,0.233508,0.871425,-1.74336,0.083516,0.830642,-1.72141,0.007856,0.82722,-1.72664,0.07544,0.941094,-1.74623,0.004006,0.937561,-1.74439,-0.21847,0.875018,-1.73395,-0.297284,0.963743,-1.81052,-0.262833,0.712675,-1.76113,-0.31599,0.739619,-1.69103,0.181671,1.11219,-2.10629,0.214693,1.03424,-2.09137,0.061001,1.06672,-2.03874,0.094206,0.992736,-2.02651,0.204495,0.880534,-2.04245,0.201978,0.688824,-2.01197,0.092578,0.718922,-2.02115,0.077138,0.65355,-2.0014,0.048063,0.432088,-1.94489,-0.04722,0.36166,-1.87616,0.23434,0.376182,-1.92708,0.180211,0.34168,-1.98828,0.099749,1.27382,-1.80806,0.073051,1.31298,-2.01801},
/*900*/{0.254256,1.83953,-1.69423,0.305214,1.78242,-1.85526,0.136005,1.71226,-1.6012,0.045807,1.62285,-1.54581,0.172208,1.54319,-1.61365,0.241752,1.49276,-1.63618,0.212827,1.85974,-2.09273,0.302762,1.7864,-1.93318,0.086828,1.84714,-1.98359,0.026175,1.66218,-2.16066,0.039152,1.56683,-2.19772,0.209083,1.48709,-2.14863,0.257358,1.44619,-2.16206,0.181458,1.35489,-1.78431,-0.01166,1.43652,-1.82107,-0.01478,1.4692,-1.87679,-0.024394,1.44899,-1.93268,0.157515,1.40506,-2.04649,0.242911,1.08302,-1.71888,0.121168,1.02747,-1.74024,0.155048,0.950648,-1.76166,0.247889,0.876915,-1.74379,0.097087,0.832062,-1.7224,0.022697,0.827241,-1.72852,0.086234,0.942765,-1.74544,0.015075,0.936201,-1.74284,-0.206985,0.868522,-1.73421,-0.289424,0.952979,-1.80986,-0.239429,0.702864,-1.76026,-0.293078,0.72777,-1.69095,0.176622,1.11116,-2.10644,0.20765,1.03221,-2.09206,0.053845,1.06711,-2.04048,0.086523,0.992073,-2.02804,0.19411,0.876598,-2.04269,0.188573,0.685029,-2.01135,0.079304,0.717352,-2.02177,0.062241,0.651081,-2.00265,0.03117,0.431223,-1.94081,-0.068083,0.363204,-1.87865,0.213425,0.375514,-1.92823,0.157581,0.341156,-1.98975,0.098936,1.27552,-1.80788,0.071773,1.3138,-2.01794},
/*901*/{0.253036,1.84091,-1.69355,0.30343,1.7823,-1.8542,0.130283,1.71722,-1.60175,0.036651,1.62948,-1.54752,0.164213,1.54708,-1.61196,0.233964,1.49588,-1.63467,0.216262,1.86169,-2.0923,0.302693,1.78748,-1.93125,0.08754,1.84774,-1.98554,0.032265,1.66001,-2.16234,0.048936,1.56549,-2.19855,0.220845,1.49107,-2.14676,0.270482,1.45204,-2.1597,0.17925,1.35795,-1.7839,-0.013296,1.43806,-1.82224,-0.01549,1.47027,-1.87695,-0.024903,1.45019,-1.93344,0.156374,1.40593,-2.04753,0.251268,1.09037,-1.72003,0.130628,1.03056,-1.73881,0.166943,0.955463,-1.76184,0.261909,0.882487,-1.74501,0.111277,0.833659,-1.72468,0.036353,0.825005,-1.72996,0.097039,0.943924,-1.74466,0.02631,0.935625,-1.74334,-0.192577,0.861622,-1.73493,-0.281578,0.940863,-1.8094,-0.217323,0.694734,-1.76154,-0.269937,0.715819,-1.69067,0.171175,1.10994,-2.10663,0.201172,1.03055,-2.09224,0.046705,1.07034,-2.04387,0.078154,0.992767,-2.02987,0.182363,0.874078,-2.04244,0.175858,0.682904,-2.00801,0.065686,0.715919,-2.02312,0.046767,0.649556,-2.00413,0.010695,0.43212,-1.94168,-0.088015,0.363874,-1.87736,0.193063,0.375358,-1.92841,0.137135,0.340642,-1.99038,0.097868,1.27768,-1.80746,0.071068,1.31463,-2.0178},
/*902*/{0.251465,1.84355,-1.69282,0.303543,1.7836,-1.8533,0.125012,1.72211,-1.60217,0.029354,1.63657,-1.54841,0.15647,1.55244,-1.61174,0.225322,1.4995,-1.63269,0.217755,1.86426,-2.09152,0.302239,1.78801,-1.93035,0.088124,1.84996,-1.98667,0.038504,1.65934,-2.16346,0.058848,1.56547,-2.19999,0.233033,1.49768,-2.14507,0.283765,1.46018,-2.15687,0.178463,1.36122,-1.78476,-0.014333,1.43941,-1.82317,-0.017035,1.47172,-1.87764,-0.025856,1.45158,-1.93471,0.155222,1.40664,-2.04878,0.260999,1.0968,-1.71926,0.141175,1.0347,-1.73856,0.17743,0.960441,-1.76045,0.274402,0.888728,-1.74778,0.125216,0.835606,-1.7265,0.052351,0.825167,-1.73244,0.107312,0.945417,-1.74442,0.035969,0.934082,-1.74238,-0.178438,0.851311,-1.73591,-0.273331,0.927001,-1.80946,-0.193757,0.684697,-1.76246,-0.246185,0.703089,-1.68964,0.165946,1.10876,-2.10651,0.193493,1.02869,-2.09204,0.04081,1.06993,-2.04421,0.070139,0.99263,-2.03116,0.169189,0.870989,-2.04158,0.158196,0.678212,-2.01001,0.050609,0.714456,-2.02336,0.030787,0.648353,-2.00418,-0.012273,0.433005,-1.94285,-0.109183,0.365411,-1.87629,0.172162,0.375825,-1.92903,0.116143,0.341153,-1.99231,0.097585,1.2801,-1.80749,0.070255,1.31545,-2.01804},
/*903*/{0.248772,1.84621,-1.69232,0.301452,1.78503,-1.85137,0.120599,1.7283,-1.60202,0.021429,1.64382,-1.54987,0.148451,1.55804,-1.61052,0.216586,1.50477,-1.63103,0.219964,1.86737,-2.0906,0.301816,1.79016,-1.92912,0.088617,1.8505,-1.98782,0.044669,1.65892,-2.1641,0.067731,1.56605,-2.20057,0.243446,1.50392,-2.14271,0.296135,1.46936,-2.1537,0.17683,1.36392,-1.78441,-0.016172,1.44148,-1.82372,-0.017723,1.47317,-1.87938,-0.026412,1.45254,-1.93652,0.155256,1.40756,-2.04922,0.265819,1.10558,-1.72212,0.149392,1.0397,-1.73791,0.188215,0.966538,-1.76091,0.287874,0.897026,-1.74918,0.139292,0.83786,-1.72838,0.066451,0.823161,-1.73309,0.116189,0.947255,-1.74391,0.045702,0.933016,-1.74256,-0.163941,0.84176,-1.73726,-0.264249,0.912212,-1.81001,-0.171011,0.675108,-1.76353,-0.222243,0.690944,-1.6902,0.160354,1.10796,-2.10644,0.185528,1.02721,-2.09177,0.033189,1.07128,-2.04535,0.060955,0.99479,-2.03244,0.154692,0.868664,-2.04105,0.141922,0.677386,-2.00972,0.034839,0.714744,-2.02409,0.014292,0.648931,-2.00442,-0.032941,0.434357,-1.9434,-0.129804,0.366011,-1.87709,0.151044,0.375141,-1.92907,0.095391,0.341337,-1.9916,0.096465,1.28241,-1.80709,0.070321,1.31626,-2.01803},
/*904*/{0.245688,1.84909,-1.69105,0.299895,1.78717,-1.8499,0.114942,1.73384,-1.60243,0.014924,1.65185,-1.55087,0.141223,1.56423,-1.60965,0.209366,1.50984,-1.62934,0.222408,1.87139,-2.08992,0.301244,1.7923,-1.92762,0.089537,1.85183,-1.98902,0.049035,1.65929,-2.16397,0.076721,1.56723,-2.20126,0.25389,1.51198,-2.14066,0.308083,1.47877,-2.15041,0.176121,1.36682,-1.78471,-0.016147,1.44327,-1.82582,-0.017669,1.47521,-1.88058,-0.026931,1.45422,-1.93801,0.15496,1.40866,-2.0503,0.275063,1.11496,-1.72125,0.159476,1.04568,-1.73748,0.198907,0.973047,-1.76048,0.300652,0.905126,-1.74956,0.153222,0.839015,-1.73047,0.080248,0.822176,-1.7348,0.125254,0.948172,-1.74376,0.055568,0.930419,-1.74251,-0.150912,0.83086,-1.73922,-0.254483,0.896162,-1.81142,-0.147391,0.665041,-1.7644,-0.198156,0.678545,-1.69067,0.153994,1.10701,-2.10609,0.177475,1.02557,-2.09173,0.025266,1.07387,-2.04622,0.051015,0.995427,-2.03268,0.13981,0.866737,-2.0407,0.124858,0.679349,-2.01151,0.018832,0.716942,-2.02366,-0.002182,0.64952,-2.00441,-0.051501,0.436013,-1.94537,-0.150863,0.367922,-1.87982,0.130714,0.374856,-1.92941,0.075121,0.341098,-1.99113,0.096198,1.28489,-1.8074,0.070328,1.31745,-2.01858},
/*905*/{0.243293,1.85318,-1.69074,0.298751,1.79052,-1.84857,0.110195,1.73964,-1.6027,0.009007,1.65881,-1.55237,0.134847,1.57136,-1.60946,0.200753,1.51607,-1.62825,0.223717,1.87546,-2.089,0.301455,1.79509,-1.92538,0.090256,1.85422,-1.99015,0.055579,1.65978,-2.16342,0.085541,1.56926,-2.20214,0.264062,1.52065,-2.13776,0.319159,1.48996,-2.14649,0.174929,1.36981,-1.78435,-0.017188,1.44514,-1.82791,-0.018629,1.47671,-1.88188,-0.027698,1.45677,-1.94043,0.154218,1.40958,-2.05096,0.281116,1.12362,-1.72313,0.166093,1.05127,-1.73854,0.208509,0.979387,-1.76098,0.311901,0.913532,-1.75182,0.16742,0.841937,-1.73201,0.096005,0.822454,-1.73635,0.134776,0.94946,-1.74254,0.064497,0.928692,-1.74244,-0.135399,0.820265,-1.73948,-0.244896,0.879389,-1.81299,-0.122076,0.656109,-1.76412,-0.174711,0.666032,-1.69075,0.147185,1.10603,-2.10526,0.167706,1.0245,-2.09057,0.017625,1.07627,-2.04631,0.039701,0.997901,-2.0331,0.123484,0.866036,-2.04049,0.107109,0.678955,-2.01097,0.002433,0.719268,-2.02311,-0.018816,0.651573,-2.00439,-0.071254,0.437142,-1.94581,-0.170508,0.368946,-1.87896,0.1106,0.374584,-1.92975,0.054449,0.340948,-1.99186,0.094981,1.28746,-1.8075,0.070049,1.31865,-2.019},
/*906*/{0.240094,1.85739,-1.69019,0.297925,1.79428,-1.84609,0.105409,1.74606,-1.60271,0.000988,1.6656,-1.553,0.126424,1.57879,-1.6101,0.194072,1.52288,-1.62758,0.225683,1.87972,-2.08799,0.301192,1.79904,-1.92381,0.090302,1.85669,-1.99165,0.059689,1.66118,-2.16285,0.092938,1.57244,-2.20352,0.273138,1.53046,-2.13518,0.330006,1.50192,-2.14244,0.174262,1.37346,-1.78359,-0.017672,1.44738,-1.82931,-0.018567,1.47946,-1.88356,-0.02755,1.45872,-1.94128,0.154889,1.41093,-2.05105,0.286495,1.13258,-1.72394,0.174338,1.05667,-1.73858,0.216248,0.987778,-1.76254,0.323332,0.922391,-1.75237,0.180888,0.843818,-1.73354,0.110027,0.820446,-1.73765,0.142078,0.950576,-1.7426,0.073945,0.925713,-1.74268,-0.119601,0.809483,-1.74196,-0.233713,0.861952,-1.81471,-0.097965,0.646034,-1.7649,-0.1506,0.653586,-1.69194,0.139899,1.10611,-2.10434,0.157757,1.02368,-2.08891,0.00926,1.08009,-2.04654,0.029368,1.00121,-2.03359,0.10797,0.866519,-2.04008,0.089194,0.680024,-2.01039,-0.015912,0.722457,-2.02221,-0.034999,0.653401,-2.00378,-0.091723,0.438664,-1.9453,-0.191075,0.371862,-1.88111,0.090339,0.374963,-1.93019,0.033954,0.3409,-1.99225,0.094694,1.29064,-1.80679,0.070878,1.32011,-2.01866},
/*907*/{0.236928,1.86172,-1.68944,0.296649,1.79856,-1.84463,0.10111,1.75239,-1.60251,-0.005049,1.67341,-1.55381,0.119986,1.58596,-1.61013,0.186619,1.52897,-1.62671,0.227236,1.88491,-2.08656,0.300813,1.8025,-1.92213,0.091248,1.85941,-1.99302,0.063981,1.66515,-2.16235,0.101508,1.57572,-2.20401,0.281043,1.53951,-2.13153,0.33921,1.51408,-2.13865,0.173378,1.37793,-1.78347,-0.018332,1.44994,-1.83194,-0.018468,1.48212,-1.88538,-0.026922,1.46151,-1.94307,0.156217,1.41213,-2.05086,0.291389,1.14155,-1.72496,0.182572,1.0622,-1.73964,0.225126,0.993722,-1.76312,0.334145,0.933124,-1.75347,0.194509,0.846763,-1.73463,0.123812,0.819327,-1.73894,0.150216,0.950225,-1.74398,0.082582,0.922882,-1.74269,-0.106714,0.79689,-1.74126,-0.221464,0.843469,-1.81631,-0.074331,0.636147,-1.76551,-0.126307,0.641259,-1.69216,0.132241,1.10649,-2.10293,0.148699,1.02349,-2.08777,0.000267,1.08409,-2.04694,0.018103,1.00398,-2.03368,0.09087,0.867016,-2.0398,0.072188,0.682004,-2.00921,-0.032181,0.724398,-2.02087,-0.056609,0.661208,-2.00293,-0.110318,0.442686,-1.9448,-0.209935,0.37531,-1.87945,0.069387,0.374754,-1.93003,0.013657,0.341161,-1.99129,0.094295,1.2943,-1.8063,0.072237,1.32178,-2.01864},
/*908*/{0.23283,1.8664,-1.68866,0.295897,1.80271,-1.84247,0.096505,1.75794,-1.60315,-0.012108,1.68045,-1.55512,0.113818,1.59311,-1.60938,0.179398,1.53671,-1.62567,0.229912,1.89014,-2.08559,0.301366,1.8067,-1.92043,0.09155,1.86221,-1.99401,0.068502,1.66803,-2.16176,0.109409,1.57987,-2.20557,0.289107,1.54984,-2.12878,0.348843,1.52642,-2.13438,0.172951,1.38249,-1.7829,-0.018418,1.45334,-1.8333,-0.017978,1.48513,-1.88748,-0.026085,1.46417,-1.94529,0.156244,1.41354,-2.05096,0.293898,1.15005,-1.7262,0.18716,1.06818,-1.74144,0.233984,1.00103,-1.76349,0.343444,0.943488,-1.75498,0.207104,0.849658,-1.73547,0.139328,0.818256,-1.74044,0.158228,0.950554,-1.74398,0.092712,0.919319,-1.74401,-0.090395,0.784864,-1.74385,-0.208065,0.824388,-1.8189,-0.048798,0.626234,-1.76555,-0.102373,0.627189,-1.69124,0.125066,1.10655,-2.10151,0.138752,1.0234,-2.08547,-0.008609,1.08816,-2.04727,0.007668,1.00833,-2.03332,0.075376,0.869343,-2.03856,0.05398,0.684191,-2.00864,-0.049439,0.72827,-2.01946,-0.074607,0.664518,-2.00251,-0.130148,0.445915,-1.94661,-0.229912,0.378609,-1.8816,0.048602,0.374617,-1.92998,-0.006823,0.340642,-1.99225,0.09406,1.29843,-1.80547,0.072991,1.32338,-2.01822},
/*909*/{0.229634,1.87172,-1.68824,0.295045,1.80707,-1.84035,0.091522,1.76442,-1.60286,-0.018595,1.68827,-1.5563,0.107609,1.60077,-1.60991,0.17329,1.54388,-1.62526,0.231238,1.89566,-2.08468,0.300996,1.81077,-1.91861,0.092533,1.86539,-1.9955,0.072662,1.67193,-2.16263,0.117141,1.58378,-2.20635,0.296227,1.55985,-2.12535,0.356774,1.53971,-2.12995,0.173331,1.3872,-1.78295,-0.018223,1.45668,-1.83573,-0.017402,1.48805,-1.88914,-0.025403,1.46789,-1.94802,0.157034,1.41473,-2.05078,0.297952,1.15962,-1.72686,0.192006,1.07478,-1.7406,0.240303,1.00733,-1.76651,0.351837,0.954296,-1.75583,0.219281,0.85167,-1.73614,0.151338,0.816638,-1.74114,0.16523,0.950662,-1.74499,0.102834,0.915055,-1.74515,-0.07511,0.772456,-1.74538,-0.194125,0.804615,-1.82114,-0.023624,0.616742,-1.7658,-0.079202,0.615648,-1.69421,0.118698,1.10735,-2.09973,0.129498,1.02387,-2.08386,-0.016041,1.09245,-2.04736,-0.002651,1.01166,-2.03297,0.059743,0.871782,-2.03727,0.03676,0.686115,-2.00931,-0.066074,0.732055,-2.01834,-0.091671,0.668277,-2.00105,-0.151156,0.448766,-1.94571,-0.250201,0.384058,-1.88115,0.028605,0.374659,-1.9296,-0.027538,0.34138,-1.9923,0.094071,1.30266,-1.80503,0.074091,1.32524,-2.01815},
/*910*/{0.225778,1.87689,-1.68786,0.294448,1.81157,-1.83916,0.087471,1.77063,-1.60298,-0.02242,1.69627,-1.55746,0.100669,1.60844,-1.61166,0.166996,1.55113,-1.62463,0.233048,1.90105,-2.08265,0.300875,1.81526,-1.91626,0.093625,1.86955,-1.99681,0.07898,1.67405,-2.16233,0.124867,1.58903,-2.20792,0.303784,1.57212,-2.12179,0.36395,1.55239,-2.1255,0.172817,1.39198,-1.78303,-0.018463,1.46048,-1.83722,-0.017297,1.49221,-1.89101,-0.024798,1.47132,-1.94953,0.158577,1.416,-2.05062,0.300709,1.16784,-1.72785,0.196299,1.08112,-1.74296,0.247426,1.01521,-1.76802,0.3604,0.966041,-1.75737,0.23207,0.855034,-1.7371,0.165505,0.815707,-1.74205,0.17208,0.950089,-1.74703,0.110583,0.911318,-1.74638,-0.058961,0.760115,-1.74658,-0.178799,0.785064,-1.82316,0.001636,0.607265,-1.76658,-0.053997,0.60306,-1.69473,0.11209,1.10863,-2.09818,0.120939,1.02465,-2.08142,-0.023711,1.09751,-2.04757,-0.012975,1.01664,-2.03301,0.044864,0.875012,-2.03509,0.020773,0.689553,-2.00726,-0.083168,0.736021,-2.01718,-0.108861,0.672332,-2.00047,-0.172958,0.45121,-1.94487,-0.268662,0.3904,-1.88024,0.007979,0.374322,-1.92949,-0.048211,0.34116,-1.99177,0.093497,1.30715,-1.80419,0.07487,1.3274,-2.01766},
/*911*/{0.221673,1.88176,-1.68808,0.293754,1.81683,-1.83706,0.082945,1.77725,-1.60267,-0.028394,1.70434,-1.55848,0.095844,1.61658,-1.61076,0.160707,1.55862,-1.62467,0.235914,1.90653,-2.08126,0.301132,1.82023,-1.91532,0.094493,1.87311,-1.99775,0.083802,1.6788,-2.16418,0.132476,1.59455,-2.20915,0.309382,1.58284,-2.11871,0.370099,1.56628,-2.12117,0.173515,1.39646,-1.78325,-0.018092,1.46476,-1.84011,-0.015799,1.49587,-1.89279,-0.022704,1.47499,-1.95199,0.15968,1.41656,-2.0508,0.304568,1.17718,-1.72827,0.201041,1.08444,-1.74323,0.253484,1.02357,-1.76878,0.366804,0.977298,-1.75768,0.243048,0.857716,-1.73664,0.181211,0.815633,-1.74261,0.177749,0.949516,-1.7486,0.119272,0.908207,-1.74869,-0.04215,0.747618,-1.74817,-0.162795,0.76425,-1.82537,0.027699,0.598783,-1.76682,-0.028178,0.59096,-1.69559,0.105413,1.10949,-2.0962,0.111443,1.02584,-2.07878,-0.030954,1.10312,-2.04784,-0.022221,1.02196,-2.03288,0.03073,0.879062,-2.03319,0.004191,0.693203,-2.00641,-0.099799,0.739512,-2.01605,-0.124587,0.677158,-1.9992,-0.186784,0.456934,-1.94673,-0.282365,0.392667,-1.88865,-0.012493,0.374115,-1.929,-0.068805,0.341245,-1.99108,0.09339,1.31161,-1.80363,0.075882,1.32905,-2.01744},
/*912*/{0.218603,1.88706,-1.68762,0.291808,1.82136,-1.83536,0.078139,1.78395,-1.60385,-0.033714,1.71272,-1.56006,0.089717,1.62413,-1.61166,0.155273,1.56602,-1.6243,0.237616,1.91178,-2.07978,0.301504,1.82483,-1.9125,0.095147,1.87752,-1.99828,0.089102,1.68413,-2.16607,0.139879,1.60001,-2.21026,0.314702,1.59345,-2.11544,0.375912,1.57843,-2.11703,0.173739,1.40149,-1.78388,-0.017779,1.46954,-1.84101,-0.014971,1.49916,-1.89571,-0.020803,1.47818,-1.95327,0.161044,1.41751,-2.0508,0.306376,1.18505,-1.72901,0.206503,1.09106,-1.74851,0.259647,1.03112,-1.76925,0.373275,0.987988,-1.75955,0.253584,0.860526,-1.73734,0.193539,0.814806,-1.74256,0.184265,0.948305,-1.75048,0.126828,0.904067,-1.75142,-0.024307,0.734162,-1.7499,-0.146196,0.744305,-1.82746,0.053695,0.590043,-1.76766,-0.002049,0.578976,-1.69668,0.099738,1.1112,-2.09421,0.102994,1.02781,-2.07689,-0.038972,1.10925,-2.04764,-0.03219,1.02757,-2.03274,0.017242,0.883247,-2.03194,-0.011875,0.697418,-2.0053,-0.114532,0.745866,-2.015,-0.140527,0.680982,-1.99767,-0.204203,0.462829,-1.94613,-0.305213,0.40357,-1.8818,-0.033184,0.374152,-1.92836,-0.088879,0.342066,-1.99113,0.0936,1.31645,-1.80262,0.0769,1.33079,-2.01673},
/*913*/{0.215429,1.89273,-1.68758,0.291571,1.8267,-1.83371,0.074125,1.79061,-1.60467,-0.039451,1.7207,-1.5614,0.085187,1.63187,-1.61225,0.149791,1.57311,-1.62362,0.238987,1.91745,-2.0779,0.30081,1.8295,-1.91112,0.096032,1.88269,-1.99983,0.094153,1.68901,-2.16835,0.146542,1.60619,-2.21214,0.318622,1.60317,-2.11216,0.380661,1.59122,-2.11259,0.174291,1.40572,-1.78534,-0.016415,1.47438,-1.8435,-0.013587,1.50317,-1.89732,-0.018827,1.48241,-1.95574,0.162595,1.41844,-2.05078,0.309058,1.19334,-1.72968,0.212086,1.09762,-1.74903,0.264784,1.03831,-1.77006,0.378437,0.998812,-1.75944,0.263955,0.86299,-1.7374,0.206272,0.813493,-1.74331,0.19042,0.946775,-1.75136,0.136785,0.898887,-1.7526,-0.006471,0.720925,-1.75107,-0.127901,0.72319,-1.8293,0.080356,0.58193,-1.76808,0.024693,0.567976,-1.69758,0.094192,1.11323,-2.09187,0.09471,1.02974,-2.07406,-0.044177,1.11216,-2.04675,-0.040561,1.0328,-2.03307,0.004833,0.888313,-2.03019,-0.027456,0.7025,-2.00544,-0.130467,0.752337,-2.01467,-0.157297,0.686825,-1.9967,-0.218287,0.467357,-1.94581,-0.322842,0.411411,-1.88252,-0.053156,0.37442,-1.92846,-0.109804,0.341668,-1.99089,0.093499,1.32093,-1.8026,0.077636,1.33305,-2.01691},
/*914*/{0.212186,1.89648,-1.68691,0.291261,1.83229,-1.83201,0.070022,1.79738,-1.60492,-0.043952,1.72859,-1.56324,0.079825,1.63861,-1.61271,0.144331,1.58059,-1.6239,0.241601,1.92349,-2.07643,0.301562,1.83487,-1.90923,0.097122,1.88664,-2.00088,0.099595,1.6951,-2.17043,0.153299,1.6121,-2.21351,0.32326,1.61465,-2.10904,0.384248,1.60185,-2.10699,0.175989,1.41071,-1.78578,-0.015402,1.47932,-1.8439,-0.012451,1.50751,-1.89876,-0.017322,1.48616,-1.95637,0.163766,1.41985,-2.05122,0.311939,1.20174,-1.72988,0.216463,1.10469,-1.74869,0.268448,1.04624,-1.77108,0.381342,1.00859,-1.76033,0.274274,0.864726,-1.73764,0.218503,0.812946,-1.74325,0.195489,0.945435,-1.75319,0.142492,0.895622,-1.75637,0.010709,0.707139,-1.75266,-0.109081,0.702628,-1.83102,0.106968,0.574211,-1.76951,0.052803,0.556967,-1.69898,0.088283,1.11542,-2.09002,0.08707,1.03175,-2.07157,-0.050257,1.11803,-2.04536,-0.049394,1.03838,-2.03261,-0.007876,0.893426,-2.02877,-0.042873,0.708669,-2.00555,-0.145887,0.756569,-2.01272,-0.171652,0.692674,-1.99623,-0.239469,0.473458,-1.94752,-0.339541,0.420361,-1.88104,-0.073493,0.375275,-1.92783,-0.129417,0.342199,-1.9894,0.094526,1.32605,-1.80158,0.078265,1.33544,-2.016},
/*915*/{0.209844,1.9019,-1.68681,0.29126,1.83562,-1.83013,0.066102,1.80379,-1.60593,-0.049696,1.73558,-1.56468,0.075158,1.64607,-1.61291,0.14019,1.58709,-1.62339,0.243468,1.92908,-2.07445,0.301584,1.83945,-1.90719,0.098528,1.89118,-2.0017,0.105575,1.70047,-2.17184,0.160188,1.61853,-2.2156,0.326493,1.62384,-2.10637,0.388556,1.61289,-2.10148,0.177985,1.41566,-1.78685,-0.014245,1.48391,-1.8463,-0.009878,1.5113,-1.90147,-0.014941,1.49025,-1.95872,0.165008,1.42124,-2.05184,0.314049,1.20931,-1.73085,0.220432,1.11159,-1.74944,0.271486,1.05418,-1.77121,0.384337,1.01697,-1.76105,0.283434,0.866977,-1.73805,0.231177,0.811892,-1.74403,0.201176,0.943214,-1.7551,0.152333,0.889182,-1.75636,0.029632,0.693721,-1.7542,-0.090494,0.681335,-1.83204,0.13418,0.56725,-1.77127,0.081536,0.546342,-1.70028,0.082967,1.11807,-2.08793,0.079854,1.03478,-2.06914,-0.056544,1.12715,-2.04876,-0.057335,1.04565,-2.03299,-0.021448,0.899289,-2.028,-0.058435,0.713868,-2.0054,-0.16054,0.763884,-2.01271,-0.187579,0.700031,-1.99567,-0.252625,0.479852,-1.94679,-0.355243,0.429832,-1.88232,-0.094237,0.37529,-1.92732,-0.150325,0.342748,-1.98922,0.095667,1.33104,-1.80162,0.079711,1.33771,-2.01616},
/*916*/{0.207515,1.90662,-1.68642,0.289641,1.84256,-1.82857,0.062583,1.81072,-1.60723,-0.053234,1.7439,-1.56671,0.07047,1.65326,-1.61413,0.134865,1.59387,-1.62359,0.244434,1.9346,-2.07268,0.301964,1.84439,-1.90576,0.09972,1.89575,-2.00216,0.108138,1.70952,-2.1763,0.166572,1.62516,-2.21722,0.328342,1.63345,-2.10426,0.391664,1.62339,-2.09826,0.177952,1.42099,-1.78767,-0.013495,1.48953,-1.84736,-0.009191,1.51648,-1.90339,-0.012308,1.49425,-1.95945,0.166952,1.42247,-2.05196,0.315313,1.21703,-1.73158,0.22209,1.11917,-1.74745,0.273913,1.06096,-1.77184,0.385007,1.02398,-1.76158,0.292388,0.868389,-1.73883,0.243683,0.810533,-1.74451,0.20554,0.938642,-1.75821,0.160194,0.882766,-1.75878,0.050437,0.680758,-1.75535,-0.069647,0.660969,-1.83338,0.162092,0.561038,-1.77233,0.11017,0.536945,-1.70249,0.079043,1.1214,-2.08651,0.072316,1.03759,-2.06694,-0.0603,1.13374,-2.04899,-0.064855,1.05296,-2.03304,-0.034249,0.905035,-2.02741,-0.073102,0.721018,-2.00619,-0.174629,0.770765,-2.0117,-0.202697,0.707727,-1.99489,-0.268278,0.486002,-1.94849,-0.370151,0.440365,-1.8811,-0.114689,0.375893,-1.92761,-0.172188,0.343253,-1.98938,0.095532,1.33655,-1.80062,0.080382,1.3404,-2.01529},
/*917*/{0.205376,1.91121,-1.68676,0.290147,1.84687,-1.82739,0.058899,1.81761,-1.60799,-0.058747,1.75072,-1.56838,0.065159,1.65966,-1.61451,0.129911,1.60051,-1.62446,0.246845,1.94015,-2.07112,0.301831,1.84946,-1.9038,0.100317,1.89984,-2.0028,0.113389,1.71394,-2.17881,0.171911,1.63201,-2.21934,0.332069,1.64363,-2.10153,0.394583,1.63436,-2.09477,0.179182,1.42539,-1.78883,-0.01098,1.49445,-1.84799,-0.007628,1.52059,-1.90528,-0.010436,1.49905,-1.96138,0.168494,1.42387,-2.05231,0.314964,1.22339,-1.73204,0.223805,1.12504,-1.75056,0.275485,1.06743,-1.77157,0.38587,1.0309,-1.76243,0.300612,0.869093,-1.73916,0.257651,0.810308,-1.74481,0.209877,0.9347,-1.76024,0.16895,0.877847,-1.76045,0.07274,0.668915,-1.7567,-0.048543,0.640827,-1.83424,0.189506,0.555094,-1.77476,0.138729,0.527229,-1.70412,0.07385,1.12395,-2.08453,0.065862,1.03937,-2.06491,-0.065269,1.14059,-2.04893,-0.07228,1.05982,-2.03368,-0.046534,0.911038,-2.02708,-0.087311,0.728144,-2.0069,-0.188981,0.778642,-2.01058,-0.215823,0.715426,-1.99488,-0.285711,0.492062,-1.95024,-0.384992,0.451521,-1.88156,-0.135193,0.376096,-1.92782,-0.193139,0.34417,-1.9911,0.096234,1.34131,-1.8005,0.081073,1.34314,-2.01519},
/*918*/{0.203495,1.91542,-1.68628,0.288973,1.85133,-1.82645,0.055489,1.82403,-1.60896,-0.063175,1.75832,-1.57147,0.061182,1.66671,-1.61528,0.125656,1.60598,-1.62324,0.248152,1.94526,-2.06981,0.301458,1.85424,-1.90257,0.101497,1.90342,-2.00329,0.117869,1.7204,-2.18116,0.177673,1.63817,-2.2212,0.333576,1.65249,-2.10013,0.396063,1.64435,-2.09172,0.179871,1.42992,-1.78936,-0.009631,1.50023,-1.84973,-0.005404,1.5257,-1.9072,-0.008301,1.50334,-1.96265,0.169567,1.42543,-2.05247,0.316352,1.22968,-1.73258,0.225077,1.13161,-1.74879,0.276697,1.07364,-1.77072,0.386068,1.03584,-1.76317,0.309399,0.869828,-1.73925,0.267646,0.807615,-1.7463,0.216083,0.92983,-1.76226,0.175995,0.870366,-1.76213,0.093149,0.655478,-1.7585,-0.026272,0.620781,-1.83521,0.216384,0.549542,-1.77745,0.1688,0.518743,-1.70672,0.069548,1.12705,-2.08335,0.057725,1.04625,-2.06458,-0.069641,1.14805,-2.04869,-0.078641,1.06709,-2.03398,-0.05844,0.917516,-2.0268,-0.100879,0.735748,-2.00795,-0.201693,0.78574,-2.00907,-0.229065,0.723754,-1.99551,-0.299863,0.498989,-1.95122,-0.399279,0.464399,-1.88123,-0.155094,0.376611,-1.92827,-0.21343,0.343938,-1.98925,0.096117,1.34655,-1.8,0.081397,1.34599,-2.01473},
/*919*/{0.201413,1.92009,-1.68624,0.287975,1.85785,-1.82567,0.052163,1.83046,-1.61081,-0.066695,1.76486,-1.57331,0.057105,1.67271,-1.61646,0.122619,1.61185,-1.62328,0.249074,1.94993,-2.06778,0.302561,1.85845,-1.90092,0.10239,1.90779,-2.00446,0.122613,1.72645,-2.18366,0.182278,1.64413,-2.22316,0.335416,1.66042,-2.09813,0.397343,1.65369,-2.09052,0.18039,1.43441,-1.79003,-0.008399,1.50622,-1.84993,-0.003741,1.5299,-1.90941,-0.005621,1.50737,-1.96342,0.171522,1.42684,-2.05253,0.317686,1.23635,-1.73345,0.225447,1.13839,-1.74487,0.276495,1.07906,-1.77104,0.384208,1.04022,-1.76384,0.317136,0.869883,-1.74022,0.278597,0.804843,-1.74573,0.221598,0.924802,-1.76241,0.184156,0.862546,-1.76397,0.112186,0.64196,-1.75986,-0.003299,0.600978,-1.83654,0.244047,0.544904,-1.77934,0.198184,0.510531,-1.70898,0.065835,1.1297,-2.08213,0.05118,1.04924,-2.062,-0.073006,1.15531,-2.04951,-0.08513,1.0749,-2.03361,-0.069469,0.924357,-2.0267,-0.113903,0.743527,-2.00927,-0.213957,0.794523,-2.01102,-0.24183,0.732046,-1.99499,-0.311442,0.505934,-1.95333,-0.41249,0.476889,-1.88232,-0.175385,0.377169,-1.92915,-0.234586,0.344998,-1.98923,0.096317,1.35162,-1.79921,0.082162,1.34871,-2.01396},
/*920*/{0.199543,1.92423,-1.68645,0.287786,1.86151,-1.82409,0.049217,1.83591,-1.61194,-0.070924,1.7713,-1.5754,0.052901,1.67786,-1.61698,0.1183,1.61741,-1.6233,0.250197,1.95452,-2.0669,0.302367,1.86285,-1.89953,0.103407,1.91107,-2.0049,0.127158,1.73116,-2.18623,0.187236,1.65055,-2.22528,0.336574,1.66771,-2.09643,0.398815,1.66236,-2.08695,0.182368,1.44044,-1.79031,-0.005979,1.51138,-1.85103,-0.001366,1.53402,-1.91188,-0.00292,1.51139,-1.96413,0.173572,1.42855,-2.05244,0.317378,1.24056,-1.7341,0.224554,1.1457,-1.74479,0.276692,1.08402,-1.76954,0.382147,1.04339,-1.7638,0.324316,0.868943,-1.74012,0.289722,0.801735,-1.74652,0.225718,0.918694,-1.76478,0.192884,0.854524,-1.76498,0.133304,0.628725,-1.76161,0.019993,0.582365,-1.83739,0.270153,0.540484,-1.78229,0.228056,0.503157,-1.71161,0.062353,1.13258,-2.08106,0.04522,1.05311,-2.06107,-0.075773,1.16256,-2.04945,-0.090376,1.08271,-2.03366,-0.08001,0.931994,-2.02709,-0.127001,0.751358,-2.01035,-0.225433,0.803093,-2.01069,-0.25399,0.739517,-1.99437,-0.321806,0.512882,-1.95462,-0.424894,0.48967,-1.88283,-0.195424,0.377512,-1.92988,-0.255255,0.346543,-1.98926,0.098258,1.35757,-1.79806,0.084157,1.3513,-2.01274},
/*921*/{0.197922,1.92839,-1.68656,0.287588,1.86669,-1.82358,0.04682,1.8419,-1.61355,-0.075228,1.77776,-1.57838,0.049928,1.68308,-1.61778,0.114443,1.62228,-1.62278,0.250962,1.9591,-2.06534,0.30207,1.86686,-1.89847,0.103862,1.91486,-2.00603,0.131333,1.73714,-2.18897,0.190854,1.65558,-2.22717,0.336331,1.67464,-2.09546,0.399557,1.66994,-2.08538,0.182629,1.44481,-1.79075,-0.004659,1.51626,-1.85288,4.8e-005,1.53849,-1.9134,-0.00036,1.5155,-1.9654,0.175187,1.4307,-2.05248,0.318752,1.24496,-1.73464,0.220652,1.14878,-1.74495,0.27485,1.08797,-1.76896,0.378891,1.04698,-1.76409,0.331762,0.86789,-1.74055,0.301786,0.799856,-1.74729,0.230662,0.912661,-1.76537,0.201278,0.845428,-1.76633,0.154468,0.616535,-1.76304,0.044457,0.563911,-1.83954,0.296971,0.537035,-1.78543,0.257181,0.49589,-1.71543,0.058163,1.13578,-2.08028,0.038981,1.05608,-2.0594,-0.078149,1.16913,-2.05018,-0.09516,1.09038,-2.03416,-0.090433,0.939943,-2.02693,-0.136109,0.759246,-2.01191,-0.236331,0.810694,-2.01098,-0.264183,0.748447,-1.99539,-0.3341,0.520736,-1.95672,-0.433842,0.505042,-1.88227,-0.214699,0.377872,-1.93126,-0.274981,0.34807,-1.98826,0.098266,1.36227,-1.79797,0.085174,1.35444,-2.01266},
/*922*/{0.196141,1.93193,-1.68665,0.28815,1.86986,-1.8226,0.044621,1.84757,-1.61481,-0.078942,1.78231,-1.58031,0.046931,1.68733,-1.61889,0.111146,1.6264,-1.62246,0.25226,1.96323,-2.0642,0.302026,1.87158,-1.89713,0.10502,1.91812,-2.00625,0.135537,1.74198,-2.19166,0.194135,1.66114,-2.22914,0.337138,1.68147,-2.09514,0.399909,1.67752,-2.08376,0.183277,1.44923,-1.7912,-0.002916,1.52204,-1.85324,0.002917,1.54288,-1.91478,0.001418,1.51915,-1.96628,0.177334,1.43264,-2.05213,0.319044,1.24831,-1.73616,0.218937,1.15341,-1.74368,0.273139,1.09167,-1.76668,0.376353,1.0487,-1.76483,0.33895,0.86674,-1.74102,0.310998,0.795761,-1.74797,0.2353,0.905234,-1.7666,0.208822,0.837433,-1.76815,0.175806,0.605135,-1.76461,0.069089,0.546724,-1.8409,0.323053,0.534205,-1.78729,0.285207,0.489488,-1.71811,0.055888,1.13898,-2.07976,0.033972,1.05998,-2.05877,-0.080327,1.17599,-2.05089,-0.09985,1.09715,-2.03424,-0.09919,0.948439,-2.02755,-0.146037,0.76765,-2.01401,-0.245956,0.818812,-2.0113,-0.273578,0.755395,-1.99574,-0.344461,0.527698,-1.958,-0.442283,0.520201,-1.88229,-0.231837,0.379008,-1.93316,-0.29498,0.3507,-1.98784,0.098822,1.36728,-1.79717,0.086206,1.35739,-2.01181},
/*923*/{0.195039,1.93548,-1.68685,0.286711,1.87358,-1.82162,0.042763,1.85261,-1.61654,-0.08176,1.78814,-1.58319,0.043549,1.69242,-1.61876,0.108062,1.62963,-1.62173,0.252222,1.96717,-2.06346,0.30207,1.87506,-1.89677,0.105435,1.92119,-2.00658,0.139503,1.74746,-2.19439,0.1969,1.66629,-2.23103,0.337108,1.68742,-2.09483,0.400217,1.68342,-2.08198,0.184579,1.4532,-1.79163,-0.000319,1.52652,-1.85369,0.003884,1.54747,-1.91591,0.004251,1.52306,-1.96732,0.178746,1.43489,-2.05151,0.318341,1.25125,-1.73721,0.216857,1.15759,-1.7429,0.270237,1.09518,-1.7655,0.373685,1.04963,-1.76501,0.345054,0.864127,-1.74125,0.321661,0.791328,-1.74851,0.240152,0.897355,-1.76827,0.216682,0.828562,-1.77127,0.197179,0.593711,-1.76675,0.093707,0.530786,-1.84324,0.348855,0.531732,-1.79107,0.312862,0.483581,-1.72202,0.052583,1.14185,-2.07949,0.029418,1.06329,-2.05926,-0.082756,1.18221,-2.05073,-0.102703,1.10429,-2.0341,-0.108077,0.956503,-2.0281,-0.154677,0.775409,-2.01539,-0.255565,0.825859,-2.00938,-0.282356,0.763259,-1.99619,-0.356791,0.539259,-1.96651,-0.451574,0.535119,-1.88405,-0.250117,0.378475,-1.9355,-0.316607,0.353732,-1.98848,0.099664,1.37177,-1.79676,0.087302,1.36049,-2.01135},
/*924*/{0.193614,1.93867,-1.68747,0.285962,1.87711,-1.8218,0.03971,1.85712,-1.61837,-0.085229,1.79234,-1.58557,0.040813,1.69643,-1.62007,0.105091,1.63378,-1.62143,0.253014,1.97094,-2.06253,0.302311,1.87884,-1.8955,0.10683,1.9241,-2.00685,0.142182,1.75198,-2.19743,0.198953,1.67133,-2.23278,0.337607,1.69126,-2.09331,0.400394,1.68811,-2.08071,0.184923,1.45765,-1.79187,0.001613,1.5308,-1.85359,0.005171,1.5509,-1.91688,0.00617,1.52703,-1.96773,0.181898,1.43598,-2.0509,0.317568,1.25337,-1.73818,0.217625,1.16165,-1.74283,0.268704,1.09723,-1.7652,0.370623,1.0486,-1.76419,0.351146,0.861294,-1.74159,0.331448,0.787727,-1.74897,0.245273,0.889348,-1.76908,0.227129,0.819433,-1.76951,0.218338,0.582148,-1.76794,0.118279,0.515745,-1.84567,0.372296,0.528551,-1.79385,0.34077,0.477697,-1.72591,0.049923,1.14583,-2.07963,0.025787,1.06675,-2.0592,-0.084266,1.18793,-2.0507,-0.106242,1.11016,-2.03342,-0.114978,0.963544,-2.02781,-0.1626,0.78199,-2.01658,-0.26213,0.833519,-2.00992,-0.290553,0.771103,-1.99795,-0.365071,0.544553,-1.96273,-0.457981,0.550233,-1.88209,-0.26659,0.378908,-1.93748,-0.337251,0.359126,-1.9874,0.100366,1.3762,-1.7957,0.088859,1.36301,-2.01022},
/*925*/{0.19303,1.94183,-1.68749,0.285256,1.88102,-1.82072,0.038041,1.86191,-1.6192,-0.086221,1.79713,-1.58802,0.038833,1.69997,-1.62039,0.102608,1.63697,-1.62121,0.253293,1.97442,-2.06163,0.302636,1.88254,-1.89494,0.10682,1.92665,-2.00712,0.145999,1.75636,-2.19924,0.200938,1.67549,-2.23489,0.337789,1.69396,-2.09322,0.40033,1.69227,-2.07983,0.186174,1.46142,-1.79267,0.002694,1.53489,-1.85413,0.007515,1.55484,-1.91697,0.008428,1.53035,-1.96838,0.182374,1.43781,-2.05071,0.315389,1.25479,-1.73988,0.21502,1.16455,-1.7426,0.265544,1.09879,-1.76411,0.36777,1.04747,-1.76262,0.357257,0.858602,-1.74148,0.342519,0.785125,-1.74966,0.249806,0.880402,-1.76998,0.235226,0.809627,-1.77127,0.23902,0.572425,-1.77009,0.142676,0.501555,-1.84813,0.396462,0.526662,-1.79738,0.368255,0.473442,-1.73008,0.047833,1.14894,-2.08014,0.022448,1.07069,-2.05971,-0.085615,1.19308,-2.05034,-0.108369,1.11558,-2.0325,-0.120358,0.97007,-2.02769,-0.168523,0.788278,-2.01708,-0.268161,0.842022,-2.01043,-0.29679,0.778384,-1.99908,-0.376306,0.555473,-1.96744,-0.46507,0.565437,-1.88409,-0.28326,0.378643,-1.93922,-0.357323,0.364923,-1.98672,0.10124,1.38025,-1.79528,0.089305,1.36569,-2.00969},
/*926*/{0.192517,1.94508,-1.68768,0.286163,1.88305,-1.81961,0.03661,1.8659,-1.62091,-0.090591,1.80051,-1.59026,0.03612,1.70406,-1.62168,0.100259,1.63971,-1.62044,0.253297,1.97743,-2.06074,0.301913,1.8852,-1.8942,0.107275,1.92926,-2.00748,0.148311,1.76108,-2.20117,0.201977,1.68005,-2.23634,0.337782,1.69693,-2.09304,0.399925,1.69601,-2.07815,0.185544,1.46547,-1.79344,0.004285,1.53851,-1.85504,0.008773,1.55803,-1.91783,0.009824,1.53444,-1.96912,0.183424,1.44054,-2.05027,0.313933,1.25576,-1.74032,0.212157,1.16614,-1.74322,0.26202,1.0991,-1.76355,0.36482,1.04575,-1.76246,0.36212,0.855118,-1.74128,0.350992,0.779933,-1.74988,0.254346,0.871578,-1.77011,0.243358,0.799947,-1.77176,0.260224,0.563506,-1.77268,0.166974,0.488707,-1.85129,0.419508,0.525609,-1.80018,0.392886,0.468632,-1.73464,0.046388,1.15269,-2.0809,0.019926,1.07433,-2.06051,-0.087028,1.19819,-2.04944,-0.110128,1.12055,-2.03215,-0.122952,0.97495,-2.02772,-0.173971,0.794233,-2.01826,-0.272528,0.849259,-2.01153,-0.302582,0.786904,-2.00136,-0.386933,0.563471,-1.96637,-0.470902,0.579955,-1.8842,-0.301414,0.379068,-1.94059,-0.378339,0.371919,-1.98555,0.101271,1.38408,-1.79538,0.090096,1.3689,-2.00979},
/*927*/{0.191783,1.94756,-1.68777,0.285843,1.88524,-1.81921,0.03549,1.86964,-1.62212,-0.091416,1.80516,-1.59259,0.033569,1.70626,-1.62201,0.097751,1.6424,-1.61959,0.254224,1.98079,-2.06032,0.303064,1.88852,-1.89344,0.108929,1.93217,-2.00838,0.150409,1.76485,-2.20192,0.203373,1.68385,-2.2374,0.337651,1.70002,-2.0931,0.39931,1.69849,-2.07881,0.186353,1.46947,-1.79403,0.006602,1.54166,-1.85496,0.009887,1.56103,-1.91804,0.011803,1.53761,-1.96938,0.184108,1.44304,-2.05005,0.31293,1.25529,-1.7405,0.209078,1.16708,-1.74194,0.258587,1.09907,-1.76248,0.360971,1.04323,-1.76149,0.367683,0.851538,-1.74125,0.360044,0.776385,-1.74997,0.257908,0.861982,-1.7705,0.251251,0.789554,-1.773,0.280119,0.55405,-1.77466,0.190236,0.47737,-1.8545,0.441386,0.524711,-1.80456,0.418922,0.466394,-1.73766,0.045422,1.15659,-2.08137,0.018033,1.07818,-2.06105,-0.087982,1.20219,-2.04802,-0.110682,1.12435,-2.03132,-0.123055,0.9787,-2.0277,-0.178706,0.798828,-2.01866,-0.275558,0.856152,-2.01321,-0.307458,0.793922,-2.00218,-0.396257,0.573162,-1.96737,-0.478039,0.597435,-1.88558,-0.318694,0.378012,-1.9399,-0.397123,0.38048,-1.98582,0.102712,1.38777,-1.79501,0.091144,1.37163,-2.00933},
/*928*/{0.191418,1.95026,-1.6881,0.285943,1.88903,-1.8192,0.034083,1.87281,-1.62412,-0.094816,1.80781,-1.59522,0.032375,1.70898,-1.62199,0.096177,1.64416,-1.6189,0.254261,1.98305,-2.05987,0.302585,1.89107,-1.89322,0.109493,1.93471,-2.00814,0.151803,1.76908,-2.20332,0.203712,1.68714,-2.23889,0.337325,1.7034,-2.09445,0.398764,1.70005,-2.07817,0.186424,1.47246,-1.79488,0.005829,1.54521,-1.85554,0.010368,1.56416,-1.91863,0.012791,1.54076,-1.96961,0.185497,1.44588,-2.0496,0.311205,1.25206,-1.73998,0.207567,1.16724,-1.74122,0.25364,1.0979,-1.7621,0.357768,1.03985,-1.75973,0.371819,0.8479,-1.74064,0.368781,0.773586,-1.75095,0.261553,0.851908,-1.76951,0.258893,0.780657,-1.7729,0.299937,0.546449,-1.77669,0.213388,0.466733,-1.85675,0.461925,0.523417,-1.80658,0.442586,0.463175,-1.74252,0.044516,1.15975,-2.08205,0.01832,1.08106,-2.06278,-0.086545,1.20587,-2.04651,-0.110711,1.12805,-2.03029,-0.121587,0.981662,-2.02793,-0.182009,0.802897,-2.01916,-0.277522,0.861917,-2.01436,-0.310707,0.800691,-2.00304,-0.405536,0.582569,-1.96858,-0.485233,0.612011,-1.88727,-0.337062,0.378451,-1.94091,-0.416091,0.389747,-1.98397,0.102581,1.39091,-1.79526,0.0919,1.37474,-2.00962},
/*929*/{0.190783,1.95291,-1.68796,0.285696,1.89142,-1.81855,0.03263,1.87555,-1.62483,-0.095485,1.81057,-1.59741,0.029895,1.71101,-1.62254,0.093615,1.64555,-1.61774,0.255008,1.98525,-2.05963,0.302305,1.8938,-1.89287,0.109641,1.93681,-2.0086,0.153027,1.77259,-2.20399,0.203002,1.6904,-2.24039,0.336969,1.70483,-2.09471,0.398243,1.70116,-2.07934,0.187298,1.4758,-1.79529,0.007284,1.54792,-1.85568,0.011975,1.56726,-1.91851,0.013873,1.54385,-1.96971,0.186716,1.44897,-2.04928,0.308105,1.25118,-1.73993,0.201705,1.16395,-1.74117,0.249292,1.09712,-1.76076,0.354391,1.03552,-1.75916,0.374639,0.843755,-1.74128,0.375028,0.768704,-1.75161,0.264762,0.843844,-1.76861,0.265755,0.771696,-1.77248,0.318701,0.538967,-1.77873,0.235153,0.45713,-1.86036,0.480996,0.524824,-1.81076,0.465266,0.460916,-1.74678,0.045478,1.1623,-2.0833,0.019305,1.08386,-2.06372,-0.086692,1.20846,-2.0462,-0.109326,1.13028,-2.0293,-0.119408,0.983104,-2.02774,-0.184762,0.806023,-2.01903,-0.278899,0.86822,-2.01521,-0.31403,0.807822,-2.00419,-0.409279,0.59232,-1.97115,-0.491957,0.627292,-1.89031,-0.358453,0.382831,-1.93962,-0.434068,0.400052,-1.98225,0.103835,1.39401,-1.79528,0.093197,1.37779,-2.00964},
/*930*/{0.190401,1.95483,-1.68865,0.285697,1.8926,-1.81821,0.032006,1.87814,-1.62633,-0.097708,1.81335,-1.59934,0.027995,1.71318,-1.62261,0.092462,1.64763,-1.61618,0.254907,1.98748,-2.05959,0.302598,1.89577,-1.89239,0.110578,1.9386,-2.00944,0.152932,1.77538,-2.20459,0.202723,1.69287,-2.24151,0.335247,1.70723,-2.09584,0.397468,1.70139,-2.07955,0.187506,1.47792,-1.7953,0.008223,1.55036,-1.85599,0.01212,1.57022,-1.91768,0.015265,1.54614,-1.96986,0.188116,1.45146,-2.04882,0.30759,1.24755,-1.73954,0.199612,1.16417,-1.73969,0.243869,1.09452,-1.76074,0.350146,1.03136,-1.7584,0.377925,0.839959,-1.74139,0.381488,0.765147,-1.75278,0.26791,0.834706,-1.76691,0.27162,0.7633,-1.77251,0.336099,0.533524,-1.7817,0.255716,0.448692,-1.8636,0.498514,0.525696,-1.81487,0.486301,0.461413,-1.75179,0.046926,1.16472,-2.08321,0.020866,1.08611,-2.06473,-0.083921,1.20941,-2.04505,-0.107666,1.13228,-2.02891,-0.115593,0.984633,-2.02822,-0.187014,0.80799,-2.01944,-0.279108,0.873049,-2.01676,-0.316101,0.814339,-2.00558,-0.417207,0.601917,-1.97252,-0.498735,0.643269,-1.89336,-0.377302,0.393523,-1.93687,-0.453943,0.411582,-1.98192,0.104161,1.39621,-1.79528,0.094181,1.38043,-2.0097},
/*931*/{0.189905,1.957,-1.68887,0.286403,1.89344,-1.81764,0.031395,1.88,-1.62717,-0.099387,1.81533,-1.60184,0.027328,1.71417,-1.62275,0.09083,1.64795,-1.61547,0.255082,1.98864,-2.05914,0.302578,1.89795,-1.89229,0.110581,1.94165,-2.0097,0.152232,1.77859,-2.2048,0.201717,1.69495,-2.24269,0.334421,1.70633,-2.09674,0.396958,1.70168,-2.08027,0.188104,1.48061,-1.79558,0.008273,1.5525,-1.85548,0.012753,1.57289,-1.91797,0.015674,1.54849,-1.96963,0.188384,1.45416,-2.04873,0.30291,1.2443,-1.73977,0.196509,1.16289,-1.7392,0.238762,1.09211,-1.7603,0.345038,1.02602,-1.75712,0.381721,0.836811,-1.74192,0.388228,0.76191,-1.75414,0.270979,0.826934,-1.7643,0.278233,0.7549,-1.77095,0.352142,0.527703,-1.78451,0.27497,0.440695,-1.86576,0.51612,0.528309,-1.81817,0.505939,0.46147,-1.75572,0.049469,1.16673,-2.08406,0.02405,1.0872,-2.06559,-0.082166,1.21144,-2.04464,-0.104635,1.1336,-2.0293,-0.110803,0.985033,-2.02888,-0.18911,0.809445,-2.01949,-0.277527,0.877634,-2.01787,-0.317379,0.819158,-2.00668,-0.426429,0.611898,-1.97333,-0.505546,0.659048,-1.89515,-0.396137,0.402275,-1.93409,-0.470143,0.424106,-1.9798,0.104852,1.39872,-1.79527,0.094681,1.38297,-2.00969},
/*932*/{0.189744,1.95889,-1.68869,0.286707,1.89454,-1.81778,0.030914,1.88195,-1.62816,-0.099275,1.81698,-1.60357,0.026255,1.71569,-1.62298,0.088974,1.64835,-1.61416,0.255123,1.98956,-2.05922,0.302645,1.89931,-1.89197,0.111513,1.94314,-2.00935,0.151006,1.78159,-2.20462,0.199798,1.6969,-2.24323,0.333937,1.70623,-2.09793,0.395984,1.69993,-2.08138,0.188081,1.48271,-1.79642,0.008205,1.55359,-1.85617,0.013465,1.574,-1.91729,0.015896,1.5506,-1.96958,0.189449,1.45714,-2.04867,0.299643,1.24011,-1.73923,0.188355,1.15794,-1.74034,0.232725,1.0895,-1.76084,0.339636,1.02049,-1.75629,0.385138,0.833627,-1.74307,0.391442,0.759663,-1.75717,0.273689,0.818595,-1.76239,0.284349,0.74744,-1.76976,0.36835,0.523048,-1.78657,0.293407,0.433901,-1.86812,0.529947,0.530778,-1.82159,0.52419,0.462997,-1.76034,0.053152,1.1682,-2.08419,0.027936,1.08878,-2.06569,-0.079558,1.21127,-2.0446,-0.10147,1.13379,-2.02971,-0.106831,0.984308,-2.02933,-0.19022,0.810554,-2.01956,-0.277232,0.882008,-2.01935,-0.318003,0.825618,-2.00781,-0.438649,0.623964,-1.97387,-0.512141,0.674,-1.89842,-0.413649,0.413023,-1.93086,-0.486174,0.436766,-1.97758,0.105643,1.4001,-1.79601,0.095956,1.38538,-2.01052},
/*933*/{0.189584,1.96005,-1.68896,0.286265,1.89602,-1.81764,0.029808,1.88307,-1.62912,-0.099415,1.81831,-1.60509,0.024851,1.71609,-1.62269,0.087807,1.64829,-1.61265,0.254935,1.99063,-2.059,0.302098,1.90106,-1.89211,0.111177,1.94479,-2.00935,0.149688,1.78288,-2.20414,0.19768,1.69807,-2.24371,0.333658,1.70548,-2.0991,0.395169,1.69813,-2.08231,0.189428,1.48429,-1.79691,0.00869,1.55483,-1.85554,0.013312,1.57684,-1.91621,0.016524,1.55218,-1.96905,0.190239,1.46003,-2.04821,0.29721,1.23412,-1.73865,0.184287,1.15602,-1.74063,0.225862,1.0859,-1.76095,0.33297,1.0154,-1.75551,0.387379,0.830677,-1.7445,0.399695,0.757227,-1.75868,0.276905,0.811459,-1.76094,0.290157,0.741318,-1.76797,0.383428,0.520791,-1.78862,0.310334,0.427656,-1.87086,0.54335,0.533142,-1.82429,0.541225,0.465994,-1.76476,0.056787,1.16893,-2.08462,0.032462,1.08911,-2.06574,-0.075771,1.21151,-2.04583,-0.097513,1.13265,-2.02987,-0.102228,0.98375,-2.03024,-0.190749,0.811506,-2.01915,-0.274818,0.886736,-2.02183,-0.3184,0.831922,-2.00997,-0.443009,0.634386,-1.97497,-0.519141,0.689869,-1.90172,-0.431222,0.424227,-1.92659,-0.501195,0.450117,-1.97595,0.106914,1.40163,-1.79619,0.096853,1.38789,-2.01075},
/*934*/{0.189657,1.96166,-1.68899,0.285541,1.89826,-1.81833,0.029761,1.88395,-1.62987,-0.099941,1.81958,-1.60731,0.02353,1.71635,-1.62223,0.08624,1.64821,-1.60998,0.254331,1.99069,-2.05894,0.301725,1.90181,-1.89192,0.111206,1.94544,-2.00995,0.147576,1.78445,-2.20395,0.195365,1.69934,-2.24419,0.331614,1.70381,-2.10103,0.393714,1.69611,-2.08214,0.190933,1.48544,-1.79713,0.009593,1.55574,-1.85453,0.013058,1.57796,-1.9164,0.017106,1.55323,-1.96843,0.190987,1.46255,-2.04803,0.293814,1.22933,-1.73802,0.179187,1.15338,-1.74092,0.219933,1.08245,-1.76179,0.326518,1.00914,-1.75598,0.389626,0.827999,-1.74626,0.40392,0.754172,-1.76014,0.280088,0.805107,-1.75937,0.294325,0.734381,-1.76772,0.39609,0.517857,-1.79021,0.324771,0.423177,-1.87256,0.554314,0.535622,-1.82734,0.555889,0.467608,-1.76793,0.061703,1.16887,-2.08431,0.037782,1.08911,-2.06565,-0.071863,1.21086,-2.04702,-0.092222,1.13192,-2.03155,-0.096647,0.98256,-2.03106,-0.190852,0.812282,-2.0192,-0.2717,0.891154,-2.02355,-0.317998,0.838152,-2.0117,-0.453878,0.646319,-1.97573,-0.525837,0.705755,-1.90473,-0.446527,0.437027,-1.92323,-0.515467,0.46383,-1.97371,0.108539,1.40267,-1.79641,0.09807,1.38965,-2.011},
/*935*/{0.189575,1.9623,-1.6891,0.285374,1.89885,-1.818,0.028991,1.88505,-1.63049,-0.100604,1.81958,-1.60884,0.023326,1.7162,-1.62159,0.085204,1.6471,-1.60886,0.254061,1.99065,-2.05901,0.301522,1.90341,-1.89182,0.110149,1.94732,-2.00861,0.14366,1.78604,-2.204,0.192563,1.69986,-2.2447,0.330366,1.70243,-2.10209,0.391062,1.69443,-2.08803,0.190445,1.48649,-1.79755,0.010661,1.5555,-1.85406,0.013774,1.57847,-1.91532,0.018313,1.55383,-1.96765,0.192092,1.46435,-2.04752,0.290587,1.22383,-1.73804,0.173936,1.15172,-1.741,0.213331,1.07865,-1.76217,0.320053,1.00412,-1.75631,0.391326,0.825938,-1.74845,0.407648,0.752796,-1.76249,0.281972,0.799141,-1.75949,0.298724,0.729719,-1.76784,0.404316,0.514831,-1.79198,0.336748,0.418981,-1.87395,0.563994,0.539112,-1.83106,0.568487,0.468965,-1.77068,0.066171,1.16877,-2.0839,0.04412,1.0885,-2.06566,-0.068026,1.20857,-2.04733,-0.087128,1.1293,-2.03196,-0.090858,0.980325,-2.03206,-0.190452,0.813213,-2.01883,-0.268279,0.89517,-2.0254,-0.316426,0.844823,-2.01353,-0.456745,0.658736,-1.97679,-0.53211,0.722054,-1.90898,-0.462038,0.450532,-1.91922,-0.528388,0.478086,-1.97134,0.109502,1.40288,-1.79654,0.099461,1.39094,-2.01121},
/*936*/{0.189814,1.96267,-1.6889,0.284999,1.89969,-1.81793,0.028987,1.88514,-1.63102,-0.100459,1.81976,-1.60957,0.023148,1.71596,-1.62071,0.083696,1.64599,-1.60674,0.252935,1.99019,-2.05929,0.301094,1.90388,-1.89204,0.109648,1.94792,-2.00797,0.140681,1.78647,-2.20327,0.188829,1.70038,-2.24465,0.328223,1.69975,-2.10398,0.389447,1.69079,-2.09052,0.191704,1.48717,-1.79759,0.010688,1.55472,-1.85364,0.013494,1.57893,-1.91451,0.018054,1.55435,-1.96679,0.192997,1.46646,-2.04729,0.286361,1.21742,-1.73694,0.167925,1.14671,-1.74205,0.20672,1.07404,-1.76337,0.313392,0.998261,-1.75763,0.392076,0.823883,-1.75066,0.409807,0.752167,-1.76466,0.282848,0.79398,-1.76036,0.301829,0.72644,-1.76775,0.412108,0.511416,-1.79223,0.347379,0.416113,-1.87424,0.572073,0.539825,-1.83238,0.577456,0.469991,-1.77304,0.071843,1.16865,-2.08321,0.050109,1.08801,-2.06544,-0.063818,1.20583,-2.04937,-0.08156,1.12632,-2.0326,-0.084252,0.978137,-2.03259,-0.189857,0.814202,-2.01848,-0.264639,0.898838,-2.02696,-0.314233,0.850487,-2.01498,-0.463022,0.671125,-1.97749,-0.536779,0.739019,-1.91207,-0.474503,0.4653,-1.91573,-0.539829,0.493584,-1.97009,0.111052,1.40297,-1.79686,0.10082,1.39223,-2.01159},
/*937*/{0.189797,1.96293,-1.68903,0.285215,1.89928,-1.81825,0.02901,1.88491,-1.63123,-0.099851,1.81949,-1.61091,0.022351,1.714,-1.61992,0.082988,1.64425,-1.60476,0.252379,1.98987,-2.05945,0.300147,1.90402,-1.89201,0.108879,1.94836,-2.00765,0.136103,1.78784,-2.20159,0.185639,1.70046,-2.24455,0.326189,1.69632,-2.10533,0.386973,1.68636,-2.09253,0.191579,1.48733,-1.79811,0.010211,1.55441,-1.85264,0.01342,1.57889,-1.91411,0.017819,1.55441,-1.96609,0.194031,1.46771,-2.04708,0.283235,1.2117,-1.73603,0.162751,1.14273,-1.7426,0.200321,1.06982,-1.76485,0.305207,0.993137,-1.75571,0.391187,0.822082,-1.75245,0.410895,0.750131,-1.76507,0.282851,0.790125,-1.7618,0.30394,0.722005,-1.76916,0.418995,0.510061,-1.7942,0.355246,0.413559,-1.87488,0.580086,0.541304,-1.83369,0.586434,0.471528,-1.77604,0.077395,1.16754,-2.08247,0.056634,1.08637,-2.06466,-0.059783,1.20309,-2.05023,-0.075939,1.12319,-2.03437,-0.078087,0.975857,-2.03262,-0.188708,0.81574,-2.01789,-0.258999,0.903497,-2.02881,-0.311459,0.857993,-2.01697,-0.472289,0.683927,-1.97791,-0.539446,0.755798,-1.91581,-0.488464,0.47898,-1.91161,-0.550993,0.508944,-1.96758,0.111607,1.4027,-1.79714,0.101594,1.39304,-2.01193},
/*938*/{0.19014,1.96278,-1.68885,0.284437,1.89939,-1.81851,0.028979,1.88383,-1.63163,-0.099427,1.81857,-1.61143,0.021833,1.71192,-1.61813,0.082608,1.64242,-1.60258,0.249814,1.98842,-2.05936,0.298881,1.90368,-1.89222,0.108007,1.9486,-2.00742,0.132631,1.78746,-2.20058,0.181213,1.70022,-2.24448,0.324837,1.69426,-2.10743,0.384982,1.68173,-2.09454,0.191812,1.48667,-1.79852,0.010371,1.55279,-1.85143,0.013465,1.57785,-1.91303,0.017513,1.5539,-1.96573,0.194244,1.46901,-2.04681,0.280366,1.20578,-1.73497,0.155977,1.13999,-1.7442,0.194006,1.06609,-1.76638,0.29963,0.987581,-1.7589,0.387897,0.820379,-1.75243,0.409966,0.748646,-1.76552,0.281049,0.785232,-1.76422,0.303553,0.717076,-1.7715,0.425554,0.509099,-1.79531,0.362235,0.410347,-1.87604,0.584417,0.5418,-1.83538,0.591555,0.471811,-1.77725,0.08325,1.16614,-2.08174,0.063713,1.08508,-2.06513,-0.054227,1.19895,-2.05123,-0.071033,1.11951,-2.03465,-0.070372,0.972777,-2.03287,-0.186829,0.816693,-2.01763,-0.253116,0.907933,-2.03009,-0.30874,0.863303,-2.01811,-0.475612,0.697688,-1.97852,-0.541781,0.773293,-1.91944,-0.500553,0.494858,-1.90866,-0.559112,0.526225,-1.96628,0.11263,1.4014,-1.79771,0.102388,1.39343,-2.01255},
/*939*/{0.190439,1.96203,-1.68862,0.284344,1.89909,-1.81869,0.02902,1.88286,-1.63143,-0.099205,1.81694,-1.61136,0.022319,1.71002,-1.61666,0.082038,1.6404,-1.59992,0.248968,1.98734,-2.05962,0.29817,1.90391,-1.89233,0.106831,1.9483,-2.0067,0.128026,1.7872,-2.1998,0.176195,1.69978,-2.24412,0.321326,1.68897,-2.10861,0.382042,1.6766,-2.09693,0.191852,1.48604,-1.79916,0.010374,1.5508,-1.85193,0.013117,1.57665,-1.91267,0.017326,1.5534,-1.96544,0.195494,1.47005,-2.04658,0.276026,1.19884,-1.73422,0.153116,1.13514,-1.74391,0.188781,1.06209,-1.76718,0.295091,0.982981,-1.7601,0.385397,0.817433,-1.75415,0.408851,0.74559,-1.76668,0.27829,0.781125,-1.7674,0.302231,0.71306,-1.77402,0.42717,0.505616,-1.79533,0.366908,0.406737,-1.87713,0.587097,0.540998,-1.8363,0.595497,0.471474,-1.77838,0.08899,1.16465,-2.08111,0.071285,1.0838,-2.06396,-0.048913,1.19554,-2.05233,-0.063718,1.11473,-2.03563,-0.062004,0.969297,-2.0324,-0.184954,0.817843,-2.01701,-0.247586,0.911704,-2.03154,-0.3032,0.872866,-2.02161,-0.473026,0.71066,-1.9794,-0.542376,0.789518,-1.92139,-0.510953,0.511985,-1.90568,-0.568326,0.544141,-1.96527,0.113457,1.40005,-1.79868,0.103856,1.39368,-2.01361},
/*940*/{0.189808,1.96103,-1.6887,0.282892,1.8994,-1.81953,0.028596,1.88187,-1.63172,-0.099154,1.8144,-1.61098,0.022393,1.70818,-1.61525,0.081818,1.63779,-1.59717,0.24709,1.98614,-2.0602,0.297458,1.90349,-1.89233,0.105423,1.94741,-2.00557,0.122279,1.78703,-2.19797,0.171323,1.69918,-2.2438,0.319589,1.68606,-2.11084,0.378905,1.67118,-2.0996,0.191517,1.48453,-1.79872,0.010829,1.54868,-1.8502,0.012974,1.57542,-1.91218,0.017749,1.55134,-1.96471,0.195981,1.47018,-2.04609,0.272209,1.1927,-1.73302,0.14875,1.13309,-1.74509,0.184019,1.05814,-1.76877,0.289634,0.979767,-1.76051,0.381409,0.814686,-1.75436,0.406796,0.743656,-1.76696,0.275865,0.776216,-1.77001,0.300829,0.709774,-1.77677,0.428795,0.504037,-1.79816,0.370416,0.404788,-1.87952,0.588383,0.54,-1.83778,0.596202,0.47123,-1.77915,0.09473,1.16313,-2.08063,0.078427,1.08136,-2.06399,-0.043611,1.1903,-2.05274,-0.05654,1.11039,-2.03659,-0.053138,0.965391,-2.03307,-0.181892,0.819435,-2.01625,-0.240903,0.916635,-2.03405,-0.299341,0.876023,-2.02121,-0.47562,0.725368,-1.98047,-0.541352,0.808728,-1.92558,-0.521921,0.528696,-1.90423,-0.57796,0.561836,-1.96471,0.114087,1.39813,-1.79862,0.104749,1.39298,-2.01359},
/*941*/{0.189559,1.95964,-1.68893,0.282463,1.89862,-1.81961,0.029012,1.87962,-1.63132,-0.09755,1.81181,-1.61059,0.022934,1.70535,-1.61298,0.08223,1.63509,-1.59497,0.244129,1.98374,-2.06036,0.296218,1.90227,-1.89285,0.103857,1.94499,-2.0046,0.117733,1.78582,-2.19696,0.166129,1.69806,-2.24363,0.315908,1.68085,-2.11283,0.375711,1.66536,-2.10249,0.192083,1.48301,-1.79837,0.010722,1.54633,-1.84986,0.012893,1.57352,-1.91132,0.017252,1.54993,-1.96413,0.196126,1.47019,-2.04604,0.2698,1.1873,-1.73117,0.145535,1.13016,-1.7465,0.178464,1.05413,-1.76954,0.284422,0.972969,-1.75969,0.377643,0.810488,-1.75366,0.402653,0.740686,-1.76796,0.27244,0.771193,-1.77231,0.297888,0.704297,-1.78,0.429046,0.499955,-1.79861,0.37153,0.401237,-1.8817,0.587783,0.538857,-1.83823,0.597006,0.470036,-1.77963,0.101211,1.16076,-2.08052,0.086089,1.07876,-2.06387,-0.037946,1.18519,-2.05416,-0.049566,1.10514,-2.03665,-0.044362,0.961176,-2.03445,-0.178465,0.821005,-2.01611,-0.232616,0.919053,-2.03406,-0.293409,0.882091,-2.02223,-0.479105,0.741812,-1.98296,-0.539888,0.826585,-1.92851,-0.530813,0.546218,-1.90268,-0.584106,0.581159,-1.96508,0.114955,1.39619,-1.79896,0.105456,1.39225,-2.01395},
/*942*/{0.190254,1.95824,-1.68877,0.282047,1.89632,-1.81911,0.029076,1.87771,-1.63106,-0.096716,1.80895,-1.60979,0.023014,1.70201,-1.61097,0.082874,1.63178,-1.5926,0.242099,1.982,-2.06126,0.295204,1.90115,-1.89311,0.102616,1.94396,-2.00377,0.111783,1.78482,-2.19518,0.161134,1.69698,-2.24324,0.311892,1.67551,-2.11508,0.372047,1.65932,-2.10477,0.192708,1.48016,-1.79798,0.011013,1.54282,-1.84937,0.012645,1.57108,-1.91153,0.017091,1.54714,-1.96403,0.197496,1.46939,-2.04541,0.266963,1.18159,-1.72947,0.143573,1.12602,-1.74655,0.1747,1.05115,-1.77184,0.281033,0.968972,-1.76056,0.373928,0.806253,-1.75473,0.399543,0.735822,-1.76788,0.268978,0.767008,-1.77483,0.295386,0.700393,-1.78279,0.427602,0.497378,-1.8018,0.370565,0.398298,-1.88547,0.586386,0.536114,-1.83816,0.594409,0.467566,-1.78039,0.106899,1.15832,-2.08012,0.09335,1.07622,-2.06366,-0.032582,1.18064,-2.05407,-0.043574,1.10007,-2.03734,-0.036033,0.956838,-2.03346,-0.17593,0.822586,-2.01548,-0.224741,0.922655,-2.03633,-0.287093,0.887139,-2.02295,-0.478519,0.756131,-1.98415,-0.534844,0.844791,-1.9307,-0.537737,0.563922,-1.90217,-0.59039,0.601143,-1.96533,0.115785,1.39313,-1.79946,0.107046,1.39059,-2.0145},
/*943*/{0.189856,1.95616,-1.68872,0.280913,1.89622,-1.81997,0.029151,1.87489,-1.63071,-0.095908,1.80533,-1.6089,0.024501,1.69859,-1.60923,0.084838,1.62848,-1.58975,0.240953,1.97984,-2.06169,0.294313,1.89926,-1.89347,0.100115,1.94165,-2.00283,0.106195,1.78389,-2.19381,0.155066,1.69543,-2.24272,0.309033,1.67124,-2.11732,0.368022,1.65192,-2.10835,0.19342,1.47772,-1.79789,0.010539,1.54018,-1.84997,0.013469,1.56768,-1.91041,0.017638,1.54449,-1.9635,0.197734,1.46821,-2.04498,0.264299,1.17628,-1.72811,0.138947,1.12106,-1.74794,0.172683,1.04719,-1.77321,0.279901,0.965817,-1.7608,0.36995,0.801639,-1.75518,0.395985,0.731912,-1.76871,0.265007,0.762374,-1.7772,0.291158,0.695665,-1.78453,0.425131,0.492866,-1.80333,0.368737,0.394308,-1.88886,0.584552,0.532847,-1.83874,0.591144,0.463271,-1.78156,0.112321,1.1558,-2.08121,0.100166,1.07303,-2.06322,-0.027586,1.17552,-2.05421,-0.036453,1.09435,-2.03756,-0.026616,0.952072,-2.03354,-0.169798,0.823929,-2.01567,-0.216067,0.925908,-2.03718,-0.279639,0.895042,-2.02403,-0.475854,0.771342,-1.98457,-0.529373,0.861919,-1.93178,-0.544949,0.582107,-1.90287,-0.595425,0.621318,-1.96608,0.116731,1.39035,-1.79965,0.108104,1.38864,-2.01471},
/*944*/{0.189602,1.95364,-1.68879,0.279867,1.89398,-1.82057,0.029406,1.87161,-1.62971,-0.096419,1.80046,-1.6066,0.025359,1.69463,-1.60676,0.086202,1.62444,-1.58681,0.238428,1.97701,-2.06184,0.292876,1.89784,-1.89397,0.09821,1.93935,-2.00135,0.101911,1.78011,-2.19258,0.149228,1.69339,-2.24206,0.304652,1.66485,-2.11976,0.36402,1.64526,-2.11202,0.192982,1.47427,-1.79803,0.010291,1.53657,-1.849,0.012953,1.56449,-1.90995,0.017432,1.54194,-1.96389,0.198636,1.46727,-2.04482,0.261587,1.17284,-1.72634,0.138243,1.11894,-1.74855,0.170073,1.04362,-1.77452,0.278602,0.963052,-1.76092,0.366086,0.796966,-1.75552,0.391141,0.726617,-1.7697,0.26166,0.758421,-1.77764,0.28734,0.691214,-1.78609,0.420298,0.490866,-1.80623,0.364539,0.391208,-1.89216,0.579384,0.527769,-1.8386,0.586089,0.457147,-1.78193,0.118729,1.15247,-2.0815,0.107417,1.06976,-2.06381,-0.022457,1.16932,-2.0539,-0.029224,1.08858,-2.03687,-0.01757,0.948152,-2.03344,-0.164101,0.825226,-2.01552,-0.206535,0.928447,-2.03706,-0.270877,0.900015,-2.02484,-0.472041,0.78545,-1.98557,-0.521323,0.879714,-1.93258,-0.550391,0.59977,-1.90396,-0.601313,0.641629,-1.96607,0.116841,1.38657,-1.80067,0.108973,1.38705,-2.01577},
/*945*/{0.188844,1.95054,-1.68896,0.2797,1.89296,-1.82098,0.029424,1.86755,-1.62895,-0.094084,1.79662,-1.60487,0.026825,1.69052,-1.60334,0.087934,1.62149,-1.58436,0.236412,1.97468,-2.06273,0.292149,1.89521,-1.89416,0.097229,1.93645,-2.00039,0.095517,1.77978,-2.19103,0.143538,1.69155,-2.24171,0.299482,1.65893,-2.1221,0.359619,1.63734,-2.11561,0.19327,1.47144,-1.79746,0.011319,1.53333,-1.84868,0.012902,1.56097,-1.90965,0.016805,1.53808,-1.96368,0.199724,1.46503,-2.04442,0.258613,1.16898,-1.72484,0.135722,1.11594,-1.75087,0.167941,1.04086,-1.77579,0.278869,0.960594,-1.76123,0.361941,0.791859,-1.75683,0.387815,0.720952,-1.77002,0.257908,0.754201,-1.77925,0.28216,0.687357,-1.78946,0.412844,0.4835,-1.80757,0.359102,0.387603,-1.89604,0.575117,0.522883,-1.83906,0.580654,0.451559,-1.78312,0.123358,1.14924,-2.08269,0.114963,1.06652,-2.0639,-0.018268,1.16388,-2.05391,-0.022504,1.08268,-2.03631,-0.008297,0.942824,-2.03329,-0.158797,0.826384,-2.01573,-0.197539,0.930541,-2.03838,-0.262735,0.904165,-2.0265,-0.467726,0.800041,-1.9864,-0.512645,0.895805,-1.9331,-0.554542,0.618299,-1.90564,-0.600453,0.662172,-1.96694,0.117837,1.38354,-1.80038,0.110143,1.38411,-2.01547},
/*946*/{0.188486,1.94745,-1.68871,0.277872,1.89017,-1.82223,0.030139,1.86311,-1.62778,-0.092944,1.79079,-1.6023,0.029011,1.68685,-1.60086,0.090614,1.61773,-1.58175,0.233518,1.97102,-2.06362,0.291234,1.89333,-1.89485,0.094922,1.93328,-1.99979,0.091186,1.77579,-2.18927,0.137676,1.68906,-2.24152,0.294528,1.65147,-2.12466,0.354367,1.62933,-2.11918,0.1929,1.46812,-1.79676,0.010703,1.52949,-1.84861,0.012265,1.55818,-1.90962,0.016627,1.5342,-1.96351,0.200051,1.46395,-2.04372,0.255578,1.16645,-1.72465,0.133736,1.11313,-1.75269,0.166284,1.03699,-1.77727,0.279075,0.957806,-1.76198,0.357765,0.787037,-1.75726,0.382493,0.717553,-1.77212,0.253517,0.750445,-1.78025,0.278277,0.683063,-1.78933,0.407468,0.476088,-1.80871,0.351234,0.383287,-1.89879,0.56814,0.514984,-1.83983,0.573078,0.443036,-1.7828,0.128845,1.14611,-2.08285,0.121931,1.0637,-2.06456,-0.012542,1.15752,-2.05342,-0.01592,1.07682,-2.03656,0.001065,0.937797,-2.03433,-0.152384,0.827119,-2.01557,-0.187429,0.93293,-2.03899,-0.252415,0.909401,-2.02825,-0.462111,0.814507,-1.98746,-0.502062,0.911427,-1.93313,-0.556603,0.63587,-1.90735,-0.599957,0.682367,-1.96919,0.117879,1.38002,-1.80076,0.111147,1.38196,-2.01588},
/*947*/{0.188088,1.94358,-1.68871,0.276208,1.88674,-1.82233,0.029993,1.85897,-1.62646,-0.0926,1.78503,-1.59967,0.030899,1.68169,-1.59814,0.093247,1.61313,-1.57852,0.231525,1.96768,-2.06439,0.29054,1.88988,-1.89523,0.093398,1.9296,-1.99898,0.086225,1.77292,-2.18823,0.131088,1.68618,-2.24067,0.289952,1.64447,-2.12656,0.349787,1.62089,-2.12301,0.192681,1.46501,-1.7963,0.010017,1.52554,-1.84854,0.011814,1.55366,-1.9092,0.016642,1.53055,-1.96439,0.200283,1.46143,-2.04294,0.255063,1.16182,-1.72348,0.133274,1.11076,-1.75347,0.163295,1.03489,-1.77883,0.278784,0.955475,-1.76266,0.353079,0.781815,-1.75769,0.378932,0.710741,-1.77255,0.24903,0.745912,-1.78144,0.272848,0.678278,-1.79081,0.401566,0.474887,-1.81195,0.342953,0.379011,-1.90207,0.560346,0.506988,-1.84043,0.563273,0.43482,-1.78375,0.134174,1.14342,-2.08327,0.128767,1.06109,-2.06505,-0.006864,1.15218,-2.05297,-0.009557,1.07048,-2.03624,0.00994,0.932663,-2.03485,-0.146306,0.828388,-2.016,-0.177182,0.936256,-2.04092,-0.24369,0.914301,-2.02887,-0.45628,0.829317,-1.98973,-0.491738,0.926668,-1.93306,-0.558045,0.652679,-1.91009,-0.599589,0.702462,-1.97101,0.118064,1.37645,-1.80074,0.112118,1.37878,-2.01587},
/*948*/{0.187635,1.93989,-1.68816,0.275632,1.88377,-1.82273,0.030511,1.85344,-1.62463,-0.090192,1.77889,-1.5966,0.033906,1.67659,-1.59518,0.096719,1.60905,-1.57588,0.228955,1.96382,-2.06527,0.289226,1.88666,-1.89562,0.091871,1.92606,-1.99739,0.079686,1.77034,-2.18698,0.125332,1.68324,-2.23999,0.284536,1.63756,-2.12909,0.34401,1.61212,-2.12694,0.192104,1.46216,-1.79561,0.009889,1.52107,-1.84817,0.011651,1.54957,-1.90914,0.016798,1.5254,-1.96441,0.200908,1.45897,-2.04298,0.253395,1.15841,-1.72291,0.129804,1.10638,-1.75617,0.161939,1.03198,-1.77975,0.276415,0.951705,-1.76399,0.349287,0.776363,-1.7597,0.373438,0.705374,-1.77402,0.243809,0.741948,-1.78256,0.267272,0.674296,-1.79339,0.389466,0.467344,-1.81246,0.332537,0.374143,-1.90358,0.551948,0.499281,-1.84169,0.552787,0.427786,-1.78541,0.139928,1.14029,-2.08365,0.136171,1.05761,-2.06603,-0.001826,1.14612,-2.05279,-0.002059,1.06514,-2.03658,0.019599,0.928024,-2.03554,-0.139809,0.829688,-2.01664,-0.166017,0.938337,-2.0426,-0.233623,0.918822,-2.02996,-0.451386,0.842625,-1.98859,-0.480423,0.940836,-1.93374,-0.55666,0.669234,-1.91304,-0.596176,0.720507,-1.97417,0.118916,1.37287,-1.80051,0.11354,1.37527,-2.01566},
/*949*/{0.186713,1.93558,-1.68842,0.275438,1.8805,-1.82275,0.03136,1.84773,-1.62303,-0.088992,1.77247,-1.59348,0.035748,1.67048,-1.59088,0.100844,1.60463,-1.57355,0.226565,1.96004,-2.06589,0.287814,1.88299,-1.89669,0.089408,1.92177,-1.99678,0.074813,1.76801,-2.18631,0.119306,1.68037,-2.23978,0.279413,1.62995,-2.132,0.338018,1.60312,-2.13088,0.192042,1.45825,-1.79488,0.008859,1.51661,-1.84847,0.012117,1.54513,-1.90851,0.015913,1.52096,-1.96452,0.200647,1.4566,-2.04201,0.251502,1.15481,-1.72316,0.127981,1.10414,-1.75809,0.160937,1.02915,-1.7811,0.273382,0.946603,-1.76453,0.344099,0.77091,-1.76061,0.367624,0.69918,-1.77535,0.238946,0.738207,-1.78413,0.259982,0.670285,-1.79344,0.379396,0.460783,-1.81329,0.321179,0.368563,-1.90393,0.543059,0.490503,-1.84162,0.542031,0.419156,-1.78615,0.145077,1.13744,-2.08402,0.143914,1.05326,-2.06628,0.003721,1.13982,-2.0517,0.005352,1.05899,-2.03613,0.028825,0.923408,-2.03672,-0.132151,0.83068,-2.01769,-0.155689,0.939113,-2.04206,-0.222576,0.923368,-2.03071,-0.440708,0.855675,-1.99212,-0.467699,0.954246,-1.93302,-0.552426,0.684687,-1.91642,-0.595494,0.740203,-1.97516,0.119055,1.3687,-1.80056,0.114245,1.37193,-2.01571},
/*950*/{0.186803,1.93086,-1.68794,0.273818,1.87598,-1.82341,0.032217,1.84117,-1.62155,-0.086127,1.76567,-1.58985,0.038673,1.6651,-1.58782,0.104579,1.59934,-1.57058,0.224318,1.95608,-2.06733,0.286928,1.87902,-1.89746,0.088054,1.91754,-1.99629,0.069298,1.76291,-2.18503,0.11207,1.6766,-2.23958,0.273376,1.62222,-2.13478,0.332177,1.59355,-2.13487,0.19188,1.45504,-1.79422,0.008737,1.51178,-1.84837,0.010894,1.54107,-1.90907,0.01576,1.51607,-1.96521,0.200428,1.4533,-2.04133,0.250543,1.15077,-1.72289,0.127146,1.10306,-1.76075,0.1591,1.02604,-1.78286,0.270004,0.94195,-1.76567,0.339199,0.765173,-1.7618,0.359743,0.693812,-1.77735,0.232941,0.734252,-1.78492,0.253689,0.666346,-1.79425,0.368666,0.454638,-1.81397,0.30931,0.364173,-1.90405,0.533376,0.482229,-1.84289,0.531762,0.409992,-1.78584,0.150189,1.1343,-2.08459,0.151285,1.05042,-2.06744,0.009406,1.13443,-2.05181,0.011823,1.05296,-2.03618,0.038495,0.918451,-2.03747,-0.124942,0.831948,-2.01839,-0.143766,0.94153,-2.04306,-0.212106,0.927389,-2.0317,-0.431434,0.86795,-1.99331,-0.456179,0.966463,-1.93372,-0.547102,0.699896,-1.91965,-0.589653,0.756695,-1.9777,0.119346,1.36508,-1.8002,0.11505,1.36789,-2.01538},
/*951*/{0.185732,1.92594,-1.68776,0.273737,1.87158,-1.8239,0.033004,1.83455,-1.61873,-0.085305,1.75771,-1.58665,0.041599,1.65849,-1.58472,0.108236,1.59426,-1.56835,0.22173,1.95096,-2.0684,0.285523,1.87476,-1.89794,0.086022,1.9128,-1.99561,0.063188,1.76113,-2.18436,0.106274,1.6726,-2.23936,0.267534,1.61425,-2.13752,0.325756,1.58423,-2.13902,0.19165,1.45155,-1.793,0.00796,1.50696,-1.84879,0.010933,1.53672,-1.90881,0.014702,1.51117,-1.96495,0.200815,1.4507,-2.0408,0.250062,1.14657,-1.72339,0.124886,1.0992,-1.76272,0.158108,1.02243,-1.78471,0.265153,0.937123,-1.76595,0.333615,0.75855,-1.76351,0.352859,0.687015,-1.7778,0.226582,0.730142,-1.78637,0.24582,0.66145,-1.79453,0.358801,0.450167,-1.81382,0.295492,0.357839,-1.90395,0.521347,0.472665,-1.84548,0.519094,0.401701,-1.78711,0.156023,1.1309,-2.08586,0.158225,1.047,-2.06882,0.015797,1.12814,-2.05184,0.020245,1.0471,-2.03525,0.049318,0.913932,-2.03902,-0.116121,0.833027,-2.02054,-0.131298,0.943229,-2.04353,-0.201614,0.931386,-2.0327,-0.421617,0.879265,-1.99434,-0.443177,0.977672,-1.93346,-0.540283,0.713003,-1.92339,-0.582414,0.77146,-1.9809,0.119735,1.36113,-1.79996,0.116166,1.36431,-2.01514},
/*952*/{0.185677,1.92079,-1.68701,0.274088,1.86616,-1.8241,0.034315,1.8274,-1.61684,-0.083187,1.75026,-1.58269,0.0459,1.65191,-1.58162,0.112469,1.58919,-1.56537,0.219514,1.94613,-2.06906,0.284601,1.87069,-1.89881,0.0846,1.90803,-1.99482,0.057166,1.75694,-2.18353,0.099711,1.66878,-2.23878,0.261044,1.60595,-2.14051,0.319251,1.57381,-2.14324,0.191545,1.44723,-1.79097,0.007277,1.50186,-1.84965,0.009287,1.53141,-1.90841,0.013292,1.50601,-1.96633,0.200391,1.44734,-2.03972,0.247793,1.14163,-1.72375,0.124418,1.09605,-1.7634,0.154995,1.01838,-1.78676,0.260887,0.931529,-1.76606,0.327762,0.752582,-1.76414,0.345674,0.680032,-1.77929,0.220147,0.726182,-1.78609,0.238417,0.656485,-1.79511,0.34767,0.444653,-1.81371,0.280302,0.352395,-1.90393,0.509223,0.462344,-1.84625,0.505406,0.39161,-1.78742,0.162515,1.12744,-2.08692,0.166018,1.0435,-2.07045,0.022066,1.12176,-2.0517,0.027983,1.04052,-2.03553,0.059155,0.909505,-2.0402,-0.107987,0.833855,-2.02178,-0.119816,0.944848,-2.04408,-0.18907,0.934769,-2.03301,-0.411333,0.889473,-1.99599,-0.430789,0.987986,-1.93358,-0.532693,0.725513,-1.92729,-0.573149,0.785309,-1.98371,0.119379,1.3567,-1.79961,0.116895,1.35999,-2.0148},
/*953*/{0.185061,1.91543,-1.68699,0.272478,1.86202,-1.82504,0.035238,1.81968,-1.61474,-0.081613,1.74124,-1.57896,0.049852,1.64484,-1.57807,0.11762,1.58335,-1.56299,0.217367,1.94143,-2.07025,0.284305,1.86607,-1.89938,0.082636,1.90318,-1.99412,0.052608,1.75332,-2.18286,0.092867,1.6645,-2.2384,0.254735,1.59647,-2.14313,0.31245,1.56374,-2.1473,0.191078,1.44336,-1.78973,0.006172,1.49508,-1.84985,0.009313,1.52607,-1.90813,0.013032,1.50061,-1.96602,0.19945,1.44351,-2.03889,0.245728,1.13748,-1.7234,0.124078,1.09088,-1.76448,0.153202,1.01444,-1.78765,0.256925,0.926449,-1.76676,0.321705,0.746181,-1.76418,0.337689,0.673184,-1.78011,0.2131,0.722123,-1.78648,0.229933,0.652064,-1.79537,0.335883,0.439566,-1.81407,0.263935,0.348567,-1.9038,0.495994,0.451419,-1.84874,0.49121,0.382169,-1.78852,0.167839,1.12431,-2.0882,0.173095,1.04031,-2.07184,0.028132,1.11539,-2.05102,0.036811,1.03493,-2.03585,0.069845,0.905282,-2.04169,-0.097935,0.834897,-2.0243,-0.107132,0.946244,-2.04467,-0.176939,0.938764,-2.03421,-0.394324,0.895491,-1.9939,-0.418941,0.997097,-1.93395,-0.522723,0.736704,-1.93023,-0.563474,0.796828,-1.98748,0.119703,1.35187,-1.79914,0.117724,1.35533,-2.01434},
/*954*/{0.18482,1.9101,-1.68644,0.272001,1.85754,-1.82548,0.037305,1.81201,-1.61241,-0.078717,1.73217,-1.5751,0.055049,1.63824,-1.57513,0.123106,1.57733,-1.55917,0.214197,1.93595,-2.0707,0.283353,1.86109,-1.89982,0.08078,1.89752,-1.99329,0.048717,1.74776,-2.18186,0.086406,1.66021,-2.23832,0.24865,1.58676,-2.14552,0.304719,1.55301,-2.15159,0.190939,1.44012,-1.78857,0.00491,1.48995,-1.85116,0.008325,1.52107,-1.90832,0.012414,1.4945,-1.96609,0.199228,1.43969,-2.03833,0.244079,1.13242,-1.72389,0.120631,1.0859,-1.76558,0.152232,1.00968,-1.78749,0.252891,0.921334,-1.76746,0.315579,0.739216,-1.76519,0.330003,0.665903,-1.78021,0.20581,0.717648,-1.78705,0.221506,0.648036,-1.79656,0.319885,0.434173,-1.81653,0.243954,0.355025,-1.90519,0.482699,0.438686,-1.85007,0.470976,0.370407,-1.7903,0.173373,1.12077,-2.08941,0.180745,1.03697,-2.07343,0.03407,1.10875,-2.05063,0.044212,1.0282,-2.03617,0.079545,0.901071,-2.0435,-0.088689,0.835323,-2.02638,-0.093505,0.947546,-2.04536,-0.163998,0.941649,-2.03492,-0.387838,0.908181,-1.99899,-0.406414,1.00558,-1.93494,-0.515447,0.744577,-1.9365,-0.5513,0.806782,-1.99108,0.12002,1.3481,-1.7984,0.118748,1.35056,-2.01361},
/*955*/{0.184912,1.9042,-1.68601,0.27225,1.85073,-1.8252,0.039462,1.80346,-1.60964,-0.074007,1.72339,-1.57098,0.059077,1.63044,-1.5722,0.128989,1.57138,-1.55751,0.212669,1.93062,-2.07175,0.282312,1.85559,-1.90088,0.079262,1.8919,-1.99266,0.042733,1.74341,-2.18151,0.079263,1.65572,-2.23778,0.241552,1.57772,-2.1491,0.297488,1.54202,-2.15584,0.190533,1.43609,-1.7871,0.004315,1.48394,-1.85102,0.006899,1.51433,-1.90783,0.011402,1.48847,-1.96691,0.198967,1.43602,-2.03751,0.242521,1.12717,-1.72418,0.119732,1.08211,-1.76684,0.150709,1.00518,-1.789,0.249902,0.915666,-1.76764,0.308405,0.732163,-1.76537,0.321523,0.659716,-1.78085,0.198744,0.712131,-1.78636,0.211541,0.642533,-1.79516,0.301678,0.42902,-1.81741,0.224565,0.351752,-1.90667,0.466422,0.425874,-1.85141,0.453347,0.357561,-1.79163,0.179514,1.11729,-2.0905,0.188276,1.03431,-2.07567,0.040371,1.10255,-2.05089,0.05231,1.02176,-2.03687,0.090829,0.896698,-2.04542,-0.077517,0.83551,-2.02847,-0.080396,0.948007,-2.04643,-0.150267,0.94394,-2.03541,-0.378387,0.915407,-1.99806,-0.393595,1.01298,-1.93443,-0.503359,0.752611,-1.94043,-0.53957,0.814776,-1.99526,0.120564,1.3433,-1.79783,0.119964,1.34572,-2.01306},
/*956*/{0.184546,1.89782,-1.68565,0.271863,1.84627,-1.82644,0.04181,1.79505,-1.60741,-0.071186,1.7137,-1.56672,0.064819,1.62316,-1.56842,0.136222,1.56552,-1.55406,0.209638,1.92488,-2.07228,0.281761,1.85061,-1.90151,0.077291,1.88675,-1.99211,0.038895,1.73931,-2.18054,0.073276,1.65137,-2.23759,0.235485,1.56844,-2.15225,0.289551,1.53119,-2.16053,0.190336,1.43162,-1.78541,0.003404,1.47843,-1.8516,0.00676,1.5092,-1.90747,0.009947,1.4823,-1.96742,0.198821,1.43192,-2.03735,0.242369,1.12178,-1.72398,0.11828,1.07772,-1.76617,0.147887,0.999922,-1.78891,0.247077,0.909778,-1.76724,0.301781,0.725851,-1.76607,0.312936,0.652266,-1.78167,0.191455,0.708018,-1.78547,0.203735,0.636449,-1.79284,0.288843,0.422575,-1.81968,0.205094,0.356239,-1.90898,0.453206,0.412086,-1.85416,0.432858,0.344672,-1.7923,0.183665,1.11387,-2.09219,0.195585,1.03086,-2.07703,0.046575,1.09552,-2.05153,0.059969,1.01529,-2.0378,0.102642,0.89215,-2.04693,-0.066279,0.835897,-2.03119,-0.066482,0.948934,-2.04792,-0.137244,0.945412,-2.03581,-0.362538,0.922302,-2.00116,-0.38053,1.01976,-1.93593,-0.4913,0.759113,-1.94491,-0.525149,0.82219,-2.0002,0.120587,1.33859,-1.79739,0.120563,1.34082,-2.01261},
/*957*/{0.184892,1.89189,-1.68507,0.271926,1.84164,-1.8271,0.04422,1.78623,-1.60468,-0.066861,1.70358,-1.56196,0.070325,1.61538,-1.56638,0.143112,1.55943,-1.5522,0.20697,1.9198,-2.07314,0.281343,1.84482,-1.90219,0.075838,1.88113,-1.99184,0.033894,1.73512,-2.17952,0.066223,1.64627,-2.23682,0.22786,1.55796,-2.15546,0.281478,1.52022,-2.16469,0.19024,1.42757,-1.78368,0.001113,1.47263,-1.85262,0.005846,1.50268,-1.90721,0.008605,1.47684,-1.96793,0.198262,1.42678,-2.03655,0.239102,1.11534,-1.72444,0.116593,1.0721,-1.76511,0.144085,0.994083,-1.78869,0.243885,0.903538,-1.7671,0.295017,0.719063,-1.76704,0.306237,0.645254,-1.78286,0.184355,0.704731,-1.78432,0.194592,0.63423,-1.7956,0.273047,0.418341,-1.82174,0.183586,0.355516,-1.90879,0.435612,0.400456,-1.85757,0.413512,0.33803,-1.79308,0.189344,1.11062,-2.09378,0.202757,1.02741,-2.07901,0.052822,1.08863,-2.05232,0.067768,1.00892,-2.03841,0.113478,0.887519,-2.04935,-0.055059,0.836216,-2.03343,-0.05168,0.94859,-2.04688,-0.122472,0.946889,-2.03695,-0.348425,0.928886,-2.00273,-0.367926,1.02523,-1.93663,-0.47596,0.764513,-1.94801,-0.511084,0.827384,-2.0038,0.12014,1.33399,-1.79644,0.120935,1.3353,-2.01167},
/*958*/{0.185224,1.88552,-1.6848,0.27129,1.83541,-1.82783,0.047323,1.77705,-1.60208,-0.060777,1.69372,-1.55752,0.07654,1.60783,-1.5632,0.1501,1.55404,-1.54987,0.205396,1.91449,-2.07425,0.281004,1.83984,-1.90408,0.074304,1.87586,-1.99059,0.029116,1.73122,-2.17962,0.059566,1.64174,-2.23624,0.220985,1.54846,-2.15853,0.273001,1.50893,-2.16903,0.189652,1.42206,-1.78202,-0.000185,1.46686,-1.8535,0.004463,1.49603,-1.90709,0.007295,1.46999,-1.96857,0.197334,1.42207,-2.03694,0.236614,1.11126,-1.72415,0.113551,1.06735,-1.76393,0.141788,0.989345,-1.7881,0.24146,0.897883,-1.76639,0.289234,0.712833,-1.76885,0.296007,0.63911,-1.78563,0.177341,0.700584,-1.78444,0.185629,0.630685,-1.79457,0.256596,0.419051,-1.82549,0.161752,0.356834,-1.90704,0.41788,0.393916,-1.8616,0.392968,0.339621,-1.79516,0.194334,1.10725,-2.09639,0.210606,1.02405,-2.08095,0.057964,1.08132,-2.05294,0.076788,1.0025,-2.03906,0.124843,0.882138,-2.05013,-0.043298,0.834552,-2.03489,-0.037164,0.949122,-2.04952,-0.106682,0.947092,-2.03695,-0.334105,0.933362,-2.00348,-0.356792,1.03157,-1.93995,-0.462404,0.768269,-1.95186,-0.495114,0.831088,-2.0083,0.119683,1.32839,-1.79637,0.12099,1.3297,-2.0116},
/*959*/{0.185471,1.8798,-1.68425,0.27097,1.82954,-1.8282,0.050795,1.7677,-1.59938,-0.054628,1.68353,-1.55298,0.084021,1.60033,-1.56008,0.157333,1.54771,-1.54767,0.203203,1.90944,-2.0746,0.280446,1.83437,-1.90487,0.072135,1.87139,-1.98948,0.025775,1.72706,-2.17869,0.052918,1.63763,-2.23568,0.213631,1.53939,-2.16177,0.264279,1.49812,-2.1737,0.187516,1.41585,-1.78059,-0.002551,1.46198,-1.85392,0.002316,1.49002,-1.90843,0.005059,1.46473,-1.96848,0.196419,1.41672,-2.0363,0.235479,1.10816,-1.72231,0.109333,1.06344,-1.7636,0.13832,0.98597,-1.78784,0.237262,0.891491,-1.76635,0.282323,0.707836,-1.77106,0.28759,0.633733,-1.78831,0.170463,0.700149,-1.78417,0.177158,0.63058,-1.79568,0.23703,0.420317,-1.82948,0.139265,0.356801,-1.90921,0.39492,0.392511,-1.8669,0.368078,0.338936,-1.7956,0.199752,1.10338,-2.09734,0.21841,1.02118,-2.08305,0.063126,1.07391,-2.05423,0.084499,0.99532,-2.03986,0.136949,0.877966,-2.05174,-0.030722,0.834211,-2.03635,-0.022886,0.94815,-2.05119,-0.093182,0.946878,-2.0379,-0.318967,0.936463,-2.00467,-0.342977,1.03489,-1.93968,-0.444419,0.771177,-1.95581,-0.478872,0.833444,-2.0129,0.116877,1.32269,-1.79617,0.119587,1.32423,-2.01138},
/*960*/{0.186515,1.87418,-1.68367,0.271534,1.8238,-1.8291,0.054801,1.75821,-1.59678,-0.049318,1.67259,-1.5479,0.091032,1.5933,-1.55719,0.166063,1.54245,-1.54541,0.201963,1.90457,-2.07553,0.280688,1.82887,-1.90601,0.070745,1.86646,-1.98789,0.019941,1.7229,-2.17805,0.046887,1.63297,-2.23497,0.205754,1.52955,-2.16513,0.254726,1.48731,-2.17806,0.185591,1.41041,-1.78089,-0.005918,1.45737,-1.85408,-0.00074,1.48417,-1.91012,0.001591,1.45876,-1.96985,0.195988,1.41199,-2.03596,0.230705,1.10583,-1.7191,0.104352,1.06057,-1.76342,0.137441,0.983928,-1.7875,0.232786,0.885552,-1.76679,0.276393,0.705512,-1.77291,0.278883,0.631162,-1.79084,0.164728,0.701268,-1.78468,0.166849,0.63117,-1.79844,0.212615,0.420223,-1.83098,0.116198,0.357889,-1.9103,0.371497,0.391672,-1.86758,0.345302,0.339823,-1.79684,0.204016,1.10093,-2.0992,0.225439,1.01881,-2.08468,0.069517,1.06699,-2.05508,0.093635,0.989217,-2.04106,0.149429,0.873872,-2.05605,-0.016608,0.832806,-2.03779,-0.007274,0.945784,-2.05176,-0.077067,0.945652,-2.03912,-0.299931,0.938313,-2.00536,-0.330505,1.03661,-1.94111,-0.428388,0.772156,-1.96023,-0.461057,0.83393,-2.01721,0.114441,1.31758,-1.79658,0.118263,1.3191,-2.01178},
/*961*/{0.186967,1.86989,-1.68281,0.272073,1.81864,-1.83001,0.059633,1.74833,-1.59332,-0.042104,1.66249,-1.54349,0.100068,1.58642,-1.55483,0.175854,1.53745,-1.54357,0.199587,1.9003,-2.07674,0.279842,1.82384,-1.90831,0.069274,1.8627,-1.98615,0.017919,1.71771,-2.17745,0.040855,1.62882,-2.2341,0.198806,1.52128,-2.16887,0.24603,1.47741,-2.18226,0.182623,1.40575,-1.77984,-0.008965,1.45316,-1.85413,-0.004055,1.4785,-1.91118,-0.000927,1.45348,-1.97083,0.194651,1.4066,-2.03605,0.226926,1.10373,-1.71604,0.103534,1.06027,-1.76293,0.134762,0.982909,-1.78611,0.229152,0.88427,-1.76694,0.271342,0.703873,-1.77505,0.270018,0.63203,-1.7932,0.15809,0.706525,-1.78571,0.157769,0.635949,-1.79898,0.192142,0.42267,-1.83354,0.093327,0.358068,-1.91155,0.3494,0.389934,-1.86877,0.322802,0.338795,-1.79762,0.209713,1.09758,-2.1002,0.232927,1.01652,-2.0858,0.07587,1.0603,-2.05571,0.102515,0.983054,-2.04181,0.161354,0.869915,-2.05741,-0.002448,0.830573,-2.03852,0.00743,0.943663,-2.05189,-0.060589,0.945146,-2.04101,-0.287893,0.941605,-2.0071,-0.318754,1.03837,-1.94436,-0.40971,0.771522,-1.96353,-0.443766,0.833374,-2.02202,0.111373,1.31304,-1.7961,0.116343,1.31372,-2.01127},
/*962*/{0.187985,1.8642,-1.68199,0.272149,1.81364,-1.83147,0.064961,1.73919,-1.59091,-0.033272,1.65203,-1.53856,0.108787,1.57908,-1.55121,0.18518,1.5332,-1.54208,0.197301,1.89616,-2.07817,0.281837,1.81857,-1.90904,0.067849,1.86029,-1.98391,0.013757,1.71445,-2.17671,0.034345,1.62537,-2.23282,0.189779,1.51149,-2.1718,0.236625,1.46807,-2.1868,0.180111,1.40172,-1.77927,-0.012243,1.44928,-1.85577,-0.007311,1.47283,-1.91241,-0.004059,1.44812,-1.97218,0.193087,1.40172,-2.03557,0.225164,1.10285,-1.71444,0.103245,1.05906,-1.76266,0.134297,0.981863,-1.78403,0.229421,0.887332,-1.76612,0.263818,0.702767,-1.77671,0.257003,0.62847,-1.79436,0.150908,0.71116,-1.78572,0.145977,0.640095,-1.80003,0.173045,0.424673,-1.83449,0.071795,0.359835,-1.91287,0.328046,0.389112,-1.86934,0.300354,0.338374,-1.79846,0.214245,1.09633,-2.1008,0.240426,1.01586,-2.0869,0.08218,1.05369,-2.05597,0.110284,0.978104,-2.04256,0.174248,0.866911,-2.05846,0.011745,0.829196,-2.03996,0.023396,0.94214,-2.05474,-0.046515,0.943295,-2.04297,-0.272612,0.942075,-2.0095,-0.306278,1.03806,-1.94641,-0.391379,0.769427,-1.96799,-0.424392,0.830319,-2.02629,0.108459,1.30908,-1.79579,0.114692,1.30856,-2.01093},
/*963*/{0.188625,1.85994,-1.68114,0.271642,1.80867,-1.83289,0.070859,1.7304,-1.58874,-0.02495,1.64123,-1.53361,0.118572,1.57318,-1.54932,0.19575,1.5293,-1.54067,0.195549,1.89274,-2.07943,0.279653,1.81504,-1.91194,0.067115,1.85816,-1.98196,0.010731,1.71174,-2.17513,0.028411,1.62214,-2.23193,0.182022,1.50409,-2.17512,0.226707,1.45892,-2.19118,0.177682,1.39821,-1.77889,-0.015754,1.44606,-1.85724,-0.009176,1.46965,-1.91296,-0.00736,1.44225,-1.97226,0.19056,1.39699,-2.03543,0.225466,1.10463,-1.71477,0.10357,1.05815,-1.75961,0.134714,0.981515,-1.78257,0.232925,0.889772,-1.76574,0.253269,0.70189,-1.77641,0.244156,0.628137,-1.79459,0.141023,0.715097,-1.78502,0.133528,0.644506,-1.79934,0.154278,0.424641,-1.83494,0.049532,0.360454,-1.91305,0.306418,0.387909,-1.86997,0.278798,0.338368,-1.79757,0.219522,1.09737,-2.10089,0.247098,1.01751,-2.08811,0.087861,1.0505,-2.05694,0.119467,0.974886,-2.04338,0.186984,0.86361,-2.05884,0.027724,0.827337,-2.03899,0.037805,0.939916,-2.05813,-0.030235,0.941954,-2.04445,-0.25764,0.941582,-2.01172,-0.293759,1.03583,-1.94709,-0.372845,0.764721,-1.97174,-0.404683,0.825379,-2.03186,0.105532,1.30591,-1.79503,0.112061,1.30364,-2.01016},
/*964*/{0.189595,1.85624,-1.6809,0.271562,1.8053,-1.83476,0.0767,1.72287,-1.58696,-0.014549,1.63242,-1.52945,0.128563,1.56883,-1.54874,0.207497,1.527,-1.54012,0.194646,1.88973,-2.08108,0.279123,1.81136,-1.91328,0.066789,1.85746,-1.98129,0.005123,1.70975,-2.17257,0.022387,1.61992,-2.2301,0.174032,1.49796,-2.17789,0.216969,1.45144,-2.19471,0.175225,1.39621,-1.77739,-0.017948,1.44266,-1.85859,-0.011038,1.46864,-1.9138,-0.010452,1.43757,-1.97304,0.188873,1.39271,-2.03553,0.221311,1.10336,-1.71553,0.099958,1.05403,-1.75779,0.133412,0.979119,-1.78068,0.23743,0.891663,-1.76661,0.241785,0.701281,-1.77524,0.231404,0.628351,-1.79333,0.129941,0.717733,-1.78581,0.120355,0.647229,-1.79825,0.13368,0.424374,-1.83569,0.028137,0.361609,-1.91322,0.285213,0.386498,-1.86851,0.257112,0.338368,-1.79815,0.224415,1.09932,-2.10162,0.255583,1.02017,-2.08851,0.093929,1.04881,-2.05878,0.1286,0.973511,-2.04485,0.20208,0.86271,-2.058,0.043321,0.826118,-2.03877,0.053782,0.936555,-2.06032,-0.016057,0.940142,-2.04749,-0.244788,0.939974,-2.01149,-0.284279,1.03259,-1.94923,-0.351259,0.759323,-1.97562,-0.383498,0.819381,-2.03628,0.10275,1.30394,-1.794,0.110035,1.29956,-2.00906},
/*965*/{0.190437,1.85294,-1.6811,0.270857,1.80187,-1.83592,0.082356,1.71666,-1.58592,-0.005399,1.62458,-1.5264,0.139363,1.56502,-1.54772,0.219451,1.52493,-1.5392,0.194832,1.88715,-2.0818,0.278346,1.80853,-1.91491,0.065714,1.85599,-1.98218,0.000232,1.70911,-2.16859,0.015831,1.61969,-2.22812,0.165494,1.49218,-2.18014,0.206468,1.44502,-2.19825,0.172401,1.39382,-1.77603,-0.020411,1.44151,-1.85965,-0.013201,1.46815,-1.9143,-0.013043,1.43415,-1.97451,0.185579,1.38937,-2.03603,0.217911,1.10249,-1.71573,0.096068,1.05451,-1.75783,0.129362,0.977897,-1.77976,0.241835,0.890852,-1.76843,0.229462,0.700225,-1.77367,0.216614,0.627549,-1.792,0.118706,0.720243,-1.78614,0.107546,0.649341,-1.79729,0.112452,0.424683,-1.83504,0.007153,0.36216,-1.91305,0.264125,0.386521,-1.86985,0.234924,0.337939,-1.79786,0.230469,1.10185,-2.10257,0.26485,1.02374,-2.0885,0.102931,1.04649,-2.06067,0.137086,0.975856,-2.049,0.218938,0.864282,-2.05783,0.05992,0.823423,-2.03879,0.068732,0.935267,-2.06146,0.000534,0.939309,-2.04845,-0.22301,0.932402,-2.01149,-0.27318,1.02853,-1.95202,-0.330765,0.752761,-1.97922,-0.363687,0.810676,-2.03985,0.098996,1.30231,-1.79354,0.106673,1.29645,-2.00856},
/*966*/{0.191059,1.85087,-1.68156,0.270459,1.79796,-1.83596,0.087699,1.71216,-1.58588,0.003868,1.61766,-1.52354,0.151388,1.56223,-1.54653,0.231944,1.52395,-1.53965,0.194254,1.88535,-2.08207,0.277175,1.80647,-1.91555,0.065815,1.8546,-1.98199,-0.003819,1.70948,-2.16533,0.00916,1.62113,-2.22622,0.157064,1.48801,-2.18235,0.19672,1.43903,-2.20132,0.169786,1.3914,-1.77385,-0.02268,1.44024,-1.86071,-0.01507,1.46721,-1.91466,-0.014675,1.43243,-1.97567,0.183664,1.38642,-2.03688,0.213653,1.10085,-1.71484,0.091827,1.053,-1.7578,0.123777,0.975108,-1.77885,0.235968,0.887405,-1.7681,0.21566,0.698023,-1.77126,0.201969,0.624946,-1.78959,0.106361,0.719529,-1.78618,0.093773,0.649903,-1.79756,0.092013,0.424823,-1.8343,-0.014638,0.362528,-1.91284,0.242238,0.38514,-1.86831,0.213103,0.337166,-1.79725,0.237485,1.10574,-2.10228,0.274485,1.02869,-2.08817,0.110849,1.04519,-2.06225,0.147887,0.975675,-2.05082,0.237164,0.868009,-2.05613,0.076635,0.822968,-2.03739,0.083526,0.934526,-2.06274,0.014839,0.938514,-2.05116,-0.214181,0.930877,-2.01545,-0.264881,1.02268,-1.95415,-0.309013,0.74404,-1.98201,-0.340395,0.799781,-2.04259,0.095473,1.30045,-1.79335,0.10419,1.29408,-2.00831},
/*967*/{0.191818,1.84906,-1.68241,0.26966,1.79729,-1.8375,0.091837,1.70924,-1.58491,0.013738,1.61234,-1.52101,0.162725,1.56045,-1.54655,0.244256,1.5247,-1.5398,0.193649,1.88339,-2.08215,0.276226,1.80535,-1.91567,0.064833,1.85317,-1.98309,-0.008555,1.71012,-2.15931,0.002418,1.62278,-2.22419,0.148141,1.48505,-2.18381,0.186107,1.43569,-2.20398,0.167926,1.39027,-1.77296,-0.023417,1.43879,-1.8611,-0.016239,1.46581,-1.91501,-0.016087,1.43134,-1.97531,0.182608,1.38502,-2.03751,0.209212,1.09827,-1.71548,0.085476,1.05128,-1.75774,0.115998,0.973519,-1.77976,0.225927,0.88285,-1.76597,0.201249,0.695133,-1.7694,0.185885,0.622431,-1.78768,0.092469,0.719747,-1.78499,0.077852,0.649896,-1.79807,0.071654,0.42529,-1.8337,-0.03655,0.362974,-1.9121,0.220872,0.38475,-1.86864,0.191935,0.336501,-1.79689,0.24531,1.11027,-2.102,0.284505,1.03501,-2.08744,0.120297,1.04765,-2.06581,0.159456,0.975885,-2.05209,0.253045,0.87286,-2.05648,0.092627,0.822511,-2.03656,0.098621,0.933754,-2.06362,0.028953,0.937025,-2.0525,-0.199762,0.924931,-2.01672,-0.256438,1.01556,-1.95642,-0.28641,0.735091,-1.98479,-0.317722,0.787414,-2.04522,0.094034,1.29919,-1.79328,0.103037,1.29274,-2.00823},
/*968*/{0.192203,1.84804,-1.68325,0.267126,1.79557,-1.83808,0.095687,1.70673,-1.58501,0.023849,1.60869,-1.51954,0.173821,1.55923,-1.54707,0.257064,1.52624,-1.54112,0.192574,1.88253,-2.08205,0.275142,1.80381,-1.91637,0.063772,1.85299,-1.98379,-0.012054,1.7123,-2.15337,-0.004382,1.62548,-2.22233,0.139524,1.48341,-2.18483,0.176248,1.43287,-2.20583,0.165439,1.38945,-1.77133,-0.024192,1.43871,-1.8611,-0.018333,1.46476,-1.91579,-0.017181,1.43066,-1.97559,0.180906,1.38401,-2.03763,0.202408,1.09289,-1.71445,0.078567,1.04994,-1.75876,0.108836,0.971432,-1.78076,0.212845,0.879021,-1.76552,0.186073,0.690822,-1.76879,0.16797,0.618596,-1.78747,0.077729,0.719474,-1.78438,0.061943,0.650283,-1.79797,0.050716,0.425369,-1.83253,-0.058237,0.363638,-1.91124,0.199685,0.384229,-1.86697,0.170155,0.3364,-1.79612,0.254629,1.11548,-2.10143,0.295812,1.04266,-2.08766,0.130645,1.0483,-2.06851,0.17178,0.978669,-2.05437,0.268895,0.878611,-2.05634,0.109385,0.822982,-2.03604,0.112286,0.934191,-2.0647,0.043014,0.93533,-2.05369,-0.187973,0.918802,-2.01807,-0.248304,1.00621,-1.95955,-0.260572,0.723837,-1.98666,-0.299595,0.776957,-2.05006,0.091694,1.29861,-1.79283,0.10146,1.29173,-2.00774},
/*969*/{0.192836,1.84679,-1.68423,0.265989,1.7947,-1.83831,0.100307,1.70582,-1.58538,0.032363,1.60498,-1.51795,0.186113,1.55938,-1.54735,0.270249,1.52896,-1.54369,0.191213,1.88207,-2.08227,0.273632,1.80264,-1.91627,0.062684,1.85323,-1.98397,-0.016439,1.71523,-2.14839,-0.010418,1.62897,-2.22058,0.131436,1.48328,-2.18574,0.1667,1.4316,-2.20706,0.164168,1.38901,-1.77047,-0.026375,1.43822,-1.86174,-0.018775,1.46453,-1.9152,-0.018804,1.4309,-1.97506,0.17941,1.38467,-2.03846,0.198204,1.09077,-1.71421,0.0714,1.04931,-1.7603,0.099872,0.970215,-1.78175,0.200479,0.876184,-1.76444,0.170933,0.686871,-1.76895,0.151327,0.616046,-1.78663,0.063085,0.717145,-1.78385,0.045808,0.648912,-1.79691,0.03035,0.425714,-1.83176,-0.079202,0.363946,-1.91106,0.177826,0.384643,-1.8681,0.149376,0.336687,-1.79511,0.261678,1.12265,-2.10052,0.305996,1.04986,-2.08692,0.141068,1.04983,-2.06903,0.1853,0.981765,-2.05568,0.286467,0.887424,-2.05675,0.126068,0.824664,-2.03535,0.126522,0.934726,-2.06483,0.056905,0.93351,-2.05427,-0.16719,0.908725,-2.0169,-0.240852,0.995796,-1.96075,-0.235865,0.71313,-1.99068,-0.276699,0.763716,-2.05355,0.09041,1.29807,-1.79327,0.100225,1.29215,-2.0082},
/*970*/{0.193386,1.84692,-1.68481,0.264596,1.79438,-1.83879,0.103985,1.70481,-1.58492,0.041525,1.60162,-1.51581,0.197085,1.56074,-1.54796,0.281663,1.53213,-1.54602,0.189441,1.88226,-2.08263,0.272703,1.80251,-1.91737,0.061178,1.85339,-1.98422,-0.020423,1.71975,-2.14341,-0.016877,1.63339,-2.21924,0.122977,1.48383,-2.18662,0.156931,1.43172,-2.20815,0.161612,1.38874,-1.7692,-0.026833,1.43778,-1.86155,-0.019461,1.46344,-1.91536,-0.019942,1.43084,-1.97382,0.179133,1.38603,-2.03901,0.189892,1.08456,-1.71482,0.061762,1.04831,-1.7628,0.08992,0.968289,-1.78133,0.186079,0.872852,-1.76441,0.155707,0.682939,-1.76924,0.135523,0.61363,-1.78709,0.047895,0.716309,-1.78396,0.030389,0.647586,-1.79774,0.009304,0.426787,-1.8318,-0.100808,0.365508,-1.91027,0.156476,0.383807,-1.86656,0.128006,0.335672,-1.79351,0.27039,1.13016,-2.09968,0.317132,1.05975,-2.08609,0.1517,1.05271,-2.07097,0.198722,0.986219,-2.05663,0.301673,0.894114,-2.05699,0.141925,0.825963,-2.0354,0.140035,0.936208,-2.06557,0.070346,0.932649,-2.05525,-0.160085,0.901481,-2.02006,-0.232772,0.983629,-1.96338,-0.211039,0.702088,-1.99081,-0.253079,0.750402,-2.05682,0.089516,1.29745,-1.79345,0.100144,1.29281,-2.00837},
/*971*/{0.194279,1.84768,-1.68566,0.265459,1.79529,-1.84079,0.108338,1.70424,-1.58461,0.051203,1.59946,-1.51519,0.206649,1.56226,-1.54979,0.294633,1.53689,-1.5497,0.188126,1.88285,-2.08266,0.271392,1.80251,-1.91801,0.059456,1.85416,-1.98442,-0.024282,1.72459,-2.13745,-0.02385,1.63791,-2.21768,0.115163,1.48592,-2.18683,0.147953,1.43271,-2.20899,0.161118,1.38886,-1.76838,-0.027076,1.43676,-1.86109,-0.020735,1.46335,-1.91484,-0.020517,1.43133,-1.97273,0.178313,1.3885,-2.03899,0.183362,1.08348,-1.71541,0.054931,1.04828,-1.7629,0.079539,0.968233,-1.78456,0.17083,0.868921,-1.76499,0.141015,0.678879,-1.76991,0.117542,0.608512,-1.78739,0.032958,0.71389,-1.78535,0.013054,0.64527,-1.79841,-0.011241,0.426451,-1.8303,-0.121511,0.365742,-1.90955,0.135751,0.383581,-1.86548,0.106313,0.335662,-1.79413,0.278406,1.13762,-2.09933,0.326867,1.06973,-2.08504,0.161799,1.05636,-2.07245,0.211162,0.991913,-2.0586,0.315875,0.900804,-2.05739,0.158909,0.828165,-2.03544,0.152651,0.939373,-2.06605,0.083073,0.932819,-2.0564,-0.139188,0.890779,-2.01902,-0.224969,0.969444,-1.96479,-0.186005,0.69009,-1.99337,-0.229232,0.7364,-2.05944,0.089849,1.29714,-1.79391,0.100459,1.29437,-2.00887},
/*972*/{0.19426,1.84876,-1.6864,0.264075,1.79532,-1.8411,0.111693,1.70441,-1.58466,0.061622,1.59743,-1.51313,0.217665,1.56533,-1.55177,0.305922,1.54237,-1.55363,0.185476,1.88428,-2.08295,0.270104,1.80297,-1.91896,0.058271,1.85499,-1.98442,-0.027081,1.72881,-2.13292,-0.029928,1.64378,-2.21661,0.107118,1.48908,-2.18743,0.138819,1.43514,-2.20927,0.160014,1.38998,-1.76789,-0.027103,1.43659,-1.8612,-0.020997,1.46354,-1.9143,-0.02067,1.43144,-1.97255,0.177914,1.39146,-2.03897,0.172119,1.07887,-1.71571,0.045144,1.04974,-1.76484,0.067903,0.967801,-1.78551,0.157445,0.864156,-1.76454,0.124405,0.67633,-1.77079,0.101414,0.606261,-1.78863,0.017327,0.712348,-1.78513,-0.004533,0.644552,-1.79846,-0.031623,0.426881,-1.83035,-0.142586,0.366442,-1.90991,0.1145,0.383813,-1.86513,0.084822,0.336375,-1.79364,0.285382,1.14656,-2.09841,0.335798,1.07941,-2.08403,0.172196,1.06026,-2.07319,0.222713,0.997369,-2.05903,0.329956,0.908042,-2.05756,0.174709,0.831132,-2.03651,0.165443,0.941105,-2.06582,0.095766,0.933135,-2.05668,-0.130076,0.883626,-2.02358,-0.216806,0.954637,-1.96633,-0.159094,0.67837,-1.99589,-0.204389,0.721606,-2.06224,0.090355,1.29766,-1.79431,0.101425,1.29619,-2.00926},
/*973*/{0.195045,1.85136,-1.6871,0.263008,1.7974,-1.84224,0.115989,1.7057,-1.58498,0.070614,1.59586,-1.51269,0.227505,1.56879,-1.55378,0.317025,1.54902,-1.55832,0.183175,1.88558,-2.08339,0.268906,1.80451,-1.92037,0.057267,1.85686,-1.9843,-0.032451,1.73411,-2.12937,-0.035752,1.64948,-2.21529,0.099271,1.49232,-2.18789,0.12998,1.43835,-2.20947,0.159549,1.39034,-1.76721,-0.028959,1.43744,-1.86188,-0.02142,1.46414,-1.91437,-0.021148,1.43242,-1.97306,0.177299,1.3936,-2.03881,0.164279,1.07941,-1.71543,0.036624,1.05109,-1.76638,0.056907,0.968206,-1.78665,0.143136,0.859485,-1.76501,0.106821,0.673247,-1.77195,0.083292,0.603848,-1.7903,0.001746,0.710209,-1.78542,-0.020713,0.641968,-1.79788,-0.051564,0.427492,-1.83004,-0.16296,0.367545,-1.90961,0.093269,0.382799,-1.8659,0.064131,0.336256,-1.79362,0.29113,1.15538,-2.09809,0.344586,1.09004,-2.0834,0.180883,1.06481,-2.07363,0.23426,1.00383,-2.05899,0.343379,0.916664,-2.05766,0.19184,0.833728,-2.03736,0.177241,0.944352,-2.06429,0.107962,0.932526,-2.05759,-0.115916,0.871754,-2.02424,-0.208526,0.93821,-1.96826,-0.13241,0.666136,-1.99758,-0.179762,0.707319,-2.06455,0.089535,1.29817,-1.79489,0.101369,1.29781,-2.00981},
/*974*/{0.196537,1.85277,-1.68815,0.263066,1.79904,-1.84337,0.121182,1.70658,-1.58495,0.080371,1.59493,-1.51168,0.237278,1.57307,-1.55679,0.32703,1.55611,-1.56396,0.180248,1.88765,-2.08363,0.268033,1.80597,-1.92083,0.055486,1.8579,-1.98333,-0.035999,1.73952,-2.12652,-0.042038,1.65563,-2.21392,0.09206,1.49713,-2.18728,0.12191,1.44368,-2.2095,0.158501,1.39059,-1.76616,-0.027922,1.43845,-1.8617,-0.021088,1.46536,-1.91449,-0.020908,1.43395,-1.97418,0.17739,1.39671,-2.03845,0.156102,1.07776,-1.71691,0.027901,1.05271,-1.76672,0.044878,0.970321,-1.78941,0.124651,0.854989,-1.76714,0.090772,0.672358,-1.77325,0.067101,0.603243,-1.79099,-0.014831,0.709965,-1.78549,-0.0369,0.643355,-1.7989,-0.072464,0.42845,-1.83046,-0.183578,0.367943,-1.91037,0.073591,0.383365,-1.86493,0.044054,0.336844,-1.79308,0.296918,1.16399,-2.09775,0.352629,1.09939,-2.0829,0.189884,1.07083,-2.07459,0.244167,1.01136,-2.05993,0.357178,0.926097,-2.05834,0.208112,0.837432,-2.03875,0.18854,0.946416,-2.06536,0.119972,0.93208,-2.05891,-0.101122,0.860515,-2.02549,-0.19877,0.920076,-1.96943,-0.10369,0.655107,-2.00122,-0.152702,0.693426,-2.06623,0.089244,1.29863,-1.79573,0.102207,1.30017,-2.01057},
/*975*/{0.198107,1.8554,-1.68931,0.262023,1.80103,-1.84462,0.125859,1.70764,-1.58564,0.090875,1.59484,-1.51119,0.245903,1.5781,-1.56053,0.336841,1.56392,-1.56936,0.17778,1.88989,-2.08355,0.266177,1.80815,-1.9222,0.053939,1.8605,-1.98231,-0.040621,1.74449,-2.12601,-0.048396,1.66198,-2.21302,0.083842,1.50106,-2.18655,0.113656,1.44863,-2.20896,0.158766,1.39103,-1.76516,-0.027129,1.43985,-1.86176,-0.020611,1.46604,-1.91431,-0.021014,1.43447,-1.97421,0.177388,1.39959,-2.03851,0.145574,1.07448,-1.71859,0.019031,1.05492,-1.76783,0.033679,0.971118,-1.78807,0.107802,0.85505,-1.76805,0.07457,0.67228,-1.77427,0.048165,0.602703,-1.79183,-0.031353,0.710787,-1.78689,-0.054934,0.64428,-1.79904,-0.092261,0.429212,-1.83091,-0.204042,0.369143,-1.91042,0.052212,0.383233,-1.86522,0.022469,0.336414,-1.79318,0.302266,1.17314,-2.09694,0.358982,1.11136,-2.08304,0.197935,1.07731,-2.07441,0.254137,1.01926,-2.06018,0.369214,0.936711,-2.05846,0.222769,0.840355,-2.03957,0.19845,0.950308,-2.06645,0.130963,0.931242,-2.05892,-0.083678,0.848451,-2.02595,-0.188376,0.901293,-1.97134,-0.0754,0.643244,-2.00321,-0.127202,0.677759,-2.06973,0.089919,1.29936,-1.79615,0.103063,1.30206,-2.01097},
/*976*/{0.199574,1.85856,-1.69003,0.262076,1.8042,-1.84539,0.132068,1.70874,-1.58519,0.101128,1.59528,-1.511,0.255238,1.58375,-1.56438,0.344932,1.5723,-1.57552,0.174581,1.89265,-2.0836,0.265385,1.81135,-1.92396,0.05211,1.86164,-1.98142,-0.046723,1.75038,-2.12563,-0.054685,1.66849,-2.2123,0.076949,1.50731,-2.18606,0.106399,1.45429,-2.20779,0.158811,1.39168,-1.76507,-0.02708,1.4407,-1.86225,-0.019702,1.46718,-1.91369,-0.019841,1.43655,-1.97446,0.178228,1.402,-2.03815,0.137337,1.07444,-1.71996,0.007764,1.05549,-1.76758,0.023329,0.973967,-1.78879,0.088944,0.856173,-1.76945,0.058091,0.672811,-1.77621,0.031139,0.603656,-1.79371,-0.047701,0.713197,-1.78766,-0.072331,0.646427,-1.80011,-0.112084,0.430124,-1.83058,-0.224874,0.37165,-1.90989,0.031577,0.382892,-1.86583,0.001696,0.33666,-1.79391,0.307438,1.1817,-2.0963,0.365295,1.12131,-2.08211,0.204943,1.08234,-2.07453,0.263214,1.02608,-2.06032,0.380524,0.949038,-2.05888,0.23794,0.844287,-2.04144,0.207868,0.952253,-2.06656,0.141654,0.930447,-2.05993,-0.071563,0.83739,-2.02993,-0.177573,0.88136,-1.97178,-0.047481,0.632061,-2.00586,-0.101436,0.662794,-2.07193,0.090224,1.29997,-1.79689,0.104171,1.30428,-2.01163},
/*977*/{0.200649,1.86279,-1.69139,0.26127,1.80708,-1.84716,0.138072,1.71087,-1.58547,0.109723,1.59604,-1.51105,0.262563,1.58996,-1.56893,0.353576,1.58102,-1.58214,0.171753,1.89563,-2.08392,0.264471,1.81413,-1.92505,0.050178,1.86345,-1.97991,-0.052532,1.7564,-2.12575,-0.060637,1.6741,-2.21151,0.07004,1.51292,-2.18538,0.098441,1.46003,-2.20692,0.159224,1.39261,-1.76529,-0.026625,1.44238,-1.86274,-0.020278,1.4689,-1.91327,-0.019092,1.43846,-1.97509,0.178862,1.40545,-2.03749,0.130214,1.0742,-1.72196,-0.000599,1.05922,-1.76721,0.009278,0.977751,-1.78882,0.073149,0.858901,-1.77162,0.039215,0.673877,-1.77736,0.010707,0.605471,-1.79484,-0.064606,0.715754,-1.78915,-0.089991,0.650158,-1.80064,-0.132673,0.431506,-1.83097,-0.245872,0.373851,-1.90888,0.011219,0.382822,-1.86584,-0.018394,0.336771,-1.79279,0.311294,1.19009,-2.09643,0.37097,1.1321,-2.08211,0.211468,1.08789,-2.07358,0.270945,1.03307,-2.05964,0.390905,0.961012,-2.05848,0.252728,0.848081,-2.04303,0.216341,0.954243,-2.06671,0.15151,0.928273,-2.06022,-0.052642,0.821204,-2.02745,-0.165742,0.860895,-1.97345,-0.018565,0.622662,-2.00901,-0.074909,0.648411,-2.07429,0.090678,1.30115,-1.79784,0.105231,1.30719,-2.0125},
/*978*/{0.20187,1.86603,-1.69238,0.261035,1.81097,-1.84872,0.144341,1.71323,-1.58655,0.119478,1.59729,-1.5112,0.271266,1.5956,-1.57272,0.360375,1.58996,-1.58887,0.167862,1.89895,-2.08385,0.263478,1.81798,-1.92638,0.047908,1.86542,-1.97795,-0.058397,1.76209,-2.12612,-0.066791,1.68046,-2.21067,0.06333,1.51969,-2.18443,0.091636,1.46633,-2.20564,0.160178,1.39277,-1.76465,-0.024389,1.44409,-1.86237,-0.0186,1.47059,-1.9126,-0.018026,1.44052,-1.97449,0.180048,1.40865,-2.03673,0.122737,1.07362,-1.72355,-0.008917,1.06702,-1.76623,-0.001658,0.982995,-1.78865,0.055829,0.861456,-1.77353,0.021536,0.676389,-1.77812,-0.006295,0.60862,-1.79593,-0.082155,0.719175,-1.79094,-0.108167,0.653453,-1.80184,-0.153457,0.433428,-1.83076,-0.265575,0.377603,-1.90928,-0.009025,0.382833,-1.86601,-0.039912,0.336508,-1.79398,0.314682,1.1977,-2.09624,0.375807,1.14136,-2.08093,0.218035,1.09325,-2.07257,0.27939,1.03979,-2.05876,0.401027,0.973212,-2.05941,0.266529,0.851396,-2.04475,0.224778,0.955858,-2.06636,0.160948,0.926977,-2.06007,-0.036585,0.808342,-2.02966,-0.15258,0.839805,-1.97415,0.009548,0.611215,-2.01097,-0.047881,0.634149,-2.07683,0.091866,1.30184,-1.79839,0.106721,1.30988,-2.01296},
/*979*/{0.203285,1.87029,-1.69347,0.261599,1.8148,-1.85069,0.151573,1.71604,-1.58659,0.129143,1.5997,-1.51161,0.278478,1.60291,-1.57746,0.367259,1.59964,-1.59567,0.164752,1.9023,-2.08364,0.262132,1.82131,-1.92817,0.046235,1.86786,-1.97748,-0.062695,1.7689,-2.12731,-0.072832,1.68613,-2.20979,0.056974,1.52649,-2.1833,0.085201,1.4733,-2.20407,0.16104,1.39399,-1.76456,-0.024266,1.44651,-1.8627,-0.017846,1.47204,-1.91146,-0.016246,1.44326,-1.97494,0.181012,1.41203,-2.03559,0.114792,1.07505,-1.72479,-0.017625,1.07304,-1.7678,-0.012812,0.98731,-1.7885,0.043326,0.86445,-1.77463,0.003479,0.678834,-1.77921,-0.024953,0.611477,-1.79584,-0.099955,0.722866,-1.79136,-0.126727,0.657545,-1.8042,-0.17161,0.436064,-1.83,-0.285559,0.382208,-1.90987,-0.028752,0.382173,-1.8662,-0.061482,0.336945,-1.79472,0.31867,1.20567,-2.09573,0.381484,1.1514,-2.07938,0.223379,1.09894,-2.07327,0.285885,1.04745,-2.05845,0.410026,0.984186,-2.05959,0.280177,0.854949,-2.04691,0.232512,0.956628,-2.06604,0.170149,0.923988,-2.06039,-0.020026,0.793255,-2.02975,-0.138079,0.81807,-1.97492,0.038314,0.601584,-2.01408,-0.021297,0.62071,-2.0791,0.092525,1.3033,-1.79891,0.108163,1.31296,-2.01336},
/*980*/{0.203583,1.87442,-1.69444,0.260539,1.81764,-1.85135,0.158736,1.71872,-1.58749,0.137304,1.6016,-1.51234,0.284941,1.60976,-1.58187,0.373393,1.60915,-1.60245,0.16148,1.90625,-2.08356,0.261482,1.8251,-1.92948,0.044488,1.86953,-1.97525,-0.066582,1.77483,-2.12723,-0.079072,1.69178,-2.20873,0.050312,1.53342,-2.18158,0.078602,1.48012,-2.20259,0.162477,1.39451,-1.76424,-0.022052,1.44833,-1.86222,-0.015265,1.47441,-1.9109,-0.015152,1.44671,-1.97536,0.182691,1.41531,-2.03477,0.108678,1.07584,-1.72751,-0.023989,1.07747,-1.76616,-0.023023,0.99232,-1.78782,0.029261,0.868465,-1.7759,-0.014554,0.682276,-1.77929,-0.043905,0.614409,-1.79548,-0.117376,0.727705,-1.79236,-0.144484,0.66259,-1.80447,-0.191837,0.440533,-1.83065,-0.30481,0.388253,-1.90902,-0.048687,0.380955,-1.8661,-0.082368,0.337334,-1.79534,0.321391,1.21315,-2.09559,0.385795,1.15938,-2.07929,0.228734,1.10467,-2.07269,0.291843,1.05443,-2.0599,0.416583,0.994654,-2.06087,0.292802,0.857737,-2.05018,0.24018,0.956687,-2.0615,0.179954,0.920144,-2.05931,-0.003931,0.780402,-2.03196,-0.123473,0.795346,-1.97517,0.067349,0.592162,-2.01733,0.005516,0.607429,-2.08182,0.093726,1.30435,-1.79984,0.109815,1.31618,-2.01415},
/*981*/{0.205091,1.87909,-1.69587,0.260744,1.82181,-1.85281,0.165563,1.72187,-1.58826,0.14679,1.60474,-1.51298,0.290057,1.61668,-1.58652,0.378731,1.6186,-1.60878,0.158754,1.90981,-2.08315,0.260457,1.82834,-1.93156,0.042711,1.87311,-1.97519,-0.071954,1.78082,-2.12833,-0.084714,1.69757,-2.208,0.044224,1.54055,-2.17954,0.07332,1.48729,-2.20112,0.163999,1.39519,-1.76371,-0.020377,1.4517,-1.86233,-0.015414,1.47722,-1.91101,-0.013367,1.45029,-1.97544,0.184012,1.41882,-2.03374,0.102725,1.07724,-1.72953,-0.030046,1.08269,-1.76619,-0.032685,0.99841,-1.78724,0.016902,0.87243,-1.77755,-0.032196,0.687452,-1.77968,-0.06148,0.619383,-1.79551,-0.13424,0.732995,-1.79442,-0.162572,0.667841,-1.80485,-0.209844,0.444753,-1.82977,-0.323672,0.395226,-1.90897,-0.0686,0.380238,-1.86651,-0.102276,0.337485,-1.79535,0.324796,1.22062,-2.09519,0.38956,1.16763,-2.07864,0.234039,1.11023,-2.07227,0.297179,1.0613,-2.05959,0.423497,1.00513,-2.05976,0.306956,0.862082,-2.05147,0.246556,0.957341,-2.06561,0.188401,0.917073,-2.05917,0.004887,0.765274,-2.03225,-0.107192,0.773035,-1.97612,0.096668,0.581542,-2.02064,0.033379,0.594425,-2.08464,0.094139,1.30609,-1.80059,0.110965,1.31967,-2.01473},
/*982*/{0.20548,1.88381,-1.69787,0.261634,1.82658,-1.85468,0.172635,1.72532,-1.58942,0.154302,1.60775,-1.51362,0.296519,1.62472,-1.59128,0.383283,1.62842,-1.61584,0.155811,1.91337,-2.08287,0.259395,1.83293,-1.93204,0.043461,1.87413,-1.97293,-0.076984,1.78722,-2.1298,-0.089959,1.70344,-2.20769,0.038437,1.54749,-2.17703,0.067536,1.49456,-2.19952,0.164618,1.39634,-1.76364,-0.019367,1.45392,-1.86214,-0.013111,1.47959,-1.90917,-0.011312,1.45395,-1.97594,0.18592,1.42241,-2.03242,0.098311,1.07871,-1.73137,-0.03618,1.08851,-1.76517,-0.040495,1.00425,-1.78603,0.00407,0.876858,-1.7779,-0.049082,0.693424,-1.7801,-0.07968,0.626054,-1.79559,-0.150813,0.739389,-1.79467,-0.178857,0.674912,-1.80667,-0.227652,0.449313,-1.82909,-0.341626,0.403553,-1.90876,-0.087787,0.37897,-1.86706,-0.123166,0.337604,-1.79662,0.328226,1.22749,-2.09427,0.393481,1.17513,-2.07784,0.238147,1.11661,-2.07232,0.301864,1.06607,-2.05855,0.427996,1.01473,-2.0598,0.31711,0.863826,-2.05302,0.252656,0.956221,-2.06447,0.197206,0.913259,-2.05941,0.026913,0.753149,-2.034,-0.091235,0.753228,-1.97787,0.125915,0.573355,-2.02413,0.060818,0.582823,-2.08752,0.094964,1.30747,-1.80127,0.11282,1.32331,-2.01518},
/*983*/{0.206532,1.88931,-1.69918,0.261695,1.83106,-1.85679,0.179103,1.72913,-1.59047,0.162249,1.612,-1.51453,0.300199,1.63117,-1.59599,0.387054,1.63753,-1.62224,0.15339,1.91738,-2.08227,0.258987,1.83741,-1.93353,0.042592,1.87547,-1.97192,-0.079223,1.79371,-2.13081,-0.094573,1.70923,-2.20594,0.033079,1.55487,-2.17457,0.063686,1.50055,-2.19656,0.166538,1.3968,-1.76423,-0.017765,1.45789,-1.86197,-0.01106,1.48281,-1.90871,-0.008842,1.45834,-1.97608,0.18668,1.4253,-2.0309,0.092283,1.08115,-1.73292,-0.040008,1.09415,-1.7639,-0.049383,1.01038,-1.78578,-0.009694,0.882387,-1.77832,-0.065372,0.699616,-1.77926,-0.09647,0.632474,-1.79443,-0.166174,0.746541,-1.79559,-0.195187,0.68187,-1.80676,-0.244448,0.455902,-1.82856,-0.359621,0.412561,-1.90828,-0.106524,0.377652,-1.86725,-0.14441,0.337999,-1.79642,0.331327,1.23361,-2.09406,0.39688,1.18202,-2.07735,0.241384,1.12247,-2.07328,0.305742,1.07287,-2.05859,0.430332,1.02296,-2.05888,0.32731,0.865547,-2.0545,0.258489,0.95433,-2.0638,0.205867,0.909353,-2.05943,0.044141,0.740552,-2.0391,-0.072953,0.728226,-1.98095,0.155504,0.565607,-2.02862,0.088708,0.570897,-2.09048,0.095249,1.30919,-1.80212,0.113444,1.32669,-2.01587},
/*984*/{0.206689,1.89347,-1.70043,0.261718,1.83532,-1.85866,0.1843,1.73355,-1.59161,0.169179,1.6158,-1.51607,0.304507,1.63874,-1.60006,0.390135,1.64662,-1.62912,0.151166,1.92121,-2.08227,0.25846,1.84133,-1.93563,0.042211,1.87876,-1.97031,-0.084204,1.79982,-2.13252,-0.09937,1.71462,-2.20411,0.027485,1.56216,-2.17276,0.058652,1.50732,-2.19509,0.167997,1.39788,-1.76537,-0.014642,1.46126,-1.86161,-0.009634,1.48658,-1.90851,-0.007612,1.46319,-1.97665,0.188513,1.42898,-2.02972,0.087291,1.0838,-1.73435,-0.046106,1.09798,-1.76301,-0.056644,1.01775,-1.78675,-0.024229,0.888563,-1.77805,-0.08035,0.70631,-1.7781,-0.110986,0.638717,-1.79373,-0.181159,0.754277,-1.79619,-0.210519,0.689729,-1.80732,-0.261811,0.461788,-1.82823,-0.376037,0.422985,-1.90792,-0.1263,0.377048,-1.86759,-0.165559,0.338359,-1.79701,0.333341,1.24044,-2.09379,0.399811,1.18882,-2.07607,0.244609,1.12844,-2.07314,0.309003,1.07929,-2.05735,0.432994,1.03022,-2.05819,0.339361,0.868149,-2.05647,0.265336,0.95306,-2.06321,0.215392,0.903837,-2.05891,0.067878,0.724345,-2.03478,-0.05241,0.705439,-1.97623,0.183589,0.559362,-2.03256,0.117385,0.560741,-2.09384,0.096038,1.3112,-1.80353,0.114561,1.33085,-2.01707},
/*985*/{0.207532,1.89918,-1.7018,0.262087,1.83959,-1.85962,0.189417,1.73818,-1.59358,0.176036,1.62073,-1.51698,0.307904,1.64565,-1.60427,0.393028,1.65501,-1.6371,0.149307,1.92453,-2.082,0.257921,1.84553,-1.93701,0.041387,1.88216,-1.96892,-0.08658,1.80586,-2.13363,-0.103898,1.72006,-2.20275,0.023255,1.56909,-2.17039,0.054597,1.51438,-2.19329,0.169843,1.39872,-1.76612,-0.013186,1.46506,-1.86118,-0.007902,1.49043,-1.90748,-0.005541,1.46796,-1.97635,0.189939,1.43234,-2.02822,0.08317,1.08641,-1.73633,-0.048777,1.10656,-1.76295,-0.063236,1.02438,-1.78514,-0.038338,0.895347,-1.77794,-0.094123,0.713697,-1.7777,-0.125635,0.646526,-1.79271,-0.19444,0.762263,-1.79696,-0.224281,0.69735,-1.80724,-0.278621,0.467925,-1.82618,-0.391879,0.434889,-1.9067,-0.145634,0.37652,-1.86736,-0.186327,0.338558,-1.79731,0.335992,1.24569,-2.09265,0.40132,1.1945,-2.07521,0.247757,1.13236,-2.07395,0.312474,1.08485,-2.05645,0.433547,1.03656,-2.05749,0.349026,0.86964,-2.05759,0.27046,0.950766,-2.06299,0.223327,0.89857,-2.05843,0.085787,0.709738,-2.03659,-0.033581,0.68265,-1.97729,0.212796,0.553272,-2.03598,0.146021,0.550568,-2.0967,0.096456,1.31317,-1.80443,0.115297,1.33487,-2.01774},
/*986*/{0.208586,1.90398,-1.7038,0.261532,1.84372,-1.86132,0.193894,1.74239,-1.59492,0.180612,1.62422,-1.51764,0.310662,1.65289,-1.60875,0.394166,1.66375,-1.64247,0.147721,1.92788,-2.08207,0.256987,1.85017,-1.93773,0.039808,1.88487,-1.9676,-0.088922,1.8113,-2.13391,-0.10798,1.72557,-2.20126,0.018375,1.57603,-2.16804,0.049454,1.52137,-2.19211,0.171718,1.40027,-1.76677,-0.011872,1.46953,-1.86103,-0.006222,1.49463,-1.90689,-0.003715,1.4732,-1.97732,0.19192,1.43579,-2.02734,0.078737,1.08737,-1.7373,-0.053785,1.11045,-1.76206,-0.068194,1.03096,-1.78444,-0.051042,0.902514,-1.77796,-0.106761,0.721171,-1.77672,-0.139206,0.653718,-1.79104,-0.206728,0.770445,-1.79726,-0.236692,0.705865,-1.80671,-0.293305,0.474646,-1.8237,-0.407055,0.447409,-1.90633,-0.165351,0.376031,-1.86707,-0.206314,0.339931,-1.7974,0.33721,1.2508,-2.09256,0.403154,1.1997,-2.07381,0.249317,1.13829,-2.07392,0.312828,1.09063,-2.0585,0.434923,1.0438,-2.05633,0.359616,0.87081,-2.05855,0.275851,0.946624,-2.06229,0.231359,0.892136,-2.05849,0.102508,0.694867,-2.03768,-0.012148,0.659931,-1.9772,0.242268,0.547971,-2.0385,0.175523,0.541481,-2.09925,0.096782,1.31588,-1.80548,0.116206,1.33911,-2.01858},
/*987*/{0.209723,1.90913,-1.70559,0.2626,1.84853,-1.86321,0.197997,1.74737,-1.59699,0.186995,1.62939,-1.51888,0.312415,1.65984,-1.61335,0.395552,1.6721,-1.64888,0.145919,1.9309,-2.08222,0.257184,1.85436,-1.93939,0.040045,1.88794,-1.967,-0.092029,1.81729,-2.13477,-0.112309,1.73096,-2.19884,0.014316,1.58201,-2.1656,0.045434,1.52742,-2.1901,0.172496,1.40074,-1.76786,-0.00985,1.47373,-1.86175,-0.004224,1.49873,-1.90553,-0.00138,1.47803,-1.97689,0.192533,1.4393,-2.02673,0.075153,1.09184,-1.73801,-0.057117,1.11831,-1.7623,-0.073289,1.03769,-1.78569,-0.061272,0.909994,-1.7784,-0.117305,0.728204,-1.77599,-0.151576,0.661121,-1.79034,-0.217114,0.778172,-1.79733,-0.247934,0.714637,-1.80643,-0.307618,0.482446,-1.82227,-0.421066,0.460623,-1.9054,-0.183326,0.375734,-1.86704,-0.227907,0.341026,-1.79756,0.33857,1.2552,-2.09112,0.404963,1.20394,-2.07278,0.250626,1.1426,-2.07342,0.313615,1.0955,-2.05871,0.433571,1.04797,-2.05668,0.368023,0.870932,-2.05935,0.280726,0.942337,-2.06199,0.239346,0.885299,-2.0583,0.118148,0.679938,-2.03925,0.009746,0.637415,-1.97834,0.269659,0.543302,-2.04081,0.203969,0.533159,-2.10138,0.096603,1.31771,-1.80709,0.116349,1.34332,-2.01988},
/*988*/{0.210494,1.91348,-1.70696,0.262711,1.85179,-1.86438,0.201953,1.75163,-1.59814,0.190377,1.63422,-1.52008,0.313954,1.66615,-1.61712,0.395484,1.67989,-1.65532,0.144694,1.934,-2.08209,0.256536,1.85765,-1.94131,0.040085,1.89054,-1.96771,-0.093732,1.82106,-2.1353,-0.115948,1.73644,-2.19748,0.010934,1.58796,-2.16375,0.042718,1.53373,-2.18842,0.174258,1.40238,-1.76829,-0.00753,1.47846,-1.86067,-0.002928,1.50371,-1.90502,-6.5e-005,1.48344,-1.97729,0.193756,1.44237,-2.02604,0.072442,1.09436,-1.73757,-0.05747,1.12534,-1.76242,-0.078923,1.04371,-1.78571,-0.06894,0.917076,-1.77794,-0.12676,0.73548,-1.77509,-0.160319,0.669226,-1.78895,-0.226056,0.785899,-1.79707,-0.257075,0.721982,-1.80515,-0.320015,0.489874,-1.8192,-0.434003,0.474946,-1.90386,-0.202328,0.375802,-1.8669,-0.248549,0.341866,-1.79796,0.33961,1.25916,-2.09043,0.405184,1.20746,-2.07141,0.250809,1.14715,-2.07329,0.312821,1.09914,-2.05925,0.43418,1.05186,-2.05584,0.376944,0.870309,-2.0599,0.286412,0.936946,-2.0623,0.247406,0.877874,-2.05799,0.133883,0.663951,-2.03899,0.03217,0.614268,-1.97962,0.29856,0.539836,-2.0417,0.233205,0.525869,-2.10329,0.096687,1.32077,-1.80767,0.116321,1.3474,-2.02035},
/*989*/{0.211752,1.91771,-1.70836,0.263333,1.85697,-1.86666,0.204839,1.7555,-1.59874,0.195745,1.63836,-1.52099,0.314401,1.67236,-1.62084,0.396042,1.68713,-1.66064,0.143806,1.93734,-2.0822,0.256279,1.86138,-1.94242,0.040114,1.89338,-1.96702,-0.095162,1.82699,-2.13451,-0.11944,1.74126,-2.19502,0.007078,1.59317,-2.16116,0.038833,1.53927,-2.18673,0.175206,1.4049,-1.76848,-0.006637,1.48199,-1.86072,-0.000818,1.50802,-1.90409,0.002043,1.4888,-1.97717,0.192327,1.44604,-2.02528,0.069032,1.09827,-1.7375,-0.060347,1.13097,-1.76295,-0.082449,1.05068,-1.78651,-0.074909,0.923116,-1.77813,-0.135001,0.742225,-1.77407,-0.1698,0.676233,-1.78672,-0.234011,0.793841,-1.79621,-0.265232,0.730293,-1.80463,-0.332265,0.497184,-1.81814,-0.445757,0.490668,-1.90272,-0.221758,0.376463,-1.86659,-0.270011,0.343786,-1.7979,0.340896,1.26242,-2.08869,0.405199,1.21019,-2.06977,0.249711,1.15145,-2.07371,0.312652,1.10248,-2.05897,0.43216,1.05342,-2.05628,0.384673,0.868214,-2.05996,0.290315,0.93064,-2.0623,0.25512,0.868714,-2.05692,0.160971,0.652037,-2.04091,0.054609,0.593146,-1.98152,0.326429,0.535949,-2.04216,0.262448,0.518799,-2.1042,0.096632,1.32385,-1.80825,0.11603,1.35157,-2.02081},
/*990*/{0.212551,1.92259,-1.70979,0.263982,1.86109,-1.86787,0.206871,1.76087,-1.59987,0.19814,1.64227,-1.5213,0.315637,1.67881,-1.62378,0.395628,1.69401,-1.66632,0.143222,1.94002,-2.08268,0.256942,1.86568,-1.94344,0.040259,1.89549,-1.96679,-0.096111,1.83197,-2.13335,-0.122111,1.74581,-2.19218,0.003391,1.59838,-2.15947,0.03574,1.54398,-2.18514,0.176983,1.40671,-1.76991,-0.005282,1.4866,-1.85947,-0.000753,1.51189,-1.90321,0.003743,1.49371,-1.9768,0.192529,1.4495,-2.02469,0.066626,1.1016,-1.73652,-0.06556,1.13659,-1.76605,-0.085872,1.05646,-1.7877,-0.079144,0.928968,-1.77816,-0.14133,0.748846,-1.77338,-0.176108,0.683132,-1.78501,-0.240059,0.800518,-1.79515,-0.271419,0.737822,-1.80319,-0.343539,0.505953,-1.8165,-0.455543,0.505843,-1.90076,-0.238838,0.377611,-1.86558,-0.289965,0.346082,-1.79808,0.340764,1.26507,-2.0876,0.404948,1.21186,-2.06792,0.249217,1.15497,-2.07377,0.31136,1.10521,-2.06058,0.431103,1.05474,-2.0568,0.392202,0.866357,-2.06049,0.295751,0.923673,-2.06284,0.26293,0.860037,-2.05778,0.181477,0.638086,-2.04084,0.077514,0.57316,-1.98445,0.352911,0.532474,-2.04212,0.290559,0.512239,-2.1042,0.097016,1.32672,-1.80902,0.115632,1.35576,-2.02147},
/*991*/{0.213673,1.92568,-1.71096,0.264568,1.86436,-1.86927,0.209251,1.76521,-1.60106,0.200037,1.6459,-1.5221,0.31498,1.68352,-1.62784,0.395197,1.69958,-1.67029,0.142648,1.94228,-2.0829,0.256957,1.86904,-1.94472,0.040783,1.8981,-1.96612,-0.096809,1.83586,-2.13109,-0.124406,1.75029,-2.19023,0.001496,1.60271,-2.15749,0.033686,1.54843,-2.1835,0.178245,1.40899,-1.7698,-0.003866,1.49054,-1.85963,0.000325,1.51588,-1.90213,0.005239,1.49842,-1.97601,0.192231,1.45248,-2.02466,0.063268,1.10516,-1.73562,-0.064584,1.14292,-1.76582,-0.088538,1.06238,-1.78797,-0.082496,0.933867,-1.77826,-0.147263,0.754006,-1.77183,-0.182614,0.688652,-1.78309,-0.243916,0.808162,-1.79316,-0.27814,0.744866,-1.80218,-0.353932,0.513512,-1.81422,-0.46459,0.521486,-1.89962,-0.256691,0.378683,-1.86536,-0.310151,0.350302,-1.79789,0.340443,1.26774,-2.08631,0.403604,1.21367,-2.06707,0.247101,1.15801,-2.07434,0.309159,1.10724,-2.06127,0.430476,1.05505,-2.05702,0.399333,0.863677,-2.06069,0.299006,0.916011,-2.06356,0.271185,0.850944,-2.05982,0.197867,0.62343,-2.04298,0.101104,0.552268,-1.9853,0.378234,0.529502,-2.0412,0.318683,0.505475,-2.10395,0.097174,1.32979,-1.80921,0.115254,1.35938,-2.02163},
/*992*/{0.215236,1.93011,-1.71225,0.266121,1.8686,-1.87071,0.210306,1.76899,-1.60196,0.203385,1.65031,-1.52265,0.31549,1.68816,-1.63014,0.393578,1.70442,-1.6752,0.142542,1.94489,-2.08314,0.25782,1.87213,-1.9455,0.040521,1.90083,-1.96663,-0.096221,1.84009,-2.12843,-0.126073,1.75394,-2.18828,-0.000445,1.60653,-2.15559,0.032013,1.55242,-2.18177,0.178955,1.4117,-1.77022,-0.002025,1.4938,-1.85938,0.001384,1.52024,-1.90157,0.006021,1.50334,-1.97547,0.192743,1.45585,-2.02422,0.06159,1.10881,-1.7352,-0.067886,1.14685,-1.76758,-0.089235,1.06663,-1.78931,-0.08452,0.938001,-1.77797,-0.151964,0.758817,-1.77085,-0.188831,0.694555,-1.78269,-0.248218,0.813502,-1.79137,-0.283241,0.750492,-1.80009,-0.362404,0.521856,-1.81133,-0.471978,0.539691,-1.89689,-0.274429,0.381086,-1.86457,-0.328711,0.354249,-1.79856,0.339241,1.2692,-2.08468,0.401528,1.21407,-2.06591,0.244527,1.15986,-2.07488,0.306247,1.10837,-2.06187,0.426644,1.05289,-2.05802,0.40606,0.860739,-2.0615,0.303237,0.907099,-2.06498,0.278357,0.840816,-2.0591,0.218408,0.610861,-2.04383,0.123849,0.534923,-1.98702,0.404026,0.526735,-2.03946,0.345754,0.499663,-2.10368,0.097459,1.33291,-1.80966,0.115376,1.36342,-2.02197},
/*993*/{0.215952,1.93231,-1.71358,0.266324,1.87142,-1.87193,0.210875,1.77257,-1.60242,0.203059,1.65335,-1.52386,0.314719,1.69094,-1.63303,0.392687,1.70862,-1.68011,0.14251,1.94737,-2.08379,0.258869,1.87526,-1.94662,0.041958,1.90282,-1.96648,-0.096076,1.84368,-2.1272,-0.127544,1.75738,-2.18533,-0.002139,1.6107,-2.15388,0.03056,1.55567,-2.18029,0.179724,1.4142,-1.77031,-0.000913,1.49765,-1.8585,0.001368,1.52341,-1.90107,0.006747,1.50705,-1.9746,0.193471,1.45907,-2.02445,0.060523,1.11336,-1.73494,-0.066715,1.15225,-1.76944,-0.090278,1.0714,-1.79115,-0.084733,0.94168,-1.77848,-0.154771,0.764072,-1.77051,-0.192849,0.699446,-1.78126,-0.250482,0.820572,-1.79049,-0.285725,0.759211,-1.79701,-0.370843,0.530815,-1.80898,-0.477751,0.556618,-1.894,-0.291175,0.382505,-1.86453,-0.349089,0.360223,-1.79834,0.337556,1.26959,-2.08416,0.399021,1.21386,-2.0654,0.242095,1.16137,-2.07516,0.302707,1.10845,-2.06198,0.423833,1.05091,-2.05839,0.411947,0.857715,-2.06182,0.306746,0.897698,-2.06647,0.285889,0.830808,-2.0612,0.239672,0.59815,-2.04425,0.146979,0.517307,-1.989,0.427691,0.523896,-2.03771,0.372038,0.492326,-2.10126,0.097954,1.33588,-1.80972,0.115413,1.36691,-2.02199},
/*994*/{0.218371,1.93533,-1.71457,0.267058,1.87517,-1.87307,0.211829,1.77641,-1.60298,0.204149,1.65705,-1.52418,0.313671,1.69484,-1.63622,0.390953,1.71232,-1.68399,0.142939,1.94975,-2.08446,0.259299,1.87783,-1.94738,0.041893,1.90562,-1.96637,-0.094693,1.84707,-2.12462,-0.128604,1.76101,-2.18238,-0.001683,1.61374,-2.15241,0.029594,1.55886,-2.17855,0.18062,1.41727,-1.7708,-0.000815,1.50095,-1.8584,0.002385,1.52698,-1.9007,0.007958,1.51124,-1.97431,0.192767,1.46199,-2.02395,0.060345,1.11519,-1.73404,-0.067714,1.15536,-1.76987,-0.089585,1.07365,-1.79188,-0.084723,0.94471,-1.77919,-0.156967,0.767666,-1.77016,-0.196988,0.703391,-1.78028,-0.251065,0.825832,-1.78798,-0.288975,0.764813,-1.79552,-0.377431,0.539592,-1.80605,-0.482835,0.574731,-1.88994,-0.309669,0.385957,-1.86426,-0.369384,0.366548,-1.79944,0.336256,1.26918,-2.08358,0.396793,1.21273,-2.06508,0.238517,1.16223,-2.07537,0.299473,1.10887,-2.06105,0.420671,1.04804,-2.05895,0.417804,0.853193,-2.06218,0.310398,0.888125,-2.06748,0.292943,0.820087,-2.06204,0.257335,0.585414,-2.0454,0.169545,0.501092,-1.99019,0.450349,0.521959,-2.03511,0.396696,0.485617,-2.09959,0.098075,1.3391,-1.80976,0.115152,1.37027,-2.02204},
/*995*/{0.218932,1.93851,-1.7159,0.267461,1.87753,-1.87441,0.212218,1.77974,-1.60328,0.204878,1.65903,-1.52408,0.31237,1.69751,-1.637,0.388969,1.71453,-1.68787,0.143678,1.95226,-2.08482,0.259508,1.88052,-1.9482,0.042882,1.90818,-1.96597,-0.094317,1.84981,-2.12339,-0.128751,1.76408,-2.17981,-0.001384,1.61562,-2.15045,0.030506,1.55989,-2.17673,0.181894,1.42005,-1.77149,0.00024,1.50431,-1.85754,0.002761,1.53019,-1.89999,0.007727,1.51462,-1.97403,0.191688,1.4646,-2.02408,0.060636,1.11794,-1.73451,-0.067118,1.1565,-1.77138,-0.089223,1.07647,-1.79259,-0.082393,0.947031,-1.77958,-0.158493,0.771416,-1.76928,-0.200563,0.708394,-1.77905,-0.251129,0.831565,-1.78679,-0.289932,0.771661,-1.79139,-0.385094,0.548536,-1.80369,-0.486677,0.592835,-1.88472,-0.326287,0.390926,-1.86544,-0.388011,0.373131,-1.80129,0.334122,1.26787,-2.08262,0.394117,1.2098,-2.06502,0.234494,1.16284,-2.07555,0.294291,1.10777,-2.06162,0.416247,1.04502,-2.0592,0.424113,0.849313,-2.061,0.313788,0.879153,-2.06998,0.298996,0.809312,-2.0641,0.275736,0.572838,-2.04607,0.192695,0.485546,-1.98966,0.472508,0.519958,-2.03296,0.42106,0.479374,-2.09669,0.098627,1.34218,-1.8096,0.114133,1.37311,-2.02204},
/*996*/{0.221218,1.94034,-1.71672,0.269079,1.88048,-1.87561,0.212515,1.78287,-1.60412,0.20556,1.66219,-1.52506,0.311455,1.6988,-1.63962,0.386793,1.71689,-1.69142,0.144366,1.9542,-2.08519,0.260719,1.88274,-1.94882,0.043875,1.91096,-1.96617,-0.093035,1.85234,-2.12114,-0.129084,1.76677,-2.17764,-0.001697,1.6171,-2.14831,0.030322,1.56259,-2.17509,0.18237,1.42308,-1.77149,0.000744,1.50721,-1.85686,0.002441,1.53319,-1.8997,0.007577,1.51798,-1.97294,0.19155,1.46753,-2.02364,0.061398,1.12077,-1.73468,-0.063777,1.16017,-1.77085,-0.087963,1.07828,-1.79312,-0.079383,0.94816,-1.78,-0.15864,0.774045,-1.76946,-0.201241,0.712311,-1.77806,-0.250376,0.837732,-1.78496,-0.290866,0.778372,-1.78922,-0.389842,0.55944,-1.8015,-0.488955,0.610987,-1.87897,-0.343715,0.397714,-1.86785,-0.405118,0.382031,-1.80351,0.330891,1.26564,-2.08253,0.390037,1.20692,-2.06507,0.229588,1.16139,-2.07563,0.288682,1.10586,-2.06283,0.411441,1.04096,-2.06002,0.427567,0.845362,-2.06089,0.3163,0.870068,-2.07162,0.305269,0.799562,-2.06631,0.293829,0.562511,-2.04703,0.213866,0.471649,-1.99101,0.491661,0.51701,-2.03021,0.445051,0.473626,-2.09356,0.098934,1.34519,-1.80921,0.1139,1.37619,-2.02168},
/*997*/{0.222109,1.94209,-1.71809,0.268875,1.88268,-1.87647,0.212065,1.78546,-1.60424,0.205543,1.6642,-1.52472,0.310889,1.70096,-1.64125,0.385977,1.71752,-1.69466,0.144933,1.95579,-2.08585,0.261065,1.88467,-1.94969,0.045978,1.91291,-1.9672,-0.091338,1.85518,-2.1197,-0.128328,1.7687,-2.17522,-0.001046,1.61845,-2.14668,0.030521,1.56344,-2.17348,0.183411,1.42569,-1.77143,0.001378,1.50988,-1.85623,0.001968,1.53632,-1.8983,0.009316,1.51899,-1.97077,0.191383,1.47036,-2.02388,0.064672,1.12309,-1.73567,-0.063003,1.15681,-1.77071,-0.084465,1.07886,-1.7931,-0.075023,0.948851,-1.78056,-0.157865,0.777044,-1.76934,-0.20251,0.716954,-1.77822,-0.2484,0.843182,-1.78297,-0.289848,0.785105,-1.78673,-0.400156,0.567396,-1.79902,-0.491136,0.628313,-1.86967,-0.36062,0.405877,-1.87141,-0.42092,0.390043,-1.80705,0.328144,1.26261,-2.08218,0.386018,1.20208,-2.06468,0.225124,1.16071,-2.07662,0.281965,1.1038,-2.06371,0.406406,1.03645,-2.06043,0.431307,0.841914,-2.06071,0.318246,0.859882,-2.07395,0.311647,0.789712,-2.06838,0.311594,0.552883,-2.04742,0.2342,0.458508,-1.99036,0.510851,0.514251,-2.02623,0.467247,0.46778,-2.08942,0.100225,1.34771,-1.80847,0.114045,1.37866,-2.02102},
/*998*/{0.223483,1.94384,-1.71897,0.269652,1.88479,-1.87742,0.212144,1.78784,-1.60504,0.205364,1.66567,-1.52489,0.310186,1.70188,-1.64397,0.383801,1.71777,-1.69725,0.146028,1.95746,-2.08626,0.261961,1.88632,-1.95027,0.04698,1.91505,-1.96716,-0.090099,1.85599,-2.11722,-0.12692,1.76998,-2.17317,2.9e-005,1.62001,-2.14521,0.032367,1.56469,-2.17186,0.184201,1.42824,-1.77113,0.001865,1.51192,-1.85548,0.002327,1.53923,-1.89778,0.009333,1.52144,-1.97006,0.191698,1.47307,-2.02395,0.069532,1.12306,-1.73724,-0.059915,1.1572,-1.76978,-0.080868,1.0784,-1.79287,-0.070603,0.948568,-1.78119,-0.156858,0.779907,-1.76961,-0.204159,0.720548,-1.77848,-0.245049,0.847942,-1.78111,-0.288994,0.790879,-1.78564,-0.397694,0.576678,-1.7958,-0.493157,0.645879,-1.8602,-0.378673,0.415226,-1.87587,-0.438572,0.400825,-1.8099,0.324089,1.25862,-2.08234,0.38103,1.19685,-2.06475,0.219724,1.15836,-2.07718,0.275817,1.10083,-2.06453,0.400437,1.03162,-2.06103,0.433154,0.838172,-2.06029,0.320876,0.850623,-2.07666,0.317463,0.78008,-2.07031,0.327546,0.542326,-2.04733,0.253433,0.44721,-1.99031,0.528778,0.513101,-2.02344,0.486584,0.463231,-2.08588,0.101023,1.3502,-1.8082,0.114289,1.38133,-2.02075},
/*999*/{0.224923,1.94518,-1.72021,0.270114,1.88631,-1.87884,0.211609,1.78977,-1.60543,0.204928,1.6679,-1.52604,0.30772,1.70146,-1.6453,0.382215,1.71746,-1.69948,0.148318,1.95871,-2.08738,0.2633,1.88711,-1.95096,0.047943,1.91761,-1.96832,-0.088812,1.85758,-2.11464,-0.125704,1.77074,-2.17123,0.001413,1.61998,-2.14286,0.031703,1.56649,-2.17153,0.185104,1.43079,-1.77136,0.001534,1.51385,-1.85508,0.002175,1.54111,-1.89732,0.008848,1.52284,-1.96882,0.191354,1.47515,-2.02408,0.073911,1.12273,-1.73758,-0.053533,1.15781,-1.76951,-0.076142,1.0769,-1.79187,-0.064697,0.947865,-1.78246,-0.154113,0.78106,-1.76974,-0.203064,0.72271,-1.77832,-0.240438,0.852591,-1.77883,-0.286584,0.796765,-1.78373,-0.402808,0.587376,-1.79467,-0.495335,0.662543,-1.85087,-0.393918,0.427786,-1.88102,-0.451808,0.413469,-1.8126,0.320146,1.25445,-2.08217,0.376172,1.19123,-2.06507,0.2138,1.15629,-2.07814,0.268586,1.09702,-2.06587,0.394388,1.02593,-2.06145,0.435573,0.834584,-2.05858,0.323943,0.841126,-2.07934,0.323518,0.771312,-2.07234,0.342467,0.534342,-2.04777,0.270597,0.441617,-1.9854,0.544223,0.511595,-2.01996,0.506047,0.458619,-2.08151,0.101877,1.35243,-1.80768,0.114057,1.3832,-2.02036},
/*1000*/{0.225577,1.94602,-1.72125,0.270293,1.88761,-1.8794,0.211281,1.79148,-1.60615,0.204113,1.66901,-1.52648,0.30623,1.70158,-1.647,0.381107,1.71617,-1.70117,0.149398,1.95917,-2.08776,0.263614,1.88777,-1.95148,0.050689,1.91894,-1.96975,-0.087733,1.85776,-2.11316,-0.124195,1.771,-2.16894,0.003353,1.62008,-2.1412,0.034391,1.56506,-2.17111,0.185642,1.43273,-1.77095,0.001607,1.51493,-1.85441,0.001792,1.54253,-1.89681,0.008117,1.52408,-1.96771,0.19066,1.47693,-2.02365,0.079656,1.12226,-1.73973,-0.051171,1.15399,-1.76824,-0.070574,1.07476,-1.79271,-0.057514,0.94689,-1.78301,-0.15117,0.781664,-1.77131,-0.203397,0.725808,-1.77901,-0.235669,0.856642,-1.77797,-0.283697,0.80292,-1.78081,-0.407637,0.596866,-1.79369,-0.498211,0.679581,-1.84151,-0.408593,0.441727,-1.88598,-0.463414,0.427367,-1.81515,0.316008,1.24935,-2.08272,0.370193,1.18595,-2.06587,0.20805,1.15297,-2.07851,0.261604,1.09362,-2.06637,0.38857,1.02001,-2.06172,0.437248,0.831253,-2.05685,0.326473,0.8332,-2.08237,0.328834,0.762913,-2.07462,0.357844,0.527857,-2.04732,0.285968,0.431532,-1.9926,0.558762,0.510766,-2.0148,0.523485,0.455684,-2.07696,0.102467,1.35409,-1.80701,0.113821,1.38471,-2.01975},
/*1001*/{0.226619,1.94663,-1.72191,0.270364,1.88817,-1.88029,0.210365,1.79225,-1.60688,0.201849,1.66982,-1.52715,0.305084,1.70037,-1.64813,0.378803,1.71331,-1.70355,0.151514,1.96019,-2.08919,0.263783,1.88852,-1.95264,0.051558,1.92098,-1.97077,-0.086374,1.85724,-2.10959,-0.122382,1.77095,-2.16834,0.005173,1.61977,-2.14037,0.03518,1.56487,-2.16965,0.185943,1.43422,-1.77116,0.001968,1.51575,-1.85228,0.001511,1.54411,-1.89667,0.008007,1.52453,-1.96714,0.190689,1.47848,-2.02347,0.085991,1.12139,-1.7417,-0.045724,1.15152,-1.7671,-0.064843,1.07361,-1.79241,-0.049822,0.943821,-1.78437,-0.148257,0.782088,-1.77272,-0.200283,0.729286,-1.78166,-0.228459,0.860384,-1.77354,-0.278697,0.809462,-1.77859,-0.410136,0.608238,-1.79264,-0.500411,0.695253,-1.83303,-0.420995,0.456867,-1.88971,-0.472108,0.441098,-1.81865,0.312229,1.2447,-2.08236,0.364823,1.1799,-2.06617,0.201731,1.15176,-2.07869,0.253905,1.08951,-2.06691,0.382502,1.01502,-2.06258,0.438561,0.827656,-2.05467,0.328952,0.82575,-2.08418,0.333634,0.756122,-2.0762,0.369348,0.521786,-2.04735,0.30105,0.420958,-1.99155,0.57066,0.510511,-2.01195,0.538201,0.453069,-2.07269,0.10323,1.35535,-1.80651,0.113804,1.38597,-2.01929},
/*1002*/{0.227436,1.94651,-1.7235,0.27008,1.88832,-1.88084,0.209437,1.79292,-1.60717,0.20102,1.67011,-1.52728,0.302529,1.69841,-1.64904,0.376609,1.71064,-1.70503,0.152448,1.96011,-2.08955,0.264038,1.8883,-1.95281,0.052761,1.92204,-1.97196,-0.085124,1.85689,-2.10824,-0.120054,1.76966,-2.16677,0.006813,1.61921,-2.1392,0.03738,1.56381,-2.16913,0.186343,1.43561,-1.77083,0.00201,1.51612,-1.85202,0.001557,1.54434,-1.89614,0.007451,1.52457,-1.96578,0.190021,1.47963,-2.0236,0.093115,1.12065,-1.74366,-0.039032,1.15117,-1.76644,-0.058615,1.06981,-1.79268,-0.041589,0.941436,-1.78519,-0.144735,0.782006,-1.77412,-0.200849,0.731719,-1.78333,-0.221596,0.863995,-1.77122,-0.273281,0.814653,-1.7746,-0.414957,0.620304,-1.791,-0.502397,0.711084,-1.82468,-0.432226,0.472891,-1.89297,-0.480758,0.456374,-1.81994,0.307501,1.23941,-2.08306,0.35939,1.17277,-2.06705,0.195656,1.14799,-2.07882,0.247309,1.08591,-2.06696,0.37634,1.00911,-2.06248,0.439246,0.824302,-2.05225,0.330204,0.819052,-2.08447,0.337152,0.749845,-2.07678,0.380627,0.516291,-2.04677,0.313256,0.415499,-1.99128,0.580085,0.509846,-2.00779,0.549262,0.451125,-2.06966,0.104135,1.35625,-1.80593,0.113763,1.38662,-2.0188},
/*1003*/{0.228011,1.94662,-1.72434,0.269638,1.88806,-1.88115,0.208433,1.79318,-1.60805,0.198531,1.67055,-1.52811,0.301574,1.69751,-1.6502,0.374618,1.7074,-1.70646,0.155072,1.95984,-2.09042,0.264388,1.88752,-1.95331,0.054214,1.92287,-1.9729,-0.082697,1.8558,-2.10616,-0.118061,1.76812,-2.166,0.009955,1.61787,-2.13848,0.039182,1.56243,-2.16855,0.187655,1.43665,-1.77094,0.002414,1.51629,-1.85139,0.001335,1.54434,-1.89543,0.007055,1.52465,-1.96476,0.190374,1.48051,-2.02322,0.102849,1.11982,-1.74762,-0.033352,1.14547,-1.76482,-0.050882,1.06594,-1.79142,-0.031668,0.939054,-1.78631,-0.140854,0.781888,-1.77607,-0.199348,0.734706,-1.78479,-0.213779,0.867785,-1.76983,-0.267652,0.821938,-1.77298,-0.415435,0.633348,-1.79059,-0.504202,0.726822,-1.81742,-0.440801,0.489062,-1.89543,-0.487736,0.471188,-1.82133,0.303765,1.23351,-2.08308,0.354239,1.16614,-2.06741,0.189691,1.14545,-2.07875,0.240405,1.08158,-2.06694,0.369702,1.00292,-2.06267,0.438597,0.821464,-2.05082,0.330009,0.813201,-2.08474,0.338871,0.743645,-2.07704,0.38948,0.511559,-2.04538,0.323686,0.410652,-1.99119,0.587858,0.509398,-2.00642,0.562174,0.450477,-2.06663,0.105576,1.35688,-1.80544,0.114289,1.38721,-2.01835},
/*1004*/{0.227765,1.94617,-1.72589,0.269968,1.88802,-1.88202,0.207022,1.79309,-1.60862,0.195341,1.66921,-1.52807,0.299652,1.69475,-1.65163,0.372633,1.70318,-1.7075,0.156136,1.95911,-2.09166,0.264743,1.88697,-1.95362,0.055024,1.92311,-1.97438,-0.082012,1.85427,-2.10419,-0.116364,1.76576,-2.16503,0.011642,1.61658,-2.13837,0.041181,1.55999,-2.16777,0.188354,1.43737,-1.77156,0.003024,1.51573,-1.85049,0.001299,1.54431,-1.89542,0.00632,1.5242,-1.9644,0.190355,1.48054,-2.02322,0.108086,1.11638,-1.74956,-0.025063,1.14234,-1.76332,-0.044021,1.06154,-1.79082,-0.022078,0.93506,-1.78746,-0.136831,0.782593,-1.7772,-0.197534,0.738092,-1.78568,-0.205911,0.871333,-1.76755,-0.262631,0.827143,-1.77181,-0.41937,0.646686,-1.78986,-0.504799,0.742721,-1.81235,-0.448839,0.50541,-1.89597,-0.495128,0.487277,-1.82093,0.300276,1.22809,-2.084,0.349429,1.15991,-2.06835,0.186834,1.1409,-2.07814,0.233662,1.077,-2.06646,0.363679,0.996934,-2.06292,0.435996,0.818334,-2.05015,0.328089,0.807378,-2.08371,0.338172,0.738197,-2.07567,0.393287,0.505182,-2.04493,0.332051,0.402938,-1.98836,0.596073,0.509161,-2.00365,0.569216,0.447235,-2.06505,0.106631,1.35711,-1.80515,0.114346,1.38706,-2.01815},
/*1005*/{0.227706,1.94519,-1.72662,0.269327,1.8877,-1.88281,0.205582,1.7923,-1.60926,0.194135,1.66834,-1.52801,0.296939,1.69141,-1.65212,0.370379,1.69875,-1.70812,0.157731,1.95825,-2.09257,0.265297,1.88596,-1.95357,0.056173,1.92373,-1.97636,-0.081734,1.8518,-2.10336,-0.114053,1.76303,-2.16469,0.013494,1.61371,-2.13839,0.044068,1.55791,-2.16784,0.188928,1.43763,-1.77179,0.002946,1.51443,-1.8509,0.002408,1.54428,-1.89553,0.006334,1.52283,-1.96404,0.190374,1.48051,-2.02322,0.11693,1.11484,-1.75232,-0.01951,1.13624,-1.76217,-0.035305,1.05708,-1.79049,-0.011593,0.930985,-1.78897,-0.133458,0.783567,-1.77855,-0.195305,0.742871,-1.78736,-0.198177,0.874951,-1.76665,-0.256745,0.833459,-1.77006,-0.421388,0.661136,-1.78733,-0.503771,0.760005,-1.80917,-0.45557,0.522039,-1.89558,-0.501012,0.504249,-1.81991,0.296335,1.22203,-2.08471,0.344421,1.15294,-2.06849,0.179827,1.13841,-2.07862,0.227121,1.0735,-2.06657,0.357044,0.990437,-2.06318,0.43205,0.815555,-2.05049,0.324492,0.801807,-2.08167,0.336048,0.732967,-2.07385,0.397585,0.500996,-2.04345,0.33685,0.39844,-1.98681,0.600138,0.50716,-2.00339,0.573614,0.444792,-2.06392,0.107657,1.35685,-1.80511,0.115058,1.38661,-2.01815},
/*1006*/{0.227702,1.94421,-1.72728,0.268917,1.88653,-1.88333,0.203673,1.79196,-1.61001,0.190752,1.66769,-1.52919,0.294812,1.68817,-1.65218,0.368453,1.69355,-1.70843,0.15837,1.95656,-2.09286,0.265262,1.88482,-1.95414,0.057151,1.92354,-1.97724,-0.077886,1.84917,-2.10164,-0.112274,1.75962,-2.16509,0.017183,1.61127,-2.13898,0.046575,1.5551,-2.16823,0.189563,1.43706,-1.77292,0.003865,1.5131,-1.84974,0.00246,1.54321,-1.89474,0.006946,1.52104,-1.96359,0.190481,1.48006,-2.02372,0.122806,1.11285,-1.75521,-0.011601,1.13401,-1.76114,-0.027018,1.05249,-1.78934,-0.000706,0.926775,-1.79061,-0.128515,0.785736,-1.7798,-0.19401,0.74681,-1.78769,-0.189485,0.87898,-1.76464,-0.24976,0.840441,-1.76814,-0.421589,0.675174,-1.78556,-0.501226,0.777119,-1.80798,-0.459966,0.536513,-1.89209,-0.508076,0.520326,-1.81712,0.294914,1.21657,-2.0847,0.340504,1.14689,-2.06934,0.174888,1.13496,-2.0784,0.221823,1.06875,-2.06556,0.350182,0.984514,-2.06347,0.427426,0.811933,-2.05133,0.318974,0.796047,-2.07987,0.332184,0.727066,-2.07168,0.400031,0.497299,-2.04121,0.341846,0.394771,-1.98249,0.602966,0.50539,-2.00405,0.576791,0.441492,-2.06341,0.109133,1.35581,-1.80526,0.115342,1.38583,-2.0183},
/*1007*/{0.227197,1.94306,-1.72799,0.268939,1.88572,-1.88348,0.201931,1.79055,-1.61065,0.187351,1.66571,-1.52889,0.292341,1.68468,-1.65311,0.365938,1.68833,-1.70863,0.159093,1.95455,-2.0936,0.265313,1.88315,-1.95373,0.056627,1.92139,-1.98024,-0.077145,1.84606,-2.10006,-0.110777,1.75588,-2.1654,0.019382,1.60808,-2.14006,0.049593,1.55248,-2.16839,0.190636,1.43655,-1.77339,0.003818,1.51162,-1.84946,0.002378,1.54095,-1.89524,0.006297,1.51929,-1.9637,0.190877,1.4788,-2.02386,0.131569,1.11035,-1.75699,-0.006041,1.12721,-1.76044,-0.019207,1.04759,-1.78928,0.010309,0.923027,-1.79165,-0.124236,0.788254,-1.7798,-0.19053,0.751332,-1.78689,-0.181549,0.883156,-1.76395,-0.24279,0.846718,-1.76643,-0.421025,0.691097,-1.78208,-0.497669,0.794746,-1.80782,-0.463428,0.551643,-1.88828,-0.513916,0.538718,-1.81409,0.290729,1.21096,-2.08517,0.335612,1.14094,-2.07009,0.170275,1.13151,-2.07819,0.216424,1.06477,-2.06554,0.342855,0.978678,-2.06344,0.422437,0.808042,-2.05255,0.31244,0.790189,-2.07797,0.32735,0.721593,-2.06928,0.399138,0.492145,-2.03879,0.344421,0.390466,-1.97851,0.603269,0.503051,-2.0057,0.576447,0.43846,-2.06369,0.110333,1.35482,-1.80509,0.115915,1.38425,-2.01823},
/*1008*/{0.226421,1.94075,-1.72844,0.269031,1.88429,-1.88398,0.199574,1.78919,-1.61096,0.183054,1.66462,-1.5301,0.288949,1.68016,-1.65294,0.363929,1.68218,-1.70905,0.159735,1.95247,-2.09458,0.26523,1.88145,-1.95411,0.057087,1.92154,-1.98082,-0.076074,1.84222,-2.09961,-0.108958,1.75159,-2.16657,0.022083,1.6049,-2.14084,0.052303,1.54896,-2.16886,0.191752,1.43506,-1.77435,0.004263,1.50919,-1.84881,0.002725,1.53916,-1.89458,0.006282,1.51653,-1.964,0.190957,1.47691,-2.0248,0.137983,1.10806,-1.76,0.003088,1.12307,-1.75921,-0.009896,1.04267,-1.78961,0.020151,0.918401,-1.79289,-0.118772,0.790443,-1.77938,-0.186045,0.756945,-1.78725,-0.172777,0.888426,-1.76378,-0.236216,0.854757,-1.76762,-0.420812,0.705398,-1.78139,-0.492332,0.811844,-1.8098,-0.466009,0.566116,-1.88385,-0.518678,0.556417,-1.81043,0.289522,1.20555,-2.08624,0.332079,1.13414,-2.07148,0.16727,1.12763,-2.07782,0.211615,1.06075,-2.06427,0.335486,0.972997,-2.06373,0.415888,0.803839,-2.05336,0.305761,0.784199,-2.07516,0.322107,0.716033,-2.06648,0.398121,0.488311,-2.03674,0.34476,0.385803,-1.97352,0.602881,0.498774,-2.00663,0.574447,0.434476,-2.06357,0.111723,1.35296,-1.80529,0.116022,1.38217,-2.01849},
/*1009*/{0.225931,1.93874,-1.72876,0.268188,1.88197,-1.88402,0.196921,1.78691,-1.61107,0.178697,1.66197,-1.53064,0.285861,1.67541,-1.65244,0.360862,1.67514,-1.70855,0.159732,1.94969,-2.09531,0.264665,1.87903,-1.9543,0.05751,1.92052,-1.98322,-0.075055,1.83764,-2.09989,-0.107406,1.7463,-2.1675,0.025708,1.60104,-2.14292,0.055649,1.54487,-2.16931,0.191509,1.43421,-1.77552,0.004164,1.50736,-1.84914,0.002765,1.53779,-1.89556,0.006804,1.51333,-1.96429,0.190199,1.47399,-2.02609,0.146706,1.10808,-1.76122,0.008597,1.11664,-1.75828,-0.002138,1.03772,-1.78895,0.030238,0.913774,-1.79403,-0.113005,0.794061,-1.7788,-0.181643,0.762039,-1.78493,-0.163898,0.893616,-1.76436,-0.228621,0.861756,-1.76783,-0.414791,0.713162,-1.78673,-0.486596,0.82839,-1.81195,-0.468145,0.579799,-1.87869,-0.521625,0.574643,-1.8059,0.285427,1.20081,-2.08769,0.329904,1.12861,-2.07201,0.163195,1.12517,-2.07736,0.207395,1.05607,-2.06334,0.328947,0.967375,-2.06369,0.410532,0.79933,-2.05409,0.299795,0.778424,-2.07238,0.316554,0.710806,-2.06388,0.395151,0.483356,-2.03408,0.342432,0.381905,-1.96896,0.601028,0.494473,-2.00756,0.571967,0.430298,-2.06259,0.111945,1.35169,-1.8051,0.115435,1.3792,-2.01854},
/*1010*/{0.224266,1.93648,-1.72905,0.269101,1.88047,-1.88459,0.194367,1.78458,-1.61157,0.174347,1.66009,-1.53158,0.282908,1.66985,-1.65255,0.357994,1.66747,-1.70806,0.16036,1.94652,-2.0962,0.2645,1.87706,-1.9553,0.057805,1.91786,-1.98395,-0.075141,1.83328,-2.10195,-0.106094,1.74102,-2.16927,0.027768,1.59669,-2.14419,0.059243,1.54082,-2.16946,0.192864,1.43204,-1.77657,0.004242,1.50533,-1.84891,0.00322,1.53461,-1.89578,0.006687,1.51162,-1.96518,0.191461,1.47101,-2.02738,0.151709,1.10376,-1.76241,0.01494,1.11147,-1.75761,0.005425,1.03182,-1.78698,0.040489,0.909695,-1.79446,-0.107186,0.797207,-1.77745,-0.178001,0.767702,-1.78352,-0.154893,0.898509,-1.76528,-0.219916,0.86883,-1.76626,-0.412055,0.730117,-1.78512,-0.479549,0.844293,-1.81477,-0.467679,0.592659,-1.87278,-0.52351,0.59207,-1.80156,0.28339,1.19596,-2.0896,0.325738,1.12377,-2.07331,0.160347,1.12188,-2.07599,0.203092,1.05288,-2.06319,0.323725,0.96289,-2.06414,0.404852,0.79466,-2.05483,0.293684,0.77312,-2.07031,0.310756,0.705322,-2.06151,0.391288,0.479345,-2.03177,0.336963,0.380526,-1.96654,0.596337,0.488985,-2.00777,0.565925,0.424266,-2.06254,0.112874,1.34942,-1.80563,0.115725,1.37662,-2.01912},
/*1011*/{0.22292,1.93396,-1.72889,0.268382,1.87803,-1.88468,0.191424,1.78252,-1.61138,0.169436,1.65841,-1.53268,0.279192,1.66418,-1.6521,0.355561,1.66013,-1.70692,0.160804,1.94341,-2.0967,0.264436,1.87503,-1.95532,0.05696,1.91512,-1.98713,-0.074203,1.82728,-2.10255,-0.103836,1.73492,-2.17073,0.031584,1.59189,-2.14551,0.063758,1.53613,-2.17023,0.193492,1.4301,-1.77712,0.005056,1.50189,-1.84935,0.00304,1.53154,-1.89627,0.006325,1.50777,-1.96612,0.190893,1.46827,-2.02864,0.15774,1.10328,-1.76392,0.021435,1.10463,-1.75743,0.013003,1.02577,-1.78691,0.04954,0.905418,-1.79495,-0.101135,0.800495,-1.77641,-0.172573,0.773445,-1.78148,-0.14497,0.904069,-1.76622,-0.211038,0.875737,-1.76727,-0.408561,0.74724,-1.78087,-0.471183,0.859006,-1.81774,-0.465954,0.605748,-1.86634,-0.523589,0.609588,-1.79667,0.281025,1.19177,-2.09095,0.322081,1.11966,-2.07507,0.156537,1.11903,-2.07535,0.198496,1.05041,-2.06288,0.318693,0.958638,-2.06418,0.398087,0.789284,-2.05529,0.286988,0.76779,-2.06856,0.304671,0.70049,-2.05898,0.384724,0.474326,-2.0293,0.332626,0.374035,-1.96182,0.592798,0.483336,-2.00682,0.560469,0.417653,-2.06128,0.114078,1.34697,-1.80595,0.115946,1.37335,-2.01955},
/*1012*/{0.22175,1.93084,-1.72862,0.269071,1.87513,-1.88511,0.187747,1.77965,-1.61126,0.165024,1.65571,-1.53319,0.275795,1.65866,-1.65167,0.35205,1.65199,-1.70547,0.160804,1.93959,-2.09728,0.264082,1.87199,-1.95562,0.056913,1.91231,-1.98782,-0.07293,1.8215,-2.10477,-0.101933,1.72858,-2.17295,0.035272,1.58669,-2.14683,0.067604,1.53086,-2.17105,0.194311,1.42805,-1.77825,0.005092,1.49881,-1.85029,0.002699,1.52917,-1.89652,0.006192,1.50447,-1.96645,0.191026,1.46548,-2.03011,0.164946,1.09888,-1.76339,0.027517,1.10334,-1.75852,0.022239,1.02103,-1.78704,0.059886,0.901849,-1.79519,-0.094504,0.803275,-1.77571,-0.165103,0.778114,-1.78065,-0.135457,0.908055,-1.76707,-0.202314,0.882698,-1.76756,-0.40823,0.761885,-1.77436,-0.462296,0.872943,-1.82009,-0.463332,0.618335,-1.8606,-0.521604,0.626249,-1.7922,0.277801,1.18756,-2.0927,0.318017,1.11485,-2.07686,0.153333,1.11701,-2.07449,0.194737,1.04724,-2.06191,0.314233,0.954435,-2.06405,0.392817,0.784567,-2.0553,0.281289,0.763279,-2.06716,0.298021,0.695655,-2.05729,0.377831,0.468616,-2.02674,0.325217,0.370161,-1.95729,0.585006,0.475925,-2.0064,0.553509,0.410353,-2.05764,0.114988,1.34458,-1.80659,0.116013,1.3705,-2.02026},
/*1013*/{0.22144,1.92833,-1.72801,0.267861,1.87203,-1.88494,0.184187,1.77643,-1.61085,0.159412,1.65297,-1.53494,0.271796,1.65204,-1.65142,0.348361,1.64364,-1.70418,0.160832,1.93554,-2.09887,0.263641,1.86912,-1.95597,0.05634,1.90856,-1.98979,-0.073153,1.81459,-2.10653,-0.100018,1.72183,-2.17482,0.03858,1.58088,-2.14842,0.072012,1.52578,-2.17206,0.19563,1.42583,-1.77979,0.005617,1.49568,-1.8498,0.003878,1.52547,-1.89713,0.006268,1.50066,-1.96605,0.191646,1.46269,-2.03201,0.169031,1.09783,-1.76499,0.034237,1.09822,-1.7577,0.029025,1.01644,-1.78791,0.068503,0.898873,-1.79491,-0.08737,0.807501,-1.77332,-0.158599,0.783955,-1.77827,-0.125052,0.912694,-1.769,-0.192628,0.889049,-1.7687,-0.397733,0.773774,-1.77557,-0.452901,0.885838,-1.82266,-0.459616,0.630146,-1.85459,-0.51885,0.641039,-1.78698,0.274947,1.18329,-2.09446,0.315505,1.11087,-2.07862,0.149886,1.11373,-2.07403,0.190766,1.04361,-2.06119,0.310399,0.950909,-2.06398,0.385842,0.778877,-2.05502,0.274293,0.758296,-2.06509,0.291394,0.69112,-2.05547,0.369987,0.463525,-2.02423,0.316933,0.366179,-1.95373,0.578011,0.468721,-2.00319,0.545182,0.401424,-2.05513,0.117046,1.34181,-1.80719,0.116562,1.36733,-2.02091},
/*1014*/{0.219928,1.92514,-1.72761,0.268277,1.86891,-1.88453,0.180385,1.77302,-1.61072,0.154277,1.64931,-1.53512,0.26766,1.64613,-1.65074,0.344396,1.6345,-1.70271,0.160524,1.93191,-2.10012,0.263788,1.86636,-1.956,0.055869,1.90521,-1.9913,-0.073448,1.80745,-2.10979,-0.097773,1.71406,-2.17747,0.042484,1.5749,-2.14919,0.076832,1.51985,-2.17229,0.195535,1.4233,-1.78121,0.005464,1.49198,-1.84975,0.003255,1.52229,-1.89735,0.005723,1.49707,-1.96642,0.191136,1.45984,-2.03327,0.174364,1.09586,-1.76432,0.03979,1.09389,-1.75937,0.035426,1.01174,-1.78815,0.077269,0.895953,-1.79335,-0.079358,0.810089,-1.7711,-0.153018,0.788322,-1.77625,-0.11474,0.917569,-1.77031,-0.181801,0.895844,-1.76896,-0.392164,0.78685,-1.76694,-0.443508,0.897628,-1.8248,-0.454551,0.640446,-1.84939,-0.513594,0.655893,-1.78204,0.271844,1.17923,-2.09623,0.311758,1.106,-2.08034,0.146505,1.111,-2.07364,0.187494,1.04025,-2.0613,0.307018,0.946948,-2.06347,0.380097,0.772683,-2.05435,0.268038,0.754407,-2.0651,0.284154,0.686423,-2.05429,0.360197,0.457849,-2.02253,0.306187,0.363446,-1.95029,0.568537,0.459296,-2.00133,0.535491,0.391852,-2.05112,0.117589,1.33879,-1.80797,0.116163,1.36429,-2.02169},
/*1015*/{0.218028,1.92036,-1.72716,0.268691,1.86616,-1.88414,0.177198,1.76933,-1.61032,0.14799,1.64714,-1.53629,0.262823,1.63867,-1.64944,0.341425,1.62498,-1.70096,0.160347,1.92733,-2.10085,0.263357,1.86259,-1.95609,0.054852,1.90057,-1.99341,-0.073868,1.79993,-2.11243,-0.095484,1.70693,-2.17974,0.046639,1.56896,-2.15046,0.081784,1.51423,-2.17283,0.196386,1.42012,-1.78253,0.004955,1.48828,-1.85038,0.002959,1.51844,-1.89796,0.005087,1.49272,-1.96622,0.191462,1.45611,-2.03518,0.179743,1.09376,-1.76329,0.044472,1.0884,-1.75972,0.043224,1.0064,-1.78812,0.086679,0.89399,-1.7925,-0.07202,0.813122,-1.76925,-0.144892,0.793107,-1.77489,-0.104429,0.92146,-1.77167,-0.173141,0.901362,-1.77145,-0.384335,0.798972,-1.76757,-0.43433,0.908712,-1.82634,-0.448034,0.651368,-1.84454,-0.506905,0.667593,-1.77732,0.269119,1.17438,-2.09863,0.308275,1.10106,-2.08234,0.143292,1.10774,-2.07286,0.183443,1.03741,-2.06045,0.302717,0.942557,-2.06306,0.37412,0.766911,-2.05425,0.261861,0.749874,-2.06451,0.276805,0.681521,-2.05341,0.350167,0.451149,-2.01991,0.294286,0.35937,-1.94871,0.558391,0.449425,-1.99871,0.525399,0.381987,-2.04623,0.118496,1.33536,-1.80872,0.116027,1.36043,-2.02248},
/*1016*/{0.217135,1.91647,-1.72598,0.269208,1.86203,-1.8837,0.173426,1.76547,-1.61004,0.142342,1.64285,-1.5363,0.25847,1.63169,-1.64904,0.336478,1.61558,-1.69815,0.160636,1.92283,-2.10154,0.263656,1.85921,-1.95612,0.054183,1.89591,-1.99407,-0.071242,1.79187,-2.11492,-0.092327,1.69844,-2.18256,0.050304,1.56186,-2.15145,0.086579,1.50854,-2.17353,0.1972,1.4175,-1.78375,0.005489,1.4838,-1.84985,0.003302,1.51471,-1.89803,0.003691,1.48867,-1.96649,0.189331,1.45253,-2.03664,0.186976,1.08958,-1.75986,0.048859,1.08239,-1.76159,0.049687,1.00162,-1.78883,0.094437,0.891927,-1.79086,-0.063188,0.81613,-1.76776,-0.137409,0.798922,-1.77138,-0.093054,0.925556,-1.77317,-0.162189,0.906611,-1.77129,-0.376319,0.809636,-1.76634,-0.424679,0.918142,-1.82841,-0.441303,0.660724,-1.83965,-0.499248,0.679991,-1.77326,0.266814,1.17058,-2.10027,0.305275,1.09624,-2.08496,0.14049,1.10419,-2.07221,0.180662,1.03369,-2.05999,0.298591,0.937738,-2.06291,0.36754,0.761026,-2.05384,0.255299,0.744843,-2.06397,0.269798,0.677046,-2.05343,0.340059,0.445054,-2.0195,0.2796,0.357405,-1.94742,0.547803,0.43919,-1.99446,0.513887,0.370768,-2.04096,0.119688,1.33214,-1.80916,0.114926,1.3565,-2.02296},
/*1017*/{0.215722,1.91195,-1.72563,0.268818,1.85831,-1.88426,0.169798,1.76103,-1.60992,0.135568,1.64019,-1.53701,0.253279,1.62417,-1.64788,0.331546,1.60564,-1.69631,0.16052,1.91792,-2.10224,0.264169,1.85492,-1.95668,0.053736,1.89092,-1.99652,-0.071368,1.7833,-2.1183,-0.090034,1.68996,-2.18527,0.055783,1.55547,-2.15251,0.092253,1.50245,-2.1746,0.197391,1.41464,-1.78626,0.006354,1.47977,-1.84948,0.002843,1.50986,-1.89861,0.003058,1.48418,-1.96577,0.189014,1.44901,-2.03875,0.189083,1.0892,-1.76049,0.053396,1.07837,-1.76286,0.056739,0.996883,-1.78955,0.103457,0.889684,-1.78893,-0.054412,0.819513,-1.76512,-0.126187,0.803382,-1.76787,-0.08118,0.928093,-1.77531,-0.150253,0.91123,-1.77303,-0.366286,0.817717,-1.76495,-0.415133,0.926262,-1.82822,-0.432088,0.66855,-1.83514,-0.489594,0.689716,-1.76878,0.263297,1.16574,-2.10216,0.302397,1.0915,-2.08701,0.138041,1.10042,-2.07199,0.177707,1.0293,-2.05889,0.294811,0.933193,-2.06314,0.361368,0.7548,-2.05249,0.249249,0.740752,-2.06394,0.26168,0.671881,-2.05327,0.328504,0.436532,-2.01709,0.267453,0.353019,-1.94405,0.535804,0.428141,-1.98951,0.501444,0.359586,-2.03545,0.121265,1.32853,-1.81019,0.114535,1.35264,-2.02396},
/*1018*/{0.214605,1.90705,-1.72478,0.269539,1.85395,-1.88344,0.166416,1.75622,-1.60989,0.12988,1.63477,-1.53665,0.247725,1.61724,-1.64656,0.326694,1.59655,-1.69407,0.16125,1.91347,-2.1036,0.263819,1.85071,-1.95664,0.052375,1.88593,-1.99725,-0.071363,1.77396,-2.12141,-0.086885,1.68111,-2.18838,0.061263,1.5486,-2.15331,0.097856,1.49567,-2.17493,0.198058,1.41135,-1.78771,0.006197,1.47442,-1.84969,0.00296,1.5055,-1.89893,0.002199,1.47875,-1.96533,0.188003,1.44517,-2.04105,0.195549,1.08444,-1.75603,0.057567,1.07588,-1.76512,0.063322,0.992266,-1.79001,0.112457,0.887091,-1.78711,-0.044862,0.821903,-1.76327,-0.118732,0.806994,-1.76699,-0.069243,0.930749,-1.77678,-0.140309,0.915983,-1.77488,-0.357055,0.826636,-1.76673,-0.404742,0.93484,-1.82987,-0.422968,0.676844,-1.8306,-0.479759,0.698961,-1.76471,0.260083,1.16017,-2.10406,0.300662,1.08672,-2.0887,0.135205,1.09535,-2.07141,0.175536,1.02488,-2.05916,0.290506,0.927377,-2.06289,0.354956,0.74805,-2.05214,0.241737,0.735629,-2.06453,0.253993,0.666745,-2.05331,0.316873,0.435382,-2.01693,0.248386,0.356849,-1.94369,0.522875,0.417119,-1.98495,0.485482,0.349446,-2.03149,0.122779,1.32451,-1.81111,0.114147,1.34826,-2.02485},
/*1019*/{0.213663,1.90243,-1.72416,0.269164,1.84924,-1.88267,0.163032,1.75116,-1.60952,0.122863,1.63058,-1.5375,0.242932,1.60964,-1.64616,0.321472,1.58657,-1.69123,0.160896,1.90851,-2.10496,0.264114,1.8462,-1.95688,0.051683,1.87894,-1.99971,-0.07072,1.76476,-2.12515,-0.083934,1.67171,-2.19092,0.06526,1.54136,-2.15452,0.103584,1.48924,-2.1753,0.198391,1.40796,-1.78958,0.006002,1.46938,-1.849,0.00216,1.50043,-1.89909,0.001206,1.47376,-1.96512,0.187463,1.44097,-2.04366,0.196714,1.08378,-1.75506,0.06233,1.07009,-1.76569,0.068908,0.987255,-1.79263,0.121803,0.885791,-1.78448,-0.035298,0.824445,-1.76057,-0.10874,0.809493,-1.76516,-0.057242,0.932652,-1.77833,-0.128196,0.91879,-1.77681,-0.345242,0.834272,-1.76316,-0.394291,0.941437,-1.83082,-0.412968,0.682445,-1.8271,-0.468743,0.706936,-1.7586,0.256835,1.15498,-2.10634,0.297131,1.081,-2.09034,0.131954,1.09116,-2.07158,0.171806,1.01974,-2.05837,0.285573,0.920585,-2.0622,0.347223,0.740992,-2.05055,0.235438,0.730245,-2.06409,0.245551,0.661166,-2.05302,0.302999,0.430789,-2.01624,0.228054,0.358922,-1.94484,0.507467,0.402336,-1.98001,0.466164,0.339396,-2.02746,0.124078,1.32039,-1.81206,0.113472,1.34381,-2.02575},
/*1020*/{0.212357,1.89691,-1.72329,0.269466,1.84439,-1.88288,0.15936,1.74657,-1.60967,0.116903,1.62701,-1.53773,0.237522,1.60156,-1.64511,0.315396,1.57627,-1.68852,0.160855,1.90365,-2.10576,0.26466,1.84161,-1.95672,0.049512,1.87517,-2.00058,-0.068953,1.75627,-2.12947,-0.08036,1.66229,-2.19425,0.071311,1.53453,-2.15568,0.110868,1.48265,-2.17631,0.198725,1.40348,-1.79156,0.005926,1.46459,-1.84834,0.002249,1.49482,-1.89972,5e-006,1.4683,-1.96406,0.186929,1.43656,-2.04622,0.203336,1.07983,-1.75073,0.065307,1.06527,-1.76782,0.076027,0.981586,-1.79215,0.129719,0.883745,-1.78257,-0.024092,0.82641,-1.75885,-0.097284,0.813615,-1.76215,-0.044849,0.934155,-1.77972,-0.1151,0.921759,-1.77649,-0.33246,0.842004,-1.76386,-0.383577,0.947068,-1.83138,-0.402094,0.689165,-1.8237,-0.456891,0.71371,-1.75585,0.253463,1.14942,-2.108,0.292898,1.07451,-2.09237,0.128198,1.08564,-2.0711,0.168119,1.01428,-2.05783,0.280498,0.914145,-2.06202,0.339845,0.733575,-2.04858,0.227695,0.724837,-2.06443,0.237031,0.655846,-2.05304,0.290303,0.426036,-2.01336,0.209001,0.357987,-1.94149,0.492978,0.390986,-1.96934,0.447589,0.338478,-2.02641,0.125226,1.31559,-1.81321,0.112594,1.33903,-2.02679},
/*1021*/{0.211362,1.8914,-1.72311,0.270015,1.83822,-1.88168,0.155527,1.74087,-1.60969,0.110477,1.62285,-1.53834,0.231701,1.59413,-1.6438,0.310786,1.5668,-1.68665,0.16151,1.89843,-2.10663,0.26544,1.83708,-1.95669,0.048557,1.86823,-2.00158,-0.067312,1.74638,-2.13401,-0.076268,1.65265,-2.19754,0.077395,1.52703,-2.15655,0.116971,1.47627,-2.17722,0.199341,1.39976,-1.7937,0.004327,1.4594,-1.84929,0.0009,1.48927,-1.9006,-0.000829,1.46319,-1.96418,0.185565,1.43146,-2.04875,0.204263,1.07813,-1.74979,0.070516,1.05728,-1.76814,0.082696,0.97591,-1.79251,0.140095,0.882635,-1.77986,-0.013051,0.827122,-1.75704,-0.08745,0.815138,-1.76038,-0.032251,0.934744,-1.7815,-0.10301,0.923917,-1.77813,-0.322273,0.848216,-1.76384,-0.372309,0.952242,-1.83218,-0.389785,0.69354,-1.81986,-0.44426,0.720159,-1.75135,0.249063,1.14203,-2.11118,0.288048,1.06757,-2.09459,0.123781,1.08136,-2.07046,0.162676,1.00897,-2.05746,0.275171,0.907767,-2.06253,0.332745,0.72638,-2.04649,0.221282,0.719841,-2.06393,0.227971,0.650444,-2.05257,0.269965,0.423342,-2.00548,0.185394,0.355068,-1.9406,0.469165,0.387601,-1.96438,0.423715,0.340298,-2.02676,0.125815,1.31126,-1.8144,0.111504,1.33389,-2.02796},
/*1022*/{0.211132,1.88595,-1.72188,0.271088,1.83433,-1.88137,0.15205,1.73579,-1.61049,0.104223,1.61887,-1.539,0.226525,1.58638,-1.64246,0.30384,1.55724,-1.68398,0.161691,1.89386,-2.10756,0.265782,1.83146,-1.9567,0.04798,1.86196,-2.00316,-0.065066,1.73618,-2.13816,-0.071161,1.64253,-2.20066,0.083793,1.51954,-2.15828,0.123968,1.46928,-2.17793,0.199033,1.39526,-1.79539,0.003646,1.45361,-1.84865,-0.000672,1.48302,-1.90117,-0.003095,1.45775,-1.96325,0.184811,1.42677,-2.05102,0.207727,1.07529,-1.74737,0.075659,1.05066,-1.76888,0.088922,0.97089,-1.79433,0.149239,0.88085,-1.77747,-0.001415,0.827849,-1.75557,-0.074704,0.817023,-1.75745,-0.017965,0.935632,-1.7819,-0.089571,0.925702,-1.77867,-0.309557,0.85135,-1.76459,-0.360273,0.955642,-1.83332,-0.377151,0.697347,-1.8157,-0.430586,0.724185,-1.74796,0.243751,1.13627,-2.11462,0.281906,1.06144,-2.09799,0.118681,1.07791,-2.07071,0.157222,1.0062,-2.05716,0.269851,0.900746,-2.0638,0.325064,0.717779,-2.04198,0.213269,0.714982,-2.06341,0.218163,0.645994,-2.04997,0.248448,0.424133,-1.99813,0.162278,0.353862,-1.93665,0.444544,0.388138,-1.96416,0.398821,0.341921,-2.02679,0.126378,1.30618,-1.81547,0.110333,1.32889,-2.0289},
/*1023*/{0.210166,1.88059,-1.72103,0.271594,1.82786,-1.88026,0.149076,1.73032,-1.61074,0.098945,1.61579,-1.54026,0.220021,1.57972,-1.64133,0.298883,1.54844,-1.68176,0.161878,1.88927,-2.10887,0.266179,1.82661,-1.95668,0.047618,1.85602,-2.00319,-0.062528,1.72634,-2.14331,-0.066106,1.63245,-2.20333,0.089729,1.51315,-2.16006,0.131448,1.46262,-2.17937,0.198531,1.39029,-1.79623,0.003256,1.44856,-1.848,-0.002397,1.47712,-1.90113,-0.00589,1.45371,-1.96414,0.182547,1.42118,-2.05327,0.214002,1.07037,-1.74356,0.078873,1.04707,-1.7713,0.096667,0.964377,-1.7941,0.158754,0.879413,-1.77484,0.011544,0.827402,-1.7534,-0.062924,0.817086,-1.75666,-0.004573,0.935319,-1.78248,-0.075663,0.926133,-1.77876,-0.294925,0.855854,-1.76101,-0.348639,0.95867,-1.83456,-0.363067,0.700505,-1.81169,-0.416223,0.728157,-1.74378,0.238302,1.13163,-2.11923,0.275046,1.05663,-2.10303,0.113627,1.07598,-2.0702,0.151489,1.00383,-2.05533,0.262474,0.894037,-2.06484,0.316968,0.711275,-2.03675,0.206343,0.712495,-2.06076,0.20604,0.644414,-2.04425,0.223623,0.424657,-1.99248,0.138512,0.354873,-1.93562,0.419763,0.385822,-1.96024,0.375754,0.341459,-2.02581,0.125562,1.30117,-1.81636,0.107759,1.32361,-2.02968},
/*1024*/{0.210347,1.8755,-1.72034,0.271203,1.82153,-1.8793,0.145262,1.72526,-1.61081,0.091559,1.61215,-1.54105,0.214862,1.57296,-1.64029,0.292257,1.53989,-1.67827,0.162439,1.88465,-2.11022,0.267561,1.82114,-1.95676,0.047591,1.85172,-2.00265,-0.05897,1.71615,-2.14838,-0.060444,1.62246,-2.20682,0.097343,1.50652,-2.16233,0.139235,1.45673,-2.18052,0.199354,1.38511,-1.79889,0.001323,1.44359,-1.84852,-0.003898,1.47157,-1.90041,-0.008824,1.44933,-1.96357,0.179111,1.41756,-2.05506,0.217741,1.06847,-1.7424,0.08539,1.03802,-1.77116,0.104184,0.959346,-1.79511,0.169842,0.877167,-1.77186,0.024851,0.827166,-1.75197,-0.051244,0.817814,-1.75529,0.010263,0.934738,-1.78219,-0.060842,0.925956,-1.77727,-0.282395,0.858594,-1.76236,-0.336786,0.960185,-1.83515,-0.348597,0.702339,-1.8081,-0.401046,0.732551,-1.73957,0.232087,1.12853,-2.12345,0.26891,1.05259,-2.1069,0.108917,1.07494,-2.06813,0.146682,1.00234,-2.05394,0.254344,0.88922,-2.06485,0.307828,0.708937,-2.03302,0.196554,0.714436,-2.05536,0.193857,0.646952,-2.03904,0.204011,0.426466,-1.98845,0.11646,0.35508,-1.93109,0.399709,0.382233,-1.95912,0.35187,0.341608,-2.02454,0.125473,1.29604,-1.81858,0.104861,1.31969,-2.03152},
/*1025*/{0.209536,1.87036,-1.71999,0.273291,1.81559,-1.87892,0.141577,1.72068,-1.61124,0.084917,1.60954,-1.54289,0.209191,1.56675,-1.63912,0.285679,1.53227,-1.67559,0.163247,1.8806,-2.11153,0.26856,1.81616,-1.95645,0.0484,1.8485,-2.0018,-0.053456,1.7066,-2.1543,-0.053167,1.61263,-2.20965,0.105524,1.49992,-2.16443,0.1477,1.45022,-2.18188,0.198177,1.38019,-1.80157,-0.001545,1.43828,-1.84852,-0.00624,1.46578,-1.90029,-0.01165,1.44535,-1.96483,0.176392,1.41483,-2.05733,0.222783,1.06485,-1.74041,0.090767,1.0329,-1.77278,0.112468,0.953679,-1.79576,0.181002,0.874417,-1.76941,0.037215,0.826252,-1.75082,-0.038752,0.820407,-1.75412,0.023925,0.933183,-1.78219,-0.047152,0.925961,-1.77664,-0.268616,0.860438,-1.76116,-0.324368,0.960563,-1.83661,-0.333635,0.703536,-1.80471,-0.385138,0.733536,-1.73636,0.227719,1.12571,-2.12483,0.265378,1.05074,-2.1083,0.105572,1.07374,-2.06798,0.143203,1.00156,-2.05365,0.250049,0.888659,-2.06471,0.296115,0.707477,-2.03099,0.184819,0.718601,-2.05078,0.178727,0.649966,-2.03559,0.18608,0.427223,-1.98475,0.09408,0.355724,-1.92765,0.376305,0.382499,-1.95737,0.330338,0.342449,-2.02261,0.12442,1.29084,-1.8215,0.102386,1.31652,-2.03406},
/*1026*/{0.209724,1.86598,-1.71919,0.273614,1.80921,-1.87776,0.138215,1.71661,-1.6123,0.077486,1.6068,-1.54421,0.202926,1.56135,-1.63792,0.279551,1.52525,-1.67317,0.163997,1.8767,-2.1132,0.270063,1.81101,-1.95622,0.048888,1.84688,-2.00121,-0.048006,1.69769,-2.16133,-0.045951,1.60229,-2.21204,0.113426,1.49343,-2.1659,0.156552,1.4449,-2.18324,0.197912,1.37595,-1.8037,-0.003427,1.43381,-1.84846,-0.008383,1.46078,-1.89979,-0.015176,1.44135,-1.96442,0.174001,1.41183,-2.05924,0.227286,1.06378,-1.73985,0.097267,1.02654,-1.77205,0.120888,0.948257,-1.79594,0.193171,0.872883,-1.76747,0.051008,0.825,-1.74967,-0.024991,0.819544,-1.75399,0.038397,0.932268,-1.78075,-0.033038,0.925618,-1.77636,-0.25435,0.861264,-1.76193,-0.311866,0.96008,-1.8374,-0.316802,0.70331,-1.80078,-0.36821,0.734055,-1.73321,0.224311,1.12491,-2.12474,0.26171,1.05021,-2.1069,0.101631,1.0719,-2.06779,0.139775,1.00066,-2.05365,0.246589,0.889105,-2.06386,0.283936,0.705744,-2.0319,0.171726,0.72269,-2.04784,0.164297,0.654728,-2.03314,0.16431,0.427516,-1.98115,0.071672,0.357375,-1.92644,0.355722,0.38064,-1.95582,0.308507,0.343019,-2.02127,0.123948,1.28647,-1.82337,0.099811,1.31319,-2.03557},
/*1027*/{0.209507,1.862,-1.71816,0.275848,1.80502,-1.87781,0.134797,1.71379,-1.61306,0.071037,1.60482,-1.54556,0.196425,1.55632,-1.63694,0.273395,1.51859,-1.67059,0.164709,1.87332,-2.11401,0.270558,1.80662,-1.95562,0.049139,1.84468,-2.00073,-0.039921,1.68795,-2.16692,-0.037078,1.59307,-2.21437,0.122323,1.48771,-2.16731,0.165735,1.44022,-2.18401,0.196559,1.37179,-1.806,-0.005955,1.42908,-1.849,-0.010113,1.45737,-1.89962,-0.018321,1.43799,-1.9633,0.17064,1.40976,-2.06081,0.231232,1.06419,-1.73914,0.103119,1.02163,-1.77266,0.130208,0.944063,-1.79671,0.207341,0.871673,-1.7659,0.065441,0.823846,-1.74855,-0.010935,0.817716,-1.75272,0.053212,0.931835,-1.77916,-0.018501,0.925727,-1.77506,-0.239689,0.861762,-1.76133,-0.30071,0.958169,-1.83884,-0.300154,0.701543,-1.79771,-0.352033,0.733097,-1.73006,0.219859,1.12419,-2.12356,0.257747,1.04947,-2.10667,0.097917,1.06751,-2.06691,0.137661,0.995827,-2.05163,0.244716,0.889762,-2.06207,0.27027,0.70504,-2.03421,0.158363,0.724908,-2.04612,0.150115,0.656765,-2.03177,0.147867,0.428777,-1.97854,0.05089,0.358501,-1.92367,0.333957,0.379838,-1.95349,0.285392,0.34288,-2.02009,0.122556,1.28219,-1.82575,0.096651,1.31085,-2.03749},
/*1028*/{0.208765,1.85874,-1.71722,0.275393,1.80101,-1.87613,0.130121,1.71187,-1.61399,0.063622,1.60448,-1.54694,0.190481,1.55257,-1.63543,0.266259,1.51404,-1.66839,0.166316,1.87084,-2.11423,0.27112,1.80382,-1.95501,0.049718,1.843,-2.00047,-0.035197,1.68076,-2.17278,-0.026191,1.58456,-2.21724,0.132331,1.48259,-2.1694,0.176502,1.43557,-2.18483,0.194707,1.36756,-1.8078,-0.008139,1.42529,-1.84857,-0.012158,1.45595,-1.89894,-0.020707,1.4356,-1.96125,0.168659,1.40879,-2.06268,0.236882,1.06638,-1.73917,0.109694,1.02097,-1.77242,0.140446,0.943382,-1.79454,0.220256,0.87036,-1.766,0.078539,0.822369,-1.7484,0.004511,0.815381,-1.75491,0.067025,0.931309,-1.77701,-0.004556,0.925333,-1.77412,-0.226266,0.860659,-1.75916,-0.289751,0.954813,-1.83946,-0.282247,0.698983,-1.79502,-0.334043,0.730634,-1.72722,0.215977,1.12387,-2.12272,0.253173,1.04837,-2.10659,0.093381,1.06689,-2.06665,0.132584,0.995142,-2.05186,0.243009,0.890453,-2.06083,0.25699,0.703653,-2.03674,0.145961,0.72543,-2.04637,0.135331,0.656574,-2.03024,0.125572,0.430208,-1.98046,0.029044,0.359147,-1.92258,0.312392,0.378608,-1.95309,0.264134,0.343113,-2.01961,0.120692,1.27831,-1.82807,0.093537,1.30986,-2.03924},
/*1029*/{0.208907,1.8559,-1.71603,0.275342,1.79859,-1.87548,0.126171,1.71067,-1.61444,0.05577,1.60535,-1.54963,0.184186,1.54956,-1.63491,0.25914,1.5085,-1.6661,0.168131,1.86857,-2.11362,0.270827,1.80141,-1.95441,0.050418,1.84138,-2.00111,-0.028092,1.67392,-2.17609,-0.016751,1.57757,-2.2184,0.142545,1.47929,-2.17048,0.18715,1.43284,-2.18555,0.19324,1.36464,-1.81081,-0.010595,1.42268,-1.84708,-0.013779,1.45684,-1.89891,-0.02196,1.43471,-1.95952,0.166311,1.40808,-2.06443,0.238773,1.06906,-1.73977,0.116831,1.02056,-1.77147,0.150086,0.943008,-1.79286,0.234772,0.869259,-1.76624,0.093885,0.822069,-1.74819,0.018281,0.815088,-1.75413,0.080746,0.931419,-1.77564,0.009965,0.924888,-1.77282,-0.211151,0.857498,-1.75846,-0.279804,0.95087,-1.8398,-0.263532,0.695946,-1.79251,-0.316349,0.725953,-1.7246,0.211101,1.12133,-2.12266,0.247925,1.04558,-2.10691,0.088863,1.06597,-2.06586,0.127672,0.99365,-2.05067,0.240493,0.890346,-2.05879,0.243772,0.700905,-2.03789,0.132847,0.725066,-2.04675,0.12157,0.655762,-2.03009,0.108739,0.429294,-1.97676,0.00669,0.358613,-1.92445,0.291265,0.378351,-1.95298,0.241693,0.342947,-2.019,0.118672,1.27578,-1.83033,0.089869,1.30971,-2.04092},
/*1030*/{0.209566,1.85305,-1.71489,0.274874,1.79696,-1.87493,0.121253,1.71042,-1.61518,0.048892,1.60742,-1.55165,0.177312,1.54714,-1.63422,0.252447,1.50477,-1.66278,0.170512,1.8672,-2.113,0.272112,1.79984,-1.953,0.050447,1.84083,-2.00139,-0.0199,1.66774,-2.17858,-0.007058,1.57187,-2.21911,0.153942,1.47686,-2.17135,0.198851,1.43079,-2.18611,0.189385,1.36193,-1.811,-0.011532,1.42185,-1.84629,-0.015742,1.45634,-1.89909,-0.023613,1.43493,-1.95808,0.164384,1.40769,-2.06652,0.246908,1.07429,-1.73887,0.126349,1.02017,-1.76918,0.161229,0.94366,-1.79056,0.251257,0.870001,-1.7673,0.107306,0.822314,-1.74813,0.032311,0.81482,-1.75441,0.094226,0.932038,-1.77388,0.022624,0.924769,-1.77191,-0.198591,0.856739,-1.76104,-0.270224,0.945158,-1.84,-0.243971,0.691088,-1.78987,-0.297427,0.720612,-1.7225,0.205395,1.11857,-2.12301,0.241777,1.04203,-2.10663,0.082536,1.06776,-2.06649,0.12023,0.992605,-2.04944,0.23312,0.887816,-2.05869,0.231866,0.696223,-2.0375,0.121558,0.724451,-2.04772,0.107778,0.657179,-2.03078,0.085802,0.428318,-1.97795,-0.015562,0.361366,-1.92315,0.268709,0.377579,-1.95313,0.220255,0.342706,-2.01921,0.115444,1.2737,-1.83168,0.086544,1.30967,-2.04191},
/*1031*/{0.210195,1.85236,-1.71434,0.274455,1.7956,-1.8739,0.11782,1.71093,-1.61566,0.041714,1.60921,-1.55319,0.170426,1.54668,-1.63292,0.245379,1.50293,-1.66084,0.172196,1.86612,-2.11224,0.272198,1.79849,-1.95267,0.051253,1.83969,-2.00179,-0.012856,1.66351,-2.17951,0.002287,1.56803,-2.2199,0.164364,1.47512,-2.17134,0.2103,1.43008,-2.18611,0.188694,1.35929,-1.81085,-0.012568,1.42216,-1.84476,-0.016642,1.45599,-1.89885,-0.024083,1.43541,-1.95644,0.162641,1.40737,-2.06795,0.254481,1.08045,-1.73845,0.135037,1.02122,-1.76759,0.1718,0.945581,-1.78917,0.265941,0.874118,-1.76794,0.121036,0.823725,-1.74735,0.04653,0.814662,-1.75325,0.106277,0.933904,-1.77258,0.036573,0.92491,-1.77075,-0.185705,0.853567,-1.76097,-0.261241,0.937579,-1.84069,-0.223793,0.686553,-1.78803,-0.276301,0.713083,-1.72014,0.200107,1.11524,-2.12328,0.235536,1.03879,-2.1066,0.076482,1.06656,-2.06577,0.113284,0.991271,-2.04908,0.223541,0.883493,-2.05931,0.219649,0.691263,-2.03565,0.110319,0.722089,-2.04925,0.09455,0.656865,-2.03225,0.066933,0.430023,-1.97795,-0.036657,0.361945,-1.92409,0.247626,0.377698,-1.95384,0.197586,0.34218,-2.01946,0.113608,1.27221,-1.83239,0.083912,1.30967,-2.04225},
/*1032*/{0.209865,1.85104,-1.71413,0.273483,1.79458,-1.87306,0.112775,1.71235,-1.61644,0.036323,1.61281,-1.5555,0.164553,1.54665,-1.63202,0.239443,1.5011,-1.65824,0.174712,1.86554,-2.11187,0.272279,1.79715,-1.95094,0.051678,1.83908,-2.00214,-0.006785,1.66055,-2.1802,0.010999,1.56561,-2.22081,0.176019,1.47505,-2.17189,0.222345,1.43106,-2.18557,0.18625,1.35741,-1.81086,-0.014211,1.42226,-1.8448,-0.017763,1.45576,-1.89878,-0.025831,1.4362,-1.95605,0.161254,1.40695,-2.06869,0.26253,1.08609,-1.73928,0.143149,1.02276,-1.76673,0.182853,0.948095,-1.78801,0.280598,0.879989,-1.76851,0.134771,0.825278,-1.74932,0.060254,0.814873,-1.75521,0.117968,0.935668,-1.77055,0.047591,0.925169,-1.76988,-0.173461,0.848201,-1.7617,-0.25258,0.92931,-1.8403,-0.20229,0.680323,-1.78711,-0.256021,0.70531,-1.7181,0.195225,1.11202,-2.12368,0.22904,1.03441,-2.10665,0.071524,1.06367,-2.06394,0.105517,0.988447,-2.04924,0.213028,0.878635,-2.05932,0.205444,0.687536,-2.03441,0.098744,0.7197,-2.05031,0.080463,0.654677,-2.03339,0.045783,0.430453,-1.97819,-0.057971,0.36143,-1.92569,0.225645,0.376262,-1.95234,0.176751,0.342389,-2.0212,0.1107,1.27102,-1.83316,0.081389,1.30977,-2.04284},
/*1033*/{0.210026,1.85073,-1.71393,0.274007,1.79385,-1.87207,0.108295,1.71426,-1.61652,0.027955,1.61703,-1.55745,0.158298,1.54628,-1.6304,0.233168,1.50063,-1.65557,0.176509,1.86558,-2.11117,0.272574,1.79682,-1.95022,0.052255,1.83996,-2.0035,-0.000408,1.65831,-2.18035,0.019049,1.56327,-2.22131,0.186924,1.47501,-2.17074,0.234189,1.43326,-2.18449,0.184412,1.35704,-1.81103,-0.014811,1.42291,-1.84482,-0.019082,1.45597,-1.89952,-0.025765,1.43699,-1.95662,0.160333,1.40677,-2.06911,0.267985,1.09315,-1.74077,0.152344,1.02323,-1.76507,0.193808,0.952758,-1.7874,0.294874,0.886939,-1.76885,0.149159,0.828281,-1.74961,0.075591,0.815284,-1.75503,0.129276,0.937965,-1.76963,0.058976,0.925549,-1.7689,-0.156507,0.842167,-1.76115,-0.243711,0.919363,-1.83982,-0.180273,0.673582,-1.78674,-0.233357,0.696141,-1.71712,0.189709,1.11005,-2.12309,0.22132,1.03074,-2.10644,0.06493,1.06308,-2.06529,0.096664,0.988165,-2.05089,0.203648,0.874064,-2.05915,0.19263,0.682684,-2.03323,0.086598,0.717408,-2.05073,0.066275,0.653044,-2.03451,0.02272,0.430177,-1.97984,-0.0808,0.361596,-1.92619,0.204585,0.376881,-1.9538,0.15405,0.341579,-2.02081,0.108913,1.27095,-1.83351,0.080165,1.30993,-2.04322},
/*1034*/{0.209166,1.85103,-1.71347,0.273292,1.79283,-1.87107,0.103878,1.71687,-1.61759,0.02215,1.62179,-1.55932,0.151946,1.54845,-1.62923,0.226385,1.50095,-1.65297,0.179182,1.86621,-2.11096,0.272967,1.7968,-1.94939,0.053879,1.84021,-2.00478,0.005618,1.65637,-2.17985,0.027435,1.56159,-2.2219,0.197806,1.47696,-2.17033,0.245937,1.43692,-2.18312,0.182266,1.35636,-1.80849,-0.016244,1.42442,-1.84607,-0.019641,1.45598,-1.90006,-0.02588,1.43751,-1.95785,0.15857,1.40647,-2.06988,0.275348,1.10077,-1.7414,0.161975,1.02916,-1.76398,0.204678,0.95832,-1.7869,0.307033,0.893882,-1.76997,0.162146,0.8307,-1.75024,0.087517,0.817236,-1.75655,0.13912,0.939925,-1.76954,0.068433,0.925495,-1.76824,-0.142403,0.834569,-1.76182,-0.235491,0.908157,-1.83911,-0.15747,0.666638,-1.78651,-0.210931,0.686633,-1.71541,0.184329,1.10844,-2.12332,0.214458,1.02787,-2.10635,0.057006,1.06387,-2.06702,0.088838,0.98825,-2.05278,0.192127,0.87032,-2.05838,0.177178,0.678127,-2.03177,0.073693,0.715136,-2.05137,0.051388,0.65074,-2.03505,0.003518,0.430786,-1.9809,-0.101253,0.362878,-1.9264,0.183654,0.376507,-1.95466,0.13334,0.341683,-2.02136,0.106275,1.27108,-1.83302,0.078948,1.30958,-2.04301},
/*1035*/{0.208136,1.85207,-1.71316,0.272118,1.79375,-1.87022,0.099872,1.71994,-1.61764,0.01548,1.62585,-1.56165,0.145493,1.55016,-1.62801,0.219647,1.50215,-1.65197,0.181425,1.86734,-2.11086,0.273242,1.79738,-1.94823,0.055027,1.84116,-2.00582,0.009819,1.65522,-2.17908,0.035757,1.56065,-2.22255,0.20726,1.47998,-2.16873,0.256908,1.4416,-2.18134,0.180428,1.35819,-1.80772,-0.016479,1.42507,-1.84694,-0.019838,1.45731,-1.90141,-0.026219,1.43861,-1.95919,0.160461,1.40577,-2.07006,0.281416,1.10769,-1.74234,0.16827,1.03326,-1.76413,0.21431,0.963554,-1.78615,0.320584,0.90156,-1.77014,0.175983,0.834429,-1.75179,0.103115,0.816458,-1.75589,0.148872,0.942388,-1.76882,0.079276,0.925767,-1.76779,-0.128042,0.826545,-1.76434,-0.225846,0.895712,-1.83904,-0.13396,0.659164,-1.78644,-0.187363,0.676232,-1.71506,0.178756,1.10503,-2.12268,0.206599,1.02505,-2.10589,0.049442,1.06479,-2.06849,0.078919,0.98775,-2.05368,0.179775,0.866653,-2.05741,0.16138,0.674513,-2.03065,0.058138,0.712711,-2.05112,0.036268,0.648968,-2.03514,-0.018829,0.43117,-1.98076,-0.122623,0.36437,-1.92729,0.161238,0.376193,-1.95549,0.110531,0.341513,-2.02285,0.105185,1.27242,-1.83217,0.079721,1.30951,-2.04265},
/*1036*/{0.206193,1.85314,-1.71241,0.272494,1.79408,-1.86897,0.094556,1.72403,-1.61836,0.009023,1.63082,-1.56307,0.140423,1.5535,-1.62701,0.212939,1.50466,-1.64968,0.184686,1.86921,-2.11052,0.273553,1.79863,-1.94712,0.056107,1.8416,-2.00685,0.014685,1.65451,-2.17826,0.042786,1.56107,-2.22236,0.217194,1.48612,-2.16742,0.267781,1.44803,-2.17924,0.178587,1.35976,-1.80576,-0.018059,1.42631,-1.84861,-0.020548,1.45845,-1.90315,-0.025743,1.43874,-1.96085,0.160059,1.40538,-2.07076,0.287755,1.11637,-1.74315,0.180917,1.03881,-1.76163,0.225703,0.969523,-1.78486,0.332242,0.909926,-1.77051,0.1898,0.837354,-1.75231,0.116889,0.817387,-1.75757,0.158304,0.944846,-1.76742,0.088508,0.925032,-1.76751,-0.113759,0.81833,-1.76488,-0.216481,0.882467,-1.83876,-0.110983,0.651428,-1.78696,-0.163348,0.665761,-1.7142,0.172879,1.10284,-2.12222,0.198682,1.02202,-2.10515,0.041963,1.06523,-2.0701,0.069462,0.988062,-2.05511,0.16554,0.862917,-2.05665,0.145778,0.670811,-2.02694,0.042441,0.711189,-2.05076,0.018693,0.648379,-2.03562,-0.038086,0.432686,-1.98125,-0.142795,0.364258,-1.92713,0.140004,0.375795,-1.95605,0.090287,0.341704,-2.0225,0.103554,1.27391,-1.83121,0.07987,1.30909,-2.04223},
/*1037*/{0.204339,1.85525,-1.71191,0.271985,1.79549,-1.86768,0.090526,1.72755,-1.61906,0.002119,1.63535,-1.5643,0.132818,1.5566,-1.62577,0.206901,1.50751,-1.64857,0.186118,1.87181,-2.1101,0.273993,1.79997,-1.94552,0.056902,1.84186,-2.00851,0.018842,1.65473,-2.17737,0.049857,1.56208,-2.22288,0.226513,1.49194,-2.16554,0.277722,1.45543,-2.17646,0.177252,1.36213,-1.80494,-0.018996,1.42782,-1.85003,-0.020598,1.45892,-1.90472,-0.026152,1.44001,-1.96284,0.162134,1.40542,-2.07039,0.29435,1.12579,-1.74273,0.187813,1.04348,-1.7616,0.233823,0.976029,-1.78488,0.343377,0.918787,-1.77151,0.202801,0.841712,-1.75257,0.13248,0.817798,-1.75809,0.166681,0.947045,-1.76777,0.098329,0.924054,-1.76607,-0.09973,0.80933,-1.76449,-0.206395,0.868072,-1.83892,-0.086994,0.643225,-1.78716,-0.139021,0.65542,-1.7145,0.166661,1.10084,-2.12158,0.189417,1.01979,-2.10403,0.035025,1.06705,-2.07114,0.059933,0.988483,-2.05624,0.150548,0.859913,-2.05635,0.129401,0.670047,-2.02663,0.026843,0.71061,-2.05033,0.002003,0.647461,-2.03497,-0.060126,0.43325,-1.9816,-0.164212,0.367306,-1.92685,0.11954,0.375825,-1.95612,0.069063,0.341826,-2.02269,0.10278,1.27576,-1.83042,0.081316,1.3094,-2.04193},
/*1038*/{0.202401,1.8573,-1.7112,0.271308,1.79739,-1.86611,0.084995,1.73218,-1.61953,-0.003628,1.64028,-1.5656,0.127795,1.56185,-1.62583,0.200609,1.51112,-1.64715,0.18797,1.87431,-2.10885,0.273673,1.80162,-1.94431,0.05812,1.84402,-2.00965,0.0233,1.65413,-2.17587,0.057275,1.56379,-2.22306,0.233867,1.49797,-2.16339,0.287387,1.46395,-2.17355,0.175866,1.36478,-1.80341,-0.019345,1.42943,-1.85278,-0.020073,1.46054,-1.90658,-0.02552,1.44096,-1.96516,0.163384,1.40543,-2.07034,0.298585,1.1335,-1.74331,0.194959,1.04964,-1.76178,0.242713,0.982691,-1.78398,0.354142,0.928445,-1.77197,0.215671,0.844191,-1.75398,0.144959,0.817406,-1.75872,0.174881,0.948796,-1.76672,0.107035,0.923297,-1.76615,-0.086291,0.801371,-1.76527,-0.19583,0.852327,-1.84036,-0.062197,0.635491,-1.78736,-0.115653,0.644047,-1.71429,0.161067,1.09861,-2.11966,0.180888,1.01724,-2.10267,0.02712,1.06859,-2.07229,0.049078,0.989474,-2.05669,0.13472,0.85763,-2.05504,0.111307,0.669467,-2.02678,0.009602,0.711787,-2.05031,-0.01621,0.648494,-2.03556,-0.078544,0.435222,-1.98063,-0.185956,0.368346,-1.92844,0.097893,0.375401,-1.95616,0.048056,0.341646,-2.02361,0.101928,1.27801,-1.82956,0.082853,1.30957,-2.04161},
/*1039*/{0.199235,1.8606,-1.7105,0.271628,1.79938,-1.86491,0.080718,1.73697,-1.61975,-0.010223,1.64599,-1.56681,0.122014,1.56617,-1.62491,0.194312,1.5157,-1.64511,0.191808,1.87818,-2.10822,0.274619,1.80434,-1.94263,0.059931,1.84529,-2.01139,0.028041,1.65583,-2.17365,0.063207,1.56602,-2.22367,0.241665,1.50549,-2.1609,0.296529,1.47361,-2.17044,0.174276,1.36833,-1.80262,-0.019365,1.43106,-1.85397,-0.019942,1.46195,-1.90818,-0.025281,1.44301,-1.96664,0.163761,1.40529,-2.07019,0.302677,1.14204,-1.74422,0.200886,1.05539,-1.7619,0.250844,0.989741,-1.78499,0.363585,0.93825,-1.77295,0.228615,0.848427,-1.75495,0.159563,0.819437,-1.7595,0.182747,0.950368,-1.76655,0.116658,0.921053,-1.76565,-0.069286,0.790556,-1.76584,-0.184251,0.836052,-1.84084,-0.038486,0.627783,-1.78808,-0.091115,0.633427,-1.71477,0.154054,1.0978,-2.11813,0.172198,1.01539,-2.10001,0.018978,1.07128,-2.07315,0.039264,0.991647,-2.05733,0.11792,0.857097,-2.05509,0.094362,0.669466,-2.02464,-0.007807,0.713483,-2.04924,-0.03498,0.649436,-2.03338,-0.096513,0.43668,-1.98114,-0.206884,0.369187,-1.93011,0.077053,0.375669,-1.95734,0.026573,0.34165,-2.02311,0.101203,1.28072,-1.82837,0.083457,1.30994,-2.04087},
/*1040*/{0.196553,1.86378,-1.7098,0.2707,1.80298,-1.86305,0.075772,1.74134,-1.62014,-0.016949,1.65065,-1.56822,0.115739,1.57104,-1.62439,0.188566,1.52039,-1.64411,0.193295,1.8812,-2.10711,0.275145,1.80749,-1.94096,0.060786,1.8479,-2.01268,0.03244,1.6573,-2.17287,0.069102,1.56893,-2.224,0.250298,1.51501,-2.15816,0.305017,1.4831,-2.16685,0.1734,1.37039,-1.80019,-0.019424,1.43329,-1.85589,-0.019771,1.46423,-1.91034,-0.024283,1.44557,-1.96915,0.165663,1.40539,-2.06959,0.306371,1.15027,-1.74456,0.208754,1.06026,-1.76175,0.258986,0.997188,-1.78593,0.373054,0.948408,-1.77283,0.24048,0.851559,-1.75468,0.173135,0.819849,-1.75966,0.189395,0.951487,-1.76564,0.125186,0.919059,-1.76561,-0.054356,0.782019,-1.76656,-0.171892,0.819112,-1.84166,-0.013489,0.619871,-1.78852,-0.066699,0.622586,-1.7152,0.147714,1.09615,-2.11652,0.162784,1.01352,-2.09786,0.010301,1.07474,-2.07401,0.027855,0.993782,-2.05826,0.101166,0.85689,-2.05366,0.075585,0.669804,-2.02402,-0.02542,0.715827,-2.04808,-0.053569,0.6526,-2.03292,-0.116554,0.438438,-1.98165,-0.227539,0.370348,-1.93118,0.056622,0.375908,-1.95702,0.005378,0.342074,-2.02302,0.099669,1.28306,-1.82737,0.084955,1.3107,-2.04031},
/*1041*/{0.193853,1.86727,-1.70938,0.270235,1.80629,-1.86084,0.07125,1.74615,-1.62074,-0.021728,1.65654,-1.5699,0.109412,1.57691,-1.62523,0.182479,1.52593,-1.64277,0.195681,1.88528,-2.1063,0.27547,1.81061,-1.93905,0.06215,1.84981,-2.01338,0.036103,1.65971,-2.17139,0.07553,1.57258,-2.22415,0.256876,1.52275,-2.15504,0.312769,1.49394,-2.16329,0.173084,1.37362,-1.79902,-0.019119,1.4356,-1.8584,-0.019305,1.4672,-1.91252,-0.022594,1.44852,-1.97177,0.168077,1.40562,-2.06892,0.311959,1.1585,-1.7444,0.211101,1.0666,-1.76339,0.264794,1.00393,-1.78677,0.380848,0.959225,-1.77409,0.251874,0.855107,-1.75589,0.187161,0.818857,-1.76032,0.196552,0.952266,-1.76462,0.134857,0.916692,-1.76601,-0.041045,0.769304,-1.7665,-0.158113,0.801889,-1.84229,0.009771,0.611772,-1.78909,-0.044263,0.610811,-1.71627,0.141435,1.09616,-2.11466,0.153364,1.01235,-2.09522,0.002249,1.07847,-2.07494,0.017143,0.997948,-2.05902,0.085269,0.858113,-2.05262,0.056874,0.672348,-2.02385,-0.044122,0.718364,-2.04708,-0.071174,0.655215,-2.03115,-0.140737,0.440665,-1.98196,-0.247319,0.374587,-1.92998,0.035757,0.375812,-1.9576,-0.016131,0.341825,-2.02307,0.098903,1.28612,-1.82662,0.086939,1.31184,-2.03998},
/*1042*/{0.189972,1.8711,-1.70895,0.270173,1.80971,-1.85921,0.066238,1.75133,-1.62119,-0.027266,1.66194,-1.57047,0.103882,1.58372,-1.62553,0.176895,1.53153,-1.6421,0.198354,1.88997,-2.10482,0.276356,1.81425,-1.9369,0.062884,1.8524,-2.01474,0.042043,1.66222,-2.16987,0.082017,1.57659,-2.22527,0.262616,1.53099,-2.15217,0.320216,1.50448,-2.15996,0.172608,1.37779,-1.79805,-0.01902,1.43875,-1.86107,-0.017899,1.47033,-1.91484,-0.021687,1.45085,-1.97458,0.169554,1.40515,-2.06852,0.313342,1.16613,-1.74474,0.216472,1.07274,-1.76418,0.271273,1.01143,-1.78792,0.388883,0.969606,-1.77394,0.264191,0.858513,-1.75541,0.199171,0.818482,-1.76082,0.202866,0.952509,-1.76516,0.142941,0.913992,-1.76619,-0.022119,0.758684,-1.76661,-0.144076,0.784498,-1.84344,0.034335,0.603791,-1.78973,-0.019811,0.599825,-1.71724,0.135065,1.09521,-2.11251,0.14376,1.01185,-2.09293,-0.004773,1.08253,-2.07501,0.006358,1.00115,-2.05836,0.068803,0.859819,-2.05054,0.038988,0.673805,-2.02251,-0.062171,0.721505,-2.04563,-0.089045,0.657981,-2.02997,-0.159904,0.444199,-1.98273,-0.268033,0.378746,-1.93034,0.01374,0.375926,-1.95673,-0.037583,0.342188,-2.02264,0.098097,1.28998,-1.82524,0.08823,1.31227,-2.03909},
/*1043*/{0.186963,1.87484,-1.70826,0.26953,1.81439,-1.8572,0.062529,1.7562,-1.62126,-0.033368,1.66773,-1.57187,0.100307,1.58937,-1.62529,0.17085,1.53756,-1.64185,0.201322,1.89455,-2.10397,0.277214,1.81806,-1.93469,0.064716,1.8552,-2.01626,0.045053,1.66619,-2.17144,0.087991,1.58057,-2.22558,0.269008,1.54072,-2.14876,0.327548,1.51576,-2.15577,0.172847,1.38161,-1.79744,-0.017675,1.44231,-1.86272,-0.016621,1.47282,-1.91672,-0.01889,1.45362,-1.97665,0.171226,1.40517,-2.0682,0.315639,1.17406,-1.74498,0.221615,1.07775,-1.76526,0.277611,1.019,-1.78814,0.396148,0.980021,-1.77467,0.274373,0.861691,-1.75549,0.214193,0.819125,-1.76169,0.20912,0.95182,-1.76732,0.150847,0.91077,-1.76712,-0.007217,0.747514,-1.76873,-0.12917,0.766457,-1.84461,0.058837,0.595741,-1.79059,0.00506,0.588676,-1.71845,0.127992,1.09487,-2.11042,0.133808,1.01182,-2.09003,-0.012837,1.08725,-2.07523,-0.005043,1.00542,-2.05838,0.053704,0.861976,-2.04865,0.020617,0.676381,-2.02114,-0.079909,0.724596,-2.04444,-0.108329,0.66133,-2.029,-0.177516,0.448122,-1.98137,-0.286942,0.383374,-1.93067,-0.006858,0.375573,-1.95706,-0.058513,0.34244,-2.02236,0.098195,1.29362,-1.82408,0.089903,1.31313,-2.03827},
/*1044*/{0.183723,1.87908,-1.70788,0.269818,1.81759,-1.85525,0.058379,1.76146,-1.62201,-0.038219,1.67408,-1.57311,0.094548,1.59569,-1.62536,0.166197,1.54411,-1.64092,0.203079,1.89922,-2.10302,0.277937,1.82251,-1.93297,0.066589,1.85812,-2.0168,0.049511,1.66903,-2.17254,0.093916,1.58509,-2.22636,0.274693,1.55025,-2.14602,0.333755,1.52712,-2.15169,0.173666,1.38607,-1.79714,-0.017209,1.44632,-1.86501,-0.014635,1.4766,-1.91909,-0.016529,1.45717,-1.97832,0.172891,1.40515,-2.06747,0.317675,1.18198,-1.74513,0.226489,1.08364,-1.76738,0.282807,1.02696,-1.78877,0.401584,0.991102,-1.77615,0.285537,0.863487,-1.7565,0.225682,0.817905,-1.76095,0.215581,0.951547,-1.76705,0.158853,0.905766,-1.76822,0.00715,0.735023,-1.7695,-0.113222,0.748381,-1.84614,0.083898,0.58792,-1.79127,0.029315,0.577361,-1.71946,0.121168,1.09563,-2.1072,0.124483,1.01239,-2.08735,-0.019734,1.09168,-2.07514,-0.014816,1.01066,-2.05768,0.038301,0.864786,-2.046,0.002915,0.680512,-2.02006,-0.096685,0.729195,-2.04377,-0.125956,0.665662,-2.02859,-0.197967,0.45216,-1.98088,-0.307231,0.390719,-1.93009,-0.027787,0.375601,-1.95622,-0.07898,0.34255,-2.02242,0.098001,1.29803,-1.82281,0.091276,1.31435,-2.03732},
/*1045*/{0.180534,1.88375,-1.70766,0.268915,1.82173,-1.85306,0.053475,1.76708,-1.62226,-0.043752,1.67998,-1.57418,0.089001,1.60205,-1.62651,0.161153,1.54993,-1.63984,0.205819,1.90403,-2.10122,0.278915,1.82625,-1.93043,0.068519,1.86119,-2.01802,0.054155,1.67313,-2.1742,0.100326,1.59011,-2.22753,0.279602,1.5601,-2.14343,0.339612,1.53863,-2.14803,0.174604,1.39056,-1.79741,-0.016334,1.45064,-1.86674,-0.013778,1.47994,-1.92116,-0.014268,1.45995,-1.98039,0.175372,1.40547,-2.06746,0.320463,1.18923,-1.7455,0.230299,1.09009,-1.76334,0.287672,1.03381,-1.78967,0.406115,0.999025,-1.7749,0.295424,0.867332,-1.75568,0.238427,0.817754,-1.76138,0.220851,0.950176,-1.76872,0.16704,0.902632,-1.76852,0.025115,0.723298,-1.77026,-0.097008,0.730832,-1.84755,0.108225,0.580708,-1.79173,0.053042,0.566815,-1.71995,0.11435,1.09659,-2.10465,0.114409,1.01289,-2.0845,-0.027299,1.09674,-2.07408,-0.024806,1.01566,-2.05746,0.024272,0.869293,-2.04378,-0.014442,0.684795,-2.01925,-0.114451,0.733424,-2.04227,-0.143704,0.670492,-2.02757,-0.21889,0.45948,-1.98754,-0.327293,0.397308,-1.9311,-0.048898,0.3758,-1.9562,-0.10034,0.343367,-2.02188,0.09841,1.30246,-1.82183,0.092945,1.31566,-2.03659},
/*1046*/{0.177664,1.88844,-1.70752,0.267032,1.82862,-1.85116,0.050518,1.77261,-1.62285,-0.048802,1.68642,-1.57586,0.084824,1.60834,-1.62709,0.156211,1.55639,-1.63969,0.207991,1.90879,-2.09995,0.27942,1.83057,-1.92833,0.069916,1.86463,-2.01986,0.059678,1.67725,-2.17692,0.105838,1.59512,-2.2287,0.284076,1.56978,-2.14044,0.34522,1.55016,-2.14414,0.175938,1.39514,-1.7976,-0.014358,1.4554,-1.86964,-0.010679,1.48318,-1.92401,-0.011742,1.46371,-1.98278,0.177213,1.40556,-2.06732,0.323143,1.19697,-1.74501,0.233954,1.09605,-1.76394,0.290556,1.03959,-1.79058,0.408805,1.0099,-1.77681,0.304762,0.868976,-1.7562,0.251223,0.81734,-1.76188,0.226741,0.949236,-1.76944,0.174272,0.898652,-1.77025,0.042,0.711549,-1.77133,-0.078679,0.711185,-1.84886,0.133263,0.573216,-1.79191,0.078289,0.556169,-1.72217,0.108322,1.09755,-2.10227,0.105051,1.01388,-2.08135,-0.034339,1.10318,-2.07384,-0.034899,1.02164,-2.05656,0.00857,0.874444,-2.0422,-0.031146,0.68984,-2.01818,-0.131562,0.739306,-2.04178,-0.161187,0.676052,-2.02712,-0.237923,0.461949,-1.98065,-0.345093,0.404327,-1.92872,-0.070379,0.37655,-1.95527,-0.122782,0.34353,-2.02093,0.098884,1.30718,-1.82109,0.094632,1.3169,-2.03606},
/*1047*/{0.17443,1.89267,-1.70733,0.267548,1.83147,-1.84945,0.046916,1.77793,-1.62395,-0.053513,1.69156,-1.5768,0.081225,1.61519,-1.62748,0.15203,1.56295,-1.64047,0.210033,1.91354,-2.09898,0.279728,1.83528,-1.92623,0.071079,1.8684,-2.02068,0.063929,1.68247,-2.17994,0.111626,1.60028,-2.22968,0.288948,1.58033,-2.13776,0.3501,1.56166,-2.14053,0.176797,1.40053,-1.79901,-0.013487,1.4598,-1.87078,-0.009164,1.48715,-1.92597,-0.008494,1.46699,-1.98435,0.179511,1.40526,-2.06736,0.323748,1.20362,-1.74508,0.235758,1.10247,-1.76657,0.293269,1.04672,-1.7919,0.410959,1.01879,-1.77756,0.314777,0.870656,-1.75567,0.262188,0.816458,-1.76202,0.231923,0.946646,-1.76994,0.183511,0.893263,-1.77199,0.058792,0.700302,-1.77237,-0.061009,0.693454,-1.85021,0.158361,0.567035,-1.79307,0.103435,0.546085,-1.72335,0.101952,1.09823,-2.09953,0.09525,1.01587,-2.07798,-0.040607,1.10974,-2.07333,-0.044873,1.02891,-2.05596,-0.007023,0.880293,-2.04162,-0.048396,0.694844,-2.0171,-0.147568,0.746155,-2.04149,-0.177447,0.683089,-2.02705,-0.253105,0.468545,-1.98109,-0.364293,0.413609,-1.92883,-0.091314,0.376345,-1.95352,-0.143173,0.344274,-2.02071,0.099521,1.3122,-1.8199,0.09592,1.3182,-2.03502},
/*1048*/{0.171933,1.89699,-1.7074,0.267048,1.83796,-1.84802,0.043545,1.78346,-1.62424,-0.055863,1.69814,-1.57867,0.076491,1.62124,-1.62841,0.147932,1.56918,-1.63931,0.212275,1.91802,-2.09752,0.279731,1.83985,-1.92431,0.073495,1.87254,-2.02165,0.069599,1.68711,-2.18222,0.118153,1.60494,-2.231,0.292562,1.5888,-2.13466,0.353553,1.57208,-2.13717,0.179898,1.40434,-1.80002,-0.010959,1.46426,-1.87234,-0.007335,1.49069,-1.92886,-0.005608,1.47093,-1.986,0.181347,1.40524,-2.06676,0.324268,1.21134,-1.74659,0.239205,1.1084,-1.76762,0.296905,1.05337,-1.7916,0.413611,1.02646,-1.77791,0.323092,0.872387,-1.75603,0.273166,0.81378,-1.76297,0.237026,0.943666,-1.77135,0.190433,0.888484,-1.77273,0.076651,0.686357,-1.77267,-0.042454,0.675502,-1.85159,0.18314,0.560388,-1.79451,0.130208,0.535841,-1.7245,0.09556,1.10033,-2.09759,0.086477,1.01791,-2.07513,-0.046777,1.11663,-2.07269,-0.052689,1.03585,-2.05483,-0.021734,0.885957,-2.04124,-0.065993,0.701426,-2.017,-0.16396,0.752589,-2.03996,-0.193911,0.690252,-2.02636,-0.278013,0.473059,-1.98029,-0.380813,0.422793,-1.92624,-0.112155,0.376499,-1.95382,-0.164827,0.344391,-2.02012,0.100737,1.31664,-1.8193,0.097292,1.31957,-2.03449},
/*1049*/{0.169533,1.90172,-1.70724,0.266724,1.84271,-1.84647,0.041094,1.78857,-1.62519,-0.060875,1.70406,-1.58054,0.072336,1.62779,-1.6298,0.143847,1.57498,-1.63938,0.215453,1.92265,-2.0962,0.280805,1.84445,-1.92255,0.075232,1.87544,-2.02335,0.074514,1.69226,-2.186,0.124519,1.60994,-2.23206,0.296786,1.59897,-2.13152,0.357776,1.58239,-2.13297,0.180641,1.4082,-1.80071,-0.00963,1.4699,-1.8743,-0.004453,1.49511,-1.93058,-0.002536,1.47497,-1.98782,0.183668,1.40587,-2.06667,0.326296,1.21645,-1.74593,0.240393,1.11462,-1.76652,0.298819,1.05948,-1.79151,0.414493,1.0327,-1.7783,0.331577,0.873314,-1.75697,0.286141,0.813341,-1.76308,0.24205,0.940004,-1.77351,0.199675,0.882566,-1.77416,0.096589,0.675892,-1.77404,-0.022501,0.657409,-1.8523,0.208507,0.553917,-1.79574,0.156313,0.527043,-1.72735,0.089465,1.10259,-2.09589,0.077937,1.02087,-2.07263,-0.051096,1.12332,-2.07188,-0.062399,1.04259,-2.05307,-0.036499,0.892416,-2.04156,-0.080707,0.708999,-2.01688,-0.179138,0.76116,-2.04061,-0.209176,0.698975,-2.02607,-0.28623,0.482302,-1.98046,-0.398188,0.433361,-1.92734,-0.134633,0.376256,-1.95272,-0.186447,0.344801,-2.01929,0.100505,1.32122,-1.81886,0.098275,1.32174,-2.03409},
/*1050*/{0.167763,1.90639,-1.70736,0.265494,1.84746,-1.84514,0.037661,1.79374,-1.6263,-0.065599,1.70947,-1.58221,0.068102,1.63369,-1.63009,0.140231,1.58125,-1.6394,0.217663,1.92728,-2.09506,0.281276,1.84879,-1.92078,0.076591,1.87873,-2.02411,0.08009,1.69712,-2.18941,0.130494,1.61489,-2.23327,0.299316,1.60697,-2.12878,0.361331,1.59203,-2.13071,0.183051,1.41281,-1.80147,-0.008028,1.47526,-1.87527,-0.001303,1.49904,-1.93279,-2.2e-005,1.47825,-1.98955,0.185548,1.40659,-2.06654,0.327677,1.22278,-1.74666,0.2429,1.1207,-1.76564,0.299018,1.06479,-1.79123,0.413787,1.03697,-1.77966,0.34016,0.872931,-1.75784,0.299374,0.812301,-1.76347,0.247593,0.935642,-1.77534,0.2067,0.875881,-1.77555,0.114086,0.661952,-1.77493,-0.003524,0.63963,-1.85256,0.233435,0.548535,-1.79905,0.184225,0.518647,-1.72953,0.084229,1.10476,-2.09422,0.069659,1.02405,-2.07075,-0.056203,1.13111,-2.07115,-0.068714,1.05071,-2.0534,-0.050789,0.899455,-2.04162,-0.095191,0.716912,-2.01738,-0.193563,0.769799,-2.03945,-0.222089,0.706977,-2.02522,-0.303023,0.489787,-1.98086,-0.413033,0.446591,-1.92637,-0.156525,0.376703,-1.95273,-0.208305,0.345672,-2.01878,0.1018,1.32633,-1.81797,0.099628,1.32354,-2.03318},
/*1051*/{0.165645,1.91074,-1.70723,0.266337,1.85158,-1.8434,0.03494,1.79923,-1.62731,-0.069581,1.71546,-1.58437,0.064726,1.63963,-1.63065,0.136162,1.58678,-1.63989,0.219759,1.9308,-2.09345,0.281221,1.85368,-1.91903,0.078581,1.88154,-2.02488,0.084253,1.70345,-2.19449,0.136074,1.6202,-2.23497,0.301443,1.61595,-2.12643,0.365077,1.60124,-2.12337,0.185121,1.41671,-1.80275,-0.005432,1.48057,-1.8764,0.000993,1.50372,-1.93474,0.002639,1.48216,-1.99043,0.186801,1.40721,-2.06666,0.328898,1.22836,-1.74696,0.239415,1.12344,-1.76693,0.300288,1.06979,-1.79041,0.413042,1.04133,-1.77958,0.348004,0.87276,-1.75797,0.308795,0.808451,-1.76469,0.252549,0.930885,-1.77567,0.213827,0.868737,-1.77778,0.134023,0.6505,-1.77629,0.016547,0.621518,-1.85309,0.258081,0.543505,-1.80163,0.2115,0.510562,-1.7321,0.079315,1.1078,-2.09262,0.061928,1.02764,-2.06875,-0.059819,1.13867,-2.07084,-0.076064,1.05953,-2.05237,-0.06267,0.907369,-2.04174,-0.108322,0.725007,-2.01887,-0.207462,0.777927,-2.03882,-0.238577,0.716966,-2.02568,-0.318141,0.49742,-1.98114,-0.428258,0.459899,-1.92346,-0.177072,0.376733,-1.95273,-0.230029,0.345955,-2.01819,0.102639,1.33111,-1.81749,0.099997,1.32565,-2.03265},
/*1052*/{0.163893,1.91531,-1.70792,0.25916,1.85914,-1.84386,0.032163,1.8037,-1.62853,-0.07322,1.72062,-1.58641,0.061082,1.64533,-1.63246,0.133476,1.59295,-1.63972,0.22163,1.93475,-2.09241,0.281421,1.85881,-1.91777,0.080467,1.88446,-2.02608,0.088995,1.70732,-2.19832,0.141085,1.62456,-2.23645,0.303673,1.62368,-2.12419,0.36729,1.61082,-2.12037,0.185936,1.42116,-1.8037,-0.003804,1.48572,-1.87706,0.0027,1.50825,-1.93683,0.005642,1.48671,-1.99156,0.188077,1.40843,-2.06622,0.32981,1.23309,-1.74751,0.242223,1.13121,-1.76506,0.299709,1.07369,-1.79079,0.411874,1.04376,-1.78049,0.355306,0.871645,-1.75902,0.318426,0.805063,-1.76551,0.257305,0.924505,-1.77607,0.222831,0.861202,-1.77838,0.153665,0.638397,-1.77788,0.037064,0.604046,-1.85331,0.284202,0.539227,-1.80498,0.239942,0.503056,-1.73481,0.074926,1.11098,-2.09234,0.054795,1.03133,-2.06765,-0.06383,1.14601,-2.07033,-0.082153,1.06792,-2.0521,-0.074075,0.915345,-2.04249,-0.122298,0.733136,-2.01989,-0.220527,0.787899,-2.03847,-0.250768,0.725324,-2.02513,-0.331991,0.505463,-1.98111,-0.440092,0.472948,-1.9225,-0.199597,0.377319,-1.95304,-0.252948,0.347348,-2.01788,0.102723,1.33606,-1.81695,0.100533,1.32831,-2.03203},
/*1053*/{0.162727,1.9195,-1.70812,0.258669,1.86326,-1.84288,0.029837,1.80866,-1.63033,-0.077136,1.72608,-1.58906,0.058198,1.65093,-1.63302,0.130496,1.59771,-1.63988,0.223453,1.938,-2.09163,0.281646,1.86281,-1.91589,0.082528,1.88765,-2.0272,0.095671,1.71189,-2.20195,0.146736,1.62893,-2.23856,0.305358,1.63111,-2.12194,0.369719,1.61966,-2.11801,0.188363,1.42503,-1.80363,-0.001258,1.49143,-1.87863,0.004532,1.51239,-1.93752,0.00772,1.49084,-1.99267,0.189626,1.41006,-2.06626,0.330379,1.2369,-1.7486,0.240684,1.13366,-1.76315,0.299911,1.07974,-1.78758,0.410375,1.04726,-1.78087,0.36241,0.869766,-1.75994,0.330698,0.802776,-1.76597,0.262358,0.91876,-1.77688,0.230392,0.853347,-1.77898,0.175297,0.628283,-1.78016,0.058325,0.586279,-1.85343,0.309329,0.535123,-1.80919,0.268432,0.497541,-1.73765,0.070149,1.11442,-2.09186,0.047986,1.03423,-2.06754,-0.067488,1.15373,-2.07038,-0.087153,1.07548,-2.05179,-0.08378,0.923937,-2.04372,-0.133333,0.742181,-2.02242,-0.23193,0.797004,-2.03762,-0.261653,0.73336,-2.02493,-0.344191,0.513391,-1.98136,-0.452897,0.488813,-1.91868,-0.22117,0.377882,-1.95464,-0.273422,0.347943,-2.01636,0.103764,1.34091,-1.81638,0.101361,1.33104,-2.03138},
/*1054*/{0.160989,1.92339,-1.70878,0.259105,1.86764,-1.84117,0.027269,1.81351,-1.63173,-0.079731,1.73224,-1.59149,0.054831,1.6556,-1.63411,0.127067,1.60271,-1.64083,0.22581,1.94128,-2.09036,0.2821,1.8664,-1.91476,0.083763,1.88981,-2.02788,0.100351,1.7156,-2.20502,0.151741,1.63311,-2.23996,0.308118,1.63929,-2.12073,0.37116,1.62904,-2.11817,0.189152,1.42928,-1.80457,0.000587,1.49646,-1.87893,0.007495,1.51701,-1.93893,0.010487,1.495,-1.99369,0.191298,1.4116,-2.06551,0.331331,1.24106,-1.75017,0.243857,1.14071,-1.76151,0.299187,1.08308,-1.78632,0.408103,1.04901,-1.78073,0.37075,0.868506,-1.76047,0.34105,0.799296,-1.767,0.267431,0.911659,-1.77748,0.23784,0.846376,-1.78122,0.194427,0.616168,-1.78154,0.079479,0.568406,-1.85404,0.334528,0.532945,-1.813,0.295917,0.490886,-1.74218,0.066077,1.11788,-2.09221,0.04141,1.0406,-2.0691,-0.070159,1.16075,-2.07013,-0.091741,1.08316,-2.05136,-0.092762,0.932303,-2.04507,-0.143444,0.751072,-2.02526,-0.242785,0.805515,-2.03756,-0.273776,0.742647,-2.02287,-0.358948,0.521615,-1.98322,-0.462778,0.504627,-1.91384,-0.241799,0.377641,-1.95585,-0.298519,0.349936,-2.01583,0.104162,1.34566,-1.81576,0.102203,1.33385,-2.03066},
/*1055*/{0.160033,1.92699,-1.70894,0.259503,1.8712,-1.84031,0.024862,1.81799,-1.63314,-0.083452,1.7368,-1.59428,0.051924,1.66067,-1.63504,0.124355,1.60751,-1.64041,0.227523,1.94422,-2.08966,0.282941,1.87037,-1.91374,0.085328,1.89245,-2.02872,0.107292,1.72042,-2.20757,0.156224,1.63673,-2.2419,0.310012,1.64603,-2.11896,0.373042,1.63735,-2.11573,0.189492,1.43268,-1.80478,0.001418,1.50202,-1.87921,0.008811,1.52211,-1.94,0.013007,1.49958,-1.99366,0.191658,1.41371,-2.0652,0.332856,1.24436,-1.75072,0.242736,1.14474,-1.76064,0.296721,1.08652,-1.78536,0.406159,1.04967,-1.78092,0.376765,0.865572,-1.76109,0.349275,0.795093,-1.76883,0.271539,0.903921,-1.77814,0.246053,0.835984,-1.78109,0.213867,0.605178,-1.78397,0.101452,0.551233,-1.85501,0.357869,0.529073,-1.81587,0.322618,0.485192,-1.7458,0.062604,1.12185,-2.09267,0.035818,1.04415,-2.07007,-0.072877,1.16759,-2.06958,-0.096025,1.09007,-2.05075,-0.100652,0.939746,-2.04675,-0.153229,0.759469,-2.02803,-0.253773,0.813855,-2.03745,-0.283693,0.751305,-2.02288,-0.367487,0.529935,-1.98272,-0.47245,0.521316,-1.91125,-0.260287,0.377942,-1.95735,-0.321469,0.352747,-2.01483,0.103437,1.35012,-1.81534,0.101715,1.33725,-2.03018},
/*1056*/{0.159632,1.93053,-1.70906,0.260004,1.87502,-1.83932,0.022534,1.82257,-1.63449,-0.087193,1.74231,-1.59739,0.049408,1.66513,-1.63653,0.121436,1.61162,-1.64053,0.230091,1.94683,-2.08941,0.283372,1.87338,-1.91229,0.087605,1.89445,-2.0299,0.11255,1.72442,-2.2102,0.160971,1.63996,-2.24395,0.311797,1.65181,-2.11804,0.374379,1.64322,-2.11258,0.193985,1.43741,-1.80451,0.003674,1.50704,-1.87916,0.011307,1.52632,-1.94032,0.015041,1.50368,-1.99371,0.192926,1.41583,-2.06475,0.333016,1.24664,-1.75215,0.24134,1.14784,-1.75969,0.294956,1.08817,-1.78452,0.403981,1.04953,-1.78032,0.383385,0.86179,-1.76127,0.359752,0.789996,-1.76917,0.276255,0.895335,-1.77798,0.253958,0.827831,-1.78182,0.233818,0.594205,-1.78588,0.124016,0.534867,-1.85722,0.380485,0.526725,-1.82135,0.350588,0.4802,-1.75073,0.058309,1.12579,-2.09369,0.031011,1.04925,-2.07133,-0.074996,1.17337,-2.06927,-0.099738,1.09585,-2.05098,-0.107774,0.946484,-2.04817,-0.161813,0.767196,-2.03109,-0.261197,0.822419,-2.036,-0.291781,0.760312,-2.02304,-0.377765,0.53868,-1.9832,-0.479982,0.537884,-1.90701,-0.280826,0.378345,-1.95904,-0.344465,0.35697,-2.01158,0.106303,1.35546,-1.814,0.103097,1.34015,-2.02867},
/*1057*/{0.15899,1.93372,-1.70943,0.261432,1.87826,-1.8382,0.020434,1.82687,-1.63629,-0.089427,1.74606,-1.60036,0.047087,1.66955,-1.63717,0.119267,1.61589,-1.64082,0.231471,1.94906,-2.08895,0.284141,1.87664,-1.91149,0.089054,1.89748,-2.0307,0.117519,1.72735,-2.21185,0.164744,1.64337,-2.24591,0.312029,1.65623,-2.11797,0.376196,1.64949,-2.11163,0.196662,1.44164,-1.80428,0.005763,1.51115,-1.87856,0.012078,1.53026,-1.93932,0.016357,1.50754,-1.99269,0.193105,1.41828,-2.06402,0.332092,1.24817,-1.75343,0.236882,1.14962,-1.75961,0.292032,1.08967,-1.7842,0.402213,1.04762,-1.77963,0.389827,0.858853,-1.76167,0.360293,0.783496,-1.77168,0.280839,0.887399,-1.77763,0.260811,0.818377,-1.78295,0.254114,0.583957,-1.7881,0.145928,0.519548,-1.85907,0.404529,0.524928,-1.82542,0.375336,0.475163,-1.75528,0.055572,1.12991,-2.09515,0.027269,1.05264,-2.07345,-0.07712,1.17901,-2.0681,-0.102988,1.10152,-2.05027,-0.11232,0.952534,-2.04919,-0.169682,0.773198,-2.0336,-0.26772,0.829505,-2.03593,-0.299647,0.767721,-2.02293,-0.388483,0.548075,-1.98491,-0.486509,0.555048,-1.90502,-0.298941,0.378182,-1.95967,-0.368742,0.362275,-2.00936,0.108264,1.35996,-1.81261,0.103471,1.34318,-2.02713},
/*1058*/{0.158356,1.93721,-1.70993,0.261655,1.88024,-1.83764,0.019138,1.83195,-1.63775,-0.091985,1.75021,-1.60334,0.044466,1.67305,-1.63801,0.117372,1.61939,-1.64086,0.232776,1.9508,-2.08845,0.284739,1.87972,-1.91069,0.091286,1.9002,-2.03098,0.12139,1.72972,-2.21369,0.16832,1.64634,-2.24754,0.313527,1.66157,-2.11809,0.377348,1.65496,-2.10975,0.192471,1.44382,-1.80558,0.006615,1.51566,-1.87863,0.013237,1.53371,-1.9393,0.017873,1.51154,-1.99224,0.19358,1.42092,-2.06379,0.332538,1.24934,-1.75443,0.237164,1.15329,-1.75849,0.290307,1.09118,-1.78134,0.399281,1.04578,-1.77831,0.394686,0.85555,-1.76163,0.377548,0.781003,-1.77163,0.28455,0.878644,-1.77902,0.268062,0.809142,-1.78269,0.271517,0.572482,-1.79026,0.168433,0.504784,-1.86163,0.426209,0.521574,-1.82745,0.400339,0.469709,-1.75903,0.052611,1.13332,-2.09679,0.02377,1.05665,-2.07584,-0.078649,1.18308,-2.06716,-0.104938,1.10679,-2.05057,-0.115721,0.957537,-2.04955,-0.17647,0.779603,-2.03646,-0.273708,0.836992,-2.03508,-0.306254,0.776959,-2.02354,-0.39849,0.556942,-1.98492,-0.492355,0.573201,-1.90375,-0.31749,0.378126,-1.96011,-0.38958,0.369261,-2.00635,0.105668,1.36245,-1.81315,0.102391,1.34674,-2.02779},
/*1059*/{0.158024,1.94015,-1.71051,0.262761,1.88281,-1.83651,0.017015,1.83585,-1.63946,-0.096239,1.75398,-1.60634,0.042474,1.67724,-1.63951,0.115312,1.62275,-1.64058,0.235435,1.95324,-2.08853,0.284994,1.88251,-1.90967,0.092944,1.90244,-2.03149,0.125761,1.73226,-2.21504,0.172425,1.64858,-2.24958,0.315763,1.66617,-2.11773,0.378694,1.65923,-2.10784,0.19435,1.44588,-1.80482,0.008345,1.51945,-1.87656,0.014734,1.5375,-1.9375,0.017923,1.51564,-1.99127,0.193795,1.42383,-2.06365,0.332194,1.24958,-1.75552,0.235286,1.15467,-1.7582,0.286536,1.09095,-1.78059,0.396249,1.04244,-1.77743,0.398978,0.85114,-1.76291,0.38592,0.777075,-1.77274,0.287811,0.869521,-1.77932,0.275981,0.79834,-1.78251,0.289909,0.562028,-1.79235,0.190811,0.490757,-1.86586,0.446273,0.520293,-1.83238,0.424001,0.464457,-1.76354,0.050787,1.13735,-2.09775,0.02204,1.06087,-2.07848,-0.079898,1.18703,-2.06638,-0.106716,1.11014,-2.04966,-0.11816,0.961166,-2.05038,-0.183038,0.784312,-2.03814,-0.278479,0.84531,-2.03644,-0.312183,0.784089,-2.02427,-0.40979,0.567448,-1.98576,-0.498411,0.590806,-1.90386,-0.336202,0.378743,-1.95899,-0.412679,0.377409,-2.0034,0.10668,1.36527,-1.8125,0.101984,1.35024,-2.02716},
/*1060*/{0.159107,1.94323,-1.71044,0.262968,1.88461,-1.83628,0.015493,1.83986,-1.64195,-0.096451,1.75793,-1.60955,0.040555,1.6799,-1.6404,0.113156,1.62547,-1.64055,0.237003,1.9548,-2.0884,0.286187,1.88424,-1.90878,0.093731,1.90539,-2.03212,0.129111,1.73496,-2.21706,0.17598,1.65085,-2.25125,0.316646,1.66876,-2.11725,0.379834,1.66205,-2.10534,0.195681,1.44658,-1.8045,0.009814,1.52301,-1.87449,0.014835,1.54109,-1.93671,0.019242,1.51927,-1.99062,0.194612,1.42689,-2.06359,0.329927,1.24931,-1.7565,0.232459,1.15503,-1.75745,0.282894,1.09055,-1.77988,0.392939,1.03902,-1.77728,0.40304,0.846934,-1.76259,0.393295,0.771771,-1.77314,0.291147,0.859119,-1.77951,0.283676,0.787335,-1.78334,0.310125,0.553782,-1.79556,0.212052,0.47855,-1.86929,0.466733,0.518514,-1.8343,0.446893,0.461242,-1.76814,0.04995,1.1409,-2.09977,0.020773,1.06304,-2.07976,-0.08119,1.1906,-2.0658,-0.106985,1.1131,-2.05001,-0.118413,0.9641,-2.05069,-0.188562,0.788624,-2.03931,-0.281591,0.850645,-2.03626,-0.317063,0.79136,-2.02551,-0.423501,0.57762,-1.98729,-0.50401,0.607312,-1.90556,-0.353128,0.377858,-1.95518,-0.43098,0.386053,-1.99897,0.107016,1.36708,-1.81272,0.101902,1.35377,-2.02749},
/*1061*/{0.159142,1.94572,-1.7108,0.264833,1.88722,-1.83639,0.013989,1.84428,-1.64364,-0.099612,1.76128,-1.61247,0.038503,1.68264,-1.6415,0.110994,1.62818,-1.64061,0.239325,1.95684,-2.08836,0.287539,1.88691,-1.90804,0.096032,1.90732,-2.03271,0.133128,1.73741,-2.218,0.178744,1.653,-2.25295,0.317656,1.671,-2.11629,0.380704,1.66553,-2.10413,0.197173,1.45,-1.80544,0.010148,1.52601,-1.87377,0.015444,1.54495,-1.93582,0.01998,1.52256,-1.98877,0.194303,1.42943,-2.06352,0.328336,1.24773,-1.75669,0.227139,1.15284,-1.75722,0.279114,1.08935,-1.77905,0.388403,1.03522,-1.7761,0.405701,0.842724,-1.76244,0.399641,0.767515,-1.77328,0.29293,0.849619,-1.78062,0.289147,0.778594,-1.78542,0.326847,0.543812,-1.79808,0.233117,0.466715,-1.87328,0.485986,0.517129,-1.83861,0.467215,0.456765,-1.77297,0.049931,1.14341,-2.10105,0.019857,1.0659,-2.08189,-0.081262,1.19207,-2.06527,-0.106137,1.11485,-2.04924,-0.117812,0.966641,-2.0513,-0.191791,0.791306,-2.03992,-0.283386,0.857171,-2.03764,-0.32143,0.79795,-2.02556,-0.431721,0.587877,-1.98875,-0.511652,0.624764,-1.91071,-0.373386,0.381007,-1.95127,-0.449452,0.395816,-1.99517,0.108292,1.37049,-1.81214,0.101567,1.35681,-2.02683},
/*1062*/{0.159228,1.94808,-1.71137,0.264958,1.88842,-1.83563,0.012757,1.84765,-1.64531,-0.101219,1.76532,-1.61551,0.037451,1.68576,-1.64332,0.109616,1.63038,-1.64072,0.240365,1.95813,-2.08831,0.287956,1.88809,-1.90806,0.097156,1.91002,-2.0334,0.135387,1.73852,-2.21868,0.181449,1.655,-2.25404,0.31911,1.67348,-2.11645,0.382327,1.66794,-2.10216,0.198272,1.45143,-1.80498,0.011465,1.52841,-1.87167,0.015278,1.54731,-1.93436,0.020628,1.52539,-1.98692,0.194086,1.43285,-2.06298,0.325601,1.24465,-1.75662,0.224115,1.15174,-1.75591,0.274906,1.08767,-1.77808,0.383717,1.0301,-1.77522,0.40665,0.838526,-1.76242,0.4053,0.762617,-1.77401,0.294995,0.839614,-1.78077,0.294991,0.767462,-1.78602,0.340997,0.535845,-1.80094,0.253456,0.456056,-1.8773,0.504141,0.516881,-1.8412,0.489106,0.453848,-1.77647,0.050199,1.14625,-2.10206,0.01912,1.06706,-2.08261,-0.081328,1.19412,-2.0658,-0.105102,1.11631,-2.04977,-0.117163,0.968084,-2.05188,-0.195459,0.793573,-2.03997,-0.2849,0.862655,-2.03997,-0.324152,0.804809,-2.02679,-0.439283,0.597438,-1.99108,-0.519004,0.641089,-1.91513,-0.392046,0.393143,-1.94606,-0.467867,0.406114,-1.99127,0.10931,1.37218,-1.81176,0.101599,1.3599,-2.02651},
/*1063*/{0.160848,1.95008,-1.71137,0.27123,1.88695,-1.83368,0.011659,1.85097,-1.64806,-0.104595,1.76807,-1.61853,0.035509,1.68814,-1.64396,0.108532,1.63233,-1.64057,0.24196,1.9593,-2.08758,0.288976,1.88989,-1.90782,0.098571,1.91236,-2.03399,0.13709,1.74069,-2.22015,0.183374,1.65612,-2.25474,0.320518,1.67376,-2.11577,0.383353,1.66799,-2.10075,0.196499,1.45304,-1.80512,0.012706,1.53072,-1.87054,0.015466,1.55049,-1.93312,0.020522,1.52817,-1.98546,0.194622,1.43617,-2.0628,0.32462,1.24048,-1.75642,0.219922,1.15034,-1.75528,0.269893,1.08459,-1.77594,0.378991,1.02525,-1.77466,0.408681,0.83412,-1.76302,0.410801,0.757381,-1.77462,0.296104,0.830056,-1.78069,0.299205,0.757902,-1.78677,0.358607,0.526087,-1.80089,0.27241,0.446549,-1.88077,0.519749,0.516524,-1.84512,0.509027,0.45274,-1.7815,0.050506,1.14854,-2.10305,0.024445,1.07024,-2.08602,-0.080367,1.1949,-2.06544,-0.104063,1.11658,-2.04956,-0.114625,0.968597,-2.05247,-0.197949,0.795805,-2.03985,-0.285227,0.867793,-2.04156,-0.32597,0.811407,-2.02896,-0.447736,0.608432,-1.99306,-0.526934,0.656528,-1.92007,-0.408565,0.404142,-1.93986,-0.484145,0.418304,-1.9874,0.108695,1.37376,-1.81198,0.101276,1.36326,-2.02683},
/*1064*/{0.161703,1.95209,-1.71135,0.266765,1.89202,-1.83554,0.011379,1.85426,-1.6499,-0.105788,1.77003,-1.62133,0.034603,1.68913,-1.64539,0.106677,1.63425,-1.64064,0.242283,1.96076,-2.08754,0.289775,1.89171,-1.90781,0.099463,1.91437,-2.03474,0.138966,1.74142,-2.2205,0.185451,1.65676,-2.25592,0.322493,1.67531,-2.11521,0.384303,1.66947,-2.09963,0.197927,1.45486,-1.80542,0.012978,1.53226,-1.86905,0.016276,1.55313,-1.93152,0.020631,1.53037,-1.98409,0.194216,1.43899,-2.06294,0.322,1.23541,-1.75606,0.213623,1.14896,-1.75581,0.263919,1.08155,-1.77658,0.372518,1.0189,-1.77493,0.409694,0.829447,-1.76341,0.415654,0.754416,-1.77564,0.297856,0.820596,-1.78106,0.30483,0.748356,-1.78702,0.37258,0.520694,-1.8051,0.29018,0.437818,-1.88423,0.535738,0.516989,-1.84745,0.526825,0.451357,-1.78517,0.052455,1.15,-2.10393,0.02714,1.07111,-2.08639,-0.078357,1.19484,-2.06521,-0.101765,1.11658,-2.05005,-0.11167,0.968309,-2.0526,-0.199372,0.797058,-2.03939,-0.283194,0.872034,-2.04271,-0.326775,0.81766,-2.03062,-0.457587,0.619315,-1.99391,-0.536093,0.671995,-1.9256,-0.425293,0.415405,-1.93391,-0.498864,0.430518,-1.98437,0.110059,1.37546,-1.81188,0.1012,1.3659,-2.02672},
/*1065*/{0.163243,1.95359,-1.71153,0.273648,1.88921,-1.83375,0.011135,1.85703,-1.65187,-0.104994,1.77362,-1.62436,0.034022,1.69147,-1.64617,0.106104,1.63516,-1.64079,0.243565,1.96137,-2.08741,0.290595,1.89207,-1.90755,0.099851,1.91724,-2.03511,0.141561,1.74269,-2.22017,0.186876,1.65759,-2.25621,0.32349,1.67548,-2.11426,0.385597,1.66923,-2.09881,0.19813,1.45539,-1.80519,0.013432,1.53334,-1.86748,0.015956,1.55523,-1.93046,0.020851,1.5324,-1.98248,0.194398,1.4417,-2.06254,0.318381,1.23146,-1.75655,0.214425,1.14694,-1.75439,0.257157,1.07712,-1.7765,0.367257,1.01292,-1.77439,0.411075,0.824933,-1.7645,0.417557,0.750126,-1.77737,0.299959,0.811516,-1.78092,0.30792,0.740492,-1.78783,0.386098,0.516481,-1.80879,0.307508,0.429639,-1.88773,0.549821,0.517675,-1.84968,0.542496,0.451679,-1.78821,0.05533,1.15145,-2.10458,0.030061,1.07111,-2.08727,-0.077561,1.19409,-2.06522,-0.098525,1.11602,-2.05024,-0.107466,0.967362,-2.05252,-0.20061,0.798038,-2.03866,-0.282131,0.876265,-2.04482,-0.327279,0.823804,-2.03219,-0.460557,0.630578,-1.99508,-0.544778,0.687524,-1.93248,-0.440537,0.42808,-1.92861,-0.511823,0.443175,-1.98143,0.110288,1.37614,-1.81201,0.101197,1.36841,-2.02691},
/*1066*/{0.164462,1.95479,-1.71198,0.27302,1.89294,-1.83466,0.011231,1.85919,-1.65295,-0.107989,1.77546,-1.62756,0.033881,1.69329,-1.64777,0.104612,1.636,-1.64062,0.244885,1.96172,-2.08697,0.290757,1.89317,-1.90778,0.10061,1.91886,-2.035,0.141606,1.74361,-2.22002,0.187922,1.65791,-2.25634,0.325146,1.67596,-2.11411,0.387277,1.66673,-2.09488,0.199726,1.45597,-1.80554,0.015067,1.53437,-1.86728,0.015989,1.55683,-1.92857,0.019994,1.53428,-1.98138,0.194606,1.44429,-2.06253,0.315081,1.22649,-1.75569,0.208933,1.14324,-1.75359,0.2514,1.07302,-1.77603,0.36028,1.00644,-1.77463,0.412433,0.821081,-1.76575,0.42342,0.746485,-1.77891,0.301299,0.803027,-1.78021,0.312231,0.732944,-1.78936,0.400304,0.510206,-1.81071,0.323659,0.421989,-1.89131,0.562693,0.518556,-1.85204,0.557288,0.45314,-1.79239,0.057666,1.15164,-2.10436,0.032479,1.07152,-2.08847,-0.074672,1.19342,-2.06511,-0.095499,1.11431,-2.05012,-0.102721,0.965939,-2.05202,-0.200367,0.799194,-2.03762,-0.279695,0.880059,-2.04557,-0.327035,0.828663,-2.03381,-0.473759,0.641619,-1.99638,-0.554829,0.701753,-1.93856,-0.455081,0.441656,-1.92282,-0.523789,0.456279,-1.97893,0.111694,1.37692,-1.81243,0.101369,1.37063,-2.02733},
/*1067*/{0.166377,1.95601,-1.71167,0.273637,1.89396,-1.83478,0.011374,1.86126,-1.65493,-0.108141,1.77761,-1.6301,0.032919,1.6943,-1.64812,0.103606,1.63645,-1.64029,0.244949,1.96243,-2.08612,0.290947,1.89387,-1.90866,0.101257,1.92057,-2.03497,0.141425,1.7441,-2.21946,0.189006,1.65799,-2.25611,0.325833,1.67367,-2.11277,0.3881,1.66619,-2.0957,0.200208,1.45649,-1.80581,0.015263,1.53518,-1.86498,0.017061,1.55772,-1.92707,0.019578,1.53512,-1.9797,0.194531,1.44611,-2.06226,0.31173,1.21935,-1.75487,0.199834,1.13833,-1.75469,0.244377,1.06902,-1.77705,0.353355,0.999963,-1.77458,0.413622,0.817068,-1.76668,0.426224,0.743048,-1.78045,0.30233,0.795412,-1.78101,0.315619,0.725949,-1.79036,0.410656,0.506037,-1.81285,0.337223,0.416816,-1.89359,0.572749,0.519356,-1.85502,0.571615,0.452528,-1.7942,0.061545,1.15175,-2.10438,0.037657,1.07157,-2.08816,-0.072597,1.19146,-2.0653,-0.091698,1.11259,-2.04998,-0.097344,0.964456,-2.05192,-0.20087,0.799751,-2.03653,-0.275952,0.8843,-2.04802,-0.325669,0.836585,-2.0361,-0.479515,0.654398,-1.99726,-0.562386,0.71808,-1.94433,-0.466005,0.454932,-1.9167,-0.534603,0.469902,-1.97651,0.112647,1.3773,-1.81213,0.101235,1.37213,-2.027},
/*1068*/{0.167597,1.95657,-1.71203,0.273895,1.89398,-1.83473,0.012331,1.86269,-1.65586,-0.107387,1.77956,-1.63244,0.032605,1.69513,-1.64961,0.103497,1.63631,-1.63955,0.24465,1.96245,-2.08594,0.290943,1.89446,-1.90883,0.100716,1.9218,-2.03498,0.141772,1.74431,-2.2185,0.188744,1.65797,-2.25542,0.326213,1.67221,-2.11181,0.38906,1.66382,-2.09495,0.199088,1.45666,-1.80618,0.015553,1.5339,-1.86371,0.016596,1.55786,-1.92547,0.020095,1.53552,-1.97864,0.194416,1.44798,-2.06223,0.308416,1.21263,-1.75458,0.196529,1.13583,-1.75581,0.237468,1.06427,-1.77752,0.346341,0.994257,-1.77647,0.413215,0.81377,-1.76892,0.429106,0.740068,-1.78264,0.303944,0.78955,-1.78235,0.319684,0.719518,-1.79042,0.421164,0.502941,-1.81484,0.349159,0.411334,-1.89631,0.582854,0.520863,-1.85622,0.58333,0.452444,-1.79642,0.064937,1.15174,-2.10449,0.041745,1.0708,-2.08819,-0.06899,1.18998,-2.06474,-0.088215,1.1103,-2.05052,-0.091781,0.961979,-2.05139,-0.201504,0.800866,-2.03525,-0.271679,0.888879,-2.04998,-0.325411,0.842798,-2.03793,-0.481943,0.666433,-1.99872,-0.568394,0.733094,-1.95035,-0.478558,0.469604,-1.9122,-0.544414,0.484191,-1.97486,0.11296,1.37652,-1.81267,0.101565,1.37341,-2.02759},
/*1069*/{0.169789,1.95697,-1.71217,0.274007,1.89453,-1.83582,0.012763,1.86413,-1.65709,-0.107495,1.78082,-1.63514,0.032059,1.69541,-1.65014,0.103171,1.63591,-1.6386,0.244216,1.96228,-2.08557,0.290603,1.89451,-1.9093,0.100506,1.92233,-2.03445,0.141061,1.74481,-2.21739,0.189237,1.65794,-2.25439,0.326036,1.67061,-2.1117,0.389475,1.66083,-2.09451,0.201858,1.45666,-1.80581,0.015211,1.53366,-1.86281,0.016785,1.5579,-1.92381,0.019497,1.53574,-1.97663,0.194825,1.44888,-2.06235,0.303518,1.20569,-1.75338,0.189673,1.1322,-1.75669,0.231947,1.05809,-1.77806,0.339525,0.987999,-1.77679,0.412429,0.81045,-1.76946,0.429589,0.738489,-1.78482,0.304135,0.78317,-1.78309,0.322538,0.713591,-1.79212,0.427764,0.49985,-1.81677,0.35925,0.407038,-1.89832,0.590291,0.520928,-1.85752,0.591615,0.452235,-1.79803,0.068558,1.15053,-2.10372,0.04632,1.0696,-2.08791,-0.065863,1.18706,-2.06462,-0.083087,1.10701,-2.05018,-0.085612,0.959644,-2.05105,-0.20139,0.801689,-2.03437,-0.268839,0.893502,-2.05112,-0.323718,0.847645,-2.03971,-0.486083,0.679858,-2.00007,-0.574226,0.749675,-1.95558,-0.490864,0.485207,-1.90894,-0.554335,0.499356,-1.97306,0.115008,1.3765,-1.81229,0.102117,1.37398,-2.02712},
/*1070*/{0.170617,1.95747,-1.71208,0.27694,1.89341,-1.83617,0.013627,1.86486,-1.65731,-0.106303,1.78219,-1.63661,0.032205,1.69584,-1.65052,0.10255,1.63472,-1.63803,0.243623,1.96184,-2.08538,0.290288,1.89438,-1.91019,0.100106,1.92272,-2.03341,0.139043,1.74422,-2.21689,0.18851,1.6579,-2.25343,0.328056,1.66776,-2.11196,0.389808,1.65785,-2.09413,0.20344,1.45607,-1.80614,0.016515,1.5321,-1.86137,0.0165,1.55793,-1.92345,0.020165,1.53515,-1.97556,0.195398,1.44934,-2.06231,0.300578,1.19896,-1.75294,0.184626,1.12765,-1.75726,0.224489,1.05411,-1.77854,0.333769,0.981897,-1.77788,0.41195,0.807594,-1.7722,0.429676,0.73566,-1.7864,0.303723,0.776737,-1.7856,0.323445,0.708964,-1.79445,0.435259,0.497633,-1.81874,0.367733,0.403832,-1.90078,0.596512,0.520843,-1.85831,0.599165,0.451624,-1.80002,0.072716,1.1492,-2.10257,0.052185,1.06854,-2.0875,-0.062623,1.18375,-2.06456,-0.078255,1.10323,-2.04969,-0.079308,0.956549,-2.05095,-0.200562,0.802948,-2.03361,-0.265061,0.895202,-2.05038,-0.320608,0.854449,-2.04144,-0.494087,0.693597,-2.0018,-0.577329,0.766531,-1.95996,-0.502561,0.500779,-1.9072,-0.564154,0.514992,-1.97123,0.116782,1.37566,-1.81245,0.103022,1.37403,-2.02724},
/*1071*/{0.171868,1.95695,-1.7124,0.265654,1.89576,-1.83939,0.014674,1.8645,-1.65886,-0.104468,1.78294,-1.63792,0.032523,1.69521,-1.65076,0.10226,1.6339,-1.63683,0.243261,1.96107,-2.08498,0.289516,1.89437,-1.91098,0.099386,1.92308,-2.03268,0.137542,1.74429,-2.21486,0.187411,1.65746,-2.25148,0.329194,1.6655,-2.1127,0.390317,1.65372,-2.09551,0.203163,1.45527,-1.80652,0.015601,1.53088,-1.86022,0.016129,1.55729,-1.92239,0.019994,1.53361,-1.97415,0.19572,1.44938,-2.06239,0.295356,1.19228,-1.75275,0.181123,1.12276,-1.7582,0.218187,1.04865,-1.78135,0.327609,0.975718,-1.77806,0.410357,0.804655,-1.77438,0.43115,0.73237,-1.78775,0.302,0.771797,-1.78811,0.323204,0.70341,-1.79621,0.440801,0.495349,-1.81964,0.374193,0.399883,-1.90249,0.600871,0.520041,-1.85944,0.604358,0.451794,-1.80044,0.077883,1.14738,-2.10213,0.057783,1.06564,-2.08607,-0.058233,1.17999,-2.06439,-0.073469,1.09928,-2.04964,-0.072987,0.9526,-2.05121,-0.201176,0.804998,-2.03354,-0.258211,0.900661,-2.0541,-0.316797,0.863569,-2.04364,-0.497318,0.70753,-2.00309,-0.579238,0.78443,-1.96182,-0.512159,0.516856,-1.90555,-0.572445,0.532045,-1.9712,0.117207,1.37445,-1.81241,0.103151,1.37369,-2.02719},
/*1072*/{0.173226,1.95648,-1.71244,0.264537,1.89467,-1.83957,0.015633,1.8642,-1.65943,-0.102953,1.78273,-1.63859,0.032938,1.69402,-1.65046,0.102135,1.63197,-1.63568,0.240772,1.96065,-2.08409,0.288802,1.89344,-1.91192,0.097817,1.92275,-2.03213,0.13546,1.74346,-2.21405,0.185593,1.65697,-2.2501,0.329054,1.66179,-2.11296,0.390371,1.65033,-2.09829,0.203376,1.45437,-1.80704,0.017056,1.52809,-1.85929,0.016994,1.55448,-1.92149,0.020251,1.53254,-1.97401,0.195954,1.44924,-2.06224,0.293551,1.18484,-1.75161,0.175743,1.11751,-1.75941,0.21205,1.04438,-1.78255,0.320401,0.969091,-1.77925,0.406618,0.801403,-1.7752,0.428527,0.729528,-1.78901,0.300174,0.766833,-1.79034,0.322271,0.699122,-1.7979,0.441547,0.491531,-1.82051,0.378404,0.395667,-1.90347,0.603755,0.520469,-1.86057,0.607423,0.451461,-1.80205,0.082181,1.14507,-2.10114,0.063669,1.06284,-2.0854,-0.053916,1.17563,-2.0638,-0.068652,1.09516,-2.04956,-0.066456,0.948495,-2.05097,-0.199201,0.807239,-2.03403,-0.252687,0.90566,-2.05618,-0.313436,0.869566,-2.04331,-0.498335,0.721736,-2.00413,-0.57837,0.801369,-1.96465,-0.521381,0.532599,-1.90569,-0.581248,0.550016,-1.97207,0.118822,1.37246,-1.81286,0.104312,1.37278,-2.0276},
/*1073*/{0.174714,1.95529,-1.7125,0.264761,1.89339,-1.83995,0.017033,1.86319,-1.65876,-0.102229,1.78173,-1.63929,0.033756,1.69213,-1.64952,0.102353,1.62969,-1.63347,0.240111,1.95962,-2.08362,0.288823,1.89257,-1.91195,0.096245,1.92176,-2.03168,0.132581,1.74273,-2.21214,0.183459,1.65598,-2.24809,0.32884,1.65795,-2.11349,0.389887,1.64607,-2.09879,0.203579,1.4532,-1.80714,0.01765,1.52558,-1.85796,0.017151,1.55248,-1.92081,0.019603,1.52981,-1.97253,0.196301,1.44882,-2.06179,0.290641,1.17793,-1.75049,0.171735,1.11309,-1.75994,0.206685,1.03934,-1.78379,0.314431,0.96296,-1.7802,0.403147,0.79826,-1.77622,0.425924,0.727617,-1.79068,0.29669,0.762133,-1.79237,0.320378,0.695046,-1.80079,0.445452,0.489681,-1.82324,0.381314,0.392162,-1.90556,0.604842,0.519043,-1.86117,0.608551,0.450987,-1.802,0.087019,1.14228,-2.10026,0.069695,1.06026,-2.08454,-0.050436,1.17084,-2.06308,-0.063536,1.0901,-2.04807,-0.058639,0.944671,-2.05162,-0.197476,0.809554,-2.03422,-0.247027,0.910311,-2.05652,-0.307918,0.875881,-2.04547,-0.501821,0.737923,-2.0075,-0.576587,0.819188,-1.96627,-0.531511,0.54921,-1.90739,-0.590093,0.567905,-1.97195,0.120262,1.37061,-1.81252,0.105131,1.37139,-2.02723},
/*1074*/{0.175639,1.95392,-1.71227,0.264853,1.89239,-1.84032,0.017683,1.86189,-1.65937,-0.099847,1.7801,-1.63886,0.034012,1.69036,-1.64847,0.103616,1.62727,-1.63275,0.237119,1.95747,-2.08349,0.28853,1.89141,-1.91255,0.09523,1.9206,-2.0302,0.129447,1.74178,-2.2103,0.180786,1.65509,-2.24653,0.328375,1.65367,-2.11414,0.388968,1.641,-2.09957,0.203014,1.45064,-1.80762,0.016921,1.5233,-1.85766,0.016735,1.55016,-1.92033,0.019946,1.52767,-1.97212,0.197019,1.44713,-2.06149,0.286267,1.1709,-1.75017,0.168747,1.10839,-1.7605,0.201359,1.03394,-1.78658,0.309411,0.957498,-1.78098,0.399902,0.794568,-1.77804,0.423542,0.722301,-1.79071,0.293921,0.757444,-1.79434,0.317393,0.689573,-1.80152,0.442863,0.484947,-1.82375,0.382449,0.387179,-1.90829,0.604661,0.518571,-1.8628,0.608436,0.449173,-1.80278,0.091033,1.13909,-2.0996,0.075532,1.05658,-2.08344,-0.04529,1.16585,-2.06246,-0.058561,1.08523,-2.0475,-0.051553,0.939644,-2.0523,-0.195295,0.811323,-2.03515,-0.240268,0.913941,-2.0565,-0.304444,0.885114,-2.04445,-0.503064,0.752238,-2.00774,-0.573678,0.83658,-1.96615,-0.539335,0.564359,-1.90937,-0.597803,0.586788,-1.97331,0.119976,1.36794,-1.81285,0.105393,1.36968,-2.02758},
/*1075*/{0.176597,1.95178,-1.71226,0.264125,1.89069,-1.84117,0.019264,1.85933,-1.65837,-0.098728,1.77818,-1.6383,0.035772,1.68899,-1.64752,0.104606,1.62546,-1.63114,0.236363,1.95662,-2.08377,0.287453,1.88995,-1.9129,0.093376,1.91798,-2.02882,0.12524,1.74039,-2.20804,0.177589,1.65317,-2.24483,0.326799,1.64861,-2.11447,0.38725,1.63546,-2.10047,0.203537,1.44914,-1.80677,0.017739,1.51999,-1.8567,0.016829,1.54718,-1.91976,0.019624,1.52543,-1.97205,0.197436,1.4458,-2.0612,0.284067,1.16338,-1.74856,0.161362,1.10168,-1.76264,0.196576,1.02902,-1.78731,0.305046,0.951557,-1.78118,0.396363,0.79008,-1.7787,0.420861,0.719113,-1.7921,0.28952,0.752471,-1.79619,0.315126,0.685052,-1.8033,0.441197,0.483489,-1.82763,0.38176,0.383899,-1.91021,0.601393,0.515723,-1.86403,0.607512,0.448089,-1.80394,0.096515,1.13617,-2.09899,0.081123,1.05408,-2.08253,-0.041555,1.16081,-2.06234,-0.052406,1.07972,-2.04701,-0.044416,0.935325,-2.05205,-0.192968,0.813953,-2.03594,-0.234339,0.917687,-2.05646,-0.297528,0.886509,-2.04461,-0.502684,0.766895,-2.00948,-0.568455,0.85504,-1.96573,-0.547383,0.580338,-1.91235,-0.605619,0.605711,-1.97591,0.121245,1.3657,-1.81252,0.106537,1.36767,-2.02724},
/*1076*/{0.176863,1.94967,-1.71196,0.263041,1.88921,-1.84234,0.020512,1.85727,-1.65711,-0.096977,1.77461,-1.63661,0.037124,1.6854,-1.64648,0.105077,1.62177,-1.62924,0.234017,1.95444,-2.08413,0.287766,1.88815,-1.91351,0.092496,1.9152,-2.02771,0.121022,1.73819,-2.20641,0.173237,1.65068,-2.24338,0.325617,1.64417,-2.11497,0.386173,1.6289,-2.10154,0.204666,1.44609,-1.80708,0.018357,1.51703,-1.85623,0.016244,1.54352,-1.9195,0.020579,1.52182,-1.97148,0.198199,1.44391,-2.06064,0.280973,1.15856,-1.74738,0.159112,1.09741,-1.76286,0.194104,1.02587,-1.78969,0.301597,0.947121,-1.78121,0.392077,0.785532,-1.77898,0.417077,0.715054,-1.79326,0.286187,0.747471,-1.7974,0.31101,0.680357,-1.80595,0.436972,0.478498,-1.82871,0.378968,0.379644,-1.91278,0.599194,0.512029,-1.86437,0.60165,0.442431,-1.80447,0.101673,1.13328,-2.09846,0.088344,1.05091,-2.08134,-0.036642,1.15524,-2.06145,-0.046076,1.07417,-2.04609,-0.036701,0.930994,-2.05153,-0.188667,0.815694,-2.03677,-0.226562,0.920899,-2.05684,-0.292274,0.894345,-2.04546,-0.50087,0.781084,-2.01074,-0.56129,0.871776,-1.96381,-0.5537,0.595612,-1.91593,-0.611307,0.625694,-1.97834,0.122639,1.36254,-1.81259,0.107791,1.36502,-2.0273},
/*1077*/{0.177801,1.94708,-1.71183,0.263391,1.88716,-1.84263,0.022277,1.85382,-1.65487,-0.094407,1.77102,-1.63464,0.037818,1.682,-1.64386,0.107986,1.61826,-1.62729,0.231384,1.95208,-2.08484,0.286731,1.8859,-1.91388,0.090216,1.91257,-2.02691,0.116873,1.73566,-2.20509,0.169353,1.64795,-2.24235,0.322778,1.63879,-2.11561,0.383975,1.62281,-2.1037,0.204419,1.44291,-1.80707,0.017874,1.51383,-1.85594,0.016989,1.54004,-1.91847,0.019924,1.51853,-1.97137,0.199249,1.4422,-2.06007,0.27852,1.15397,-1.74603,0.15603,1.09536,-1.76396,0.19103,1.02129,-1.79012,0.301036,0.944714,-1.78139,0.388266,0.780392,-1.77985,0.412235,0.708881,-1.79356,0.282751,0.743071,-1.79824,0.306987,0.675462,-1.80692,0.433557,0.473771,-1.83148,0.373821,0.375569,-1.91586,0.594637,0.505097,-1.8651,0.598353,0.437519,-1.80547,0.106485,1.12993,-2.09768,0.094403,1.04717,-2.08081,-0.032852,1.15002,-2.06086,-0.040402,1.06882,-2.04584,-0.029199,0.926991,-2.05137,-0.184305,0.817748,-2.03763,-0.218949,0.924391,-2.05708,-0.285468,0.899597,-2.04653,-0.493031,0.791682,-2.00969,-0.553731,0.88792,-1.96332,-0.559436,0.610959,-1.92035,-0.61544,0.644873,-1.98163,0.122961,1.35907,-1.81285,0.108686,1.3627,-2.02758},
/*1078*/{0.178687,1.94384,-1.71181,0.264445,1.88449,-1.84292,0.02318,1.84954,-1.65391,-0.092959,1.76662,-1.63219,0.040649,1.67833,-1.64137,0.110139,1.61407,-1.62515,0.229447,1.9495,-2.08564,0.286319,1.88329,-1.91482,0.08898,1.90902,-2.02539,0.113487,1.73326,-2.20307,0.165464,1.64487,-2.24155,0.320139,1.63327,-2.11652,0.381123,1.61682,-2.10485,0.204809,1.44029,-1.80679,0.017097,1.51012,-1.85483,0.017101,1.53687,-1.91794,0.020072,1.51411,-1.97135,0.199655,1.43972,-2.0593,0.276115,1.14923,-1.74424,0.151836,1.09192,-1.76633,0.188817,1.01875,-1.79207,0.301014,0.942267,-1.78143,0.38428,0.774895,-1.78023,0.409018,0.704072,-1.79615,0.278888,0.738731,-1.79953,0.302264,0.670557,-1.808,0.427629,0.467928,-1.83338,0.367809,0.37117,-1.91933,0.588443,0.498586,-1.86649,0.590389,0.430296,-1.8069,0.111566,1.12629,-2.09712,0.100938,1.04317,-2.07953,-0.027404,1.1453,-2.06099,-0.034575,1.0634,-2.04545,-0.02232,0.922878,-2.05143,-0.179903,0.819214,-2.0381,-0.21142,0.927474,-2.05843,-0.277416,0.905489,-2.04657,-0.493802,0.808794,-2.01306,-0.543631,0.904325,-1.96205,-0.564154,0.625577,-1.92526,-0.615572,0.661748,-1.98383,0.123813,1.356,-1.81228,0.109645,1.35953,-2.02702},
/*1079*/{0.179049,1.93993,-1.71156,0.275149,1.8791,-1.84058,0.02463,1.84518,-1.65281,-0.091781,1.76071,-1.62922,0.042446,1.67311,-1.6383,0.112314,1.60943,-1.62263,0.226613,1.94667,-2.08647,0.286727,1.88023,-1.91487,0.087481,1.90544,-2.02504,0.108314,1.73022,-2.20156,0.160264,1.64108,-2.24029,0.316805,1.62691,-2.1175,0.378047,1.6087,-2.10676,0.203786,1.43665,-1.8069,0.017168,1.50667,-1.85468,0.016739,1.53328,-1.91791,0.02041,1.51039,-1.97118,0.200469,1.43725,-2.05849,0.275366,1.14558,-1.74291,0.15319,1.08959,-1.76512,0.185748,1.01559,-1.79237,0.301133,0.940444,-1.78214,0.380068,0.769273,-1.78122,0.403555,0.697925,-1.79672,0.274081,0.733655,-1.80015,0.29762,0.666607,-1.80954,0.420645,0.46243,-1.83527,0.359829,0.366425,-1.92188,0.58214,0.492185,-1.86719,0.583645,0.422794,-1.80909,0.117797,1.12295,-2.09682,0.108326,1.0397,-2.07915,-0.021753,1.13911,-2.06058,-0.02836,1.05823,-2.04531,-0.014482,0.918578,-2.05087,-0.174881,0.820523,-2.03873,-0.201985,0.930086,-2.0586,-0.269497,0.909351,-2.04729,-0.488738,0.822838,-2.01522,-0.534108,0.918043,-1.95999,-0.567844,0.639637,-1.93014,-0.620749,0.68307,-1.98852,0.123514,1.35223,-1.81248,0.110333,1.35663,-2.02727},
/*1080*/{0.179032,1.93582,-1.7113,0.27418,1.87725,-1.8417,0.026782,1.83912,-1.65061,-0.087763,1.75573,-1.62557,0.044898,1.66751,-1.63563,0.115817,1.60541,-1.62053,0.224249,1.94349,-2.0873,0.286346,1.87779,-1.91542,0.085934,1.90074,-2.02382,0.105664,1.72631,-2.20071,0.155434,1.6371,-2.23955,0.313919,1.62073,-2.11908,0.376358,1.60098,-2.10879,0.204189,1.43367,-1.80655,0.017555,1.50174,-1.85422,0.016689,1.52882,-1.91787,0.019705,1.50621,-1.97176,0.201258,1.43468,-2.05807,0.273114,1.14267,-1.74237,0.148357,1.08525,-1.76654,0.184156,1.01373,-1.79366,0.300096,0.937997,-1.78277,0.374856,0.762548,-1.78186,0.397579,0.692019,-1.79748,0.268854,0.728742,-1.80011,0.291785,0.661485,-1.81095,0.411441,0.456167,-1.8369,0.349673,0.361825,-1.92428,0.574152,0.48353,-1.86866,0.573014,0.414073,-1.81105,0.122641,1.11954,-2.09705,0.115928,1.03614,-2.07966,-0.016207,1.13395,-2.06035,-0.021941,1.05194,-2.04433,-0.007609,0.914301,-2.05106,-0.169329,0.820968,-2.03902,-0.192605,0.929794,-2.05696,-0.261138,0.912692,-2.04826,-0.481956,0.835148,-2.01651,-0.523667,0.932108,-1.95883,-0.567478,0.653953,-1.93526,-0.618033,0.700924,-1.99204,0.124728,1.3485,-1.81254,0.111816,1.35318,-2.02734},
/*1081*/{0.179773,1.93179,-1.71086,0.273994,1.87415,-1.84177,0.027965,1.83407,-1.64827,-0.0867,1.74929,-1.6217,0.048595,1.6617,-1.63221,0.119506,1.59936,-1.61752,0.221878,1.93976,-2.08888,0.286249,1.8743,-1.9159,0.084374,1.89588,-2.02336,0.10024,1.72283,-2.19929,0.150608,1.63316,-2.23867,0.310026,1.61279,-2.12011,0.370378,1.59319,-2.11219,0.203842,1.43035,-1.80634,0.017842,1.49749,-1.85414,0.017305,1.52509,-1.91723,0.020243,1.50105,-1.9709,0.201295,1.43185,-2.05753,0.272452,1.13959,-1.74161,0.148805,1.08419,-1.76717,0.18069,1.00926,-1.79403,0.297648,0.93402,-1.7829,0.369674,0.756493,-1.78352,0.391642,0.685432,-1.79869,0.262964,0.723906,-1.80138,0.285343,0.656697,-1.81078,0.4032,0.451752,-1.83715,0.338915,0.356251,-1.92578,0.563927,0.474567,-1.87016,0.563856,0.404874,-1.81187,0.128644,1.11574,-2.0974,0.121974,1.03254,-2.08003,-0.010437,1.12776,-2.0599,-0.015055,1.04635,-2.04493,0.000548,0.910555,-2.0515,-0.163895,0.821264,-2.03954,-0.183637,0.932001,-2.05766,-0.252246,0.917275,-2.04921,-0.474453,0.847641,-2.01665,-0.511718,0.943539,-1.95802,-0.567866,0.667437,-1.94047,-0.61818,0.718628,-1.99675,0.12552,1.34469,-1.81218,0.112666,1.34951,-2.02698},
/*1082*/{0.180195,1.92701,-1.7107,0.275024,1.86916,-1.84162,0.030284,1.82787,-1.64589,-0.084141,1.74169,-1.61734,0.052551,1.65593,-1.62834,0.123289,1.59453,-1.616,0.219587,1.9355,-2.08965,0.285642,1.87104,-1.91626,0.083425,1.8907,-2.02151,0.093543,1.71719,-2.19867,0.144495,1.62891,-2.23827,0.305464,1.60507,-2.12183,0.366076,1.58418,-2.11485,0.203291,1.42698,-1.80632,0.017898,1.49325,-1.85514,0.017404,1.52046,-1.91706,0.020016,1.49606,-1.97147,0.201486,1.42887,-2.05655,0.270122,1.13547,-1.74159,0.146216,1.08214,-1.76898,0.17981,1.00648,-1.79416,0.294964,0.928399,-1.78401,0.364567,0.750316,-1.78397,0.385562,0.679398,-1.79973,0.256381,0.719225,-1.80169,0.278767,0.652538,-1.81129,0.393672,0.445457,-1.83763,0.326272,0.351175,-1.92657,0.554616,0.466821,-1.87158,0.551267,0.395625,-1.81359,0.13372,1.11217,-2.09785,0.128383,1.02843,-2.08112,-0.005102,1.12219,-2.05972,-0.007685,1.04106,-2.04476,0.009071,0.906248,-2.05172,-0.157544,0.821823,-2.04053,-0.173916,0.933068,-2.05772,-0.242842,0.919609,-2.04977,-0.462117,0.855318,-2.01591,-0.500545,0.954897,-1.95825,-0.564729,0.679469,-1.94525,-0.613526,0.733139,-2.00109,0.125869,1.34085,-1.81215,0.113739,1.3456,-2.02699},
/*1083*/{0.180214,1.92177,-1.71034,0.274833,1.86521,-1.8426,0.032416,1.82099,-1.64307,-0.080658,1.73519,-1.61307,0.055576,1.64844,-1.62476,0.127888,1.58835,-1.61337,0.2186,1.93133,-2.09091,0.285992,1.86791,-1.91694,0.081282,1.88621,-2.02117,0.090565,1.71277,-2.19738,0.139619,1.62427,-2.23771,0.300833,1.59766,-2.12378,0.362185,1.57539,-2.11774,0.203611,1.42376,-1.80599,0.017543,1.48849,-1.85512,0.016013,1.51622,-1.9161,0.019716,1.49122,-1.97154,0.202369,1.42528,-2.05638,0.26839,1.13165,-1.74196,0.145445,1.0785,-1.77006,0.17893,1.00347,-1.79586,0.291359,0.922709,-1.78421,0.357959,0.744161,-1.78446,0.376684,0.671411,-1.80072,0.249667,0.715305,-1.80204,0.268665,0.646403,-1.81433,0.383147,0.439201,-1.83748,0.312574,0.346286,-1.9267,0.543171,0.457003,-1.87098,0.539706,0.386568,-1.81387,0.139096,1.10831,-2.09862,0.135436,1.0245,-2.08198,-0.000136,1.11616,-2.05974,-0.001579,1.03535,-2.04522,0.017198,0.902226,-2.05241,-0.150191,0.821904,-2.04111,-0.164047,0.934025,-2.05749,-0.232835,0.921751,-2.04999,-0.458087,0.868377,-2.01915,-0.490294,0.964692,-1.95787,-0.560335,0.690546,-1.95002,-0.606933,0.746387,-2.00503,0.1267,1.33707,-1.81176,0.114716,1.34159,-2.02662},
/*1084*/{0.181243,1.91663,-1.7099,0.275396,1.85995,-1.84312,0.034768,1.81424,-1.6407,-0.077139,1.72676,-1.60868,0.05985,1.64157,-1.62144,0.132781,1.58199,-1.61091,0.215777,1.92649,-2.09213,0.285592,1.86315,-1.9178,0.080383,1.8811,-2.02043,0.084313,1.7084,-2.19672,0.133103,1.62022,-2.23735,0.296981,1.59,-2.12528,0.356956,1.5654,-2.12072,0.204131,1.42189,-1.80628,0.016686,1.48335,-1.85562,0.016792,1.51069,-1.91637,0.019424,1.48562,-1.97195,0.202782,1.42124,-2.05518,0.266948,1.12741,-1.7423,0.144475,1.07515,-1.7716,0.176048,0.999213,-1.79662,0.286692,0.916826,-1.7843,0.351476,0.737376,-1.78562,0.369765,0.664858,-1.80165,0.242445,0.710433,-1.80238,0.261029,0.641201,-1.81246,0.367788,0.43242,-1.8392,0.293505,0.352707,-1.92666,0.529247,0.444649,-1.87478,0.523287,0.376095,-1.81535,0.144945,1.10453,-2.09925,0.142482,1.02086,-2.08316,0.004614,1.10999,-2.05974,0.004746,1.0287,-2.04527,0.025785,0.897421,-2.05295,-0.142283,0.82239,-2.04229,-0.153433,0.934384,-2.05854,-0.223006,0.924637,-2.05121,-0.447857,0.877668,-2.02014,-0.48019,0.97365,-1.95785,-0.553922,0.701721,-1.95464,-0.599163,0.757384,-2.00944,0.128386,1.33394,-1.81077,0.116543,1.33664,-2.02566},
/*1085*/{0.181835,1.91093,-1.70962,0.276182,1.85518,-1.84377,0.03711,1.80656,-1.63723,-0.074141,1.71876,-1.60347,0.064565,1.63428,-1.6176,0.138274,1.57554,-1.609,0.214203,1.92166,-2.09335,0.285915,1.85855,-1.91859,0.079663,1.8759,-2.0199,0.079584,1.70396,-2.19577,0.127867,1.61567,-2.23654,0.291285,1.58155,-2.12769,0.351231,1.55548,-2.12348,0.204617,1.41822,-1.80488,0.015992,1.47813,-1.85594,0.016066,1.50589,-1.91704,0.019199,1.48001,-1.97216,0.203651,1.41708,-2.05409,0.266448,1.12308,-1.74192,0.142072,1.06971,-1.77343,0.173838,0.995409,-1.79641,0.282557,0.911794,-1.78493,0.344514,0.730832,-1.78637,0.36131,0.657621,-1.80244,0.235491,0.705443,-1.80301,0.251609,0.636514,-1.81294,0.350685,0.426179,-1.83952,0.273923,0.351141,-1.92831,0.513864,0.430856,-1.87472,0.502307,0.361803,-1.81505,0.148448,1.10077,-2.10075,0.147632,1.01642,-2.08395,0.009427,1.10494,-2.06095,0.011528,1.02222,-2.0458,0.034338,0.892547,-2.05378,-0.13435,0.821722,-2.04387,-0.141647,0.933842,-2.05957,-0.211038,0.927089,-2.05088,-0.440412,0.886389,-2.02093,-0.469498,0.980915,-1.95774,-0.546046,0.7105,-1.95847,-0.591449,0.768602,-2.01443,0.128872,1.32993,-1.80988,0.118067,1.3318,-2.02483},
/*1086*/{0.182483,1.90534,-1.70925,0.275515,1.8502,-1.84477,0.040084,1.79871,-1.63481,-0.069125,1.71008,-1.59916,0.06984,1.62671,-1.61415,0.143102,1.56917,-1.60617,0.21253,1.91683,-2.09395,0.285253,1.85456,-1.92015,0.077936,1.87075,-2.01939,0.074816,1.69922,-2.19543,0.121027,1.61111,-2.23583,0.286443,1.57324,-2.12907,0.345487,1.54544,-2.12672,0.20548,1.41488,-1.80466,0.015846,1.47324,-1.8558,0.016316,1.5002,-1.91694,0.017663,1.4734,-1.97174,0.202884,1.41328,-2.05467,0.264833,1.11865,-1.74174,0.140802,1.06563,-1.77334,0.172683,0.990924,-1.79717,0.277825,0.90617,-1.78489,0.336695,0.723573,-1.78682,0.350975,0.65091,-1.80369,0.227981,0.701641,-1.80379,0.243512,0.63196,-1.81385,0.335134,0.423362,-1.84312,0.255711,0.35469,-1.93119,0.500036,0.416881,-1.87693,0.482085,0.347658,-1.81543,0.153397,1.09652,-2.10145,0.153935,1.01228,-2.08549,0.015002,1.09926,-2.06204,0.017493,1.01584,-2.04565,0.044485,0.887076,-2.05543,-0.12637,0.820961,-2.04507,-0.129908,0.934118,-2.06005,-0.200539,0.925908,-2.05058,-0.428529,0.894372,-2.02296,-0.459768,0.989997,-1.95939,-0.537522,0.718502,-1.96228,-0.580622,0.776591,-2.01774,0.130666,1.32602,-1.80941,0.118642,1.32673,-2.02431},
/*1087*/{0.182959,1.89958,-1.70885,0.275961,1.84552,-1.84465,0.043546,1.79026,-1.63119,-0.064126,1.70125,-1.59379,0.074903,1.6179,-1.61054,0.149238,1.56183,-1.60415,0.210631,1.91184,-2.0951,0.285759,1.8499,-1.92054,0.076593,1.86594,-2.01843,0.070304,1.69442,-2.19481,0.114839,1.6061,-2.23545,0.280664,1.56433,-2.13166,0.339494,1.5346,-2.13007,0.204954,1.40941,-1.80309,0.014697,1.46695,-1.85699,0.015693,1.49459,-1.91674,0.017309,1.46886,-1.97279,0.20262,1.40846,-2.05489,0.263013,1.11253,-1.7423,0.138302,1.06159,-1.77327,0.169487,0.986715,-1.7977,0.274342,0.900934,-1.78495,0.329678,0.717072,-1.7869,0.339731,0.643478,-1.80422,0.219613,0.696882,-1.80386,0.233065,0.628332,-1.81458,0.319402,0.42089,-1.84572,0.234671,0.354654,-1.93116,0.484254,0.404768,-1.87873,0.463785,0.337783,-1.81723,0.158489,1.09183,-2.10328,0.159797,1.00791,-2.08722,0.018442,1.09324,-2.06146,0.024014,1.00933,-2.04594,0.053774,0.881768,-2.05718,-0.116671,0.820293,-2.04696,-0.118638,0.934066,-2.06044,-0.18908,0.927883,-2.05126,-0.416943,0.900303,-2.02386,-0.449598,0.995672,-1.96077,-0.527303,0.725384,-1.96663,-0.570377,0.783324,-2.02249,0.129689,1.32031,-1.80984,0.118848,1.32184,-2.02479},
/*1088*/{0.183498,1.89366,-1.70768,0.276167,1.84187,-1.84595,0.046786,1.7821,-1.62789,-0.057976,1.69134,-1.58872,0.081169,1.60968,-1.60699,0.155825,1.55501,-1.6023,0.20965,1.90744,-2.09603,0.285465,1.84387,-1.92136,0.076289,1.86071,-2.01708,0.06409,1.69084,-2.19445,0.108284,1.60146,-2.23541,0.274254,1.55405,-2.13415,0.332697,1.52339,-2.13407,0.203469,1.40527,-1.80265,0.013418,1.46166,-1.85771,0.014342,1.4907,-1.91703,0.016003,1.46315,-1.9736,0.202758,1.40376,-2.05465,0.260562,1.10724,-1.7428,0.137315,1.05956,-1.77275,0.168139,0.982701,-1.79761,0.27082,0.895043,-1.78458,0.322175,0.711781,-1.78955,0.333724,0.639139,-1.80679,0.211961,0.694891,-1.80409,0.222858,0.624398,-1.81533,0.304349,0.418271,-1.84912,0.213808,0.35523,-1.93091,0.467941,0.396544,-1.88433,0.44401,0.337499,-1.8206,0.161988,1.08774,-2.10446,0.166144,1.00365,-2.08826,0.021682,1.08665,-2.05563,0.030107,1.00166,-2.04572,0.06355,0.875839,-2.05874,-0.107588,0.819674,-2.04855,-0.105411,0.931369,-2.06068,-0.176194,0.929819,-2.05194,-0.401332,0.903072,-2.02293,-0.438066,1.00212,-1.96159,-0.5164,0.730624,-1.96933,-0.558288,0.789116,-2.02639,0.128554,1.31593,-1.80961,0.118746,1.31697,-2.02461},
/*1089*/{0.185159,1.88772,-1.707,0.277231,1.83549,-1.84652,0.050835,1.7731,-1.62485,-0.052603,1.68164,-1.5834,0.087853,1.6016,-1.60305,0.162767,1.5479,-1.59983,0.208507,1.90251,-2.0971,0.286361,1.84016,-1.92235,0.075268,1.85694,-2.01608,0.060039,1.68765,-2.19381,0.101501,1.59707,-2.23558,0.268406,1.54453,-2.13595,0.325907,1.51261,-2.13745,0.202047,1.40047,-1.80076,0.010573,1.45716,-1.85833,0.012341,1.48233,-1.91731,0.014655,1.45803,-1.97496,0.202214,1.39933,-2.0546,0.25415,1.1042,-1.74358,0.134785,1.05596,-1.77178,0.165564,0.97906,-1.79672,0.263673,0.888936,-1.78384,0.315026,0.706996,-1.7914,0.323666,0.63352,-1.80824,0.204311,0.69403,-1.80406,0.214169,0.624665,-1.81764,0.286357,0.415658,-1.85153,0.191129,0.355981,-1.93063,0.445302,0.393442,-1.89089,0.421816,0.338107,-1.82069,0.166392,1.08362,-2.10487,0.172642,0.999432,-2.08957,0.028933,1.07521,-2.06033,0.036903,0.994351,-2.04614,0.073979,0.870081,-2.06129,-0.097061,0.818181,-2.05029,-0.093249,0.932361,-2.06303,-0.162172,0.929313,-2.05233,-0.39269,0.910808,-2.02587,-0.427462,1.00682,-1.96335,-0.504223,0.736074,-1.97305,-0.544273,0.793278,-2.03058,0.127179,1.31082,-1.80938,0.118914,1.31176,-2.02445},
/*1090*/{0.186224,1.88231,-1.70578,0.278304,1.83145,-1.84766,0.055511,1.7643,-1.62114,-0.046802,1.67153,-1.57814,0.095064,1.59396,-1.59984,0.170109,1.54132,-1.59813,0.2072,1.89809,-2.09842,0.286776,1.83481,-1.92328,0.074402,1.85361,-2.01549,0.053318,1.68212,-2.1932,0.094953,1.59219,-2.23545,0.262141,1.53586,-2.13921,0.318298,1.50153,-2.14112,0.200726,1.39558,-1.79958,0.007541,1.45254,-1.85931,0.010229,1.47689,-1.91917,0.012171,1.4523,-1.9755,0.200984,1.39434,-2.0539,0.25616,1.10172,-1.73785,0.131491,1.05409,-1.77135,0.162586,0.978226,-1.79676,0.25835,0.883255,-1.78422,0.309148,0.705815,-1.79265,0.314421,0.631518,-1.81163,0.197831,0.697996,-1.80549,0.203104,0.626675,-1.81952,0.265032,0.417891,-1.85464,0.169069,0.356523,-1.93293,0.424126,0.392055,-1.89418,0.400651,0.340722,-1.82361,0.171157,1.0792,-2.10599,0.178267,0.995474,-2.09095,0.033407,1.06828,-2.06144,0.043994,0.987028,-2.04619,0.084181,0.863729,-2.06297,-0.085182,0.816729,-2.0521,-0.080086,0.93058,-2.06336,-0.149252,0.928312,-2.05287,-0.379223,0.913957,-2.02767,-0.415702,1.01018,-1.96542,-0.490651,0.739081,-1.97675,-0.530759,0.797106,-2.03481,0.124962,1.30626,-1.80895,0.117901,1.30633,-2.02407},
/*1091*/{0.187208,1.8766,-1.70502,0.279585,1.82643,-1.84785,0.060064,1.75459,-1.61769,-0.03763,1.66146,-1.57286,0.101917,1.58509,-1.59675,0.178873,1.53514,-1.59704,0.206418,1.89348,-2.09951,0.287845,1.8302,-1.92446,0.074192,1.85165,-2.01381,0.049507,1.67892,-2.19238,0.087401,1.5875,-2.23538,0.255224,1.52606,-2.14228,0.310857,1.49001,-2.14454,0.198064,1.3907,-1.79844,0.00407,1.44919,-1.85942,0.007871,1.47186,-1.92036,0.009712,1.44674,-1.97645,0.202083,1.38927,-2.05181,0.252411,1.10088,-1.7343,0.128465,1.05198,-1.77033,0.160544,0.978041,-1.79705,0.253487,0.881229,-1.78548,0.304479,0.705784,-1.79483,0.305678,0.63202,-1.81283,0.191974,0.703695,-1.80607,0.195366,0.632317,-1.82001,0.244787,0.419787,-1.857,0.146422,0.35766,-1.93384,0.402309,0.390988,-1.89566,0.376367,0.339607,-1.82602,0.175109,1.07598,-2.10678,0.185251,0.991807,-2.09124,0.03793,1.06017,-2.06118,0.05113,0.980121,-2.04737,0.094559,0.855733,-2.06117,-0.072942,0.814774,-2.05237,-0.066305,0.928235,-2.06429,-0.136307,0.926941,-2.05413,-0.367022,0.916043,-2.0279,-0.401894,1.01258,-1.96773,-0.476854,0.741181,-1.97945,-0.519779,0.800912,-2.03375,0.121762,1.30193,-1.80784,0.11739,1.30125,-2.02303},
/*1092*/{0.188746,1.87257,-1.70369,0.279653,1.82051,-1.8485,0.06664,1.74524,-1.61379,-0.031915,1.65072,-1.56763,0.110198,1.5772,-1.59331,0.187332,1.52904,-1.59482,0.205735,1.88992,-2.10137,0.28859,1.82653,-1.92562,0.073567,1.84931,-2.01243,0.045452,1.6768,-2.19218,0.080264,1.58357,-2.23451,0.247111,1.51568,-2.14483,0.302648,1.47878,-2.14817,0.195948,1.38876,-1.79808,0.000461,1.4464,-1.86292,0.003954,1.4679,-1.92203,0.006873,1.442,-1.97818,0.201045,1.38519,-2.05114,0.250545,1.10177,-1.73081,0.12788,1.0537,-1.77103,0.160201,0.978153,-1.79736,0.253818,0.885166,-1.78396,0.298991,0.705752,-1.79536,0.297441,0.632241,-1.81342,0.186457,0.708948,-1.80655,0.185687,0.638085,-1.82076,0.225288,0.423284,-1.85834,0.124229,0.358954,-1.93555,0.380086,0.390433,-1.89599,0.354214,0.339281,-1.82517,0.179498,1.07211,-2.10728,0.192379,0.989167,-2.09139,0.042492,1.05339,-2.06235,0.058423,0.972727,-2.04682,0.104871,0.851381,-2.0637,-0.060617,0.813345,-2.05497,-0.052212,0.9263,-2.06573,-0.121951,0.925559,-2.05547,-0.350906,0.917455,-2.03121,-0.389072,1.01353,-1.96991,-0.464112,0.740675,-1.98392,-0.500986,0.799328,-2.04143,0.119051,1.29994,-1.80734,0.116398,1.29689,-2.02254},
/*1093*/{0.189917,1.86807,-1.70223,0.281124,1.81625,-1.84977,0.072718,1.7357,-1.61081,-0.022299,1.6406,-1.56157,0.118934,1.57056,-1.59144,0.196637,1.52369,-1.59423,0.205781,1.88673,-2.10227,0.289469,1.82251,-1.92771,0.073839,1.84881,-2.01182,0.042336,1.675,-2.19043,0.073169,1.58011,-2.2335,0.240452,1.50728,-2.14796,0.29387,1.46838,-2.15181,0.193597,1.38717,-1.79675,-0.003337,1.44403,-1.86405,0.001609,1.46544,-1.9226,0.003452,1.43791,-1.98039,0.198741,1.38113,-2.05045,0.247736,1.10111,-1.73032,0.125923,1.05359,-1.77227,0.160088,0.97796,-1.79685,0.256815,0.889978,-1.78324,0.291566,0.705044,-1.79611,0.286407,0.630938,-1.81459,0.17915,0.712687,-1.80625,0.174593,0.643209,-1.82095,0.205143,0.423974,-1.85888,0.102528,0.359637,-1.93654,0.359302,0.389196,-1.89543,0.333231,0.338722,-1.82365,0.183144,1.07255,-2.10717,0.199683,0.989139,-2.09201,0.048207,1.04696,-2.06298,0.065485,0.968155,-2.04785,0.115898,0.846877,-2.06409,-0.047125,0.809736,-2.05502,-0.037742,0.919634,-2.06524,-0.10719,0.923858,-2.05662,-0.33602,0.916971,-2.03304,-0.3762,1.01365,-1.97259,-0.447899,0.740309,-1.98648,-0.484583,0.797771,-2.04697,0.115892,1.2984,-1.80613,0.114218,1.29291,-2.02129},
/*1094*/{0.191071,1.86443,-1.70091,0.281121,1.81438,-1.85072,0.079394,1.72667,-1.60763,-0.011631,1.63048,-1.55696,0.129126,1.56334,-1.58875,0.206709,1.51891,-1.59307,0.20667,1.88449,-2.10297,0.28961,1.81874,-1.92927,0.073863,1.84856,-2.01146,0.038985,1.6737,-2.18826,0.06681,1.57892,-2.23162,0.232079,1.4971,-2.15005,0.284912,1.45765,-2.15496,0.190577,1.38648,-1.79479,-0.006398,1.44182,-1.86684,3.2e-005,1.46324,-1.92402,0.001491,1.43264,-1.98232,0.196166,1.37751,-2.04962,0.245078,1.10107,-1.72949,0.124909,1.05128,-1.7713,0.158958,0.976141,-1.79624,0.262863,0.894429,-1.7827,0.28238,0.704942,-1.79599,0.274085,0.631386,-1.8143,0.170516,0.71623,-1.80491,0.162757,0.645891,-1.81941,0.185591,0.423435,-1.85912,0.082175,0.361803,-1.93678,0.338853,0.387396,-1.89496,0.311208,0.338365,-1.82328,0.188448,1.07278,-2.10623,0.206789,0.990565,-2.09182,0.053708,1.04413,-2.0637,0.073366,0.964888,-2.04954,0.128964,0.843579,-2.0634,-0.033274,0.807443,-2.05406,-0.023182,0.918845,-2.06684,-0.0933,0.922173,-2.05849,-0.322318,0.916765,-2.03329,-0.363852,1.01285,-1.97461,-0.432119,0.738262,-1.98898,-0.467346,0.795226,-2.04877,0.11295,1.29754,-1.80461,0.113019,1.28875,-2.01966},
/*1095*/{0.192807,1.86096,-1.70021,0.281164,1.80976,-1.85253,0.086108,1.71907,-1.60585,-0.00189,1.62112,-1.55198,0.139601,1.55832,-1.58754,0.217542,1.51587,-1.59202,0.207394,1.88223,-2.10273,0.290178,1.81572,-1.9302,0.074017,1.84847,-2.01147,0.033868,1.67518,-2.18522,0.061924,1.57922,-2.22934,0.225153,1.4903,-2.15223,0.275684,1.44817,-2.15814,0.18796,1.38569,-1.79295,-0.00675,1.4399,-1.86728,-0.001687,1.46305,-1.92534,-0.000676,1.42969,-1.98476,0.194844,1.37519,-2.0493,0.243099,1.10057,-1.73013,0.1222,1.04951,-1.77181,0.156744,0.975027,-1.79726,0.26954,0.896035,-1.78454,0.271105,0.703994,-1.79489,0.261293,0.630572,-1.81312,0.159654,0.718924,-1.80433,0.152288,0.648708,-1.8169,0.16436,0.424047,-1.85908,0.06022,0.362149,-1.93589,0.317599,0.386982,-1.89581,0.290777,0.338195,-1.8231,0.195021,1.07404,-2.10599,0.215885,0.992243,-2.09084,0.059163,1.04214,-2.06555,0.082175,0.962708,-2.05082,0.143364,0.84271,-2.06206,-0.018814,0.805645,-2.05311,-0.008644,0.916548,-2.06761,-0.078485,0.920206,-2.0593,-0.306872,0.913825,-2.03588,-0.351713,1.01038,-1.97709,-0.414437,0.734525,-1.99193,-0.451229,0.790749,-2.05165,0.110521,1.29678,-1.80388,0.111899,1.28638,-2.01886},
/*1096*/{0.19357,1.85817,-1.70014,0.280806,1.80706,-1.85269,0.092756,1.71286,-1.60473,0.007769,1.61384,-1.54867,0.150337,1.55504,-1.58801,0.228225,1.5129,-1.59157,0.207696,1.88074,-2.10259,0.289717,1.81319,-1.93117,0.074506,1.84844,-2.01155,0.029883,1.67582,-2.18206,0.057447,1.5813,-2.22675,0.217311,1.48398,-2.15298,0.265762,1.43974,-2.1616,0.18497,1.38552,-1.7905,-0.009452,1.439,-1.8692,-0.002991,1.46202,-1.92592,-0.002475,1.42802,-1.98579,0.192854,1.37263,-2.049,0.239748,1.09812,-1.72941,0.116846,1.04705,-1.77229,0.152696,0.973336,-1.7968,0.270965,0.894337,-1.78679,0.259662,0.701806,-1.79324,0.248553,0.629011,-1.81196,0.149156,0.720103,-1.80461,0.137767,0.649271,-1.81673,0.146046,0.425922,-1.85806,0.039164,0.362926,-1.93596,0.296969,0.386349,-1.89498,0.269037,0.337572,-1.82308,0.20183,1.07631,-2.1052,0.224793,0.994423,-2.08985,0.066675,1.03939,-2.06717,0.09164,0.961049,-2.05264,0.159326,0.843253,-2.06083,-0.004933,0.804072,-2.05242,0.006686,0.914288,-2.06936,-0.062987,0.916694,-2.0603,-0.293077,0.911681,-2.03795,-0.340829,1.00704,-1.97897,-0.396471,0.72967,-1.99438,-0.43298,0.78436,-2.05431,0.107204,1.29654,-1.80267,0.110157,1.28417,-2.01753},
/*1097*/{0.193982,1.85665,-1.70076,0.281004,1.80661,-1.8535,0.098084,1.70792,-1.60366,0.018559,1.60793,-1.54546,0.161359,1.55189,-1.58748,0.241143,1.51169,-1.59088,0.208991,1.87917,-2.10223,0.287939,1.81177,-1.93192,0.074668,1.84841,-2.01186,0.026325,1.67817,-2.17909,0.052185,1.58408,-2.22409,0.208558,1.47925,-2.15363,0.2555,1.43215,-2.16498,0.18203,1.38549,-1.78851,-0.010392,1.43806,-1.87002,-0.004354,1.46189,-1.92565,-0.004589,1.42716,-1.98602,0.192333,1.37103,-2.04841,0.233787,1.09567,-1.72907,0.111835,1.04608,-1.77268,0.146813,0.971638,-1.79843,0.264125,0.890024,-1.78611,0.24738,0.698695,-1.79174,0.235544,0.627848,-1.81108,0.136586,0.719346,-1.80425,0.124991,0.65018,-1.8177,0.125894,0.424541,-1.85699,0.018343,0.362916,-1.93525,0.275579,0.386069,-1.89456,0.248001,0.337077,-1.82314,0.210837,1.07907,-2.1048,0.235932,0.998284,-2.08975,0.075218,1.03965,-2.07034,0.102366,0.959805,-2.05398,0.175728,0.845223,-2.06041,0.009877,0.803556,-2.05143,0.021166,0.911662,-2.07052,-0.049359,0.914811,-2.06172,-0.281015,0.907961,-2.03741,-0.330904,1.00187,-1.98113,-0.376387,0.723985,-1.99484,-0.414039,0.777347,-2.05715,0.104685,1.29632,-1.80155,0.108974,1.28299,-2.01633},
/*1098*/{0.194834,1.85531,-1.70109,0.28044,1.80471,-1.85401,0.102836,1.70536,-1.60319,0.028733,1.60398,-1.54281,0.173052,1.54984,-1.58703,0.252699,1.51174,-1.59138,0.209683,1.87835,-2.10183,0.287464,1.81038,-1.93141,0.074645,1.84835,-2.01205,0.02287,1.68165,-2.17557,0.045672,1.5875,-2.22344,0.199876,1.47589,-2.1558,0.245221,1.427,-2.16865,0.18042,1.38479,-1.78777,-0.012594,1.43767,-1.87069,-0.006567,1.46131,-1.92566,-0.005583,1.42706,-1.98614,0.189179,1.37023,-2.0483,0.228168,1.09371,-1.72746,0.10641,1.04438,-1.77348,0.140531,0.969188,-1.79801,0.253776,0.885081,-1.78432,0.233704,0.694365,-1.79138,0.21779,0.623153,-1.80992,0.123661,0.71845,-1.80347,0.10958,0.64934,-1.81792,0.10563,0.424701,-1.85605,-0.00337,0.364068,-1.93409,0.254165,0.385383,-1.89483,0.225582,0.336887,-1.82211,0.21931,1.08199,-2.10423,0.247271,1.00228,-2.08881,0.085432,1.03756,-2.07173,0.115464,0.959565,-2.05622,0.192109,0.848057,-2.06013,0.026815,0.799198,-2.04805,0.03597,0.910613,-2.0721,-0.034185,0.9139,-2.06374,-0.265405,0.903365,-2.04011,-0.320422,0.99666,-1.98373,-0.356776,0.716025,-1.99639,-0.395195,0.768439,-2.05943,0.102307,1.29581,-1.80144,0.106617,1.28231,-2.01621},
/*1099*/{0.196075,1.85372,-1.70122,0.279734,1.80193,-1.853,0.108265,1.70294,-1.60217,0.038658,1.60075,-1.54041,0.184175,1.54948,-1.58653,0.265579,1.51282,-1.59198,0.20987,1.8777,-2.10119,0.286941,1.80901,-1.93107,0.074023,1.84794,-2.0121,0.018406,1.68511,-2.17216,0.039271,1.59082,-2.22195,0.190776,1.47355,-2.15792,0.234568,1.42354,-2.17133,0.177813,1.38454,-1.78532,-0.01286,1.43757,-1.87047,-0.007069,1.46085,-1.92496,-0.007525,1.42792,-1.98587,0.187689,1.37043,-2.04833,0.222668,1.08869,-1.72834,0.10029,1.04361,-1.77433,0.131905,0.967944,-1.79962,0.24212,0.880309,-1.7836,0.220436,0.690623,-1.79109,0.202159,0.618805,-1.81015,0.109229,0.717125,-1.80301,0.094556,0.648201,-1.81705,0.085178,0.425496,-1.85618,-0.024315,0.364633,-1.93401,0.233527,0.385613,-1.89277,0.205823,0.337418,-1.82083,0.228247,1.08652,-2.10372,0.258718,1.00754,-2.08796,0.095776,1.03658,-2.07387,0.128352,0.960157,-2.05782,0.208087,0.851162,-2.05929,0.043085,0.797956,-2.04664,0.050647,0.908764,-2.07281,-0.019804,0.911537,-2.06459,-0.251243,0.898777,-2.04094,-0.311288,0.98986,-1.98621,-0.335965,0.707879,-1.9991,-0.375395,0.757962,-2.06173,0.100243,1.29545,-1.80093,0.105222,1.28251,-2.01572},
/*1100*/{0.197605,1.85346,-1.7012,0.279546,1.80132,-1.85319,0.113445,1.70171,-1.60204,0.04835,1.59674,-1.53818,0.195166,1.54996,-1.58665,0.277665,1.51549,-1.59338,0.209236,1.87707,-2.10126,0.286121,1.80823,-1.93063,0.074172,1.8484,-2.01244,0.0154,1.69018,-2.16874,0.032377,1.59423,-2.22047,0.182479,1.47326,-2.16011,0.224664,1.42093,-2.17384,0.176084,1.38426,-1.78501,-0.01487,1.43694,-1.87079,-0.008625,1.4606,-1.92526,-0.007895,1.42824,-1.98457,0.186309,1.37126,-2.04871,0.216981,1.085,-1.72845,0.091017,1.0428,-1.77678,0.12344,0.966417,-1.79937,0.230321,0.875794,-1.78413,0.204938,0.686818,-1.79134,0.185971,0.615504,-1.81058,0.095857,0.715935,-1.80266,0.079534,0.6468,-1.81696,0.065198,0.425549,-1.85496,-0.044946,0.364895,-1.93341,0.212424,0.384966,-1.89329,0.18413,0.336773,-1.82083,0.238104,1.09124,-2.10304,0.270743,1.01324,-2.08757,0.106561,1.03695,-2.07572,0.141376,0.960171,-2.05891,0.224563,0.855428,-2.0603,0.058498,0.797533,-2.04664,0.064254,0.90842,-2.07369,-0.00517,0.909341,-2.06572,-0.236999,0.892312,-2.04293,-0.300797,0.98065,-1.98791,-0.312582,0.698866,-1.9995,-0.354196,0.747787,-2.06454,0.098885,1.29493,-1.80134,0.104279,1.28305,-2.01618},
/*1101*/{0.199223,1.85236,-1.70125,0.279575,1.80026,-1.8532,0.118084,1.70113,-1.60156,0.057984,1.59497,-1.53667,0.205988,1.55137,-1.58656,0.290267,1.51903,-1.59478,0.208374,1.87655,-2.10062,0.285118,1.80663,-1.93055,0.073475,1.84882,-2.01208,0.012316,1.69575,-2.16551,0.025706,1.59843,-2.22026,0.174428,1.47347,-2.16266,0.214093,1.42074,-2.17678,0.175057,1.38434,-1.78411,-0.015739,1.4364,-1.87055,-0.010422,1.46045,-1.92495,-0.010264,1.42973,-1.98399,0.184713,1.37231,-2.04893,0.210586,1.08088,-1.72906,0.085393,1.04061,-1.77501,0.113891,0.964282,-1.80058,0.217379,0.871747,-1.78407,0.190142,0.681834,-1.79238,0.17181,0.612752,-1.81147,0.082124,0.7131,-1.80342,0.063995,0.644502,-1.81667,0.044449,0.425679,-1.85416,-0.065337,0.365052,-1.93308,0.191641,0.384755,-1.8916,0.163236,0.33604,-1.82051,0.245915,1.09714,-2.10305,0.281513,1.02042,-2.08685,0.116554,1.03746,-2.07667,0.153595,0.961937,-2.05964,0.239905,0.858844,-2.06079,0.074558,0.797873,-2.04711,0.078598,0.908934,-2.07462,0.008168,0.907895,-2.06676,-0.217718,0.882218,-2.04041,-0.292318,0.97137,-1.98866,-0.290042,0.688811,-2.00083,-0.333518,0.735818,-2.06677,0.097771,1.2948,-1.80162,0.102914,1.28397,-2.01652},
/*1102*/{0.201167,1.85285,-1.70101,0.277761,1.80118,-1.85349,0.124014,1.70127,-1.60053,0.06833,1.5926,-1.53399,0.216572,1.55364,-1.58747,0.302792,1.52359,-1.59758,0.207317,1.87659,-2.10041,0.285018,1.80645,-1.9307,0.073252,1.84924,-2.01188,0.007063,1.70172,-2.16338,0.018634,1.60391,-2.22012,0.165103,1.47448,-2.16554,0.204132,1.42094,-2.17903,0.173018,1.38428,-1.7822,-0.017431,1.43608,-1.87039,-0.01067,1.46046,-1.92465,-0.010641,1.43007,-1.98334,0.183609,1.37352,-2.04903,0.202845,1.07775,-1.72875,0.076518,1.04259,-1.77688,0.104233,0.963531,-1.79976,0.204075,0.866879,-1.78449,0.176482,0.678009,-1.79276,0.15548,0.60918,-1.81238,0.067712,0.710438,-1.80369,0.048878,0.644109,-1.8171,0.024441,0.426471,-1.85439,-0.085958,0.365488,-1.93278,0.17064,0.384242,-1.89257,0.14282,0.335679,-1.82065,0.253844,1.10366,-2.10255,0.291934,1.02834,-2.08617,0.126491,1.03999,-2.07765,0.165094,0.968971,-2.0637,0.253909,0.862615,-2.06159,0.09051,0.798343,-2.04778,0.091942,0.910308,-2.07547,0.022268,0.908637,-2.06847,-0.210673,0.878563,-2.04439,-0.28386,0.960983,-1.99034,-0.267366,0.678681,-2.00287,-0.311215,0.723141,-2.0687,0.096312,1.29448,-1.80149,0.10245,1.28474,-2.01641},
/*1103*/{0.202659,1.854,-1.70136,0.277856,1.80248,-1.85391,0.127592,1.70188,-1.60007,0.077741,1.59153,-1.53213,0.227041,1.55678,-1.58772,0.314066,1.52918,-1.6009,0.206385,1.87742,-2.10063,0.284091,1.80652,-1.931,0.072067,1.84925,-2.01057,0.00354,1.70708,-2.16073,0.01088,1.60937,-2.22008,0.156516,1.47687,-2.16852,0.193882,1.42298,-2.18126,0.171987,1.38439,-1.78177,-0.018186,1.43585,-1.87042,-0.010879,1.46054,-1.92435,-0.011589,1.43046,-1.98315,0.183542,1.37535,-2.04882,0.195236,1.07534,-1.72924,0.069477,1.04322,-1.77611,0.093825,0.962721,-1.80074,0.19086,0.861703,-1.78468,0.160326,0.674389,-1.79433,0.137628,0.604436,-1.8135,0.053668,0.708868,-1.80374,0.032815,0.641184,-1.81719,0.004732,0.426561,-1.85474,-0.106339,0.366202,-1.93289,0.150522,0.384288,-1.89196,0.123325,0.336868,-1.81974,0.262185,1.11072,-2.10206,0.302303,1.03645,-2.08599,0.136195,1.04201,-2.07904,0.176815,0.973337,-2.06442,0.268661,0.867609,-2.06272,0.106191,0.799925,-2.04871,0.104762,0.911559,-2.07574,0.035038,0.907929,-2.06947,-0.195137,0.870513,-2.0455,-0.274368,0.948249,-1.9924,-0.243735,0.667553,-2.00407,-0.288482,0.710292,-2.07133,0.095921,1.29434,-1.80191,0.102692,1.28591,-2.01688},
/*1104*/{0.204342,1.85548,-1.7017,0.277263,1.80264,-1.85421,0.132535,1.70354,-1.59921,0.086894,1.59023,-1.53069,0.236732,1.56056,-1.58925,0.324674,1.53568,-1.60411,0.20483,1.87819,-2.10066,0.283425,1.80746,-1.93188,0.070763,1.85159,-2.00953,-0.001913,1.71305,-2.16008,0.002777,1.61576,-2.21985,0.14812,1.48003,-2.17077,0.184439,1.42601,-2.1822,0.171152,1.38415,-1.78203,-0.018963,1.43615,-1.87081,-0.011568,1.46138,-1.92437,-0.012405,1.43116,-1.98286,0.182231,1.37722,-2.04934,0.185268,1.0728,-1.73381,0.059629,1.04457,-1.77794,0.083676,0.963633,-1.80065,0.175054,0.857057,-1.78546,0.145303,0.672372,-1.79577,0.121616,0.602506,-1.81487,0.037748,0.707134,-1.80441,0.016925,0.641246,-1.81826,-0.015592,0.427169,-1.85535,-0.126842,0.366979,-1.93287,0.13039,0.383603,-1.89242,0.101502,0.336326,-1.81944,0.268295,1.11835,-2.10192,0.310835,1.045,-2.08568,0.144749,1.04607,-2.08014,0.188027,0.977587,-2.06528,0.282409,0.874137,-2.06346,0.122348,0.802633,-2.05008,0.117745,0.914474,-2.07707,0.047656,0.906816,-2.07078,-0.177945,0.859615,-2.04496,-0.267151,0.936127,-1.99257,-0.218327,0.657275,-2.00643,-0.265783,0.697807,-2.07383,0.09519,1.29425,-1.80295,0.101852,1.28729,-2.01797},
/*1105*/{0.20624,1.85833,-1.70213,0.278085,1.80462,-1.85555,0.137187,1.70529,-1.59865,0.097632,1.59034,-1.52931,0.245872,1.56543,-1.59117,0.33473,1.54313,-1.60772,0.203207,1.87964,-2.10064,0.283038,1.80876,-1.93256,0.070244,1.85284,-2.00871,-0.006373,1.71901,-2.15884,-0.003695,1.62183,-2.22005,0.139168,1.48487,-2.17216,0.173923,1.4303,-2.18331,0.170988,1.38443,-1.78196,-0.019633,1.43791,-1.87043,-0.011489,1.46226,-1.92446,-0.012465,1.43223,-1.98231,0.183085,1.37973,-2.04985,0.179197,1.07253,-1.73353,0.052633,1.04508,-1.77652,0.072754,0.96357,-1.80021,0.159559,0.853707,-1.78529,0.128908,0.670883,-1.79716,0.104545,0.601323,-1.8161,0.022055,0.707078,-1.80544,-0.000503,0.640389,-1.81986,-0.034245,0.427355,-1.8552,-0.147326,0.367631,-1.93343,0.110539,0.383741,-1.89229,0.081876,0.336927,-1.81889,0.274081,1.1268,-2.10139,0.318972,1.05438,-2.08607,0.153106,1.05031,-2.08089,0.198027,0.982737,-2.06617,0.295533,0.881596,-2.06348,0.138269,0.804269,-2.05066,0.129597,0.917144,-2.07813,0.060067,0.904206,-2.07188,-0.168,0.853172,-2.0479,-0.257588,0.921359,-1.99327,-0.19409,0.646347,-2.00879,-0.242991,0.684864,-2.07643,0.095237,1.29483,-1.80363,0.102259,1.28929,-2.01868},
/*1106*/{0.208307,1.86147,-1.70276,0.277617,1.80602,-1.85592,0.142742,1.70703,-1.59827,0.105872,1.59201,-1.52885,0.255364,1.57098,-1.59334,0.343308,1.55127,-1.61115,0.201173,1.88155,-2.10032,0.282197,1.80998,-1.9332,0.068605,1.85483,-2.00683,-0.011713,1.72505,-2.15784,-0.011601,1.62892,-2.21983,0.13121,1.49023,-2.17222,0.164453,1.43548,-2.18338,0.170435,1.38459,-1.78174,-0.018697,1.43937,-1.87078,-0.012249,1.46416,-1.92361,-0.012417,1.43297,-1.98289,0.182824,1.38215,-2.04959,0.170929,1.07019,-1.73458,0.043538,1.04688,-1.77677,0.061699,0.965268,-1.80039,0.142842,0.852739,-1.78732,0.113602,0.669476,-1.7979,0.086969,0.600496,-1.81709,0.007,0.70769,-1.80551,-0.01606,0.641845,-1.82033,-0.055392,0.427544,-1.85507,-0.167269,0.36913,-1.93398,0.090132,0.383022,-1.89251,0.060963,0.336961,-1.81994,0.280087,1.13358,-2.1011,0.326719,1.0635,-2.08591,0.161422,1.05409,-2.08104,0.208101,0.988054,-2.06628,0.310832,0.890715,-2.06463,0.154115,0.807474,-2.05234,0.140465,0.91896,-2.07615,0.07132,0.906601,-2.0721,-0.150879,0.841621,-2.04539,-0.247042,0.906115,-1.99258,-0.168998,0.635479,-2.01142,-0.218611,0.671584,-2.07916,0.094865,1.29545,-1.80424,0.102226,1.29119,-2.01931},
/*1107*/{0.209745,1.86428,-1.70351,0.277622,1.80785,-1.85743,0.148529,1.70975,-1.5985,0.114322,1.59355,-1.52792,0.26345,1.57692,-1.59567,0.35214,1.55996,-1.61568,0.197067,1.88362,-2.09994,0.280859,1.81225,-1.93416,0.067543,1.85602,-2.00539,-0.017823,1.73206,-2.15791,-0.018835,1.63586,-2.21928,0.121832,1.496,-2.17225,0.154802,1.44153,-2.1836,0.169889,1.3851,-1.78166,-0.018574,1.44144,-1.86999,-0.012351,1.4643,-1.92354,-0.012856,1.43504,-1.98324,0.182452,1.38468,-2.04948,0.163548,1.06876,-1.73548,0.034758,1.04845,-1.77648,0.050685,0.966964,-1.80053,0.125774,0.852552,-1.78857,0.097158,0.669008,-1.79957,0.070554,0.600651,-1.81759,-0.009146,0.708957,-1.80657,-0.034147,0.643741,-1.81888,-0.075854,0.428506,-1.85653,-0.187353,0.370238,-1.93377,0.069379,0.383221,-1.89306,0.04108,0.336931,-1.81931,0.285965,1.14111,-2.10115,0.333437,1.07305,-2.08603,0.168602,1.05782,-2.08113,0.217112,0.993624,-2.06687,0.322866,0.900924,-2.06522,0.169708,0.811131,-2.05374,0.150977,0.921586,-2.07805,0.081994,0.905666,-2.07386,-0.136344,0.829781,-2.0474,-0.238391,0.890121,-1.99437,-0.142854,0.625076,-2.01503,-0.19573,0.658061,-2.08162,0.09455,1.29622,-1.80483,0.102061,1.29325,-2.01991},
/*1108*/{0.212202,1.86806,-1.70424,0.277797,1.8102,-1.85803,0.154623,1.71245,-1.598,0.124276,1.59601,-1.52697,0.271202,1.58451,-1.59846,0.35963,1.5692,-1.6201,0.194801,1.88653,-2.1004,0.280723,1.81431,-1.93508,0.06566,1.85778,-2.00304,-0.023758,1.73854,-2.15725,-0.026133,1.64262,-2.21967,0.113055,1.50279,-2.17181,0.146461,1.44829,-2.18333,0.169724,1.38484,-1.78088,-0.018225,1.44369,-1.86939,-0.011991,1.46701,-1.92298,-0.01179,1.43639,-1.98287,0.183059,1.38795,-2.04893,0.161154,1.07141,-1.73565,0.025562,1.05103,-1.77558,0.040201,0.968975,-1.80208,0.109601,0.852592,-1.78974,0.07871,0.669811,-1.8003,0.05211,0.601774,-1.81835,-0.025829,0.711175,-1.80695,-0.052457,0.644945,-1.82255,-0.095249,0.429702,-1.85539,-0.206792,0.371446,-1.93297,0.049234,0.3829,-1.89292,0.019978,0.336451,-1.82093,0.29037,1.14893,-2.10126,0.340456,1.08238,-2.08586,0.175456,1.06209,-2.08105,0.22588,0.999101,-2.06686,0.334894,0.910882,-2.06504,0.183997,0.813939,-2.05539,0.160453,0.92451,-2.0781,0.092544,0.906334,-2.074,-0.125976,0.820804,-2.05078,-0.229398,0.873179,-1.99531,-0.117241,0.614369,-2.01834,-0.171492,0.645385,-2.08527,0.094206,1.29685,-1.80538,0.102516,1.29597,-2.02046},
/*1109*/{0.214782,1.87201,-1.70494,0.278978,1.81376,-1.8597,0.160677,1.71563,-1.59797,0.131944,1.59849,-1.52748,0.278855,1.59079,-1.60152,0.366971,1.57932,-1.62476,0.192358,1.88947,-2.10077,0.279843,1.81693,-1.93653,0.064459,1.85965,-2.00177,-0.029963,1.74482,-2.15629,-0.033105,1.64982,-2.21948,0.105493,1.51029,-2.17121,0.137774,1.45527,-2.18246,0.169979,1.38525,-1.7814,-0.018633,1.44552,-1.86937,-0.010352,1.46925,-1.92128,-0.011449,1.4392,-1.98273,0.183382,1.3911,-2.04775,0.149499,1.06845,-1.73801,0.0157,1.05444,-1.77639,0.028801,0.971349,-1.8003,0.093721,0.853924,-1.79082,0.062009,0.671117,-1.80127,0.033253,0.602882,-1.81989,-0.042762,0.713315,-1.80788,-0.069553,0.647181,-1.82146,-0.114682,0.432388,-1.85689,-0.227201,0.375102,-1.93277,0.029262,0.38287,-1.89358,0.00024,0.337011,-1.82124,0.294464,1.157,-2.1014,0.346291,1.09115,-2.08582,0.181958,1.06726,-2.08166,0.234608,1.00497,-2.06686,0.347145,0.921983,-2.06525,0.198988,0.81734,-2.057,0.170645,0.926104,-2.07737,0.102029,0.906119,-2.07395,-0.112189,0.810351,-2.0515,-0.217331,0.855817,-1.99489,-0.089837,0.605186,-2.0224,-0.146604,0.632356,-2.08828,0.094088,1.29764,-1.80617,0.102772,1.29901,-2.02122},
/*1110*/{0.216938,1.87643,-1.70533,0.278606,1.81633,-1.86113,0.167246,1.71887,-1.59793,0.14193,1.60139,-1.52689,0.285763,1.59921,-1.60423,0.373186,1.58883,-1.62924,0.189088,1.89357,-2.1002,0.279787,1.8203,-1.93828,0.063612,1.86265,-1.99942,-0.035908,1.75214,-2.15601,-0.039413,1.65694,-2.21858,0.097184,1.51834,-2.17043,0.129759,1.46307,-2.18167,0.17021,1.38557,-1.78077,-0.017595,1.44804,-1.86905,-0.010886,1.47086,-1.92152,-0.010653,1.44229,-1.98275,0.183949,1.39409,-2.0468,0.142238,1.0681,-1.74107,0.009032,1.05493,-1.77439,0.017071,0.974391,-1.80039,0.080742,0.856049,-1.7928,0.044397,0.672738,-1.80183,0.015941,0.604917,-1.8203,-0.059795,0.715379,-1.80923,-0.086397,0.64923,-1.82175,-0.132932,0.432837,-1.85508,-0.246513,0.378349,-1.93325,0.009986,0.382537,-1.89297,-0.020406,0.336975,-1.82036,0.298619,1.16464,-2.10144,0.353148,1.09893,-2.08577,0.188593,1.07254,-2.08245,0.242795,1.01157,-2.06737,0.358333,0.932437,-2.06571,0.213086,0.820692,-2.0586,0.179013,0.928704,-2.07787,0.111649,0.905945,-2.07426,-0.096867,0.798771,-2.05276,-0.205969,0.837429,-1.99669,-0.063475,0.595825,-2.02694,-0.121589,0.620207,-2.09185,0.093739,1.29873,-1.80678,0.103252,1.30184,-2.02178},
/*1111*/{0.219516,1.88064,-1.7065,0.279939,1.8202,-1.86165,0.173435,1.72271,-1.59813,0.14972,1.6054,-1.52698,0.291763,1.60626,-1.60725,0.378838,1.59876,-1.63395,0.18482,1.89705,-2.09967,0.279575,1.82303,-1.93878,0.062187,1.86418,-1.99722,-0.040269,1.75946,-2.15519,-0.04618,1.66409,-2.21801,0.090137,1.52469,-2.16833,0.121993,1.4714,-2.18089,0.1709,1.38599,-1.77992,-0.016338,1.45099,-1.86843,-0.010183,1.47366,-1.92073,-0.010443,1.44549,-1.9831,0.185476,1.39732,-2.04605,0.13494,1.06833,-1.7427,0.001132,1.05827,-1.77388,0.008093,0.978561,-1.80049,0.067341,0.85823,-1.79366,0.027173,0.674194,-1.80224,-0.003817,0.60637,-1.82124,-0.076927,0.718376,-1.81007,-0.103698,0.652274,-1.82166,-0.151131,0.437155,-1.85548,-0.265792,0.382505,-1.93269,-0.009264,0.382394,-1.89337,-0.040663,0.337295,-1.82067,0.302767,1.17223,-2.10146,0.357582,1.10953,-2.08614,0.194336,1.07783,-2.08251,0.249261,1.01828,-2.06808,0.367449,0.942464,-2.06565,0.226319,0.823809,-2.06028,0.187117,0.93017,-2.07749,0.122806,0.901375,-2.0732,-0.076622,0.784301,-2.05077,-0.193922,0.819341,-1.99576,-0.037592,0.586172,-2.03014,-0.095922,0.607731,-2.09504,0.093708,1.30012,-1.80731,0.103913,1.30509,-2.02224},
/*1112*/{0.22177,1.88538,-1.70734,0.280321,1.82372,-1.86382,0.180227,1.72682,-1.59886,0.158143,1.6089,-1.52588,0.297878,1.61417,-1.61,0.383902,1.60858,-1.63899,0.182645,1.90097,-2.09899,0.279294,1.82698,-1.94052,0.060799,1.8676,-1.9952,-0.045692,1.76664,-2.15486,-0.052466,1.6713,-2.21705,0.082525,1.53326,-2.16708,0.114442,1.47925,-2.18002,0.171558,1.38653,-1.77878,-0.015213,1.45323,-1.86793,-0.009031,1.47601,-1.91928,-0.008472,1.44853,-1.9821,0.186102,1.40059,-2.04491,0.128537,1.06969,-1.74354,-0.006371,1.06573,-1.77465,-0.002384,0.982788,-1.79983,0.055707,0.861324,-1.795,0.009686,0.677363,-1.80306,-0.019418,0.60898,-1.82071,-0.093696,0.721516,-1.81103,-0.121081,0.656333,-1.8232,-0.170259,0.43954,-1.85472,-0.285313,0.388829,-1.93178,-0.028933,0.381726,-1.89339,-0.061056,0.337783,-1.82054,0.305972,1.17978,-2.10154,0.362027,1.11875,-2.08715,0.199865,1.08246,-2.0822,0.257687,1.02361,-2.06823,0.376764,0.952439,-2.06554,0.239728,0.827465,-2.06185,0.194858,0.930909,-2.07691,0.132355,0.899292,-2.07224,-0.06053,0.772569,-2.05213,-0.178755,0.799387,-1.99738,-0.010729,0.576871,-2.0342,-0.07006,0.596534,-2.09897,0.094068,1.30125,-1.80743,0.104859,1.30822,-2.02228},
/*1113*/{0.223664,1.89014,-1.70888,0.280491,1.8269,-1.86549,0.186016,1.73106,-1.59962,0.165977,1.61274,-1.52571,0.302454,1.62183,-1.6126,0.388474,1.61923,-1.64409,0.179237,1.90504,-2.09859,0.278842,1.83129,-1.94233,0.059782,1.86992,-1.99298,-0.051009,1.77353,-2.15412,-0.057976,1.67837,-2.2158,0.075862,1.54192,-2.16524,0.108186,1.48811,-2.17889,0.172119,1.38736,-1.77727,-0.0138,1.45563,-1.86844,-0.008085,1.47944,-1.91818,-0.00741,1.45272,-1.98221,0.187346,1.40408,-2.04334,0.122279,1.07068,-1.74523,-0.013867,1.07127,-1.77478,-0.012421,0.987794,-1.7996,0.043104,0.863662,-1.79644,-0.006913,0.680823,-1.80374,-0.037288,0.612573,-1.82055,-0.109995,0.725777,-1.81115,-0.138058,0.660947,-1.82303,-0.187978,0.443751,-1.85398,-0.303896,0.395485,-1.93117,-0.048866,0.381304,-1.89387,-0.081302,0.33814,-1.82114,0.309544,1.18776,-2.10187,0.366807,1.12772,-2.08611,0.205256,1.08883,-2.08289,0.26271,1.03085,-2.06796,0.384529,0.962145,-2.06563,0.253136,0.830819,-2.06356,0.202369,0.932393,-2.07699,0.141549,0.897481,-2.07202,-0.044521,0.759902,-2.05274,-0.16526,0.779862,-1.99758,0.017695,0.567824,-2.0376,-0.043494,0.585347,-2.10242,0.093776,1.30288,-1.80785,0.105933,1.31193,-2.02256},
/*1114*/{0.225352,1.89451,-1.71048,0.282473,1.83178,-1.86645,0.192116,1.7357,-1.60061,0.173311,1.61725,-1.52543,0.307047,1.62993,-1.61537,0.392988,1.62908,-1.64888,0.175803,1.90927,-2.09813,0.278926,1.83492,-1.94386,0.058379,1.87323,-1.99145,-0.054506,1.78059,-2.15319,-0.064011,1.68595,-2.21457,0.069164,1.55053,-2.16344,0.101939,1.49633,-2.17788,0.172808,1.38789,-1.77686,-0.012339,1.45807,-1.86647,-0.006928,1.48229,-1.91686,-0.006196,1.45712,-1.98253,0.188197,1.40767,-2.04239,0.114995,1.0712,-1.74807,-0.02103,1.07426,-1.77413,-0.021562,0.992974,-1.79947,0.028865,0.867562,-1.7971,-0.023062,0.684772,-1.80313,-0.054869,0.616535,-1.82128,-0.126482,0.730966,-1.81135,-0.154481,0.665603,-1.8242,-0.205424,0.44812,-1.85375,-0.321184,0.402372,-1.9308,-0.067217,0.380039,-1.89368,-0.10179,0.338596,-1.82206,0.313036,1.19554,-2.10179,0.370709,1.13607,-2.08568,0.210123,1.09519,-2.0829,0.269229,1.03794,-2.06812,0.390928,0.971874,-2.06527,0.265323,0.83417,-2.0646,0.209901,0.933362,-2.07663,0.150472,0.894463,-2.07184,-0.030151,0.749519,-2.05418,-0.148753,0.759332,-1.99834,0.045408,0.559598,-2.04142,-0.016274,0.574304,-2.10599,0.093991,1.30416,-1.80859,0.106473,1.31576,-2.02315},
/*1115*/{0.227031,1.89986,-1.71181,0.28273,1.83535,-1.86798,0.198803,1.74079,-1.60069,0.180333,1.62234,-1.52546,0.311983,1.63791,-1.61835,0.395803,1.63861,-1.65342,0.173574,1.91279,-2.09753,0.278184,1.83853,-1.94468,0.057362,1.87699,-1.98934,-0.057326,1.78824,-2.15288,-0.069093,1.69303,-2.21244,0.063605,1.55899,-2.16125,0.096006,1.50476,-2.17721,0.174671,1.38897,-1.77566,-0.01077,1.46117,-1.86605,-0.005593,1.48572,-1.91476,-0.004231,1.46151,-1.98195,0.189595,1.41071,-2.0409,0.110607,1.07313,-1.74983,-0.026442,1.07951,-1.77417,-0.030237,0.998638,-1.79999,0.014857,0.872307,-1.79653,-0.039862,0.690057,-1.80248,-0.070003,0.623077,-1.82037,-0.142196,0.735936,-1.81219,-0.170915,0.672056,-1.82454,-0.222855,0.452957,-1.85267,-0.33944,0.410278,-1.93024,-0.085592,0.379198,-1.89365,-0.121241,0.338817,-1.82164,0.316374,1.20325,-2.10115,0.374786,1.14409,-2.08499,0.214469,1.10143,-2.08336,0.273573,1.04551,-2.06796,0.39622,0.980539,-2.06542,0.277351,0.836798,-2.06541,0.217385,0.933479,-2.07633,0.160281,0.891751,-2.07173,-0.013485,0.736632,-2.05518,-0.133227,0.740476,-1.99993,0.074346,0.552478,-2.04549,0.011109,0.564715,-2.10981,0.09457,1.30615,-1.80844,0.107474,1.31935,-2.02289},
/*1116*/{0.229126,1.90435,-1.71319,0.282244,1.83891,-1.86983,0.203544,1.74575,-1.60157,0.186038,1.62667,-1.52551,0.315417,1.64496,-1.62064,0.398305,1.64815,-1.65786,0.17159,1.91677,-2.09664,0.277796,1.84278,-1.94635,0.057081,1.8801,-1.98873,-0.062782,1.7946,-2.15234,-0.075058,1.70049,-2.21088,0.057548,1.56742,-2.15963,0.090556,1.51307,-2.17628,0.174765,1.38932,-1.77521,-0.00862,1.46388,-1.86598,-0.00381,1.48936,-1.91405,-0.003266,1.46596,-1.98188,0.190586,1.41494,-2.03998,0.103088,1.07479,-1.75094,-0.031984,1.08547,-1.77492,-0.04005,1.00512,-1.7997,7.6e-005,0.877016,-1.79662,-0.054562,0.695243,-1.80173,-0.085922,0.628243,-1.81932,-0.157199,0.742459,-1.81222,-0.186493,0.678039,-1.82363,-0.240516,0.457873,-1.85163,-0.355613,0.418888,-1.92999,-0.104611,0.37849,-1.89371,-0.141342,0.338919,-1.82174,0.318838,1.2104,-2.1012,0.379097,1.15263,-2.08441,0.218543,1.1081,-2.08388,0.27708,1.05092,-2.06805,0.400461,0.988732,-2.06498,0.289253,0.839328,-2.06635,0.224047,0.932168,-2.07602,0.168585,0.887507,-2.07204,0.001383,0.723429,-2.05656,-0.115556,0.71981,-2.00177,0.10196,0.544956,-2.04845,0.039864,0.555719,-2.11327,0.094388,1.30757,-1.80979,0.108279,1.32366,-2.02398},
/*1117*/{0.230071,1.90901,-1.71479,0.283018,1.84315,-1.87182,0.208331,1.74991,-1.60248,0.1921,1.6315,-1.52572,0.318228,1.65278,-1.62331,0.400555,1.65676,-1.66223,0.170061,1.92077,-2.09612,0.277793,1.84689,-1.94816,0.057883,1.8823,-1.98587,-0.065514,1.80146,-2.15078,-0.080342,1.70811,-2.20851,0.05137,1.57545,-2.15736,0.085023,1.52092,-2.1747,0.176077,1.39062,-1.7751,-0.007292,1.46717,-1.86543,-0.002766,1.49278,-1.91241,-0.00145,1.47061,-1.98059,0.191488,1.41831,-2.03902,0.098046,1.07785,-1.75286,-0.038082,1.09141,-1.77381,-0.048224,1.01143,-1.80077,-0.01491,0.882975,-1.79603,-0.070107,0.700889,-1.80097,-0.102291,0.63372,-1.81744,-0.171408,0.749075,-1.8124,-0.201467,0.68531,-1.82325,-0.257025,0.463083,-1.85103,-0.372534,0.428506,-1.92785,-0.123412,0.377602,-1.89346,-0.162288,0.339484,-1.82256,0.322186,1.2173,-2.10104,0.382342,1.16025,-2.08362,0.222477,1.11454,-2.085,0.282946,1.059,-2.06759,0.404963,0.997478,-2.06547,0.300145,0.840676,-2.06717,0.230893,0.930656,-2.07619,0.177824,0.88248,-2.07204,0.02381,0.711101,-2.05657,-0.097085,0.699749,-2.00209,0.131403,0.53855,-2.05159,0.067914,0.546553,-2.11634,0.09482,1.30967,-1.81014,0.108731,1.32761,-2.02417},
/*1118*/{0.232375,1.91321,-1.71649,0.283103,1.84706,-1.87316,0.212742,1.75443,-1.60301,0.197222,1.63615,-1.52537,0.320312,1.65934,-1.62533,0.401968,1.66579,-1.66659,0.168613,1.92427,-2.0958,0.277833,1.85058,-1.9495,0.057622,1.88507,-1.98448,-0.068479,1.8075,-2.14959,-0.084604,1.71512,-2.20629,0.04705,1.58341,-2.15575,0.080617,1.52894,-2.17384,0.177862,1.39171,-1.77603,-0.005995,1.47028,-1.86465,-0.001527,1.49633,-1.91044,-0.000188,1.47551,-1.98082,0.192489,1.42194,-2.03861,0.091843,1.08061,-1.75437,-0.043541,1.09865,-1.7737,-0.054784,1.0184,-1.80117,-0.028299,0.889164,-1.79468,-0.084218,0.707581,-1.79924,-0.117405,0.640676,-1.81572,-0.18562,0.756698,-1.81214,-0.215977,0.692936,-1.82269,-0.272454,0.468559,-1.84838,-0.388368,0.438447,-1.92845,-0.142889,0.376433,-1.89336,-0.182737,0.339418,-1.82279,0.324288,1.22434,-2.10075,0.384717,1.16788,-2.08306,0.225739,1.12059,-2.08598,0.285928,1.06559,-2.06674,0.406211,1.00563,-2.06428,0.309129,0.841163,-2.06777,0.237119,0.927996,-2.07611,0.187332,0.877769,-2.07234,0.041933,0.697994,-2.05778,-0.076081,0.679121,-2.00282,0.160141,0.533725,-2.05443,0.097281,0.537839,-2.11921,0.09554,1.31161,-1.81137,0.109083,1.3319,-2.02522},
/*1119*/{0.233796,1.91767,-1.71753,0.283702,1.85113,-1.87456,0.217055,1.75879,-1.60348,0.202554,1.6408,-1.52496,0.322828,1.66638,-1.62785,0.404067,1.67391,-1.67072,0.167259,1.92829,-2.09557,0.277118,1.85462,-1.95064,0.057562,1.88847,-1.98289,-0.070437,1.81421,-2.14779,-0.089005,1.72222,-2.20332,0.041914,1.59054,-2.1534,0.07609,1.53599,-2.17238,0.178854,1.39239,-1.77662,-0.003321,1.47337,-1.86339,-0.00023,1.49995,-1.90896,0.001825,1.48016,-1.98055,0.193606,1.42625,-2.03847,0.088767,1.08307,-1.75418,-0.045668,1.10677,-1.77369,-0.063388,1.02591,-1.80035,-0.040386,0.895373,-1.79466,-0.097503,0.714271,-1.79764,-0.130453,0.648089,-1.81358,-0.198322,0.764193,-1.81197,-0.228754,0.699845,-1.82156,-0.288191,0.473669,-1.84605,-0.403943,0.450402,-1.92764,-0.161761,0.376255,-1.89295,-0.202919,0.339836,-1.82304,0.326332,1.23117,-2.10083,0.387487,1.17506,-2.08232,0.228916,1.12552,-2.08508,0.289016,1.07187,-2.06642,0.407884,1.01325,-2.06369,0.322967,0.844471,-2.06774,0.244228,0.92589,-2.07634,0.197382,0.873022,-2.07248,0.056569,0.683995,-2.05831,-0.059355,0.657991,-2.00411,0.189356,0.528722,-2.05675,0.125793,0.529944,-2.12087,0.096332,1.31328,-1.81288,0.109798,1.33652,-2.02643},
/*1120*/{0.235492,1.9211,-1.71949,0.2847,1.85509,-1.87641,0.220925,1.76355,-1.60419,0.20722,1.64541,-1.52492,0.324595,1.67236,-1.63021,0.404416,1.68142,-1.67467,0.166484,1.93101,-2.0951,0.277431,1.85849,-1.95235,0.057319,1.89229,-1.98276,-0.072422,1.81991,-2.14654,-0.09325,1.72926,-2.20093,0.037673,1.59698,-2.15116,0.072116,1.54301,-2.17062,0.181428,1.39418,-1.77731,-0.00141,1.47729,-1.8627,0.001337,1.50357,-1.90698,0.003595,1.48475,-1.98003,0.193486,1.43033,-2.03784,0.084084,1.08727,-1.75485,-0.051599,1.11259,-1.77338,-0.068986,1.03303,-1.80094,-0.051082,0.9031,-1.79364,-0.110867,0.7225,-1.79625,-0.143354,0.655465,-1.81116,-0.210306,0.772082,-1.81112,-0.241252,0.708757,-1.82152,-0.30368,0.480896,-1.84451,-0.41893,0.46168,-1.92568,-0.180577,0.375841,-1.89294,-0.223953,0.340488,-1.82322,0.328268,1.23762,-2.10009,0.389491,1.18172,-2.08158,0.231807,1.1313,-2.08467,0.291945,1.07861,-2.06581,0.409294,1.0201,-2.06387,0.333765,0.846149,-2.06815,0.250241,0.922367,-2.07674,0.205743,0.866997,-2.07344,0.07562,0.672146,-2.06373,-0.038748,0.636885,-2.00505,0.216942,0.524495,-2.05803,0.154647,0.522789,-2.1226,0.097712,1.31596,-1.81352,0.110061,1.34085,-2.02695},
/*1121*/{0.236751,1.92496,-1.72078,0.285215,1.85873,-1.87815,0.224015,1.76714,-1.60465,0.212204,1.64901,-1.52378,0.326511,1.67908,-1.63308,0.404241,1.68838,-1.67769,0.165681,1.93414,-2.09524,0.2771,1.86174,-1.95364,0.057925,1.89556,-1.98112,-0.072651,1.82592,-2.14396,-0.097006,1.73541,-2.19761,0.034577,1.60352,-2.14927,0.068422,1.55029,-2.16985,0.182566,1.39569,-1.77827,0.000358,1.48065,-1.86161,0.004584,1.50707,-1.90738,0.005131,1.48933,-1.97923,0.194836,1.43436,-2.03826,0.078643,1.0884,-1.75513,-0.05224,1.11952,-1.7729,-0.074941,1.0405,-1.80038,-0.060174,0.909706,-1.79293,-0.121469,0.729163,-1.79426,-0.154972,0.662602,-1.8081,-0.221297,0.780047,-1.81061,-0.25251,0.716081,-1.82068,-0.316164,0.487182,-1.84107,-0.430344,0.474278,-1.92492,-0.19918,0.375763,-1.89282,-0.244643,0.341075,-1.82365,0.330318,1.24342,-2.09955,0.390861,1.18755,-2.08074,0.232781,1.13766,-2.08469,0.293894,1.08417,-2.06514,0.409586,1.0252,-2.06421,0.343968,0.846162,-2.06782,0.256182,0.918335,-2.07731,0.21503,0.860663,-2.07399,0.095972,0.658451,-2.06047,-0.015865,0.615064,-2.00582,0.246091,0.520676,-2.05828,0.183198,0.515093,-2.12336,0.098705,1.31823,-1.81494,0.110922,1.34515,-2.02814},
/*1122*/{0.238823,1.92822,-1.72168,0.285688,1.86292,-1.87975,0.227135,1.77117,-1.60472,0.214551,1.65295,-1.52335,0.327149,1.68273,-1.63445,0.404466,1.69466,-1.68151,0.165468,1.93733,-2.09521,0.277377,1.865,-1.95424,0.058081,1.89877,-1.98087,-0.074133,1.83172,-2.14072,-0.100463,1.7419,-2.19489,0.032369,1.60934,-2.14729,0.066935,1.55526,-2.16783,0.184931,1.39754,-1.77959,0.001634,1.48387,-1.86156,0.005178,1.51046,-1.90556,0.006385,1.49387,-1.97714,0.195518,1.43833,-2.03881,0.074869,1.09115,-1.75543,-0.054656,1.12642,-1.77173,-0.079858,1.04853,-1.80008,-0.069254,0.917434,-1.79234,-0.131406,0.736849,-1.79232,-0.165436,0.670185,-1.80617,-0.230628,0.787923,-1.81011,-0.262255,0.7243,-1.81962,-0.328939,0.493543,-1.83766,-0.442445,0.487959,-1.92326,-0.217291,0.376002,-1.89204,-0.264477,0.342956,-1.823,0.33159,1.24871,-2.09914,0.392624,1.19269,-2.07939,0.234062,1.14243,-2.08462,0.293309,1.09074,-2.06654,0.409903,1.02952,-2.06444,0.353257,0.845917,-2.06813,0.261798,0.913232,-2.07755,0.22447,0.854599,-2.07502,0.119305,0.645186,-2.05949,0.006218,0.595568,-2.00713,0.274044,0.516954,-2.0583,0.211979,0.508107,-2.12346,0.10023,1.3206,-1.81611,0.111088,1.34963,-2.0291},
/*1123*/{0.239767,1.93098,-1.72304,0.28658,1.86619,-1.88161,0.230214,1.77422,-1.60523,0.218825,1.65672,-1.52369,0.327387,1.68689,-1.6364,0.40484,1.69963,-1.68439,0.164803,1.94061,-2.09497,0.277551,1.86843,-1.95571,0.057063,1.90149,-1.97955,-0.075531,1.83741,-2.13788,-0.103599,1.74797,-2.19157,0.029465,1.61572,-2.14558,0.062214,1.5619,-2.16741,0.186949,1.39979,-1.78016,0.003847,1.48749,-1.861,0.006032,1.51449,-1.90524,0.007599,1.49793,-1.97701,0.196248,1.44213,-2.03952,0.072293,1.09475,-1.7542,-0.056845,1.13265,-1.77171,-0.08334,1.05436,-1.79886,-0.075935,0.924362,-1.79163,-0.140332,0.743919,-1.79043,-0.175459,0.676891,-1.80412,-0.239656,0.795389,-1.80928,-0.271351,0.731729,-1.8171,-0.341314,0.500714,-1.83514,-0.452397,0.502442,-1.91966,-0.236617,0.376688,-1.8909,-0.284756,0.344059,-1.82358,0.331964,1.25373,-2.09857,0.393196,1.19694,-2.07882,0.233965,1.14847,-2.08494,0.293965,1.09456,-2.06664,0.410376,1.03305,-2.06522,0.363157,0.846099,-2.06827,0.268702,0.908161,-2.07879,0.232897,0.846961,-2.07569,0.137819,0.632212,-2.05938,0.02853,0.576211,-2.00702,0.301222,0.514851,-2.05735,0.240433,0.50183,-2.1231,0.10157,1.32361,-1.81696,0.111545,1.35364,-2.02986},
/*1124*/{0.241689,1.93392,-1.72384,0.287321,1.87,-1.88211,0.232236,1.77771,-1.60527,0.222139,1.65935,-1.52304,0.328871,1.69114,-1.63823,0.40523,1.70335,-1.68757,0.164698,1.94394,-2.09469,0.277734,1.87154,-1.95638,0.058501,1.90376,-1.97943,-0.07568,1.84266,-2.13464,-0.106128,1.7533,-2.18804,0.027335,1.62064,-2.14341,0.059504,1.56692,-2.16603,0.188424,1.40219,-1.78125,0.005344,1.49118,-1.85977,0.007365,1.51817,-1.90369,0.009015,1.50266,-1.97627,0.195872,1.44618,-2.03947,0.068224,1.09803,-1.75256,-0.062257,1.14188,-1.77376,-0.088284,1.06138,-1.79994,-0.082084,0.930341,-1.7912,-0.147758,0.750484,-1.78844,-0.183699,0.68388,-1.80177,-0.245985,0.803078,-1.80818,-0.278191,0.740297,-1.81554,-0.352897,0.508316,-1.83306,-0.461786,0.517831,-1.91703,-0.253279,0.377679,-1.89082,-0.304642,0.346822,-1.82353,0.332493,1.25673,-2.09791,0.392486,1.20048,-2.07797,0.233375,1.15215,-2.08409,0.29316,1.0986,-2.06732,0.409146,1.03509,-2.06548,0.371639,0.845738,-2.06836,0.27394,0.902233,-2.07933,0.242344,0.839847,-2.0761,0.160011,0.620286,-2.05933,0.053674,0.557708,-2.00753,0.328376,0.512225,-2.05565,0.26857,0.495532,-2.12123,0.102507,1.32651,-1.81766,0.111276,1.35805,-2.0304},
/*1125*/{0.243643,1.93626,-1.72441,0.287754,1.87325,-1.88345,0.233866,1.78057,-1.60591,0.224065,1.66226,-1.5231,0.329334,1.69406,-1.63841,0.405588,1.70688,-1.69022,0.16405,1.94624,-2.09421,0.277813,1.87444,-1.95745,0.059265,1.90727,-1.97852,-0.075779,1.8467,-2.13047,-0.108387,1.75901,-2.18481,0.024508,1.62563,-2.14231,0.057733,1.57129,-2.16469,0.189551,1.4051,-1.78174,0.006522,1.49422,-1.85823,0.008333,1.52111,-1.90227,0.010674,1.50684,-1.97524,0.19663,1.4494,-2.04021,0.065382,1.10112,-1.75269,-0.064006,1.14631,-1.77563,-0.088524,1.06626,-1.79851,-0.08599,0.936716,-1.79072,-0.154331,0.756562,-1.78666,-0.190982,0.691053,-1.79911,-0.251863,0.80994,-1.80604,-0.284682,0.746493,-1.8124,-0.363273,0.516056,-1.83018,-0.470623,0.535048,-1.9138,-0.270612,0.379284,-1.88893,-0.324571,0.350528,-1.82328,0.332177,1.25988,-2.09729,0.391726,1.20246,-2.07704,0.23216,1.15559,-2.08384,0.291575,1.1018,-2.06816,0.409143,1.03706,-2.06638,0.380617,0.845358,-2.06824,0.279689,0.897598,-2.08036,0.250802,0.832343,-2.07686,0.173325,0.606935,-2.05925,0.07624,0.539515,-2.00672,0.354539,0.510716,-2.05309,0.296694,0.489973,-2.11937,0.103749,1.32933,-1.81783,0.111553,1.36173,-2.03047},
/*1126*/{0.244791,1.93862,-1.72545,0.288682,1.87549,-1.88407,0.236462,1.78342,-1.60617,0.225845,1.66409,-1.52287,0.33065,1.69668,-1.64011,0.405949,1.7092,-1.69309,0.164748,1.94959,-2.09408,0.278617,1.87732,-1.95743,0.06012,1.90972,-1.97713,-0.074573,1.85126,-2.12755,-0.11026,1.76403,-2.1807,0.02314,1.62937,-2.14047,0.055426,1.576,-2.16343,0.19093,1.40757,-1.78177,0.007943,1.49781,-1.85808,0.009061,1.52497,-1.90175,0.009886,1.51086,-1.97339,0.196415,1.45271,-2.04042,0.063443,1.10582,-1.75018,-0.065429,1.1522,-1.77748,-0.091864,1.07197,-1.79881,-0.089092,0.941379,-1.79119,-0.157619,0.762734,-1.78518,-0.1951,0.696572,-1.79644,-0.254905,0.816674,-1.80391,-0.290587,0.754199,-1.81189,-0.369805,0.52455,-1.82578,-0.477741,0.551525,-1.90992,-0.286185,0.381427,-1.88787,-0.345272,0.354662,-1.8234,0.330719,1.26185,-2.09669,0.390857,1.20401,-2.07691,0.230487,1.159,-2.08396,0.28892,1.10361,-2.06928,0.407388,1.0377,-2.06759,0.388041,0.843799,-2.06818,0.285371,0.891305,-2.08132,0.259582,0.825534,-2.0782,0.197315,0.596805,-2.0595,0.101357,0.522867,-2.00561,0.379864,0.508868,-2.05075,0.322622,0.484346,-2.11637,0.104301,1.33248,-1.81785,0.11086,1.36535,-2.03046},
/*1127*/{0.24738,1.94056,-1.72556,0.288093,1.87845,-1.88449,0.238124,1.78588,-1.60628,0.22867,1.66591,-1.52356,0.331618,1.69809,-1.64179,0.405766,1.71177,-1.6952,0.164914,1.95285,-2.09417,0.279153,1.87968,-1.95895,0.061748,1.91279,-1.97683,-0.074252,1.85499,-2.12412,-0.112068,1.76888,-2.17753,0.021323,1.63357,-2.13914,0.053846,1.57961,-2.16209,0.192187,1.4102,-1.78341,0.008995,1.50094,-1.8566,0.009943,1.52828,-1.90037,0.009975,1.51495,-1.97289,0.196571,1.45661,-2.0409,0.06195,1.10997,-1.74961,-0.065802,1.15495,-1.77732,-0.093715,1.07693,-1.79972,-0.089659,0.945742,-1.79153,-0.162412,0.767464,-1.78386,-0.200269,0.702762,-1.79492,-0.257576,0.822407,-1.80163,-0.293206,0.761173,-1.80882,-0.378809,0.532596,-1.82186,-0.482424,0.568877,-1.90474,-0.306253,0.383758,-1.88799,-0.364253,0.360409,-1.82347,0.329441,1.26301,-2.09572,0.388136,1.20406,-2.07644,0.227492,1.16049,-2.08399,0.2857,1.10463,-2.07025,0.405785,1.03774,-2.06783,0.395555,0.842005,-2.0678,0.290188,0.884069,-2.08255,0.267956,0.816379,-2.07808,0.217283,0.586024,-2.05901,0.123284,0.507713,-2.00576,0.405129,0.509282,-2.04696,0.34939,0.478929,-2.113,0.105428,1.33524,-1.81874,0.11055,1.36953,-2.03117},
/*1128*/{0.24859,1.9418,-1.72615,0.289793,1.88163,-1.88539,0.238762,1.78766,-1.60641,0.230121,1.66664,-1.52233,0.331981,1.69977,-1.64333,0.406898,1.71447,-1.69709,0.165251,1.95539,-2.0938,0.279458,1.88241,-1.95934,0.062084,1.91529,-1.97671,-0.075016,1.85806,-2.1202,-0.112995,1.77276,-2.17418,0.020648,1.63668,-2.1372,0.052287,1.5829,-2.16087,0.192925,1.41301,-1.78366,0.009795,1.50424,-1.85646,0.010207,1.5315,-1.90035,0.010185,1.51854,-1.97232,0.196965,1.45967,-2.04099,0.061185,1.11389,-1.7481,-0.066148,1.15725,-1.77687,-0.093399,1.08098,-1.8002,-0.089769,0.948866,-1.79198,-0.164325,0.772057,-1.78334,-0.203371,0.708057,-1.79378,-0.259839,0.829309,-1.79979,-0.296109,0.768828,-1.80665,-0.384496,0.540561,-1.81699,-0.487707,0.586543,-1.898,-0.323788,0.388445,-1.88845,-0.38432,0.367196,-1.82468,0.327388,1.26297,-2.09502,0.38525,1.20326,-2.07617,0.224539,1.16155,-2.08443,0.281844,1.1052,-2.06959,0.403215,1.03693,-2.06907,0.402964,0.841058,-2.06822,0.295487,0.877825,-2.08352,0.276289,0.808844,-2.07828,0.237216,0.575801,-2.05807,0.146191,0.492881,-2.0049,0.427792,0.50829,-2.04246,0.376127,0.474545,-2.10889,0.105853,1.33829,-1.81887,0.110624,1.37282,-2.03127},
/*1129*/{0.250809,1.94356,-1.7261,0.291228,1.88515,-1.88604,0.239962,1.78925,-1.60671,0.231916,1.66862,-1.52337,0.333341,1.70043,-1.64468,0.406086,1.71257,-1.6993,0.165717,1.95812,-2.09374,0.280812,1.88463,-1.95987,0.063925,1.91762,-1.97505,-0.073765,1.86226,-2.11692,-0.114061,1.77672,-2.17076,0.019616,1.64003,-2.13613,0.050902,1.58553,-2.16015,0.193247,1.41607,-1.78427,0.010662,1.50703,-1.85496,0.010721,1.53523,-1.89986,0.014164,1.52033,-1.97148,0.196198,1.46249,-2.04064,0.060526,1.11703,-1.74779,-0.066994,1.16027,-1.77771,-0.093515,1.08366,-1.80172,-0.088117,0.952168,-1.79224,-0.165571,0.775457,-1.78328,-0.207176,0.712094,-1.79231,-0.259981,0.835477,-1.79736,-0.297643,0.774652,-1.80227,-0.39077,0.549348,-1.81392,-0.49146,0.603913,-1.8917,-0.341982,0.394517,-1.88926,-0.402828,0.374524,-1.82664,0.325128,1.26186,-2.0943,0.382161,1.20138,-2.07616,0.221671,1.1614,-2.08482,0.278352,1.10426,-2.07155,0.401441,1.03569,-2.07062,0.407722,0.838568,-2.06854,0.299025,0.870441,-2.08441,0.283276,0.801127,-2.07893,0.256695,0.565697,-2.05714,0.169022,0.478635,-2.00239,0.449765,0.508189,-2.0387,0.401322,0.470647,-2.10419,0.106666,1.34111,-1.81835,0.110912,1.37552,-2.03077},
/*1130*/{0.251753,1.94487,-1.7266,0.291344,1.88699,-1.88723,0.240905,1.79022,-1.6067,0.232559,1.66886,-1.52336,0.334213,1.7003,-1.64595,0.406023,1.71256,-1.70129,0.166254,1.96065,-2.09365,0.281345,1.88675,-1.96065,0.06428,1.92082,-1.97535,-0.074868,1.86503,-2.11318,-0.115705,1.77934,-2.16708,0.018326,1.64296,-2.13509,0.050134,1.58812,-2.15974,0.193831,1.41897,-1.78377,0.010749,1.51058,-1.8552,0.010921,1.53893,-1.89972,0.014028,1.52391,-1.97053,0.195586,1.46472,-2.0406,0.06198,1.12062,-1.74775,-0.06572,1.16218,-1.77832,-0.091631,1.08522,-1.8028,-0.085896,0.952813,-1.79292,-0.166498,0.778916,-1.78228,-0.20997,0.717201,-1.79152,-0.259169,0.84079,-1.79626,-0.298343,0.78187,-1.79909,-0.398931,0.55806,-1.81008,-0.495027,0.621022,-1.88237,-0.358838,0.402791,-1.89141,-0.419795,0.383131,-1.82997,0.322236,1.25993,-2.09335,0.378785,1.19884,-2.07599,0.217944,1.16031,-2.08526,0.27419,1.10284,-2.07193,0.39809,1.0334,-2.07204,0.413786,0.83677,-2.06867,0.303318,0.862734,-2.08554,0.290151,0.792668,-2.07952,0.274465,0.555853,-2.05535,0.191238,0.465463,-2.00108,0.471028,0.508668,-2.03336,0.42519,0.467086,-2.09907,0.106304,1.34447,-1.81771,0.110042,1.37824,-2.03025},
/*1131*/{0.253326,1.94624,-1.7267,0.292484,1.88931,-1.88753,0.240961,1.79151,-1.60702,0.235122,1.66934,-1.52389,0.334691,1.69928,-1.64704,0.407376,1.71125,-1.70303,0.167309,1.96311,-2.09404,0.281986,1.8885,-1.96101,0.065303,1.92284,-1.97474,-0.073776,1.86731,-2.10924,-0.116016,1.78219,-2.16364,0.017814,1.64506,-2.13339,0.048916,1.59039,-2.15853,0.194103,1.42194,-1.78405,0.011843,1.51284,-1.85476,0.011086,1.54162,-1.89986,0.013673,1.52534,-1.97049,0.196514,1.46747,-2.04065,0.062961,1.12122,-1.74764,-0.059601,1.16265,-1.77659,-0.08933,1.08495,-1.80269,-0.08426,0.955134,-1.79387,-0.166241,0.781731,-1.78181,-0.210934,0.720269,-1.78968,-0.257352,0.846615,-1.7931,-0.298487,0.789183,-1.79596,-0.405334,0.567361,-1.80815,-0.497805,0.637927,-1.8722,-0.37721,0.411547,-1.89522,-0.439442,0.39261,-1.83265,0.319668,1.25803,-2.09339,0.37587,1.19586,-2.07606,0.213677,1.15996,-2.08645,0.269328,1.10099,-2.07268,0.395359,1.0302,-2.07333,0.417104,0.834486,-2.06898,0.30673,0.855221,-2.08694,0.297184,0.785559,-2.08003,0.292483,0.547199,-2.05466,0.21343,0.454549,-2.00014,0.491638,0.509751,-2.02838,0.447793,0.463079,-2.09343,0.107343,1.34711,-1.81752,0.110803,1.38059,-2.0301},
/*1132*/{0.254554,1.94661,-1.72679,0.292633,1.89151,-1.88816,0.241078,1.79239,-1.60727,0.235345,1.66913,-1.52417,0.335875,1.69888,-1.64857,0.407205,1.70952,-1.70453,0.16771,1.96493,-2.09438,0.2825,1.88994,-1.96119,0.067157,1.92487,-1.975,-0.074303,1.86871,-2.10623,-0.116065,1.78394,-2.1603,0.018138,1.64704,-2.13241,0.048204,1.59155,-2.15813,0.194226,1.42447,-1.78476,0.011785,1.51515,-1.85478,0.009847,1.54429,-1.89935,0.013172,1.52754,-1.96952,0.195078,1.46953,-2.04036,0.065972,1.12187,-1.74792,-0.059308,1.16419,-1.77919,-0.086384,1.08436,-1.80247,-0.078246,0.954078,-1.79307,-0.16471,0.783014,-1.78176,-0.211724,0.724052,-1.78951,-0.253702,0.851854,-1.79038,-0.297367,0.795242,-1.7935,-0.409361,0.577022,-1.806,-0.500452,0.654647,-1.86321,-0.39502,0.422099,-1.90004,-0.456028,0.404853,-1.83535,0.316616,1.25502,-2.09375,0.371719,1.19207,-2.07651,0.209591,1.15756,-2.08729,0.264141,1.09844,-2.07319,0.391426,1.0262,-2.07377,0.421033,0.831857,-2.06846,0.308506,0.846791,-2.08826,0.303236,0.777303,-2.08065,0.307692,0.53754,-2.05155,0.23391,0.443492,-1.99599,0.508788,0.509246,-2.02409,0.470262,0.460559,-2.08798,0.10716,1.34957,-1.81724,0.109578,1.3828,-2.02988},
/*1133*/{0.255021,1.94673,-1.72682,0.292051,1.89337,-1.88855,0.241182,1.79259,-1.60762,0.235975,1.66889,-1.5253,0.336202,1.69685,-1.64987,0.407423,1.7073,-1.7056,0.170083,1.96658,-2.09438,0.283077,1.8914,-1.96168,0.068715,1.92646,-1.97469,-0.074692,1.87049,-2.1024,-0.116461,1.78563,-2.15749,0.018841,1.64824,-2.13093,0.047918,1.592,-2.15723,0.194361,1.42692,-1.78478,0.01174,1.51716,-1.8543,0.010175,1.54562,-1.90049,0.012539,1.52902,-1.96972,0.196228,1.47155,-2.04035,0.070576,1.12258,-1.74916,-0.056883,1.16351,-1.77934,-0.08182,1.0833,-1.80257,-0.073384,0.95212,-1.79318,-0.163402,0.783707,-1.7813,-0.212838,0.727431,-1.7898,-0.250048,0.855324,-1.78828,-0.297051,0.799849,-1.79207,-0.414136,0.588273,-1.80356,-0.504886,0.670188,-1.85383,-0.410027,0.435939,-1.90373,-0.469743,0.417703,-1.83769,0.313406,1.25053,-2.09328,0.367642,1.18759,-2.0769,0.204805,1.1557,-2.08774,0.257784,1.09646,-2.0724,0.388098,1.02229,-2.0749,0.422242,0.828952,-2.06803,0.310992,0.838502,-2.08934,0.308576,0.769095,-2.08061,0.325775,0.530977,-2.05031,0.25353,0.434417,-1.99353,0.525639,0.50928,-2.02037,0.488842,0.456189,-2.08217,0.107759,1.35171,-1.81706,0.110444,1.3845,-2.02977},
/*1134*/{0.256092,1.94789,-1.72692,0.292925,1.89382,-1.88929,0.241076,1.79253,-1.60845,0.234938,1.66707,-1.52626,0.336125,1.69494,-1.65108,0.408523,1.7037,-1.70761,0.170647,1.96774,-2.09445,0.283474,1.89233,-1.96189,0.069183,1.92928,-1.97469,-0.074271,1.87148,-2.09894,-0.116197,1.78648,-2.15465,0.018838,1.64905,-2.12983,0.047274,1.59247,-2.15647,0.194422,1.42906,-1.78468,0.011511,1.51842,-1.85537,0.009737,1.54798,-1.89983,0.012488,1.52945,-1.96909,0.195003,1.47277,-2.04016,0.075599,1.12247,-1.75034,-0.053978,1.15873,-1.77752,-0.076585,1.08081,-1.80164,-0.067344,0.950627,-1.79326,-0.160872,0.78419,-1.78217,-0.21329,0.728827,-1.79065,-0.245344,0.859722,-1.7845,-0.291975,0.805941,-1.78827,-0.417471,0.599168,-1.80218,-0.507971,0.68598,-1.84364,-0.42473,0.450282,-1.90797,-0.480921,0.431572,-1.84121,0.310312,1.24686,-2.09472,0.36327,1.18262,-2.0779,0.200115,1.15318,-2.08838,0.253036,1.09232,-2.07359,0.382607,1.01677,-2.07526,0.424915,0.826702,-2.06683,0.313322,0.830754,-2.09018,0.314056,0.760538,-2.0806,0.340385,0.523857,-2.04855,0.271681,0.424959,-1.98984,0.540816,0.509624,-2.01562,0.507264,0.452986,-2.07649,0.107791,1.3536,-1.81643,0.109895,1.38553,-2.02927},
/*1135*/{0.257199,1.9471,-1.727,0.29327,1.8953,-1.88983,0.240987,1.79223,-1.60878,0.233869,1.66576,-1.52789,0.337613,1.69208,-1.6521,0.40875,1.70014,-1.7087,0.170758,1.96882,-2.09466,0.283492,1.89261,-1.96216,0.071208,1.93058,-1.97515,-0.07287,1.87294,-2.09582,-0.116074,1.78691,-2.15165,0.018661,1.64914,-2.12864,0.047544,1.5923,-2.15636,0.194933,1.43054,-1.78487,0.011918,1.51916,-1.85482,0.01032,1.54909,-1.90043,0.012387,1.52943,-1.9692,0.195106,1.47392,-2.03998,0.081019,1.12154,-1.75218,-0.049555,1.15684,-1.77753,-0.071454,1.07742,-1.80097,-0.060941,0.948231,-1.79343,-0.159332,0.784344,-1.78222,-0.21118,0.731851,-1.7908,-0.239496,0.862771,-1.78156,-0.288916,0.810959,-1.78545,-0.423714,0.610598,-1.80149,-0.511725,0.70088,-1.83455,-0.436809,0.466677,-1.91202,-0.491005,0.446085,-1.84315,0.306478,1.24245,-2.09497,0.359574,1.17719,-2.0783,0.195134,1.15038,-2.08853,0.24761,1.08889,-2.0742,0.375988,1.0117,-2.07602,0.425543,0.82393,-2.06618,0.314307,0.822964,-2.09049,0.318226,0.753293,-2.0804,0.352049,0.516752,-2.04604,0.286642,0.420375,-1.98764,0.555382,0.509749,-2.01112,0.522964,0.449174,-2.0707,0.108672,1.3548,-1.81613,0.110413,1.38621,-2.02905},
/*1136*/{0.257864,1.94642,-1.72707,0.293059,1.89527,-1.88988,0.239927,1.79079,-1.60939,0.234294,1.66452,-1.52932,0.337306,1.68887,-1.65351,0.409893,1.69567,-1.70951,0.171797,1.96925,-2.09431,0.283635,1.89289,-1.96185,0.072137,1.93126,-1.97568,-0.071578,1.87239,-2.09275,-0.115673,1.78667,-2.14916,0.020225,1.64891,-2.12759,0.047959,1.5914,-2.15594,0.195258,1.43162,-1.78507,0.011401,1.52005,-1.85545,0.009668,1.54998,-1.90135,0.010826,1.52965,-1.97037,0.194339,1.47447,-2.03999,0.085214,1.12052,-1.75482,-0.044885,1.15363,-1.77735,-0.065621,1.07439,-1.80154,-0.052686,0.945344,-1.79274,-0.156238,0.784323,-1.78249,-0.212208,0.734538,-1.79143,-0.233296,0.866535,-1.77951,-0.283096,0.817464,-1.78238,-0.42742,0.622349,-1.80048,-0.514898,0.716089,-1.82602,-0.447266,0.484165,-1.91501,-0.499327,0.461424,-1.84524,0.303122,1.23741,-2.09579,0.355155,1.17176,-2.07923,0.190007,1.14788,-2.08726,0.240877,1.08518,-2.0748,0.369549,1.00588,-2.07615,0.425642,0.821115,-2.06427,0.315427,0.815732,-2.09018,0.322344,0.746573,-2.07957,0.364865,0.511962,-2.04415,0.300272,0.412429,-1.98259,0.566959,0.510396,-2.00751,0.537068,0.447897,-2.06558,0.108484,1.35598,-1.81612,0.109943,1.38649,-2.02918},
/*1137*/{0.25795,1.94536,-1.7266,0.292641,1.8948,-1.88936,0.239342,1.79022,-1.61011,0.232295,1.6627,-1.53002,0.336836,1.6853,-1.6545,0.41014,1.69094,-1.71026,0.173313,1.96947,-2.09443,0.284096,1.89315,-1.96174,0.073196,1.93248,-1.9755,-0.071959,1.8725,-2.09018,-0.114535,1.78653,-2.14705,0.021284,1.6477,-2.12669,0.048074,1.59067,-2.15559,0.195043,1.43293,-1.78547,0.011372,1.51986,-1.8558,0.009624,1.54985,-1.90157,0.011624,1.5285,-1.97074,0.194457,1.47479,-2.03953,0.093999,1.11843,-1.75619,-0.037702,1.15097,-1.77461,-0.059531,1.07071,-1.80094,-0.044086,0.941765,-1.79364,-0.152907,0.784419,-1.78323,-0.211912,0.737778,-1.79216,-0.226187,0.870744,-1.77676,-0.281406,0.823934,-1.77972,-0.432139,0.634811,-1.79905,-0.518111,0.73166,-1.81878,-0.455815,0.500801,-1.91785,-0.506093,0.477325,-1.84702,0.299226,1.23242,-2.09671,0.350509,1.16555,-2.07994,0.184999,1.14484,-2.08669,0.234823,1.08111,-2.07428,0.361825,1.00021,-2.07591,0.42631,0.818481,-2.0623,0.31656,0.809693,-2.08957,0.324626,0.740633,-2.07879,0.372095,0.505547,-2.04048,0.31304,0.408331,-1.97981,0.576448,0.51061,-2.00443,0.54916,0.447286,-2.06214,0.109225,1.35646,-1.81576,0.110881,1.38625,-2.02892},
/*1138*/{0.258192,1.94451,-1.72723,0.292704,1.89368,-1.88937,0.2381,1.7888,-1.61073,0.230049,1.66121,-1.53227,0.336532,1.68118,-1.65543,0.410422,1.68534,-1.71107,0.174466,1.96933,-2.09465,0.283879,1.89269,-1.96118,0.073604,1.93249,-1.97552,-0.07012,1.87183,-2.08678,-0.113238,1.78522,-2.14468,0.022322,1.64666,-2.12593,0.048339,1.58883,-2.15541,0.195102,1.43363,-1.78563,0.011088,1.51888,-1.8567,0.009606,1.54982,-1.902,0.011522,1.52769,-1.97094,0.193817,1.47502,-2.03906,0.100867,1.11703,-1.75916,-0.032868,1.14711,-1.7751,-0.051233,1.06579,-1.79954,-0.034925,0.937267,-1.79362,-0.15021,0.784882,-1.78352,-0.211598,0.740638,-1.79296,-0.219054,0.874412,-1.77468,-0.276052,0.830459,-1.77882,-0.433711,0.648683,-1.79742,-0.519751,0.746932,-1.81205,-0.465249,0.518575,-1.92089,-0.512615,0.493665,-1.8486,0.295298,1.22698,-2.09715,0.344793,1.15996,-2.08091,0.179431,1.14116,-2.0866,0.228554,1.07622,-2.07393,0.354688,0.994215,-2.07579,0.425745,0.815461,-2.06046,0.315479,0.804483,-2.0877,0.325569,0.735365,-2.07694,0.382178,0.502978,-2.039,0.32342,0.401783,-1.97567,0.584052,0.511693,-2.00078,0.558454,0.445617,-2.05738,0.109648,1.35657,-1.81574,0.111331,1.38601,-2.02895},
/*1139*/{0.258541,1.94303,-1.72727,0.29305,1.89284,-1.88963,0.237188,1.78691,-1.61102,0.22879,1.65805,-1.53361,0.336334,1.67663,-1.65651,0.410153,1.67942,-1.71136,0.174682,1.96871,-2.09431,0.283824,1.89254,-1.96121,0.074081,1.93264,-1.97535,-0.069571,1.87037,-2.08444,-0.112777,1.78357,-2.14289,0.023369,1.64445,-2.12553,0.048843,1.58682,-2.15554,0.195267,1.43386,-1.7861,0.010428,1.51814,-1.85766,0.009413,1.54834,-1.90325,0.010586,1.52584,-1.97225,0.193862,1.47489,-2.03894,0.107863,1.11484,-1.76125,-0.026273,1.14083,-1.77362,-0.044227,1.06128,-1.7991,-0.025048,0.932936,-1.79393,-0.146975,0.785876,-1.78388,-0.210482,0.744755,-1.7927,-0.211367,0.877855,-1.77267,-0.269861,0.836902,-1.77539,-0.436023,0.662987,-1.79515,-0.519465,0.763326,-1.80832,-0.471239,0.535176,-1.92052,-0.519462,0.510498,-1.8484,0.292053,1.22153,-2.09749,0.340634,1.15315,-2.08149,0.175513,1.1379,-2.08635,0.222779,1.07224,-2.07348,0.347694,0.988954,-2.07557,0.423619,0.81293,-2.05899,0.314439,0.799378,-2.08523,0.325433,0.730749,-2.0744,0.387748,0.498737,-2.03608,0.330677,0.396434,-1.97267,0.589232,0.51286,-1.99932,0.565049,0.445297,-2.05454,0.11025,1.35629,-1.81599,0.112184,1.38504,-2.02928},
/*1140*/{0.257739,1.9404,-1.72699,0.293046,1.89116,-1.88845,0.236407,1.7848,-1.61199,0.22773,1.65618,-1.53609,0.335202,1.67122,-1.65733,0.410229,1.67253,-1.71268,0.174578,1.96758,-2.0936,0.283707,1.89147,-1.96083,0.075673,1.93198,-1.9761,-0.066797,1.86963,-2.08261,-0.111221,1.78128,-2.14155,0.023706,1.64256,-2.12554,0.049881,1.58406,-2.15575,0.195399,1.43358,-1.78669,0.010743,1.51644,-1.85748,0.010599,1.54636,-1.9038,0.010987,1.52384,-1.97321,0.193752,1.47399,-2.0393,0.116037,1.11289,-1.76222,-0.020531,1.13639,-1.77265,-0.03652,1.05564,-1.79873,-0.013611,0.928554,-1.79446,-0.142797,0.787704,-1.7837,-0.207693,0.74953,-1.79252,-0.203407,0.882399,-1.77011,-0.263695,0.845013,-1.77369,-0.437953,0.677196,-1.79095,-0.51721,0.779977,-1.80587,-0.476076,0.550366,-1.91886,-0.526423,0.527827,-1.8478,0.28928,1.21625,-2.09809,0.336539,1.14701,-2.08229,0.170716,1.13427,-2.08619,0.218062,1.06838,-2.07359,0.340812,0.982644,-2.07536,0.421147,0.810723,-2.05808,0.310843,0.794619,-2.08208,0.323581,0.725686,-2.07088,0.39193,0.496128,-2.03319,0.336853,0.393923,-1.96922,0.593148,0.511633,-1.99914,0.567863,0.444593,-2.05286,0.111355,1.35525,-1.81614,0.113011,1.38354,-2.0295},
/*1141*/{0.257193,1.93855,-1.72668,0.292892,1.88973,-1.8881,0.235012,1.78228,-1.61199,0.226195,1.65263,-1.53764,0.334618,1.66621,-1.65774,0.41014,1.66529,-1.71232,0.17482,1.96601,-2.09303,0.283133,1.88975,-1.96084,0.07564,1.93106,-1.97627,-0.065318,1.86677,-2.08064,-0.109807,1.77908,-2.1404,0.02451,1.63967,-2.12506,0.051068,1.58072,-2.15622,0.195981,1.43297,-1.78707,0.010297,1.51488,-1.85915,0.01037,1.54537,-1.90449,0.010198,1.52196,-1.97461,0.193857,1.47283,-2.03922,0.122287,1.11029,-1.76333,-0.01272,1.13305,-1.77127,-0.028512,1.05127,-1.7969,-0.002986,0.924439,-1.79545,-0.138036,0.789895,-1.78331,-0.205662,0.754549,-1.79167,-0.194497,0.886794,-1.76878,-0.256576,0.851327,-1.77256,-0.438654,0.690866,-1.78956,-0.513532,0.797571,-1.80585,-0.478839,0.566365,-1.91586,-0.533172,0.545497,-1.84683,0.286354,1.21096,-2.0995,0.332817,1.14129,-2.08312,0.16633,1.13133,-2.08626,0.212965,1.06495,-2.07206,0.333614,0.976786,-2.07397,0.417548,0.807439,-2.05728,0.306646,0.789819,-2.07823,0.320544,0.72137,-2.06726,0.394905,0.493707,-2.0293,0.341201,0.389082,-1.96464,0.595307,0.510569,-1.99686,0.57063,0.443282,-2.05289,0.111672,1.35442,-1.81648,0.113587,1.38208,-2.02992},
/*1142*/{0.257017,1.93658,-1.72689,0.292829,1.88772,-1.88775,0.233621,1.77963,-1.61266,0.222572,1.64987,-1.54027,0.333303,1.6603,-1.65825,0.409377,1.65767,-1.71233,0.17498,1.96464,-2.09263,0.283536,1.88909,-1.96006,0.075806,1.92905,-1.97559,-0.065229,1.86455,-2.07928,-0.109163,1.77563,-2.13973,0.026068,1.6359,-2.12555,0.051565,1.57731,-2.15652,0.196436,1.43191,-1.78772,0.010892,1.51247,-1.86063,0.010203,1.54293,-1.90522,0.009884,1.51953,-1.97601,0.19307,1.47191,-2.03962,0.129672,1.10951,-1.76516,-0.007116,1.12624,-1.76994,-0.020653,1.04584,-1.79583,0.006781,0.920099,-1.79603,-0.132967,0.792504,-1.78305,-0.2018,0.759337,-1.79086,-0.186532,0.891643,-1.76775,-0.248747,0.858504,-1.77021,-0.438456,0.707029,-1.78006,-0.508836,0.815137,-1.80583,-0.479763,0.580454,-1.91149,-0.538628,0.563398,-1.84374,0.283109,1.20581,-2.10041,0.327946,1.13665,-2.08509,0.163532,1.12827,-2.08511,0.208422,1.06083,-2.07106,0.326607,0.971096,-2.07313,0.412948,0.803993,-2.05636,0.30186,0.785081,-2.07461,0.317488,0.717547,-2.06327,0.393663,0.48918,-2.02621,0.341831,0.386318,-1.96084,0.596364,0.509174,-1.99765,0.571729,0.441459,-2.05231,0.11265,1.35282,-1.81733,0.114275,1.38036,-2.03079},
/*1143*/{0.256718,1.93472,-1.72653,0.292136,1.88516,-1.88761,0.231838,1.77626,-1.61283,0.220734,1.64768,-1.54172,0.33199,1.65422,-1.65857,0.408261,1.64974,-1.71269,0.174567,1.96326,-2.09235,0.283071,1.88671,-1.95971,0.075088,1.92747,-1.97627,-0.063381,1.86143,-2.0788,-0.107729,1.77164,-2.13923,0.027441,1.63234,-2.12651,0.052632,1.57259,-2.15632,0.197274,1.43099,-1.78867,0.010931,1.51006,-1.86187,0.010038,1.54089,-1.90644,0.01063,1.51713,-1.97671,0.192364,1.4695,-2.04053,0.136609,1.10566,-1.7656,-0.001186,1.12105,-1.76902,-0.012961,1.04076,-1.79678,0.016046,0.915897,-1.7967,-0.128156,0.795404,-1.78183,-0.197099,0.76464,-1.78906,-0.177171,0.896301,-1.76697,-0.24149,0.864759,-1.76947,-0.437922,0.720564,-1.78626,-0.502315,0.832143,-1.80736,-0.481583,0.593771,-1.90752,-0.542588,0.581389,-1.8404,0.280705,1.20079,-2.10121,0.32651,1.13013,-2.08565,0.160096,1.12574,-2.08366,0.204333,1.05815,-2.06938,0.321362,0.966198,-2.07241,0.408289,0.800542,-2.05553,0.297004,0.78064,-2.07166,0.313173,0.712685,-2.05936,0.391555,0.485778,-2.02311,0.341759,0.383165,-1.95565,0.595095,0.506292,-1.99778,0.568651,0.43779,-2.05171,0.113464,1.35138,-1.81766,0.114479,1.3778,-2.03127},
/*1144*/{0.255832,1.93159,-1.72584,0.292478,1.88246,-1.8871,0.230702,1.77278,-1.61368,0.216355,1.64401,-1.54367,0.330148,1.64761,-1.65943,0.40741,1.64178,-1.71212,0.17339,1.96055,-2.09196,0.282756,1.88475,-1.95971,0.07443,1.92522,-1.97686,-0.062507,1.85747,-2.07878,-0.106813,1.76737,-2.13915,0.028967,1.62768,-2.1274,0.054392,1.56893,-2.15762,0.197443,1.42904,-1.78939,0.010738,1.50724,-1.8624,0.009932,1.53804,-1.90658,0.01007,1.51377,-1.97778,0.192283,1.46708,-2.04121,0.143221,1.10452,-1.76708,0.005799,1.1177,-1.76766,-0.005099,1.03556,-1.79489,0.026368,0.911232,-1.7971,-0.122358,0.798592,-1.7806,-0.192918,0.770522,-1.78728,-0.167629,0.900898,-1.76697,-0.232763,0.873268,-1.76777,-0.434971,0.73475,-1.78366,-0.494516,0.848524,-1.81008,-0.480512,0.608033,-1.89978,-0.544711,0.598326,-1.83739,0.279299,1.19668,-2.10378,0.322492,1.1256,-2.08821,0.157677,1.12319,-2.08231,0.201108,1.0557,-2.06772,0.316943,0.961646,-2.0714,0.402514,0.796072,-2.05485,0.292013,0.775886,-2.06774,0.308383,0.708413,-2.05601,0.388785,0.482048,-2.01919,0.339123,0.378871,-1.95125,0.592256,0.502423,-1.99795,0.564725,0.434102,-2.05056,0.114033,1.34901,-1.81805,0.114693,1.37503,-2.03171},
/*1145*/{0.255314,1.92869,-1.72485,0.291713,1.87931,-1.88647,0.228607,1.76925,-1.61348,0.213956,1.64019,-1.54489,0.327708,1.64169,-1.65983,0.406037,1.63279,-1.71183,0.173656,1.95815,-2.09201,0.282893,1.88246,-1.95934,0.073952,1.92256,-1.97774,-0.06203,1.85229,-2.07809,-0.105473,1.76185,-2.13939,0.031002,1.62235,-2.12782,0.056144,1.56393,-2.15837,0.197726,1.42748,-1.79023,0.010446,1.5049,-1.8626,0.009897,1.53566,-1.90659,0.011062,1.5108,-1.97747,0.192126,1.46491,-2.04204,0.149907,1.10091,-1.76793,0.012172,1.11087,-1.76621,0.001985,1.03033,-1.79488,0.035509,0.90727,-1.79686,-0.115968,0.801526,-1.779,-0.186918,0.776006,-1.7855,-0.158673,0.9058,-1.76728,-0.223641,0.879662,-1.76923,-0.431971,0.748633,-1.78026,-0.485843,0.864055,-1.81223,-0.480307,0.619904,-1.89599,-0.545065,0.616118,-1.83313,0.277303,1.1923,-2.10493,0.319653,1.12099,-2.08917,0.154786,1.12047,-2.08107,0.197348,1.05259,-2.06652,0.313504,0.958202,-2.0692,0.398011,0.79211,-2.05366,0.2867,0.771211,-2.06479,0.304071,0.703731,-2.05293,0.384026,0.477897,-2.01604,0.336793,0.376259,-1.94285,0.588071,0.497419,-1.99685,0.561026,0.430072,-2.04898,0.114822,1.34697,-1.81821,0.114905,1.37265,-2.03191},
/*1146*/{0.253391,1.92489,-1.72447,0.29258,1.876,-1.88638,0.226676,1.76518,-1.6138,0.209862,1.63709,-1.54679,0.325657,1.63498,-1.65982,0.402755,1.62372,-1.71086,0.173118,1.9552,-2.09223,0.282651,1.87962,-1.95952,0.073022,1.91918,-1.97827,-0.062752,1.84738,-2.08015,-0.104726,1.75641,-2.14014,0.032665,1.61771,-2.1292,0.05792,1.5581,-2.15933,0.199793,1.42602,-1.79119,0.010418,1.50221,-1.86302,0.010008,1.53217,-1.9069,0.01046,1.50821,-1.97876,0.191966,1.46289,-2.04256,0.15492,1.09955,-1.76961,0.018511,1.10565,-1.76573,0.010385,1.02483,-1.79429,0.044858,0.903687,-1.79673,-0.109344,0.80432,-1.77776,-0.181644,0.781071,-1.78355,-0.148999,0.909234,-1.7677,-0.21515,0.885041,-1.76803,-0.42673,0.761168,-1.77631,-0.476691,0.877945,-1.81335,-0.477221,0.63148,-1.89071,-0.543792,0.631599,-1.82868,0.276054,1.18792,-2.10693,0.317171,1.11672,-2.09081,0.152357,1.11906,-2.07924,0.19406,1.04958,-2.06505,0.3108,0.955564,-2.06853,0.393334,0.787499,-2.05316,0.281323,0.767215,-2.06353,0.298784,0.700096,-2.05056,0.377321,0.472368,-2.01348,0.330495,0.372853,-1.93793,0.582704,0.491396,-1.99597,0.554565,0.423519,-2.04667,0.116599,1.34499,-1.8187,0.115609,1.37016,-2.03246},
/*1147*/{0.253092,1.92225,-1.72373,0.292075,1.87352,-1.88578,0.225056,1.76097,-1.61398,0.206402,1.63352,-1.54778,0.322096,1.62778,-1.65985,0.401088,1.61485,-1.71013,0.172744,1.95096,-2.0926,0.28208,1.8767,-1.95917,0.072631,1.91572,-1.9787,-0.061921,1.84137,-2.08102,-0.103796,1.74975,-2.14076,0.034634,1.61125,-2.13052,0.0603,1.55233,-2.16029,0.199976,1.42347,-1.79234,0.010337,1.49908,-1.86312,0.010623,1.52884,-1.9087,0.009681,1.5042,-1.97884,0.19204,1.46085,-2.04298,0.160002,1.09739,-1.76943,0.024234,1.10127,-1.76651,0.017281,1.02044,-1.79331,0.05339,0.899984,-1.79516,-0.102517,0.80704,-1.77582,-0.175632,0.784516,-1.78252,-0.138765,0.91383,-1.76812,-0.206724,0.890916,-1.76877,-0.420215,0.776509,-1.77866,-0.467235,0.892074,-1.81703,-0.473539,0.643215,-1.88526,-0.540287,0.646463,-1.82374,0.274281,1.18331,-2.10912,0.314656,1.11145,-2.09183,0.149655,1.11643,-2.07894,0.191244,1.047,-2.06415,0.309208,0.953157,-2.0672,0.388693,0.782133,-2.05161,0.27651,0.76246,-2.06125,0.293121,0.694929,-2.04846,0.371935,0.468387,-2.0107,0.32251,0.370011,-1.93288,0.576758,0.484753,-1.99245,0.547221,0.416963,-2.04378,0.117459,1.34214,-1.81947,0.116198,1.36736,-2.03322},
/*1148*/{0.252075,1.9181,-1.72318,0.292398,1.86948,-1.88548,0.222388,1.75644,-1.61375,0.200831,1.62937,-1.548,0.319385,1.62052,-1.66007,0.397789,1.60569,-1.70893,0.172958,1.9468,-2.0935,0.282434,1.87322,-1.95908,0.071814,1.91161,-1.97909,-0.062446,1.83423,-2.08235,-0.102337,1.7427,-2.14232,0.037244,1.60566,-2.13208,0.063021,1.5456,-2.16134,0.200428,1.42162,-1.79317,0.010561,1.49502,-1.86288,0.010797,1.5257,-1.90876,0.008787,1.50085,-1.97867,0.191677,1.45891,-2.04358,0.165364,1.09452,-1.76932,0.029492,1.09604,-1.76635,0.025316,1.01473,-1.79181,0.061875,0.896923,-1.79534,-0.095252,0.809291,-1.77403,-0.167269,0.789809,-1.77985,-0.12857,0.917027,-1.76917,-0.197067,0.897265,-1.76946,-0.413729,0.788351,-1.77682,-0.457618,0.904359,-1.81963,-0.469377,0.653555,-1.8804,-0.535428,0.660384,-1.81861,0.272353,1.17894,-2.10999,0.311606,1.10694,-2.09202,0.147474,1.11361,-2.07813,0.18783,1.04378,-2.06348,0.307815,0.950181,-2.06551,0.382156,0.777049,-2.05084,0.271111,0.758005,-2.05968,0.286796,0.690219,-2.04681,0.362926,0.462908,-2.00725,0.313108,0.365279,-1.93392,0.568215,0.4765,-1.99037,0.538777,0.407895,-2.0393,0.11884,1.33943,-1.81996,0.116579,1.36486,-2.03368},
/*1149*/{0.251841,1.91468,-1.72257,0.292795,1.8661,-1.88523,0.220093,1.75167,-1.61415,0.197578,1.62464,-1.54781,0.31593,1.61337,-1.66018,0.39489,1.59653,-1.7081,0.172141,1.94285,-2.09413,0.282708,1.86982,-1.95905,0.071248,1.9071,-1.97931,-0.063129,1.82721,-2.08453,-0.101045,1.7352,-2.14393,0.03999,1.59866,-2.13372,0.065687,1.53878,-2.16275,0.201117,1.41935,-1.79425,0.010668,1.49116,-1.86321,0.010433,1.52166,-1.90914,0.008964,1.49735,-1.97842,0.190974,1.45616,-2.04406,0.173004,1.09101,-1.76748,0.034835,1.09111,-1.76613,0.030909,1.00934,-1.7936,0.070856,0.894071,-1.79331,-0.087688,0.811484,-1.77254,-0.161455,0.792856,-1.77866,-0.117956,0.920041,-1.76977,-0.187109,0.901044,-1.76929,-0.404818,0.799243,-1.77533,-0.448148,0.915507,-1.82271,-0.463676,0.663281,-1.87516,-0.529713,0.672992,-1.81293,0.269675,1.17413,-2.11083,0.309084,1.10144,-2.09261,0.144528,1.11048,-2.07787,0.184824,1.03999,-2.06248,0.30542,0.946865,-2.06432,0.377344,0.770645,-2.04998,0.265115,0.753593,-2.05894,0.280448,0.685615,-2.04617,0.354569,0.457506,-2.00614,0.303092,0.361703,-1.92983,0.560624,0.468011,-1.98644,0.530077,0.399311,-2.03541,0.120076,1.33643,-1.8204,0.116872,1.36171,-2.03412},
/*1150*/{0.250714,1.9104,-1.72193,0.291886,1.86136,-1.8847,0.218021,1.74712,-1.61453,0.192472,1.62068,-1.54852,0.312038,1.60577,-1.65965,0.391137,1.58693,-1.70701,0.172292,1.93804,-2.09469,0.282899,1.86581,-1.95867,0.07019,1.90297,-1.98055,-0.063245,1.81802,-2.08596,-0.099276,1.72737,-2.14612,0.042708,1.59154,-2.13539,0.068321,1.53088,-2.16386,0.200977,1.41691,-1.79497,0.010936,1.48744,-1.86306,0.01042,1.51745,-1.90917,0.008824,1.49245,-1.97711,0.191211,1.45346,-2.04446,0.176508,1.09064,-1.76736,0.040421,1.08603,-1.76759,0.037907,1.00406,-1.79391,0.079199,0.891318,-1.79154,-0.078914,0.813896,-1.77169,-0.151733,0.798178,-1.7756,-0.106624,0.923849,-1.77043,-0.176558,0.906364,-1.77014,-0.397862,0.81123,-1.775,-0.437898,0.925404,-1.82442,-0.457534,0.671894,-1.86996,-0.521953,0.683949,-1.80726,0.267625,1.16988,-2.11119,0.306729,1.09677,-2.09329,0.142043,1.10682,-2.0772,0.18239,1.0356,-2.06159,0.302505,0.941648,-2.06328,0.37224,0.765044,-2.04907,0.259465,0.748758,-2.05823,0.273319,0.680502,-2.04542,0.344225,0.451253,-2.00414,0.291112,0.357205,-1.92829,0.550371,0.458723,-1.98198,0.520714,0.389869,-2.03055,0.12144,1.33321,-1.8203,0.117539,1.35827,-2.03404},
/*1151*/{0.250558,1.90645,-1.72159,0.292915,1.85629,-1.8839,0.215452,1.74209,-1.61449,0.187322,1.6159,-1.54926,0.307668,1.59794,-1.65925,0.386957,1.57809,-1.70628,0.171679,1.93287,-2.0953,0.28295,1.86148,-1.95892,0.06934,1.89806,-1.98183,-0.063119,1.80967,-2.0883,-0.097517,1.71889,-2.1485,0.046107,1.58313,-2.13783,0.07187,1.52295,-2.16459,0.200978,1.41413,-1.7962,0.010691,1.48295,-1.86168,0.010478,1.51334,-1.90853,0.008171,1.4881,-1.97715,0.190751,1.45055,-2.04566,0.182072,1.087,-1.76358,0.046057,1.08313,-1.76762,0.045009,0.999684,-1.79398,0.089123,0.888531,-1.78985,-0.070223,0.816167,-1.76838,-0.14416,0.801094,-1.77536,-0.095419,0.925902,-1.7711,-0.16561,0.910253,-1.77187,-0.386141,0.819873,-1.77334,-0.427699,0.934165,-1.82706,-0.449297,0.679775,-1.86519,-0.513195,0.69382,-1.80295,0.265696,1.1652,-2.1118,0.304446,1.09144,-2.0937,0.140073,1.10224,-2.07658,0.179342,1.03212,-2.06105,0.299854,0.937008,-2.06313,0.365293,0.758458,-2.04834,0.253103,0.743621,-2.05836,0.266363,0.675747,-2.04558,0.335501,0.445915,-2.00374,0.275447,0.352969,-1.93432,0.539747,0.448236,-1.97811,0.509678,0.379506,-2.02694,0.122655,1.3296,-1.82079,0.117367,1.35491,-2.03447},
/*1152*/{0.249432,1.90161,-1.72066,0.292222,1.85271,-1.8836,0.212547,1.73772,-1.61428,0.182892,1.61163,-1.54965,0.303629,1.5908,-1.65873,0.381641,1.56914,-1.70478,0.172181,1.92748,-2.09627,0.282958,1.8573,-1.95856,0.068543,1.893,-1.9822,-0.063042,1.80115,-2.09052,-0.095075,1.71007,-2.15113,0.048697,1.57436,-2.13926,0.075872,1.51462,-2.16564,0.201251,1.41097,-1.79678,0.010751,1.47796,-1.86079,0.009538,1.50925,-1.9084,0.007956,1.4831,-1.97648,0.190747,1.44717,-2.04654,0.183971,1.08534,-1.7621,0.049444,1.07612,-1.77003,0.051623,0.995536,-1.79434,0.0988,0.886008,-1.78759,-0.061294,0.818316,-1.76702,-0.135743,0.804566,-1.77265,-0.083802,0.928125,-1.77352,-0.154901,0.913833,-1.7739,-0.376113,0.828685,-1.77261,-0.417292,0.942264,-1.82922,-0.440356,0.686896,-1.86057,-0.503312,0.702726,-1.79791,0.263633,1.16023,-2.1124,0.302859,1.08657,-2.09358,0.137807,1.09796,-2.07567,0.177142,1.02749,-2.06079,0.295781,0.931204,-2.0628,0.360254,0.751856,-2.04725,0.246495,0.738381,-2.05888,0.258632,0.670141,-2.04563,0.324535,0.439109,-2.00395,0.262872,0.348884,-1.93,0.528659,0.436599,-1.97314,0.497769,0.368086,-2.02137,0.123907,1.32575,-1.82092,0.117633,1.35106,-2.03457},
/*1153*/{0.248957,1.89687,-1.71988,0.293728,1.84834,-1.88359,0.210584,1.73247,-1.61489,0.177832,1.60809,-1.55033,0.29889,1.58368,-1.65831,0.376274,1.56062,-1.70323,0.17264,1.92231,-2.09716,0.283193,1.85226,-1.95833,0.06765,1.88756,-1.98302,-0.061426,1.79162,-2.09285,-0.092538,1.70058,-2.15393,0.052444,1.56538,-2.14158,0.079034,1.5055,-2.16664,0.201816,1.40763,-1.79782,0.010936,1.4728,-1.86035,0.009829,1.5046,-1.90818,0.007492,1.47844,-1.97516,0.191315,1.4446,-2.0473,0.18976,1.08158,-1.75902,0.053835,1.0712,-1.7703,0.058297,0.989407,-1.79425,0.107947,0.88393,-1.78521,-0.051829,0.820121,-1.76539,-0.125496,0.808316,-1.76977,-0.071573,0.930157,-1.77424,-0.142805,0.917811,-1.77445,-0.366545,0.839054,-1.77414,-0.406916,0.948551,-1.8313,-0.430005,0.692115,-1.85583,-0.492678,0.710432,-1.79207,0.261155,1.15562,-2.11258,0.300527,1.08217,-2.09388,0.135322,1.09385,-2.07556,0.174811,1.02283,-2.06019,0.292356,0.92435,-2.06172,0.352613,0.744441,-2.04635,0.240143,0.733641,-2.05957,0.250779,0.664916,-2.04673,0.31192,0.434469,-2.00361,0.244734,0.355814,-1.92834,0.51573,0.424202,-1.96965,0.479785,0.355895,-2.01785,0.125757,1.32159,-1.82168,0.118508,1.34785,-2.03519},
/*1154*/{0.247879,1.89122,-1.71879,0.293066,1.84225,-1.88254,0.208089,1.7276,-1.61497,0.171355,1.60458,-1.55103,0.294127,1.57701,-1.65728,0.3714,1.55254,-1.70179,0.172919,1.9166,-2.09812,0.283712,1.84684,-1.95841,0.066942,1.88207,-1.98441,-0.061528,1.78212,-2.09646,-0.089651,1.69107,-2.1567,0.056198,1.55588,-2.14377,0.083841,1.49658,-2.16777,0.201749,1.404,-1.79873,0.010723,1.46701,-1.86011,0.009994,1.49943,-1.90826,0.006354,1.47344,-1.97456,0.191576,1.44116,-2.04818,0.192661,1.07964,-1.75716,0.058865,1.06729,-1.7711,0.064382,0.984109,-1.79535,0.117699,0.881466,-1.78331,-0.041279,0.822152,-1.76222,-0.115532,0.811132,-1.76898,-0.059309,0.931931,-1.77554,-0.130588,0.920516,-1.77612,-0.353769,0.843427,-1.77308,-0.39626,0.954162,-1.83353,-0.419952,0.697143,-1.85215,-0.482344,0.717803,-1.78808,0.259424,1.15001,-2.11265,0.298108,1.07695,-2.09402,0.133529,1.08851,-2.07542,0.172545,1.01786,-2.06012,0.288317,0.918072,-2.06145,0.347012,0.737547,-2.04534,0.233778,0.727853,-2.06007,0.242828,0.659195,-2.04717,0.300196,0.429823,-2.0036,0.225376,0.354485,-1.93129,0.502092,0.408573,-1.96702,0.461533,0.341924,-2.01557,0.126994,1.31707,-1.82241,0.119016,1.3439,-2.03581},
/*1155*/{0.247477,1.88654,-1.71889,0.293915,1.83769,-1.88244,0.204391,1.72222,-1.61539,0.166263,1.59977,-1.55073,0.288112,1.57066,-1.65663,0.364918,1.54458,-1.69991,0.173412,1.91073,-2.0991,0.284253,1.84209,-1.9583,0.065765,1.87636,-1.98565,-0.061153,1.77127,-2.09927,-0.086034,1.68117,-2.15953,0.060387,1.54696,-2.14576,0.088897,1.48755,-2.16859,0.20227,1.40008,-1.79919,0.010381,1.46179,-1.85879,0.008932,1.49409,-1.90822,0.0062,1.46855,-1.97281,0.192284,1.4374,-2.04963,0.198225,1.07581,-1.75269,0.062723,1.06001,-1.77242,0.070896,0.979204,-1.79558,0.125843,0.879549,-1.78048,-0.030451,0.822869,-1.7609,-0.104379,0.812985,-1.76704,-0.046542,0.932935,-1.77691,-0.118563,0.922765,-1.7776,-0.341989,0.849506,-1.77205,-0.384339,0.95904,-1.83529,-0.408195,0.701265,-1.84613,-0.470765,0.723453,-1.78388,0.256736,1.14456,-2.11362,0.294856,1.07021,-2.09478,0.130114,1.08417,-2.07521,0.169107,1.01317,-2.06062,0.284025,0.911542,-2.06113,0.339993,0.73042,-2.04403,0.227461,0.722319,-2.06109,0.235935,0.653166,-2.04757,0.286827,0.424299,-2.00103,0.205936,0.357443,-1.92828,0.488268,0.392673,-1.96096,0.444378,0.336305,-2.01404,0.128378,1.31256,-1.82266,0.119321,1.3398,-2.03597},
/*1156*/{0.247041,1.88105,-1.71805,0.293408,1.83148,-1.88174,0.201056,1.71762,-1.6153,0.160631,1.5967,-1.55116,0.28232,1.56467,-1.65527,0.358904,1.53742,-1.69814,0.174498,1.9048,-2.10042,0.285002,1.83686,-1.95736,0.065879,1.87105,-1.98648,-0.058848,1.76205,-2.1024,-0.082296,1.671,-2.16295,0.064867,1.5369,-2.14805,0.093772,1.47833,-2.16954,0.202003,1.39531,-1.7996,0.009802,1.4569,-1.85792,0.008196,1.48858,-1.90792,0.005456,1.46348,-1.97206,0.193216,1.43301,-2.05093,0.202026,1.07212,-1.74963,0.067347,1.05606,-1.77291,0.078521,0.973117,-1.7953,0.135644,0.87769,-1.7773,-0.018879,0.824448,-1.75874,-0.092866,0.816693,-1.76356,-0.033988,0.933655,-1.77838,-0.105116,0.924429,-1.77837,-0.330024,0.854018,-1.77138,-0.372794,0.962539,-1.83782,-0.395957,0.70452,-1.84138,-0.456817,0.72833,-1.77885,0.252901,1.1382,-2.11499,0.291174,1.06381,-2.09635,0.127033,1.07998,-2.07539,0.164948,1.00803,-2.06085,0.278022,0.905885,-2.0624,0.331965,0.722585,-2.04226,0.220808,0.71719,-2.06076,0.227746,0.647906,-2.0484,0.266748,0.420254,-1.99524,0.183507,0.354885,-1.92998,0.467071,0.386705,-1.95019,0.422144,0.339026,-2.01471,0.12875,1.30757,-1.82301,0.119258,1.33527,-2.03624},
/*1157*/{0.246003,1.8761,-1.7176,0.293423,1.82661,-1.88125,0.19817,1.7133,-1.61509,0.152883,1.59337,-1.55208,0.275661,1.55943,-1.6534,0.352694,1.53069,-1.69587,0.17455,1.8993,-2.10144,0.286142,1.8314,-1.95761,0.066691,1.86553,-1.98855,-0.056474,1.75218,-2.10665,-0.077775,1.66045,-2.16681,0.069683,1.52874,-2.15066,0.099583,1.46941,-2.17062,0.202233,1.39039,-1.80006,0.008983,1.45149,-1.85779,0.008199,1.4825,-1.90706,0.00438,1.45913,-1.97159,0.191507,1.42756,-2.05207,0.206199,1.06939,-1.74723,0.07201,1.05083,-1.77389,0.085553,0.967542,-1.79549,0.145105,0.875593,-1.77461,-0.007705,0.824515,-1.75637,-0.082503,0.816362,-1.762,-0.020803,0.93347,-1.77981,-0.091347,0.926271,-1.77822,-0.31688,0.858212,-1.7701,-0.361488,0.965239,-1.84046,-0.382343,0.706496,-1.83691,-0.443559,0.732136,-1.77397,0.250197,1.13305,-2.11719,0.286659,1.05814,-2.09933,0.123544,1.07662,-2.07522,0.160157,1.00505,-2.05955,0.272599,0.898995,-2.06316,0.324783,0.714599,-2.03819,0.21386,0.712047,-2.06123,0.216652,0.642852,-2.04712,0.248474,0.423152,-1.98765,0.160479,0.353146,-1.92549,0.442071,0.386791,-1.95293,0.397692,0.341118,-2.01477,0.128754,1.30236,-1.82332,0.117795,1.33001,-2.03649},
/*1158*/{0.245768,1.87098,-1.71763,0.295102,1.8216,-1.88068,0.193659,1.70868,-1.61543,0.145901,1.59049,-1.55139,0.268909,1.5543,-1.65261,0.345885,1.5251,-1.69388,0.17621,1.89303,-2.10257,0.286548,1.82566,-1.95746,0.066697,1.86091,-1.98916,-0.055131,1.74201,-2.11177,-0.072591,1.65,-2.17017,0.075761,1.51744,-2.15176,0.106219,1.46039,-2.17154,0.202842,1.38516,-1.80033,0.008133,1.4467,-1.85668,0.007059,1.47589,-1.90667,0.003798,1.45448,-1.97141,0.190689,1.4223,-2.0532,0.209896,1.06641,-1.7449,0.077436,1.04441,-1.77419,0.092638,0.961046,-1.79657,0.155487,0.873271,-1.77204,0.00489,0.824759,-1.75426,-0.070464,0.817776,-1.7608,-0.006859,0.933303,-1.78074,-0.078282,0.926608,-1.77892,-0.305391,0.861487,-1.77117,-0.349843,0.96646,-1.8427,-0.368726,0.708393,-1.83206,-0.428592,0.734338,-1.77037,0.245848,1.12889,-2.12061,0.281436,1.05328,-2.10391,0.119744,1.07485,-2.07459,0.156346,1.00276,-2.05875,0.265832,0.8915,-2.06442,0.317121,0.707773,-2.03367,0.206684,0.708689,-2.05871,0.206604,0.640306,-2.04137,0.224367,0.423577,-1.98146,0.136908,0.354573,-1.92335,0.418416,0.386102,-1.94744,0.373629,0.340831,-2.01327,0.128941,1.29713,-1.8235,0.11683,1.32477,-2.03661},
/*1159*/{0.245342,1.86614,-1.71651,0.295802,1.81642,-1.8804,0.189788,1.705,-1.61547,0.138637,1.5889,-1.55058,0.262035,1.55002,-1.65053,0.338378,1.51925,-1.69143,0.178303,1.88746,-2.10426,0.287765,1.82086,-1.95678,0.068306,1.85674,-1.9912,-0.050969,1.732,-2.11726,-0.067004,1.63928,-2.17341,0.082561,1.50855,-2.15391,0.113308,1.45214,-2.17238,0.202081,1.37969,-1.80061,0.006793,1.44132,-1.85589,0.004918,1.47013,-1.90576,0.000487,1.4516,-1.97132,0.189407,1.4167,-2.05477,0.213759,1.06302,-1.74234,0.083136,1.03688,-1.77501,0.102178,0.955952,-1.79657,0.165693,0.870878,-1.76873,0.017545,0.824847,-1.75254,-0.058463,0.817645,-1.75867,0.006625,0.932438,-1.78135,-0.064996,0.92692,-1.77968,-0.291581,0.864246,-1.76973,-0.33804,0.96737,-1.84489,-0.354287,0.708996,-1.8274,-0.414593,0.736162,-1.76554,0.241752,1.12584,-2.12416,0.277383,1.04978,-2.10702,0.11601,1.07447,-2.07461,0.152417,1.0009,-2.05878,0.258739,0.88655,-2.06512,0.308974,0.704889,-2.02959,0.198201,0.710525,-2.05371,0.194963,0.642763,-2.03544,0.203554,0.4253,-1.97806,0.113541,0.354783,-1.92057,0.397484,0.381739,-1.94639,0.350693,0.341851,-2.01134,0.12734,1.29173,-1.82417,0.114106,1.32,-2.03713},
/*1160*/{0.244828,1.86204,-1.71539,0.296923,1.81138,-1.87938,0.185008,1.70207,-1.61482,0.130616,1.58673,-1.55018,0.254785,1.54574,-1.64816,0.330993,1.51359,-1.68881,0.179951,1.8818,-2.10627,0.288972,1.81576,-1.9567,0.067645,1.85392,-1.99196,-0.04592,1.72248,-2.12392,-0.060914,1.62835,-2.17726,0.09029,1.50016,-2.15542,0.121484,1.44401,-2.17305,0.201835,1.37479,-1.80219,0.00588,1.43607,-1.85584,0.002309,1.46554,-1.90489,-0.001851,1.44745,-1.97138,0.187786,1.41252,-2.05563,0.218225,1.0611,-1.73994,0.088937,1.02937,-1.77459,0.108482,0.949682,-1.79646,0.177132,0.868337,-1.76657,0.030817,0.82357,-1.75114,-0.042963,0.817036,-1.7575,0.020287,0.931515,-1.78101,-0.050255,0.926327,-1.77872,-0.276036,0.864521,-1.77012,-0.326238,0.966967,-1.84696,-0.338885,0.708774,-1.82278,-0.398539,0.736941,-1.76112,0.239189,1.12445,-2.1253,0.2746,1.04802,-2.10771,0.113225,1.07357,-2.07482,0.150281,1.00031,-2.05935,0.253461,0.884863,-2.06477,0.297988,0.70302,-2.02686,0.187516,0.715005,-2.0492,0.180903,0.646924,-2.03183,0.186862,0.426362,-1.97481,0.091239,0.355314,-1.91859,0.374407,0.381863,-1.94429,0.329776,0.342206,-2.00935,0.126658,1.2868,-1.82539,0.112058,1.31599,-2.03814},
/*1161*/{0.244436,1.85805,-1.71486,0.297015,1.80573,-1.87857,0.179521,1.69909,-1.61467,0.122448,1.58506,-1.55021,0.247366,1.54255,-1.64681,0.323042,1.50917,-1.68545,0.181152,1.8764,-2.1075,0.289742,1.81102,-1.95541,0.068196,1.85093,-1.99217,-0.041153,1.71193,-2.13091,-0.053327,1.61699,-2.18084,0.097076,1.49367,-2.15701,0.131023,1.43718,-2.17374,0.200849,1.37006,-1.80364,0.003368,1.43165,-1.85587,0.001185,1.46087,-1.90389,-0.00491,1.44352,-1.97138,0.18491,1.40977,-2.05653,0.223939,1.05903,-1.73781,0.094732,1.02394,-1.77531,0.118564,0.944323,-1.79627,0.188797,0.865533,-1.7643,0.04358,0.822405,-1.74978,-0.031481,0.816634,-1.75767,0.034728,0.930806,-1.78048,-0.037071,0.926095,-1.7787,-0.263564,0.866318,-1.76909,-0.315022,0.965065,-1.84863,-0.322096,0.708063,-1.8186,-0.38288,0.736798,-1.75705,0.235526,1.12393,-2.1245,0.272955,1.04843,-2.10608,0.11089,1.07029,-2.07467,0.148434,0.997818,-2.05876,0.251063,0.885046,-2.06359,0.285833,0.701848,-2.02753,0.175002,0.719709,-2.0458,0.165571,0.651821,-2.02986,0.16496,0.427277,-1.97146,0.069516,0.358258,-1.91704,0.353331,0.379968,-1.94333,0.306608,0.342377,-2.00825,0.12544,1.28212,-1.82703,0.10947,1.31288,-2.03946},
/*1162*/{0.244023,1.85466,-1.71361,0.298509,1.80252,-1.87718,0.174194,1.69827,-1.61365,0.113251,1.58339,-1.54915,0.23855,1.53969,-1.64448,0.314531,1.50539,-1.68267,0.18314,1.87169,-2.10856,0.291059,1.80661,-1.95509,0.06846,1.84838,-1.99224,-0.036984,1.70294,-2.13683,-0.046187,1.60649,-2.18406,0.106442,1.48711,-2.15792,0.140267,1.43098,-2.17434,0.199771,1.36537,-1.80525,0.001306,1.42863,-1.8531,-9.7e-005,1.45899,-1.90442,-0.00778,1.44037,-1.97003,0.183157,1.40705,-2.05795,0.228205,1.05909,-1.73703,0.100772,1.01773,-1.77591,0.126711,0.940308,-1.79684,0.201545,0.864016,-1.76202,0.057031,0.822487,-1.74885,-0.017747,0.815713,-1.75571,0.04795,0.929834,-1.77987,-0.022767,0.925002,-1.77739,-0.249604,0.865261,-1.76852,-0.304214,0.962443,-1.85017,-0.306351,0.705565,-1.815,-0.365784,0.734722,-1.75301,0.232506,1.12339,-2.12282,0.269915,1.04872,-2.10527,0.107984,1.06853,-2.07509,0.14637,0.996784,-2.05951,0.249932,0.885446,-2.06249,0.273316,0.701448,-2.02913,0.161844,0.723045,-2.04278,0.151559,0.655256,-2.02794,0.139649,0.425686,-1.96942,0.047943,0.358698,-1.91705,0.332092,0.379084,-1.94087,0.285268,0.342551,-2.00691,0.123632,1.27825,-1.82814,0.106118,1.31034,-2.04025},
/*1163*/{0.244378,1.85157,-1.71234,0.298929,1.79801,-1.87546,0.168991,1.69753,-1.61309,0.10535,1.58521,-1.54972,0.230868,1.53738,-1.64323,0.306868,1.50224,-1.68042,0.184281,1.86717,-2.11023,0.291592,1.80285,-1.95353,0.069787,1.84585,-1.9925,-0.033152,1.69451,-2.14219,-0.038243,1.59668,-2.18728,0.115622,1.48098,-2.15805,0.151666,1.42606,-2.17521,0.197898,1.36164,-1.80673,-0.001735,1.42529,-1.85008,-0.000671,1.45878,-1.90297,-0.009931,1.4376,-1.96843,0.181226,1.40611,-2.05925,0.231775,1.06111,-1.73633,0.106293,1.01564,-1.77554,0.136306,0.938095,-1.79468,0.214208,0.86399,-1.76129,0.07014,0.82156,-1.74859,-0.005184,0.815095,-1.75591,0.062188,0.929392,-1.77753,-0.009113,0.924764,-1.77628,-0.234514,0.864108,-1.77028,-0.29332,0.958764,-1.8513,-0.28899,0.702419,-1.81197,-0.348668,0.731112,-1.74901,0.228827,1.12282,-2.12284,0.265969,1.0475,-2.10543,0.103883,1.06471,-2.07298,0.141706,0.995657,-2.05865,0.249255,0.885879,-2.06031,0.258546,0.700033,-2.03266,0.148514,0.724564,-2.04286,0.135976,0.657735,-2.02564,0.123471,0.428765,-1.96948,0.025683,0.359931,-1.91361,0.310438,0.377816,-1.94076,0.262072,0.341879,-2.00719,0.12184,1.27488,-1.82942,0.102924,1.3094,-2.04102},
/*1164*/{0.244617,1.84889,-1.71145,0.297662,1.79469,-1.87447,0.162869,1.6975,-1.61298,0.096057,1.58683,-1.5498,0.222791,1.53571,-1.64166,0.298104,1.49995,-1.67835,0.185506,1.86397,-2.11007,0.29156,1.79929,-1.95335,0.069981,1.84457,-1.99197,-0.02811,1.68496,-2.14638,-0.030007,1.58811,-2.18981,0.126909,1.47709,-2.15822,0.163376,1.42194,-2.17459,0.196175,1.35772,-1.80644,-0.002058,1.42279,-1.85331,-0.002488,1.4586,-1.90348,-0.011372,1.43565,-1.96644,0.179185,1.40558,-2.06105,0.237194,1.06466,-1.73598,0.114713,1.01657,-1.77369,0.146766,0.938374,-1.79243,0.227704,0.865006,-1.7603,0.084447,0.820122,-1.7478,0.009195,0.813895,-1.75679,0.075167,0.929333,-1.77644,0.00457,0.924323,-1.77548,-0.22291,0.860732,-1.7709,-0.284309,0.953669,-1.85199,-0.270735,0.698785,-1.80796,-0.329923,0.72569,-1.74562,0.224971,1.12012,-2.12245,0.261254,1.04449,-2.10472,0.099707,1.06322,-2.07094,0.136883,0.994395,-2.05743,0.248288,0.88582,-2.05779,0.245943,0.698244,-2.0347,0.135857,0.725052,-2.04331,0.122509,0.658022,-2.02521,0.102298,0.429432,-1.96938,0.004008,0.361269,-1.91224,0.28956,0.377463,-1.93959,0.240052,0.341781,-2.00678,0.119711,1.27195,-1.83153,0.100847,1.30868,-2.04277},
/*1165*/{0.245202,1.84683,-1.71062,0.299132,1.79243,-1.8738,0.156977,1.69901,-1.61219,0.088274,1.5893,-1.54997,0.213997,1.53572,-1.64046,0.288465,1.497,-1.67626,0.186962,1.86117,-2.10953,0.292414,1.79746,-1.95186,0.07031,1.84291,-1.99123,-0.024306,1.67733,-2.15048,-0.021914,1.58085,-2.19193,0.137841,1.47397,-2.15828,0.175719,1.41941,-2.17422,0.194981,1.35445,-1.80662,-0.002824,1.42117,-1.85188,-0.004268,1.4583,-1.9035,-0.012303,1.43514,-1.96468,0.177603,1.40525,-2.06244,0.244715,1.06824,-1.73628,0.122246,1.01684,-1.77242,0.157289,0.93913,-1.79092,0.241999,0.866052,-1.7608,0.097988,0.820301,-1.74747,0.021852,0.81442,-1.75598,0.088085,0.929812,-1.77464,0.016759,0.924391,-1.77511,-0.207258,0.854946,-1.76941,-0.275115,0.947096,-1.8528,-0.25215,0.693005,-1.80621,-0.310354,0.720111,-1.74194,0.219463,1.11717,-2.12257,0.255549,1.04054,-2.10462,0.094786,1.0633,-2.07029,0.130621,0.993149,-2.05541,0.241832,0.883859,-2.0558,0.23398,0.694033,-2.0335,0.124035,0.723843,-2.04336,0.109047,0.658204,-2.02608,0.079603,0.427336,-1.96831,-0.018117,0.361314,-1.91496,0.266877,0.376902,-1.94082,0.218078,0.341683,-2.00685,0.117953,1.26962,-1.83283,0.098392,1.30852,-2.04362},
/*1166*/{0.245418,1.84536,-1.71007,0.298457,1.7913,-1.8732,0.151471,1.70067,-1.61231,0.079644,1.5933,-1.55127,0.205886,1.53546,-1.63998,0.28039,1.49577,-1.67352,0.188551,1.85972,-2.10898,0.29186,1.79557,-1.95164,0.070529,1.84215,-1.99083,-0.017662,1.67088,-2.15257,-0.013443,1.57487,-2.19404,0.148845,1.4721,-2.15786,0.188363,1.41897,-2.17322,0.193929,1.35198,-1.80763,-0.004081,1.42108,-1.85098,-0.003678,1.45686,-1.90316,-0.012942,1.4353,-1.9627,0.176034,1.40457,-2.06377,0.250606,1.07264,-1.73497,0.129967,1.01719,-1.77025,0.166504,0.941209,-1.78924,0.255607,0.870144,-1.76008,0.110873,0.821124,-1.74738,0.036519,0.813619,-1.75684,0.100778,0.93123,-1.77338,0.028871,0.924525,-1.77415,-0.194193,0.853526,-1.7721,-0.267141,0.939608,-1.85342,-0.23238,0.687206,-1.80377,-0.290018,0.713054,-1.73837,0.213447,1.11438,-2.12377,0.24886,1.03658,-2.10445,0.089082,1.06112,-2.06858,0.12558,0.988236,-2.05226,0.231037,0.880387,-2.05673,0.22139,0.689999,-2.03191,0.112787,0.721775,-2.04506,0.096267,0.655848,-2.0267,0.065527,0.43002,-1.96917,-0.039253,0.362012,-1.91411,0.246018,0.376617,-1.94074,0.197476,0.341815,-2.00708,0.116526,1.26779,-1.83389,0.09596,1.30821,-2.04429},
/*1167*/{0.245614,1.84444,-1.70941,0.297986,1.78958,-1.87247,0.146053,1.70287,-1.61237,0.071184,1.59749,-1.55243,0.197554,1.5368,-1.63884,0.27034,1.49483,-1.67181,0.189976,1.85885,-2.10822,0.292261,1.79432,-1.95071,0.070685,1.84099,-1.9913,-0.012608,1.66832,-2.15664,-0.004754,1.57046,-2.19588,0.159461,1.47165,-2.15679,0.201717,1.42015,-2.17175,0.193199,1.35047,-1.80626,-0.004564,1.42115,-1.8501,-0.005194,1.45651,-1.90327,-0.01343,1.43558,-1.96109,0.175198,1.40383,-2.06463,0.258704,1.0794,-1.73388,0.139485,1.01894,-1.76828,0.178157,0.943841,-1.78735,0.269398,0.875923,-1.76105,0.12434,0.822895,-1.74733,0.0489,0.81345,-1.75585,0.111122,0.932632,-1.77255,0.039996,0.923962,-1.77385,-0.182285,0.847919,-1.77279,-0.259393,0.931219,-1.85351,-0.212366,0.681432,-1.80174,-0.27019,0.705456,-1.73549,0.208541,1.10959,-2.12314,0.242611,1.03256,-2.10464,0.082953,1.06063,-2.06691,0.117862,0.986736,-2.05154,0.220931,0.875718,-2.05738,0.208882,0.684682,-2.02968,0.10138,0.719344,-2.04654,0.082411,0.654592,-2.02846,0.042895,0.431162,-1.9695,-0.060455,0.362841,-1.91326,0.224114,0.37609,-1.94026,0.173912,0.3408,-2.00699,0.11509,1.26703,-1.83351,0.094418,1.30774,-2.04385},
/*1168*/{0.244417,1.84414,-1.70911,0.298387,1.78911,-1.87146,0.141137,1.70568,-1.61227,0.062538,1.60315,-1.5549,0.1892,1.53799,-1.63822,0.261733,1.49537,-1.66944,0.192255,1.85873,-2.10744,0.291888,1.7933,-1.94981,0.07193,1.84073,-1.99176,-0.007039,1.66444,-2.15797,0.003871,1.56654,-2.19736,0.171214,1.4731,-2.15566,0.213981,1.42268,-2.16985,0.191591,1.34994,-1.8045,-0.004427,1.42184,-1.85017,-0.005428,1.45616,-1.90314,-0.012696,1.43592,-1.96114,0.174913,1.40354,-2.0652,0.26596,1.08455,-1.73405,0.14822,1.02119,-1.76649,0.189371,0.947485,-1.78551,0.282298,0.882544,-1.76035,0.137243,0.824512,-1.74749,0.063536,0.813404,-1.75628,0.120813,0.934705,-1.7719,0.050513,0.923409,-1.7737,-0.167578,0.840759,-1.77224,-0.251014,0.920508,-1.85412,-0.190415,0.674428,-1.79967,-0.247451,0.69565,-1.7329,0.202166,1.10626,-2.12303,0.234446,1.02816,-2.1043,0.076342,1.0597,-2.06664,0.109933,0.985387,-2.05134,0.210004,0.871207,-2.0568,0.19555,0.679792,-2.02866,0.09021,0.716748,-2.04672,0.06805,0.652416,-2.02915,0.01604,0.429682,-1.97077,-0.082134,0.362831,-1.91435,0.203513,0.37532,-1.94033,0.153725,0.340686,-2.00788,0.113865,1.26686,-1.83299,0.09409,1.30749,-2.04343},
/*1169*/{0.243322,1.84439,-1.70806,0.297279,1.78891,-1.87078,0.13613,1.70924,-1.61231,0.054868,1.60844,-1.55554,0.181047,1.54004,-1.63741,0.253367,1.4962,-1.66798,0.193712,1.85906,-2.10716,0.292193,1.79311,-1.94885,0.07239,1.8406,-1.99251,-0.00158,1.66099,-2.15935,0.012868,1.56382,-2.19825,0.181911,1.47565,-2.15414,0.22648,1.42736,-2.16752,0.190307,1.35091,-1.80257,-0.005047,1.423,-1.85048,-0.005492,1.45627,-1.90297,-0.013131,1.4373,-1.96144,0.176466,1.40294,-2.06526,0.271627,1.09166,-1.73499,0.156701,1.02433,-1.76509,0.199305,0.951497,-1.78422,0.295192,0.888743,-1.76117,0.150188,0.827573,-1.74794,0.075809,0.814011,-1.75605,0.130356,0.936441,-1.77197,0.059639,0.923706,-1.77363,-0.154154,0.835297,-1.77295,-0.242927,0.909162,-1.85485,-0.168976,0.667124,-1.79858,-0.224537,0.687812,-1.73006,0.196572,1.10356,-2.12226,0.226569,1.02427,-2.10423,0.06955,1.05993,-2.06672,0.099535,0.98452,-2.0519,0.198998,0.867361,-2.05635,0.181418,0.674774,-2.02574,0.077171,0.714337,-2.04648,0.053538,0.650207,-2.02958,-0.001053,0.431604,-1.97178,-0.102847,0.363244,-1.91587,0.180717,0.374647,-1.94147,0.130992,0.339808,-2.00851,0.112745,1.26774,-1.83172,0.094493,1.30743,-2.04247},
/*1170*/{0.241629,1.8459,-1.70805,0.296878,1.78873,-1.86943,0.132242,1.71235,-1.61308,0.047176,1.61495,-1.55779,0.17369,1.54304,-1.63605,0.244177,1.49732,-1.66571,0.195124,1.86023,-2.10648,0.292205,1.79329,-1.9476,0.072639,1.84053,-1.99336,0.003909,1.65927,-2.16068,0.021305,1.5624,-2.19932,0.192181,1.47954,-2.15217,0.238603,1.43276,-2.16453,0.188687,1.35261,-1.80044,-0.00506,1.42415,-1.85076,-0.006168,1.45736,-1.9034,-0.012825,1.43747,-1.96226,0.17591,1.40278,-2.06559,0.280788,1.09669,-1.73343,0.165917,1.02796,-1.7635,0.21011,0.956043,-1.78293,0.307505,0.895559,-1.76139,0.163152,0.830038,-1.7484,0.090442,0.814662,-1.75657,0.1394,0.938515,-1.77164,0.069962,0.923068,-1.77323,-0.141309,0.828455,-1.77495,-0.234354,0.896927,-1.85556,-0.147393,0.66017,-1.7968,-0.202411,0.678911,-1.72796,0.190621,1.10029,-2.1211,0.217738,1.02097,-2.10366,0.06164,1.06084,-2.06764,0.090083,0.98454,-2.05214,0.187128,0.863364,-2.05488,0.165956,0.671299,-2.0245,0.06221,0.712215,-2.04624,0.038135,0.648849,-2.03034,-0.017853,0.432228,-1.97173,-0.125267,0.364989,-1.91591,0.160039,0.374793,-1.94234,0.110244,0.340867,-2.00915,0.111817,1.26925,-1.83024,0.094434,1.30713,-2.0414},
/*1171*/{0.239898,1.84861,-1.70773,0.296834,1.78976,-1.86835,0.126347,1.71638,-1.61354,0.038909,1.62078,-1.55978,0.165719,1.54657,-1.63527,0.236532,1.49893,-1.66408,0.196605,1.8625,-2.10654,0.292941,1.79436,-1.94692,0.073839,1.84101,-1.99449,0.010141,1.65762,-2.16248,0.029229,1.56148,-2.19991,0.202394,1.48465,-2.14964,0.251074,1.44025,-2.16168,0.188349,1.35556,-1.79902,-0.004894,1.42563,-1.85148,-0.00604,1.45897,-1.90392,-0.013098,1.43904,-1.96318,0.17644,1.40248,-2.06568,0.28757,1.10407,-1.73453,0.174861,1.0319,-1.76146,0.21897,0.961074,-1.78216,0.318438,0.902936,-1.7615,0.176103,0.83321,-1.74906,0.102728,0.815253,-1.75692,0.14814,0.940274,-1.77157,0.078276,0.922195,-1.7724,-0.127142,0.820543,-1.77447,-0.225569,0.883554,-1.85674,-0.12507,0.652846,-1.79517,-0.179412,0.668875,-1.72575,0.184246,1.0979,-2.12122,0.20821,1.01716,-2.10326,0.053254,1.06256,-2.06784,0.079346,0.984555,-2.05266,0.173144,0.858939,-2.05395,0.149653,0.667856,-2.02295,0.04675,0.710032,-2.04594,0.021036,0.646727,-2.02954,-0.038545,0.434373,-1.97236,-0.145586,0.366145,-1.91645,0.139331,0.375441,-1.94334,0.088734,0.340784,-2.00941,0.111642,1.27166,-1.82871,0.094895,1.30727,-2.04032},
/*1172*/{0.238156,1.85069,-1.70713,0.296634,1.79102,-1.8672,0.122149,1.72058,-1.61404,0.032685,1.62664,-1.55973,0.158459,1.55076,-1.63505,0.227878,1.50211,-1.66173,0.197515,1.86524,-2.106,0.293777,1.79607,-1.94534,0.074378,1.84173,-1.99503,0.01652,1.65633,-2.16322,0.037174,1.56135,-2.20037,0.213164,1.49093,-2.14724,0.262579,1.44878,-2.15819,0.18689,1.35759,-1.79651,-0.005274,1.42645,-1.85229,-0.005696,1.45924,-1.90468,-0.011885,1.43995,-1.96416,0.177745,1.40264,-2.06539,0.294133,1.11113,-1.73513,0.183384,1.03636,-1.75968,0.228096,0.966304,-1.78084,0.329035,0.910824,-1.76152,0.18771,0.835932,-1.74942,0.116608,0.815426,-1.75749,0.156249,0.941806,-1.77091,0.087067,0.920818,-1.77312,-0.116279,0.814934,-1.77484,-0.216001,0.869204,-1.85728,-0.102931,0.645195,-1.79435,-0.158084,0.65952,-1.72338,0.176921,1.09591,-2.12059,0.199354,1.01425,-2.10271,0.045175,1.06365,-2.06793,0.069148,0.985519,-2.05264,0.158855,0.855519,-2.05326,0.13157,0.666288,-2.02119,0.030176,0.710124,-2.04534,0.004473,0.646661,-2.02824,-0.062221,0.433949,-1.97313,-0.166899,0.36663,-1.91767,0.117352,0.375375,-1.9425,0.066665,0.340799,-2.00953,0.111151,1.27311,-1.82732,0.096543,1.30738,-2.03931},
/*1173*/{0.23555,1.85331,-1.70623,0.295749,1.79377,-1.86519,0.116835,1.7252,-1.61422,0.023915,1.63318,-1.56242,0.15047,1.5552,-1.63436,0.220639,1.50511,-1.66015,0.199229,1.86831,-2.10564,0.294082,1.79796,-1.94372,0.075477,1.84249,-1.99678,0.021041,1.65669,-2.16346,0.045145,1.56227,-2.201,0.221894,1.49722,-2.14445,0.273927,1.4583,-2.15461,0.186605,1.35974,-1.79549,-0.004649,1.42881,-1.85221,-0.004516,1.46097,-1.90572,-0.011354,1.44104,-1.96481,0.176927,1.40189,-2.06558,0.298334,1.11951,-1.73577,0.189649,1.03892,-1.75891,0.237298,0.97304,-1.78022,0.338845,0.918351,-1.76103,0.200693,0.838866,-1.74981,0.130189,0.814204,-1.75771,0.163844,0.943703,-1.77044,0.095571,0.919065,-1.77284,-0.100489,0.80246,-1.77598,-0.20539,0.854309,-1.85861,-0.078899,0.637736,-1.79197,-0.134748,0.650233,-1.72225,0.170352,1.09431,-2.11882,0.189827,1.012,-2.10138,0.036187,1.06656,-2.06824,0.058272,0.987207,-2.05272,0.141477,0.853811,-2.05167,0.114619,0.666176,-2.02081,0.012429,0.710825,-2.04417,-0.013659,0.64744,-2.02735,-0.082577,0.4362,-1.97288,-0.187883,0.368577,-1.91854,0.096236,0.375489,-1.94304,0.047014,0.341244,-2.00954,0.110688,1.27529,-1.82577,0.096046,1.30706,-2.03814},
/*1174*/{0.233292,1.85649,-1.7053,0.293619,1.79548,-1.8627,0.112482,1.73015,-1.61441,0.018047,1.63952,-1.56229,0.143653,1.55981,-1.63281,0.212449,1.50887,-1.65777,0.200973,1.87253,-2.10505,0.294336,1.80083,-1.94165,0.075955,1.84465,-1.99781,0.024935,1.65727,-2.1635,0.052222,1.56324,-2.20119,0.231008,1.50552,-2.14176,0.285219,1.46868,-2.15102,0.18656,1.36261,-1.79445,-0.004528,1.43013,-1.85309,-0.004033,1.46265,-1.90596,-0.010606,1.44266,-1.96595,0.178849,1.40236,-2.06528,0.30532,1.12679,-1.73406,0.195867,1.04406,-1.75859,0.246352,0.978129,-1.78051,0.348457,0.926725,-1.76193,0.212847,0.842363,-1.75007,0.142486,0.815105,-1.75855,0.171225,0.944754,-1.77109,0.103628,0.917798,-1.77347,-0.086225,0.793444,-1.77597,-0.194886,0.838268,-1.86068,-0.056439,0.630101,-1.79081,-0.113274,0.640242,-1.72072,0.163242,1.09347,-2.11756,0.179941,1.01007,-2.09902,0.027414,1.06903,-2.06841,0.047307,0.98929,-2.05207,0.125499,0.853729,-2.0514,0.096742,0.666914,-2.02015,-0.004321,0.712964,-2.04311,-0.032501,0.649682,-2.02711,-0.099296,0.438799,-1.9725,-0.207217,0.36882,-1.92014,0.075603,0.375172,-1.94347,0.025163,0.340924,-2.0093,0.111002,1.27756,-1.82474,0.097657,1.3079,-2.03741},
/*1175*/{0.231152,1.85962,-1.70456,0.293786,1.79985,-1.86195,0.107519,1.73568,-1.61444,0.010742,1.64681,-1.56407,0.136503,1.56625,-1.6324,0.205429,1.5132,-1.65563,0.202917,1.87638,-2.104,0.294522,1.80389,-1.94031,0.076616,1.84542,-1.99895,0.029703,1.65839,-2.16325,0.060035,1.565,-2.20132,0.239877,1.51468,-2.13931,0.295219,1.47957,-2.14756,0.18716,1.36587,-1.7935,-0.004151,1.43244,-1.85511,-0.002852,1.4645,-1.90737,-0.009669,1.44443,-1.96761,0.180957,1.40297,-2.06401,0.310078,1.13404,-1.73496,0.204538,1.05161,-1.75794,0.253881,0.98424,-1.77935,0.357172,0.935017,-1.76242,0.224281,0.844851,-1.7505,0.155481,0.814857,-1.75818,0.177575,0.945347,-1.77092,0.112335,0.915754,-1.77341,-0.070934,0.78328,-1.77601,-0.183048,0.822216,-1.86099,-0.033761,0.621922,-1.78898,-0.090674,0.630359,-1.71915,0.156386,1.09238,-2.11572,0.170349,1.00941,-2.09723,0.020926,1.0726,-2.06835,0.036771,0.992221,-2.05229,0.108638,0.854215,-2.05042,0.078611,0.668263,-2.02019,-0.022464,0.715964,-2.04135,-0.050944,0.653143,-2.02586,-0.120083,0.441086,-1.97291,-0.228192,0.374007,-1.91836,0.054341,0.374986,-1.94331,0.006344,0.340886,-2.0092,0.111435,1.28046,-1.82362,0.099905,1.30877,-2.03667},
/*1176*/{0.228006,1.86315,-1.70374,0.293202,1.80252,-1.85974,0.102584,1.74114,-1.61497,0.004084,1.65358,-1.56522,0.129471,1.57088,-1.63078,0.197036,1.51785,-1.65416,0.205029,1.88109,-2.10346,0.295431,1.80719,-1.93862,0.07809,1.84845,-2.00026,0.035688,1.66029,-2.16297,0.067685,1.56751,-2.20214,0.247367,1.52306,-2.13651,0.304822,1.49114,-2.14377,0.188103,1.36983,-1.79411,-0.003811,1.43462,-1.856,-0.001653,1.46714,-1.90839,-0.006638,1.44672,-1.96818,0.182229,1.40337,-2.06363,0.315004,1.14211,-1.73471,0.211159,1.05678,-1.75681,0.261083,0.990716,-1.77928,0.366593,0.943708,-1.76308,0.235458,0.848098,-1.75033,0.168416,0.813727,-1.75901,0.185057,0.945573,-1.77139,0.120633,0.912753,-1.77348,-0.056914,0.772765,-1.77688,-0.170558,0.805299,-1.86206,-0.011581,0.614124,-1.78835,-0.068595,0.619991,-1.7183,0.149159,1.09206,-2.11344,0.160572,1.00884,-2.09483,0.01228,1.07709,-2.06861,0.025122,0.996206,-2.05232,0.092334,0.856027,-2.04941,0.060141,0.669818,-2.01991,-0.04062,0.719878,-2.04042,-0.069327,0.657099,-2.02495,-0.14279,0.442375,-1.97264,-0.248153,0.375313,-1.91791,0.033599,0.374756,-1.94327,-0.016636,0.340939,-2.00966,0.112456,1.28364,-1.82269,0.101457,1.30989,-2.03603},
/*1177*/{0.224783,1.86717,-1.70348,0.292941,1.80614,-1.85834,0.098021,1.74685,-1.61503,-0.002387,1.66102,-1.56621,0.122666,1.57684,-1.63036,0.190701,1.52236,-1.65176,0.206619,1.8853,-2.10243,0.295739,1.81071,-1.93696,0.078988,1.84985,-2.00106,0.039916,1.66149,-2.16242,0.074941,1.5707,-2.20265,0.255176,1.53293,-2.1337,0.313262,1.50337,-2.13995,0.189469,1.37424,-1.7935,-0.001981,1.43743,-1.85709,-0.000587,1.46946,-1.91002,-0.00577,1.44957,-1.96982,0.182934,1.40394,-2.06331,0.317098,1.15034,-1.73559,0.21658,1.06163,-1.75681,0.268457,0.997783,-1.77918,0.374714,0.952435,-1.76298,0.246919,0.85054,-1.7505,0.180946,0.813296,-1.75812,0.19113,0.945703,-1.77217,0.129172,0.909576,-1.77389,-0.042254,0.762954,-1.77759,-0.156644,0.788468,-1.86322,0.011637,0.606732,-1.78666,-0.04627,0.609753,-1.7178,0.14274,1.09267,-2.11131,0.151159,1.00856,-2.09217,0.004585,1.08127,-2.06842,0.015105,1.00039,-2.05151,0.076237,0.858922,-2.04838,0.042275,0.673344,-2.01953,-0.058045,0.723219,-2.03948,-0.087171,0.660937,-2.02338,-0.164405,0.446765,-1.97286,-0.269788,0.381947,-1.91742,0.012734,0.375092,-1.94247,-0.037586,0.341698,-2.00929,0.113566,1.28755,-1.82144,0.102813,1.31092,-2.03513},
/*1178*/{0.222206,1.87106,-1.70272,0.293469,1.81069,-1.85653,0.092697,1.75235,-1.61559,-0.0097,1.66743,-1.56829,0.115746,1.58261,-1.6304,0.184083,1.52807,-1.6504,0.20853,1.88994,-2.10156,0.296111,1.81451,-1.93548,0.07988,1.85269,-2.00242,0.045039,1.66452,-2.1619,0.082668,1.57413,-2.20336,0.262148,1.54224,-2.13039,0.321862,1.51544,-2.13562,0.189845,1.37785,-1.79378,-0.001393,1.44073,-1.85934,0.001107,1.47227,-1.91095,-0.003568,1.45242,-1.97115,0.185202,1.40463,-2.06307,0.322832,1.1575,-1.73519,0.222067,1.06723,-1.75649,0.275022,1.00347,-1.77892,0.382099,0.961129,-1.76365,0.25767,0.85263,-1.75019,0.194516,0.812272,-1.75793,0.196946,0.945499,-1.77288,0.137198,0.905636,-1.77578,-0.027769,0.752441,-1.77887,-0.142811,0.770837,-1.86473,0.034762,0.598881,-1.78611,-0.024158,0.598947,-1.71691,0.135774,1.09306,-2.10969,0.141756,1.0089,-2.08993,-0.003104,1.08608,-2.06743,0.005683,1.00448,-2.05134,0.059748,0.861044,-2.04682,0.024735,0.675519,-2.0182,-0.075423,0.727316,-2.03863,-0.104996,0.664798,-2.02279,-0.17897,0.451758,-1.9727,-0.289263,0.388133,-1.91842,-0.008181,0.374819,-1.94221,-0.058791,0.341928,-2.00865,0.113836,1.29089,-1.82089,0.104505,1.31245,-2.03484},
/*1179*/{0.218882,1.87546,-1.70251,0.292355,1.81383,-1.85503,0.088117,1.75844,-1.61607,-0.016079,1.67528,-1.5698,0.109847,1.58919,-1.62987,0.176722,1.5333,-1.64851,0.210816,1.89467,-2.10025,0.296832,1.81835,-1.93313,0.081733,1.85616,-2.00387,0.049319,1.66736,-2.1619,0.089462,1.57744,-2.20409,0.269655,1.5536,-2.1273,0.330282,1.52805,-2.13154,0.191257,1.38251,-1.7943,-5e-005,1.44397,-1.85959,0.00292,1.47485,-1.91237,-0.000812,1.455,-1.97235,0.186994,1.40504,-2.06312,0.324592,1.16532,-1.73537,0.226173,1.07261,-1.75598,0.280917,1.0098,-1.77941,0.388434,0.969806,-1.76413,0.268227,0.855314,-1.74966,0.206371,0.811688,-1.75764,0.203644,0.944582,-1.77412,0.145627,0.903057,-1.77642,-0.011127,0.740675,-1.77766,-0.128358,0.753957,-1.86418,0.057862,0.591238,-1.78437,-0.001246,0.588608,-1.71628,0.129342,1.09429,-2.10668,0.132957,1.01001,-2.08692,-0.009306,1.09098,-2.06694,-0.004153,1.00965,-2.05041,0.045339,0.86492,-2.04526,0.007945,0.680216,-2.01786,-0.092338,0.731921,-2.03735,-0.122131,0.669074,-2.02238,-0.198144,0.456111,-1.97276,-0.307242,0.394472,-1.9181,-0.029426,0.375027,-1.94212,-0.07928,0.341726,-2.00797,0.115428,1.29488,-1.81969,0.106314,1.31357,-2.03392},
/*1180*/{0.215422,1.87951,-1.70194,0.292688,1.81856,-1.85324,0.083445,1.76471,-1.61623,-0.022578,1.68293,-1.57146,0.104124,1.59542,-1.62977,0.170293,1.53898,-1.6472,0.213288,1.89956,-2.09883,0.297173,1.82199,-1.9317,0.082662,1.85941,-2.00504,0.054775,1.66997,-2.16261,0.096948,1.58151,-2.20488,0.276234,1.56387,-2.12405,0.337199,1.54083,-2.12759,0.194067,1.38681,-1.79414,0.001978,1.44791,-1.86096,0.004715,1.47792,-1.91331,0.001259,1.458,-1.97287,0.189089,1.40533,-2.06277,0.32893,1.17216,-1.73508,0.231565,1.07852,-1.75602,0.286398,1.01635,-1.77883,0.394628,0.977358,-1.76444,0.277893,0.857379,-1.74896,0.218236,0.810569,-1.75654,0.209895,0.943487,-1.77468,0.15371,0.898896,-1.77566,0.004231,0.729816,-1.77865,-0.112837,0.737021,-1.86504,0.081266,0.583556,-1.7838,0.021603,0.578678,-1.7157,0.123148,1.09568,-2.10434,0.123555,1.01185,-2.0845,-0.015817,1.09698,-2.06642,-0.014027,1.01524,-2.05021,0.031279,0.868898,-2.04328,-0.009024,0.685162,-2.01758,-0.108742,0.737105,-2.03633,-0.139872,0.675832,-2.02194,-0.22402,0.460187,-1.97278,-0.325475,0.401819,-1.91868,-0.050359,0.376119,-1.94099,-0.102344,0.341878,-2.00848,0.117219,1.29914,-1.81821,0.108075,1.31479,-2.03268},
/*1181*/{0.213181,1.88394,-1.70166,0.291638,1.82244,-1.85093,0.079584,1.7709,-1.61694,-0.028092,1.68974,-1.57391,0.097648,1.60216,-1.6296,0.163981,1.54519,-1.64601,0.21546,1.90409,-2.09759,0.298115,1.82657,-1.9299,0.084245,1.86232,-2.00552,0.059698,1.67379,-2.16319,0.10341,1.5858,-2.20547,0.282396,1.57415,-2.12087,0.343623,1.55361,-2.12375,0.195428,1.39132,-1.79555,0.003273,1.45239,-1.86154,0.007365,1.48073,-1.915,0.004186,1.46144,-1.97381,0.19084,1.40584,-2.06262,0.331491,1.17876,-1.73535,0.237641,1.08452,-1.75451,0.291502,1.02317,-1.77857,0.400083,0.986391,-1.76477,0.288033,0.858182,-1.74909,0.229929,0.80945,-1.75659,0.216487,0.941719,-1.77516,0.161562,0.894398,-1.77765,0.020761,0.717792,-1.77768,-0.096239,0.719368,-1.86452,0.105263,0.577082,-1.78428,0.045444,0.568476,-1.71595,0.117582,1.09716,-2.10174,0.1147,1.01298,-2.08141,-0.022069,1.10357,-2.06641,-0.023758,1.0214,-2.04944,0.017722,0.873734,-2.04152,-0.026809,0.690246,-2.01689,-0.125681,0.742847,-2.03572,-0.156206,0.681789,-2.02169,-0.23891,0.466782,-1.97372,-0.344196,0.409731,-1.9201,-0.071581,0.375545,-1.94111,-0.122182,0.342425,-2.00745,0.11842,1.30342,-1.81733,0.109426,1.31634,-2.03199},
/*1182*/{0.21061,1.88826,-1.70151,0.29201,1.82666,-1.84952,0.075226,1.77716,-1.61773,-0.034402,1.69713,-1.57536,0.09206,1.60828,-1.62979,0.157772,1.5506,-1.64502,0.21825,1.90894,-2.09641,0.298809,1.83084,-1.92799,0.085786,1.8657,-2.00708,0.064565,1.67738,-2.16451,0.109993,1.59048,-2.20737,0.287821,1.58502,-2.11757,0.349556,1.56647,-2.11983,0.197829,1.39543,-1.79619,0.005228,1.45625,-1.86267,0.00859,1.48459,-1.91669,0.00706,1.46503,-1.97456,0.19314,1.40605,-2.06245,0.335055,1.18645,-1.73505,0.241577,1.09042,-1.75386,0.296183,1.02972,-1.7771,0.405448,0.993751,-1.76486,0.297463,0.859654,-1.74841,0.243643,0.809125,-1.75649,0.222309,0.939686,-1.7756,0.170496,0.889955,-1.77778,0.036547,0.705657,-1.77772,-0.078905,0.700758,-1.86436,0.128663,0.569727,-1.78359,0.070382,0.558343,-1.71483,0.112193,1.09854,-2.09919,0.10652,1.0156,-2.0785,-0.027382,1.10946,-2.06657,-0.031196,1.02781,-2.04884,0.00357,0.87995,-2.04053,-0.042246,0.696181,-2.01737,-0.140934,0.749609,-2.0358,-0.172706,0.689068,-2.02143,-0.252889,0.473217,-1.97324,-0.362215,0.419175,-1.91877,-0.092568,0.375516,-1.94064,-0.143887,0.342225,-2.00738,0.119705,1.30767,-1.81639,0.110926,1.31789,-2.03121},
/*1183*/{0.208154,1.89273,-1.7015,0.292073,1.83114,-1.8479,0.070965,1.78349,-1.61873,-0.039136,1.70457,-1.57712,0.08687,1.61491,-1.6299,0.15321,1.55681,-1.6443,0.221306,1.91419,-2.09535,0.299742,1.83482,-1.92643,0.0873,1.86897,-2.00806,0.070839,1.68179,-2.16596,0.11691,1.59512,-2.20789,0.291803,1.59475,-2.1146,0.354625,1.57916,-2.11619,0.199845,1.39988,-1.79734,0.007831,1.46088,-1.8627,0.011264,1.48863,-1.91729,0.010235,1.46835,-1.97535,0.195808,1.40593,-2.06222,0.337888,1.19345,-1.73584,0.244772,1.09655,-1.75411,0.300446,1.03582,-1.77779,0.410134,1.00107,-1.76558,0.307774,0.860017,-1.74816,0.254076,0.805764,-1.75605,0.228734,0.936285,-1.77657,0.179002,0.88507,-1.77867,0.053309,0.695074,-1.77718,-0.062008,0.683351,-1.86336,0.152708,0.562606,-1.78333,0.094364,0.54834,-1.71543,0.106653,1.10057,-2.09685,0.098499,1.01771,-2.0761,-0.03366,1.11614,-2.06541,-0.040145,1.03458,-2.04881,-0.010209,0.885854,-2.04083,-0.058039,0.701607,-2.01757,-0.156535,0.756925,-2.03565,-0.187824,0.694338,-2.0215,-0.272025,0.4807,-1.97742,-0.378249,0.429667,-1.91919,-0.113877,0.375793,-1.94009,-0.164562,0.342626,-2.00679,0.121352,1.31219,-1.81496,0.112331,1.31933,-2.02989},
/*1184*/{0.205409,1.89725,-1.70154,0.291787,1.83522,-1.84629,0.06738,1.78949,-1.6199,-0.044744,1.71172,-1.57925,0.082229,1.62209,-1.63036,0.147502,1.56281,-1.64405,0.224328,1.919,-2.09374,0.30048,1.83902,-1.92406,0.089819,1.87292,-2.00906,0.076253,1.68656,-2.16887,0.123531,1.60023,-2.20921,0.296198,1.60429,-2.11126,0.359268,1.59163,-2.11301,0.201955,1.40351,-1.79822,0.009108,1.46602,-1.86319,0.013537,1.49158,-1.91869,0.012689,1.47218,-1.97589,0.197652,1.40642,-2.06143,0.340553,1.19945,-1.73629,0.247578,1.10188,-1.75363,0.304603,1.04201,-1.777,0.413797,1.00807,-1.76581,0.316812,0.860409,-1.74773,0.26663,0.803999,-1.75588,0.234745,0.933147,-1.77666,0.186978,0.878571,-1.7797,0.070863,0.681845,-1.7766,-0.044009,0.666237,-1.86216,0.176648,0.555914,-1.78367,0.120631,0.538545,-1.71593,0.101682,1.10315,-2.09466,0.090896,1.02087,-2.07308,-0.03874,1.12248,-2.06534,-0.046691,1.0414,-2.0491,-0.024232,0.891946,-2.0411,-0.073331,0.708733,-2.01884,-0.171539,0.764641,-2.03552,-0.201876,0.702375,-2.02191,-0.287906,0.4873,-1.97928,-0.39486,0.440365,-1.9185,-0.135078,0.376583,-1.93954,-0.186523,0.343291,-2.00626,0.122229,1.31639,-1.8139,0.113288,1.32106,-2.02889},
/*1185*/{0.203935,1.90112,-1.70165,0.291259,1.84033,-1.84524,0.064022,1.79615,-1.62073,-0.048594,1.71939,-1.58192,0.076809,1.6284,-1.63046,0.14233,1.56892,-1.64323,0.22707,1.92384,-2.09243,0.301017,1.84331,-1.92268,0.091454,1.87697,-2.01019,0.081046,1.69121,-2.17092,0.130026,1.6049,-2.2108,0.300928,1.61548,-2.10967,0.363568,1.60341,-2.1103,0.203793,1.40791,-1.79846,0.012272,1.4714,-1.86411,0.016235,1.49579,-1.91969,0.015576,1.47645,-1.97665,0.198733,1.40649,-2.06105,0.342254,1.20619,-1.73656,0.251286,1.10792,-1.75276,0.307713,1.04795,-1.77647,0.416783,1.0134,-1.76594,0.32631,0.860415,-1.74795,0.278638,0.802105,-1.7553,0.24024,0.929814,-1.77717,0.195882,0.873249,-1.77794,0.089465,0.670544,-1.77615,-0.02586,0.648276,-1.86005,0.201806,0.550517,-1.78554,0.147316,0.528461,-1.71716,0.097134,1.10559,-2.09276,0.083408,1.0236,-2.07148,-0.043098,1.12991,-2.06534,-0.054444,1.05023,-2.04925,-0.036946,0.898099,-2.04146,-0.087665,0.71616,-2.02019,-0.18541,0.7734,-2.03516,-0.216104,0.709945,-2.02215,-0.302727,0.492793,-1.97809,-0.409592,0.452179,-1.91946,-0.156553,0.376998,-1.94036,-0.208034,0.343539,-2.00671,0.12312,1.32136,-1.81241,0.113778,1.32275,-2.02744},
/*1186*/{0.202211,1.90503,-1.70145,0.29259,1.84366,-1.84299,0.060144,1.80253,-1.62229,-0.053976,1.72682,-1.58342,0.071923,1.63512,-1.63161,0.13671,1.57489,-1.6427,0.228804,1.92782,-2.09117,0.301733,1.84672,-1.9208,0.093472,1.8802,-2.01144,0.087258,1.69532,-2.17287,0.136175,1.60992,-2.21244,0.303224,1.62411,-2.10699,0.367208,1.61446,-2.10772,0.205714,1.41165,-1.79964,0.013969,1.47646,-1.86356,0.019,1.50016,-1.9207,0.018736,1.48,-1.97633,0.200754,1.40705,-2.0607,0.344167,1.21171,-1.73681,0.254939,1.11341,-1.75164,0.309885,1.05371,-1.77616,0.420242,1.01893,-1.76638,0.334726,0.859881,-1.74825,0.289822,0.798945,-1.75602,0.24667,0.925083,-1.77609,0.20454,0.867848,-1.77862,0.107707,0.658403,-1.77483,-0.007378,0.630727,-1.85813,0.227091,0.545211,-1.788,0.174418,0.520008,-1.71788,0.092417,1.10826,-2.09108,0.075938,1.02727,-2.0697,-0.047641,1.13712,-2.06529,-0.061384,1.05723,-2.04903,-0.048854,0.905804,-2.04161,-0.100831,0.72325,-2.0215,-0.198618,0.781594,-2.03546,-0.231554,0.720982,-2.02228,-0.317188,0.499275,-1.97981,-0.423801,0.464853,-1.9193,-0.177392,0.377065,-1.94087,-0.229094,0.343225,-2.00633,0.124297,1.32571,-1.81124,0.114514,1.32482,-2.02625},
/*1187*/{0.200601,1.90902,-1.70149,0.291125,1.84747,-1.84152,0.057046,1.8088,-1.62357,-0.05802,1.7344,-1.5864,0.067218,1.64118,-1.63211,0.132783,1.58006,-1.6424,0.231563,1.93184,-2.08992,0.303641,1.85038,-1.91864,0.09541,1.8836,-2.01206,0.091304,1.70072,-2.17626,0.142384,1.61463,-2.21344,0.306101,1.63421,-2.10518,0.369874,1.62588,-2.10427,0.206832,1.41561,-1.80034,0.017087,1.48151,-1.8631,0.021748,1.50411,-1.92126,0.021577,1.48419,-1.97709,0.202486,1.40761,-2.06069,0.346257,1.21735,-1.73783,0.254205,1.11573,-1.75155,0.312269,1.05795,-1.77564,0.420822,1.02299,-1.76709,0.344673,0.859058,-1.74843,0.3021,0.796919,-1.75575,0.252985,0.920246,-1.77621,0.21221,0.859978,-1.77754,0.127685,0.645891,-1.77446,0.012036,0.613047,-1.85504,0.25277,0.540011,-1.79055,0.202499,0.510631,-1.71893,0.088418,1.11065,-2.09005,0.068404,1.03045,-2.06785,-0.050532,1.14413,-2.06527,-0.066901,1.06443,-2.0486,-0.060999,0.913062,-2.04219,-0.114191,0.73206,-2.02388,-0.21107,0.789853,-2.03549,-0.244557,0.728122,-2.0223,-0.336433,0.50396,-1.97984,-0.437173,0.478094,-1.91863,-0.198125,0.377084,-1.94087,-0.249207,0.344722,-2.00585,0.12526,1.3301,-1.8102,0.115101,1.327,-2.02517},
/*1188*/{0.199052,1.91274,-1.70148,0.292846,1.85136,-1.84013,0.054065,1.8148,-1.62515,-0.061654,1.74174,-1.58931,0.063896,1.64734,-1.63273,0.127922,1.58626,-1.64243,0.234046,1.93584,-2.08816,0.304469,1.85389,-1.91667,0.097315,1.88583,-2.01257,0.096293,1.70619,-2.17979,0.147964,1.61899,-2.21515,0.309715,1.6439,-2.10306,0.372436,1.63654,-2.10178,0.208758,1.41976,-1.80087,0.01904,1.4866,-1.86291,0.024248,1.50838,-1.92222,0.024193,1.48791,-1.97691,0.204972,1.40854,-2.06022,0.348301,1.22199,-1.73788,0.255577,1.12067,-1.75088,0.313583,1.0633,-1.77539,0.421146,1.02684,-1.76724,0.353192,0.857719,-1.74864,0.314562,0.793102,-1.75607,0.258944,0.914333,-1.77535,0.222032,0.852418,-1.77621,0.147325,0.63418,-1.77438,0.031343,0.595594,-1.85181,0.277634,0.53476,-1.79267,0.231188,0.503632,-1.72226,0.083887,1.11318,-2.0885,0.062242,1.03306,-2.06675,-0.053069,1.15175,-2.06531,-0.072998,1.07268,-2.04803,-0.070148,0.920674,-2.04256,-0.127596,0.739764,-2.02482,-0.223368,0.797654,-2.03579,-0.255374,0.735287,-2.02165,-0.342218,0.513874,-1.98264,-0.447853,0.49328,-1.91861,-0.21894,0.377466,-1.94213,-0.27245,0.345255,-2.00655,0.126581,1.33478,-1.8089,0.116286,1.32933,-2.02382},
/*1189*/{0.198195,1.91618,-1.70154,0.291965,1.85556,-1.83941,0.051613,1.8205,-1.62668,-0.065011,1.74875,-1.59204,0.060103,1.65334,-1.63446,0.124332,1.59149,-1.64216,0.235908,1.93921,-2.08686,0.305208,1.85715,-1.91521,0.099272,1.88841,-2.0133,0.101726,1.70953,-2.18215,0.153679,1.62368,-2.21718,0.310958,1.65119,-2.10169,0.375066,1.64675,-2.09981,0.210954,1.42262,-1.80102,0.022257,1.49112,-1.86256,0.026337,1.51304,-1.92311,0.026669,1.49089,-1.97633,0.206866,1.40907,-2.05959,0.350062,1.22569,-1.73848,0.256923,1.12424,-1.75009,0.313544,1.06749,-1.7747,0.420896,1.0296,-1.768,0.362645,0.856606,-1.74885,0.325991,0.789633,-1.75661,0.264186,0.908104,-1.77424,0.229632,0.845207,-1.77507,0.167455,0.622176,-1.77451,0.05255,0.57858,-1.84957,0.302191,0.531009,-1.79648,0.259664,0.495984,-1.72442,0.080288,1.11596,-2.08836,0.056922,1.03597,-2.06592,-0.055675,1.15797,-2.06441,-0.078226,1.08044,-2.04831,-0.079455,0.928535,-2.04309,-0.135762,0.748252,-2.02734,-0.233796,0.805696,-2.03588,-0.265518,0.743331,-2.0217,-0.352991,0.52065,-1.98505,-0.457493,0.508324,-1.91825,-0.239327,0.378277,-1.94376,-0.293803,0.346994,-2.00624,0.12783,1.33873,-1.8076,0.116953,1.33125,-2.02243},
/*1190*/{0.197294,1.9193,-1.70113,0.293179,1.8592,-1.83772,0.048831,1.82548,-1.62868,-0.069272,1.75547,-1.59531,0.055705,1.6586,-1.63517,0.119454,1.59686,-1.64153,0.238878,1.94253,-2.08573,0.305832,1.86041,-1.91382,0.10089,1.89119,-2.01341,0.106904,1.71301,-2.18502,0.159268,1.62748,-2.21876,0.312796,1.65848,-2.10052,0.377066,1.65501,-2.09503,0.212396,1.4265,-1.80124,0.024527,1.49687,-1.8612,0.028653,1.51705,-1.92352,0.029824,1.49513,-1.97632,0.207968,1.41005,-2.05892,0.351407,1.22923,-1.73963,0.257123,1.12903,-1.74791,0.311859,1.0709,-1.77435,0.419422,1.03207,-1.76834,0.370409,0.854341,-1.75049,0.338249,0.786492,-1.75691,0.269634,0.901634,-1.77324,0.239188,0.836927,-1.77326,0.187338,0.610455,-1.77345,0.073794,0.561252,-1.84722,0.326293,0.527436,-1.8001,0.286861,0.48862,-1.72759,0.076238,1.1187,-2.08823,0.05037,1.04142,-2.06657,-0.058955,1.1643,-2.06423,-0.081876,1.08678,-2.04775,-0.08846,0.935612,-2.04338,-0.145103,0.75595,-2.0295,-0.242941,0.813434,-2.036,-0.27488,0.751243,-2.02281,-0.368026,0.525451,-1.98652,-0.466312,0.523119,-1.91827,-0.256886,0.378197,-1.94507,-0.313685,0.349966,-2.00576,0.128655,1.34339,-1.80606,0.117178,1.3338,-2.02077},
/*1191*/{0.196688,1.92224,-1.70136,0.29263,1.86083,-1.83606,0.046805,1.83119,-1.63035,-0.071983,1.7619,-1.59823,0.052252,1.6636,-1.63617,0.116092,1.60154,-1.64232,0.240794,1.9455,-2.08487,0.306996,1.8638,-1.91217,0.103835,1.89356,-2.01423,0.113021,1.71646,-2.18697,0.163714,1.63102,-2.22043,0.314155,1.66554,-2.09927,0.378823,1.66289,-2.09315,0.212223,1.4304,-1.80173,0.026441,1.50039,-1.8614,0.030661,1.52072,-1.92409,0.032381,1.49855,-1.97625,0.208486,1.41111,-2.05835,0.3534,1.23186,-1.73978,0.255073,1.13237,-1.74734,0.311097,1.07398,-1.77467,0.418393,1.03352,-1.76829,0.378,0.852172,-1.75089,0.348469,0.782857,-1.75777,0.275205,0.894574,-1.77114,0.244394,0.827965,-1.77511,0.207397,0.59891,-1.77402,0.095223,0.545144,-1.84542,0.350767,0.523527,-1.8029,0.315057,0.48272,-1.72932,0.072748,1.12089,-2.08814,0.045131,1.04437,-2.06754,-0.061042,1.16975,-2.06346,-0.086333,1.09254,-2.04708,-0.096334,0.942786,-2.04388,-0.153174,0.763486,-2.0312,-0.252433,0.819914,-2.03665,-0.283587,0.758521,-2.02372,-0.370291,0.536068,-1.98889,-0.47355,0.538502,-1.91987,-0.274603,0.378088,-1.94634,-0.336162,0.353045,-2.00625,0.128913,1.34726,-1.80513,0.117461,1.33598,-2.01976},
/*1192*/{0.196967,1.92501,-1.70134,0.293897,1.86416,-1.83426,0.045572,1.83667,-1.63193,-0.075909,1.76818,-1.60174,0.048775,1.66867,-1.63669,0.113125,1.60615,-1.64191,0.2427,1.94804,-2.08406,0.308447,1.86626,-1.91037,0.105689,1.89513,-2.015,0.116838,1.71941,-2.18908,0.168063,1.63412,-2.22227,0.316122,1.6713,-2.097,0.380153,1.67019,-2.09107,0.213109,1.43313,-1.80192,0.028651,1.50411,-1.86102,0.031987,1.52358,-1.92458,0.033774,1.50106,-1.97605,0.210961,1.41202,-2.05747,0.353346,1.23461,-1.7406,0.253377,1.13638,-1.7467,0.309328,1.07639,-1.77271,0.416106,1.03376,-1.76961,0.385617,0.849847,-1.75023,0.357615,0.778032,-1.75832,0.280216,0.887283,-1.76922,0.256054,0.819836,-1.77103,0.227209,0.589038,-1.77403,0.117272,0.529505,-1.84492,0.373333,0.520636,-1.8053,0.340692,0.475948,-1.73408,0.069799,1.12448,-2.08881,0.039947,1.04774,-2.06854,-0.063421,1.17484,-2.06332,-0.089522,1.09851,-2.0462,-0.102166,0.948893,-2.04449,-0.160423,0.769896,-2.03245,-0.258732,0.826976,-2.03688,-0.29063,0.766254,-2.0259,-0.37922,0.544236,-1.99073,-0.480413,0.553285,-1.91969,-0.29124,0.378679,-1.94726,-0.35694,0.357837,-2.00538,0.129791,1.35048,-1.80409,0.118594,1.33782,-2.01866},
/*1193*/{0.196461,1.92743,-1.70146,0.294474,1.86782,-1.83384,0.043354,1.84072,-1.63361,-0.077556,1.77394,-1.60485,0.046015,1.67336,-1.63779,0.109774,1.61053,-1.64163,0.245118,1.94991,-2.08247,0.309043,1.86872,-1.90945,0.107167,1.89755,-2.01553,0.122117,1.72263,-2.19169,0.171977,1.63739,-2.22412,0.318673,1.67774,-2.09706,0.381301,1.67723,-2.08997,0.213914,1.43614,-1.80174,0.030823,1.50831,-1.86005,0.034606,1.52732,-1.92477,0.036014,1.50502,-1.97601,0.211593,1.41317,-2.05658,0.353555,1.23479,-1.74136,0.253423,1.13926,-1.74716,0.307866,1.07774,-1.77177,0.413955,1.0338,-1.77066,0.392136,0.846968,-1.75029,0.364274,0.77318,-1.75929,0.285145,0.879434,-1.768,0.263354,0.810656,-1.77041,0.247281,0.577269,-1.7742,0.139283,0.514653,-1.84489,0.396617,0.51764,-1.80818,0.366651,0.469438,-1.73837,0.066424,1.12726,-2.08896,0.036381,1.05109,-2.06935,-0.065051,1.17966,-2.06126,-0.091638,1.10273,-2.04584,-0.106873,0.954413,-2.04471,-0.166868,0.775883,-2.03364,-0.264856,0.833848,-2.03755,-0.296716,0.772796,-2.02674,-0.386579,0.55272,-1.99247,-0.487777,0.570131,-1.92125,-0.308813,0.377485,-1.94829,-0.37663,0.364103,-2.00537,0.130097,1.35413,-1.80297,0.118617,1.34029,-2.01746},
/*1194*/{0.196364,1.9297,-1.70171,0.295609,1.86874,-1.83266,0.042337,1.84513,-1.63594,-0.081616,1.77777,-1.60757,0.044277,1.6784,-1.63873,0.107006,1.61435,-1.64097,0.2479,1.95276,-2.08207,0.310837,1.87112,-1.90816,0.109824,1.89879,-2.0156,0.126177,1.7257,-2.19329,0.176124,1.64013,-2.22587,0.319758,1.68348,-2.09782,0.382735,1.68291,-2.08866,0.214718,1.43919,-1.80177,0.032585,1.51248,-1.85876,0.035551,1.53049,-1.92465,0.037202,1.50775,-1.97479,0.212378,1.4152,-2.05592,0.352985,1.23589,-1.74257,0.251944,1.14053,-1.74725,0.305174,1.07867,-1.77213,0.411592,1.0331,-1.76987,0.398925,0.844387,-1.75054,0.38047,0.772988,-1.7591,0.290083,0.87217,-1.76689,0.271402,0.802892,-1.76909,0.266699,0.567347,-1.77493,0.161568,0.500751,-1.84587,0.418069,0.515028,-1.81112,0.391146,0.464123,-1.74063,0.064383,1.13072,-2.0898,0.033848,1.05394,-2.07044,-0.066584,1.18339,-2.06027,-0.093619,1.10696,-2.04446,-0.109422,0.958499,-2.04431,-0.172121,0.780425,-2.03434,-0.267793,0.842588,-2.03873,-0.302256,0.780174,-2.02806,-0.394943,0.561578,-1.99431,-0.493011,0.586529,-1.92301,-0.326362,0.377633,-1.94993,-0.396878,0.370684,-2.00424,0.131039,1.35763,-1.80181,0.118852,1.34282,-2.01619},
/*1195*/{0.196442,1.93164,-1.70167,0.296315,1.87026,-1.83191,0.041263,1.84953,-1.63738,-0.082394,1.78308,-1.6104,0.041636,1.68221,-1.64006,0.104149,1.6182,-1.64108,0.249183,1.95424,-2.08133,0.311433,1.873,-1.90734,0.111953,1.90061,-2.01542,0.13053,1.72789,-2.19529,0.179579,1.64244,-2.22779,0.320346,1.687,-2.0977,0.3832,1.68707,-2.08654,0.216404,1.4416,-1.80204,0.033335,1.51498,-1.85907,0.036348,1.53361,-1.92402,0.038913,1.51061,-1.97414,0.213112,1.41693,-2.05574,0.353226,1.23626,-1.74291,0.251933,1.14399,-1.74757,0.302705,1.08008,-1.77043,0.408607,1.03201,-1.76938,0.40503,0.841674,-1.75109,0.390538,0.767779,-1.75973,0.294375,0.863575,-1.76559,0.281232,0.792774,-1.7675,0.284944,0.558622,-1.7758,0.183319,0.487499,-1.84648,0.439085,0.512616,-1.81373,0.415396,0.4587,-1.74405,0.064065,1.13395,-2.09079,0.031716,1.05727,-2.07152,-0.066876,1.18621,-2.05891,-0.094319,1.11065,-2.04429,-0.110549,0.961566,-2.04394,-0.177371,0.784701,-2.03483,-0.271588,0.847203,-2.03925,-0.307639,0.785907,-2.02859,-0.406393,0.570914,-1.99691,-0.498639,0.601659,-1.92592,-0.34481,0.37771,-1.9494,-0.417371,0.378806,-2.00343,0.132098,1.36027,-1.80151,0.119404,1.34518,-2.01584},
/*1196*/{0.19746,1.93341,-1.70156,0.298488,1.87204,-1.83054,0.040827,1.85298,-1.63934,-0.086286,1.78762,-1.61405,0.039155,1.68552,-1.64091,0.10245,1.62092,-1.64076,0.251625,1.95621,-2.08007,0.313087,1.87456,-1.90625,0.113681,1.9022,-2.01569,0.134451,1.72947,-2.19688,0.182781,1.64458,-2.22917,0.321261,1.69002,-2.09738,0.383685,1.69073,-2.0845,0.216224,1.44368,-1.8019,0.034588,1.51785,-1.85709,0.037742,1.53656,-1.92341,0.039313,1.51386,-1.97371,0.213759,1.41866,-2.05496,0.349389,1.23544,-1.74418,0.248161,1.14436,-1.7471,0.298573,1.07953,-1.76967,0.405852,1.02953,-1.76884,0.410455,0.838264,-1.75154,0.397496,0.764234,-1.76068,0.299307,0.854704,-1.76449,0.288356,0.783113,-1.76707,0.30346,0.548738,-1.77731,0.204732,0.474876,-1.84805,0.45999,0.509835,-1.81517,0.438719,0.455081,-1.74664,0.062857,1.13671,-2.09109,0.031638,1.06003,-2.07335,-0.066577,1.18927,-2.05743,-0.094713,1.11235,-2.04214,-0.109609,0.963779,-2.04359,-0.180732,0.787621,-2.03472,-0.273573,0.8522,-2.0402,-0.310174,0.792486,-2.03011,-0.415911,0.579807,-1.99774,-0.50331,0.617971,-1.92743,-0.36431,0.376055,-1.94872,-0.435911,0.387904,-2.00243,0.132007,1.36262,-1.80079,0.119139,1.34772,-2.01512},
/*1197*/{0.198075,1.93529,-1.70145,0.299116,1.87338,-1.83017,0.039942,1.85625,-1.64089,-0.08673,1.7914,-1.61663,0.03794,1.68925,-1.64189,0.100973,1.62346,-1.64062,0.25429,1.95788,-2.07932,0.314349,1.87632,-1.90539,0.115811,1.90381,-2.01573,0.138298,1.7316,-2.19745,0.185354,1.64597,-2.23058,0.321775,1.69201,-2.09686,0.383579,1.69403,-2.08208,0.216701,1.44653,-1.80215,0.034737,1.5208,-1.85797,0.037539,1.53949,-1.92316,0.041206,1.51608,-1.97267,0.214925,1.42062,-2.05446,0.347177,1.23309,-1.7439,0.246315,1.14462,-1.7468,0.295301,1.07859,-1.76854,0.40257,1.02684,-1.76817,0.415502,0.835373,-1.75118,0.406865,0.7599,-1.76127,0.303314,0.845474,-1.76328,0.295249,0.773331,-1.76614,0.321877,0.541015,-1.77857,0.224941,0.46301,-1.84982,0.478548,0.50805,-1.81753,0.461005,0.453081,-1.74931,0.063249,1.13942,-2.09137,0.0325,1.06224,-2.07392,-0.066559,1.19056,-2.05682,-0.094163,1.11393,-2.04191,-0.108362,0.965131,-2.04265,-0.184074,0.79028,-2.03451,-0.274422,0.857304,-2.04043,-0.313502,0.79861,-2.03323,-0.423753,0.589142,-1.99921,-0.507867,0.63352,-1.93183,-0.384059,0.378704,-1.94828,-0.454257,0.397726,-2,0.132496,1.36554,-1.80027,0.119969,1.35004,-2.01458},
/*1198*/{0.198468,1.93668,-1.70127,0.292796,1.87806,-1.83127,0.039756,1.85918,-1.64238,-0.088362,1.79512,-1.61942,0.036508,1.69157,-1.64297,0.098629,1.62637,-1.64034,0.255476,1.95901,-2.07881,0.315144,1.87834,-1.90492,0.117208,1.90492,-2.01586,0.141402,1.73317,-2.19868,0.187763,1.64743,-2.23174,0.323416,1.69561,-2.09755,0.384942,1.69592,-2.08161,0.217446,1.44802,-1.80235,0.036035,1.52266,-1.85662,0.039266,1.54126,-1.92293,0.041254,1.51838,-1.97291,0.215136,1.42283,-2.05389,0.344756,1.23187,-1.7448,0.243359,1.14367,-1.74637,0.291105,1.07696,-1.76775,0.398999,1.02324,-1.76719,0.418614,0.831173,-1.75177,0.41532,0.757575,-1.76257,0.306347,0.836505,-1.76268,0.302449,0.76452,-1.7663,0.337499,0.533062,-1.78018,0.245174,0.451975,-1.85126,0.496971,0.507822,-1.8206,0.481398,0.450068,-1.75292,0.064714,1.14087,-2.09201,0.034115,1.06396,-2.07411,-0.064924,1.19178,-2.0556,-0.092049,1.11522,-2.04107,-0.105744,0.966234,-2.04205,-0.185945,0.792099,-2.03399,-0.27354,0.86287,-2.04175,-0.31549,0.803713,-2.03206,-0.428996,0.597949,-2.0018,-0.512115,0.648588,-1.93393,-0.404545,0.388608,-1.9444,-0.475114,0.40808,-1.99828,0.133245,1.36715,-1.80025,0.120278,1.35215,-2.01457},
/*1199*/{0.199883,1.93811,-1.70096,0.301105,1.87676,-1.82846,0.039888,1.86163,-1.64428,-0.089292,1.79773,-1.62253,0.035753,1.69403,-1.64332,0.098277,1.62809,-1.64004,0.257259,1.95999,-2.07842,0.316224,1.87885,-1.9038,0.118976,1.90645,-2.01567,0.143454,1.73509,-2.19945,0.189934,1.64856,-2.23265,0.323957,1.69516,-2.09697,0.386561,1.69722,-2.08164,0.217719,1.44982,-1.80218,0.035705,1.5245,-1.85664,0.039161,1.54396,-1.9226,0.042342,1.51993,-1.97159,0.216252,1.42499,-2.05321,0.342818,1.22917,-1.74502,0.239588,1.1421,-1.74535,0.284414,1.07502,-1.76788,0.395509,1.01885,-1.76596,0.422094,0.827324,-1.75248,0.418344,0.751888,-1.76424,0.309321,0.827469,-1.76097,0.30852,0.755168,-1.76535,0.354773,0.526967,-1.78188,0.264096,0.44197,-1.8529,0.514475,0.508071,-1.82441,0.501003,0.448443,-1.75539,0.066314,1.14271,-2.09152,0.03628,1.06492,-2.07469,-0.0638,1.19289,-2.05519,-0.089835,1.11527,-2.04012,-0.10243,0.965867,-2.04136,-0.187199,0.793582,-2.03388,-0.273541,0.866822,-2.04304,-0.316446,0.810104,-2.03447,-0.433827,0.607217,-2.00273,-0.517627,0.664502,-1.93745,-0.425313,0.400021,-1.94213,-0.492019,0.42101,-1.99677,0.133499,1.36901,-1.79987,0.121061,1.3543,-2.01425},
/*1200*/{0.201048,1.93871,-1.70115,0.301306,1.87731,-1.82832,0.03978,1.86348,-1.6454,-0.090178,1.80012,-1.62553,0.034242,1.69636,-1.64454,0.097179,1.6297,-1.63944,0.259257,1.96063,-2.07752,0.318168,1.87868,-1.90271,0.1202,1.90861,-2.0156,0.145235,1.73614,-2.19927,0.191615,1.64899,-2.23356,0.325701,1.69514,-2.0968,0.387209,1.69706,-2.08079,0.217396,1.45224,-1.80199,0.035774,1.52595,-1.85629,0.039904,1.54502,-1.92153,0.043426,1.52167,-1.97063,0.217778,1.42714,-2.05285,0.340188,1.22496,-1.74445,0.236466,1.14056,-1.74473,0.280496,1.07208,-1.76665,0.391758,1.01451,-1.76575,0.425251,0.823104,-1.753,0.426319,0.747732,-1.76423,0.312319,0.818529,-1.75995,0.313772,0.747898,-1.7663,0.369245,0.519246,-1.78381,0.282378,0.43265,-1.85493,0.529206,0.507632,-1.82624,0.519013,0.447444,-1.75798,0.068776,1.14323,-2.09115,0.039672,1.06532,-2.07385,-0.061605,1.1925,-2.05383,-0.087696,1.11515,-2.03959,-0.098627,0.965363,-2.04083,-0.188588,0.794206,-2.03325,-0.272007,0.870508,-2.04363,-0.316015,0.815343,-2.03469,-0.443591,0.618322,-2.00398,-0.523554,0.679463,-1.94091,-0.442693,0.409723,-1.93877,-0.506833,0.434345,-1.99475,0.134277,1.37064,-1.79945,0.122466,1.35628,-2.01388},
/*1201*/{0.202787,1.94008,-1.70022,0.302097,1.87724,-1.828,0.04095,1.86488,-1.6465,-0.090671,1.80198,-1.6278,0.034328,1.69793,-1.64525,0.096084,1.63029,-1.63901,0.26153,1.96068,-2.07711,0.31862,1.87903,-1.90253,0.121981,1.9102,-2.01553,0.147005,1.73717,-2.19894,0.19233,1.64933,-2.23376,0.326117,1.69505,-2.09554,0.388668,1.69657,-2.08105,0.217929,1.45338,-1.80248,0.035914,1.52627,-1.85654,0.039542,1.54698,-1.92202,0.042937,1.52338,-1.97063,0.218204,1.42909,-2.05222,0.336192,1.22053,-1.74491,0.231092,1.13828,-1.74424,0.274058,1.06877,-1.76705,0.387632,1.00898,-1.76467,0.427712,0.818836,-1.75371,0.429315,0.743741,-1.7653,0.314222,0.810551,-1.75915,0.319667,0.738564,-1.76579,0.385181,0.514335,-1.78504,0.299272,0.424026,-1.85735,0.543436,0.508357,-1.82776,0.536474,0.448189,-1.76062,0.072752,1.14362,-2.09094,0.044313,1.06428,-2.07358,-0.058461,1.19175,-2.05359,-0.083509,1.11335,-2.03825,-0.094491,0.963934,-2.04069,-0.189254,0.794604,-2.0321,-0.268997,0.874503,-2.04448,-0.316618,0.820704,-2.0359,-0.450371,0.629299,-2.00487,-0.529009,0.694712,-1.94405,-0.459088,0.423409,-1.9361,-0.523056,0.447836,-1.99387,0.134505,1.37175,-1.79992,0.122907,1.358,-2.0144},
/*1202*/{0.203951,1.94041,-1.70038,0.303123,1.87714,-1.8273,0.041629,1.86525,-1.64821,-0.090534,1.8039,-1.63051,0.034075,1.69877,-1.64591,0.096119,1.63111,-1.63823,0.263678,1.96109,-2.07713,0.31915,1.87918,-1.90162,0.123015,1.91059,-2.01526,0.147875,1.73808,-2.19868,0.192825,1.64924,-2.23386,0.326974,1.69509,-2.09533,0.390419,1.69572,-2.08253,0.217979,1.45502,-1.8019,0.035901,1.52649,-1.85614,0.038993,1.54843,-1.92175,0.043132,1.52383,-1.96999,0.218877,1.43073,-2.05204,0.332883,1.21602,-1.74469,0.226886,1.1344,-1.74336,0.268385,1.06488,-1.76711,0.382618,1.00325,-1.76438,0.428055,0.814924,-1.75388,0.434739,0.7398,-1.76565,0.316332,0.802384,-1.75925,0.32277,0.732178,-1.76706,0.398444,0.50882,-1.78679,0.315328,0.416069,-1.85995,0.556404,0.508884,-1.83017,0.551393,0.446702,-1.76263,0.076238,1.14315,-2.08979,0.048304,1.06418,-2.0729,-0.055436,1.18959,-2.05266,-0.079453,1.11199,-2.03797,-0.08908,0.962144,-2.04001,-0.189416,0.795349,-2.03158,-0.266384,0.877876,-2.04512,-0.315754,0.826077,-2.03663,-0.45584,0.640659,-2.00519,-0.534808,0.710011,-1.94805,-0.474697,0.435449,-1.93312,-0.536526,0.462257,-1.99212,0.135127,1.37288,-1.79957,0.123818,1.35921,-2.01407},
/*1203*/{0.205331,1.94062,-1.69989,0.303311,1.87712,-1.82727,0.041971,1.8668,-1.64948,-0.089939,1.80406,-1.63207,0.034807,1.69878,-1.6467,0.096238,1.6307,-1.63774,0.265496,1.96065,-2.07663,0.319771,1.879,-1.90101,0.123622,1.91266,-2.016,0.148087,1.73889,-2.19799,0.192762,1.6489,-2.23359,0.327695,1.6921,-2.09477,0.390443,1.69268,-2.08184,0.218148,1.45514,-1.80183,0.036408,1.52676,-1.85543,0.039409,1.54868,-1.92121,0.043058,1.52469,-1.96903,0.219534,1.43178,-2.05178,0.32853,1.2116,-1.74483,0.221774,1.13158,-1.74273,0.260757,1.06235,-1.76828,0.376811,0.997491,-1.76386,0.429463,0.811735,-1.75479,0.437523,0.737468,-1.76668,0.317358,0.794995,-1.75985,0.327119,0.724774,-1.76621,0.410109,0.503938,-1.78889,0.329549,0.410075,-1.86253,0.567988,0.510308,-1.83148,0.565174,0.446444,-1.76527,0.080472,1.14175,-2.08848,0.053787,1.06255,-2.07179,-0.051314,1.18746,-2.05262,-0.075136,1.10939,-2.03788,-0.084127,0.960132,-2.03992,-0.189344,0.795755,-2.03075,-0.262944,0.881325,-2.0458,-0.314683,0.831532,-2.03748,-0.462424,0.65198,-2.00542,-0.539674,0.725427,-1.95028,-0.486353,0.449738,-1.9303,-0.548239,0.477677,-1.99248,0.135559,1.37289,-1.79958,0.124214,1.36012,-2.01414},
/*1204*/{0.206906,1.94069,-1.69966,0.304741,1.87699,-1.82692,0.043225,1.86691,-1.65003,-0.089174,1.80441,-1.63431,0.034817,1.69856,-1.64678,0.096689,1.63001,-1.63673,0.265959,1.95969,-2.07547,0.32027,1.87895,-1.90087,0.124663,1.91383,-2.01577,0.147161,1.73904,-2.19696,0.192337,1.64882,-2.23311,0.32949,1.69023,-2.09317,0.391458,1.68853,-2.08164,0.217848,1.45673,-1.80186,0.036166,1.52658,-1.85504,0.03978,1.54851,-1.92067,0.043556,1.52492,-1.96859,0.220287,1.43316,-2.05129,0.325186,1.20536,-1.74455,0.211976,1.12618,-1.74391,0.256768,1.05719,-1.76739,0.369665,0.991917,-1.76304,0.429215,0.808149,-1.75546,0.440826,0.733968,-1.76686,0.317314,0.788489,-1.75955,0.330527,0.717532,-1.7665,0.419539,0.499745,-1.79005,0.341456,0.404067,-1.86437,0.577935,0.511165,-1.83197,0.575734,0.445794,-1.76699,0.085335,1.1404,-2.08713,0.059685,1.06109,-2.06991,-0.047696,1.1844,-2.05196,-0.069821,1.10575,-2.03719,-0.078068,0.957481,-2.03924,-0.188948,0.796439,-2.02997,-0.2591,0.884813,-2.0469,-0.313019,0.838469,-2.03853,-0.46908,0.664984,-2.00585,-0.544828,0.741484,-1.95436,-0.499671,0.46436,-1.92948,-0.558257,0.492347,-1.99143,0.136444,1.37353,-1.79929,0.125518,1.36087,-2.01388},
/*1205*/{0.208243,1.94012,-1.6993,0.305067,1.87496,-1.82654,0.044037,1.86662,-1.65085,-0.088589,1.80307,-1.63596,0.035678,1.69803,-1.64715,0.096921,1.62866,-1.63572,0.267333,1.95852,-2.07483,0.32079,1.87841,-1.90072,0.125382,1.91423,-2.01558,0.146456,1.73865,-2.19594,0.1912,1.6482,-2.23217,0.328804,1.68664,-2.09316,0.391515,1.68395,-2.08051,0.218656,1.45742,-1.80196,0.036023,1.52566,-1.8548,0.039603,1.54819,-1.92012,0.043546,1.52433,-1.96883,0.22048,1.43364,-2.05121,0.322416,1.19977,-1.74366,0.210466,1.12487,-1.74318,0.249574,1.05301,-1.76732,0.362437,0.986,-1.76316,0.428359,0.805579,-1.75568,0.441545,0.731175,-1.76764,0.317356,0.782054,-1.761,0.332202,0.711937,-1.76807,0.426658,0.495861,-1.79083,0.352086,0.399129,-1.86665,0.586584,0.509615,-1.83268,0.585365,0.446391,-1.77015,0.09047,1.13859,-2.08528,0.065281,1.05949,-2.06848,-0.043743,1.18064,-2.05164,-0.064807,1.10134,-2.03644,-0.071628,0.954422,-2.03847,-0.188703,0.798187,-2.02867,-0.254288,0.888668,-2.04767,-0.30884,0.84467,-2.03815,-0.473505,0.678233,-2.00565,-0.547742,0.757519,-1.9556,-0.510076,0.478607,-1.92689,-0.568011,0.507953,-1.99104,0.137632,1.37361,-1.79918,0.126401,1.3608,-2.01374},
/*1206*/{0.209876,1.93934,-1.69864,0.305066,1.87391,-1.82681,0.045157,1.86491,-1.6509,-0.087582,1.80217,-1.63747,0.035986,1.69665,-1.64711,0.09789,1.62709,-1.63475,0.267248,1.95667,-2.07441,0.320917,1.87757,-1.90072,0.125652,1.9144,-2.01555,0.145135,1.73869,-2.19464,0.189603,1.64727,-2.23073,0.330883,1.68415,-2.09384,0.390826,1.67902,-2.08006,0.218688,1.45786,-1.80178,0.036703,1.52399,-1.85407,0.039788,1.54666,-1.91981,0.044145,1.52301,-1.96862,0.221722,1.43388,-2.05097,0.319078,1.19484,-1.74316,0.202653,1.11837,-1.74413,0.243431,1.04883,-1.76766,0.355773,0.979763,-1.76225,0.425708,0.802361,-1.75591,0.440041,0.728667,-1.76823,0.315992,0.776106,-1.76269,0.332858,0.706865,-1.77054,0.431752,0.491992,-1.79224,0.361476,0.394911,-1.86933,0.593184,0.51041,-1.83395,0.593801,0.444017,-1.77029,0.095871,1.13637,-2.08398,0.071733,1.0562,-2.06715,-0.039214,1.17668,-2.05145,-0.059596,1.09747,-2.03649,-0.065175,0.9502,-2.03767,-0.187673,0.798958,-2.02776,-0.249856,0.891811,-2.04761,-0.30571,0.850748,-2.03857,-0.477564,0.691867,-2.00553,-0.55003,0.773125,-1.95737,-0.521423,0.494377,-1.92592,-0.576632,0.524634,-1.99139,0.139132,1.373,-1.7989,0.128259,1.36023,-2.01348},
/*1207*/{0.211268,1.93831,-1.69792,0.305223,1.87292,-1.82699,0.046311,1.86362,-1.65134,-0.084496,1.80049,-1.63826,0.037658,1.69423,-1.64658,0.099411,1.6246,-1.63373,0.2688,1.95536,-2.07414,0.320469,1.87694,-1.90047,0.126619,1.91441,-2.01518,0.143266,1.73836,-2.19254,0.188019,1.64671,-2.22942,0.330854,1.67944,-2.0946,0.391952,1.67318,-2.08089,0.218971,1.45758,-1.80156,0.036287,1.52241,-1.85464,0.039785,1.54545,-1.91894,0.044479,1.52122,-1.96795,0.222206,1.43352,-2.05055,0.315096,1.18813,-1.74325,0.199852,1.11728,-1.74485,0.237098,1.04408,-1.76749,0.348459,0.973698,-1.76213,0.422466,0.798963,-1.75668,0.440315,0.725469,-1.76818,0.313989,0.770204,-1.76506,0.332475,0.701235,-1.77146,0.436245,0.487774,-1.79327,0.367939,0.391273,-1.8714,0.598163,0.509058,-1.8347,0.599855,0.443444,-1.7725,0.101075,1.13421,-2.08208,0.078498,1.05368,-2.06458,-0.034304,1.17113,-2.05084,-0.053531,1.0925,-2.03524,-0.057247,0.946425,-2.03684,-0.18631,0.800709,-2.02701,-0.243923,0.896183,-2.04751,-0.302878,0.857707,-2.03826,-0.479986,0.706149,-2.00609,-0.551314,0.789755,-1.95999,-0.530615,0.510025,-1.92643,-0.583832,0.541909,-1.99266,0.140001,1.37216,-1.79852,0.129318,1.35926,-2.01311},
/*1208*/{0.212753,1.93683,-1.69787,0.306314,1.87346,-1.82709,0.047053,1.86112,-1.65148,-0.083378,1.79778,-1.63899,0.039697,1.69206,-1.64616,0.100634,1.62163,-1.63203,0.269527,1.95304,-2.07358,0.320551,1.87449,-1.90067,0.126559,1.91417,-2.01431,0.14037,1.73786,-2.19101,0.186063,1.64566,-2.2281,0.329717,1.67288,-2.09388,0.391371,1.66658,-2.08033,0.218736,1.45674,-1.80121,0.036275,1.51952,-1.8538,0.039758,1.5433,-1.91964,0.043585,1.51921,-1.96856,0.222947,1.43326,-2.05012,0.311995,1.18172,-1.74252,0.193254,1.11247,-1.74412,0.231587,1.04001,-1.76874,0.340917,0.967555,-1.76158,0.419414,0.795492,-1.75609,0.437914,0.722102,-1.76794,0.311106,0.764797,-1.7672,0.330598,0.696155,-1.77353,0.43887,0.484961,-1.79453,0.372835,0.3872,-1.8733,0.601353,0.507679,-1.83629,0.603664,0.442174,-1.77326,0.107362,1.13105,-2.08069,0.086557,1.05048,-2.06352,-0.028897,1.16636,-2.05098,-0.046708,1.08647,-2.03485,-0.048966,0.942035,-2.03583,-0.184578,0.802192,-2.02656,-0.238223,0.899803,-2.04725,-0.298052,0.862922,-2.03747,-0.48208,0.721171,-2.00686,-0.54979,0.806609,-1.96004,-0.538767,0.527024,-1.92792,-0.59043,0.56017,-1.99416,0.140695,1.37051,-1.79867,0.130702,1.35801,-2.01331},
/*1209*/{0.213434,1.9348,-1.69763,0.306288,1.87115,-1.82715,0.047962,1.85877,-1.6509,-0.081372,1.79416,-1.63876,0.041565,1.6885,-1.64477,0.103044,1.61812,-1.63028,0.269786,1.95108,-2.07327,0.320341,1.87415,-1.90093,0.127012,1.91361,-2.01395,0.138234,1.73782,-2.18916,0.182941,1.64448,-2.22698,0.329602,1.66729,-2.09394,0.390915,1.65912,-2.08102,0.218952,1.45531,-1.80085,0.036213,1.51805,-1.85468,0.039932,1.54144,-1.9189,0.044144,1.51681,-1.96872,0.223961,1.43245,-2.04966,0.309107,1.17603,-1.74142,0.190493,1.11025,-1.74429,0.224618,1.03598,-1.7694,0.334611,0.961343,-1.76121,0.41563,0.791765,-1.75585,0.435416,0.72022,-1.76908,0.307754,0.759131,-1.76854,0.328433,0.690158,-1.77444,0.441638,0.481333,-1.7964,0.376133,0.383442,-1.87495,0.602697,0.506245,-1.83679,0.605505,0.439789,-1.77405,0.11318,1.12779,-2.07948,0.093901,1.04516,-2.06157,-0.024721,1.16108,-2.05089,-0.040227,1.08127,-2.03459,-0.040768,0.93694,-2.03453,-0.181922,0.803653,-2.02585,-0.230755,0.903278,-2.04675,-0.293369,0.868983,-2.03698,-0.48464,0.73698,-2.01156,-0.547914,0.824357,-1.95951,-0.546009,0.543175,-1.92947,-0.594708,0.57903,-1.99553,0.141225,1.36893,-1.79859,0.131978,1.35658,-2.01327},
/*1210*/{0.214865,1.93326,-1.69694,0.306872,1.86921,-1.82671,0.048789,1.85537,-1.65046,-0.080294,1.79028,-1.6389,0.042626,1.68451,-1.64396,0.104523,1.615,-1.62869,0.269356,1.94863,-2.07308,0.320141,1.87162,-1.90087,0.12697,1.91222,-2.01288,0.134582,1.73614,-2.18717,0.180155,1.6432,-2.22518,0.329251,1.662,-2.09442,0.389553,1.65121,-2.08199,0.218637,1.45465,-1.80045,0.035793,1.51504,-1.85472,0.04058,1.53872,-1.91912,0.044633,1.51411,-1.96859,0.224424,1.43178,-2.04929,0.306272,1.16984,-1.73981,0.184284,1.10536,-1.74583,0.220995,1.03191,-1.76855,0.328155,0.95551,-1.76154,0.411316,0.787111,-1.75591,0.432433,0.714798,-1.76868,0.303894,0.753896,-1.77135,0.325585,0.685281,-1.77895,0.441663,0.478042,-1.79761,0.377774,0.380096,-1.87791,0.603665,0.503798,-1.83684,0.605755,0.436946,-1.77519,0.119344,1.12454,-2.0785,0.101099,1.04256,-2.06018,-0.019734,1.15453,-2.05056,-0.033403,1.0745,-2.03371,-0.032312,0.931231,-2.03358,-0.17739,0.805634,-2.02549,-0.223746,0.907099,-2.04583,-0.287244,0.875919,-2.03237,-0.480463,0.748344,-2.00687,-0.54294,0.841018,-1.95858,-0.553041,0.560028,-1.93305,-0.599077,0.598115,-1.99781,0.142212,1.36722,-1.79841,0.133678,1.35483,-2.01312},
/*1211*/{0.215169,1.93027,-1.69691,0.306913,1.86762,-1.82697,0.050066,1.85128,-1.64975,-0.078471,1.78425,-1.63704,0.045219,1.68,-1.64218,0.107233,1.6109,-1.62712,0.268231,1.94581,-2.07317,0.320425,1.86945,-1.90106,0.126906,1.91069,-2.01257,0.132225,1.73502,-2.18527,0.177873,1.641,-2.2238,0.327815,1.6555,-2.09486,0.388845,1.64329,-2.08269,0.220726,1.45256,-1.79946,0.035968,1.51101,-1.85455,0.039804,1.53586,-1.91905,0.044221,1.51123,-1.96933,0.225127,1.42952,-2.04823,0.303858,1.16462,-1.73878,0.18079,1.10019,-1.74557,0.21624,1.02713,-1.77043,0.323167,0.948891,-1.76146,0.407388,0.782052,-1.75553,0.429166,0.709922,-1.76903,0.299871,0.746921,-1.77346,0.322776,0.680219,-1.78107,0.439489,0.473539,-1.80022,0.376665,0.375585,-1.88035,0.601818,0.499655,-1.8368,0.603941,0.433628,-1.77525,0.124896,1.12079,-2.07765,0.109295,1.03882,-2.05908,-0.014426,1.14876,-2.04995,-0.02688,1.06806,-2.03329,-0.024059,0.926203,-2.0331,-0.173851,0.806708,-2.0248,-0.215785,0.910529,-2.04467,-0.279824,0.880874,-2.03515,-0.481953,0.76612,-2.00996,-0.536874,0.856738,-1.95728,-0.558054,0.576156,-1.93492,-0.60369,0.618156,-2.00054,0.143594,1.36482,-1.79791,0.135168,1.35204,-2.0126},
/*1212*/{0.215801,1.92727,-1.69665,0.306865,1.8655,-1.82721,0.051232,1.84728,-1.64848,-0.076356,1.77969,-1.63588,0.047814,1.67566,-1.64063,0.110177,1.60625,-1.62543,0.268474,1.94272,-2.07315,0.320324,1.86732,-1.90128,0.126434,1.90775,-2.01197,0.128518,1.73293,-2.18314,0.17485,1.63872,-2.22232,0.326445,1.64911,-2.09556,0.386526,1.63424,-2.08351,0.21963,1.44978,-1.79869,0.036436,1.50805,-1.85507,0.039477,1.53317,-1.91895,0.045405,1.50751,-1.9693,0.226067,1.42743,-2.04756,0.301392,1.1592,-1.73659,0.178179,1.09641,-1.74519,0.213544,1.02374,-1.77126,0.318948,0.945395,-1.76175,0.404257,0.777447,-1.75625,0.426482,0.705766,-1.76994,0.297106,0.743437,-1.77408,0.320047,0.675495,-1.78255,0.437349,0.4683,-1.80075,0.375023,0.37149,-1.88446,0.5991,0.495569,-1.83703,0.601477,0.428767,-1.77627,0.130852,1.11676,-2.07682,0.116484,1.03511,-2.05774,-0.008608,1.14216,-2.04998,-0.021276,1.06189,-2.03237,-0.014768,0.921253,-2.03217,-0.169459,0.808032,-2.02425,-0.20711,0.912858,-2.04364,-0.271905,0.886905,-2.0347,-0.480934,0.78088,-2.00896,-0.529459,0.87344,-1.95556,-0.563334,0.592926,-1.93885,-0.604333,0.637965,-2.00333,0.143339,1.36185,-1.79771,0.13634,1.34941,-2.01247},
/*1213*/{0.216386,1.92403,-1.69602,0.306415,1.86348,-1.82753,0.052252,1.8417,-1.64714,-0.07402,1.77377,-1.63384,0.050024,1.67086,-1.6386,0.114106,1.60209,-1.62311,0.266731,1.93946,-2.07272,0.320367,1.86437,-1.90087,0.126016,1.90499,-2.01129,0.124752,1.73084,-2.18161,0.170855,1.63621,-2.22099,0.323997,1.64075,-2.09576,0.384684,1.62476,-2.08486,0.219026,1.44677,-1.79791,0.035767,1.50465,-1.85501,0.039888,1.53034,-1.91838,0.045147,1.50366,-1.97033,0.227168,1.42611,-2.04669,0.298566,1.15437,-1.73446,0.17642,1.09303,-1.74563,0.210174,1.01959,-1.77204,0.316402,0.942329,-1.76126,0.399791,0.772715,-1.75667,0.421,0.701632,-1.77036,0.293223,0.738397,-1.77516,0.315505,0.671805,-1.78323,0.43281,0.46427,-1.80264,0.371197,0.367802,-1.88717,0.594936,0.49064,-1.83715,0.596292,0.424013,-1.77742,0.136792,1.11305,-2.07672,0.123173,1.03057,-2.0566,-0.003307,1.13646,-2.04969,-0.013713,1.05543,-2.03174,-0.006636,0.915706,-2.03143,-0.163896,0.809075,-2.02401,-0.197764,0.91675,-2.04353,-0.26398,0.892213,-2.03437,-0.474358,0.795683,-2.00988,-0.521457,0.888417,-1.95467,-0.565722,0.609902,-1.94314,-0.606434,0.657276,-2.00613,0.143252,1.35854,-1.79787,0.137737,1.34713,-2.01273},
/*1214*/{0.217214,1.92023,-1.69524,0.30633,1.85929,-1.82751,0.053338,1.83705,-1.64559,-0.071361,1.76639,-1.63163,0.052711,1.66507,-1.63601,0.116242,1.59747,-1.62161,0.266225,1.93602,-2.0737,0.319948,1.86117,-1.90121,0.125031,1.90151,-2.01075,0.121612,1.72771,-2.17968,0.16747,1.63326,-2.21952,0.32201,1.63319,-2.09628,0.38364,1.61534,-2.08655,0.218132,1.44328,-1.79744,0.035752,1.50035,-1.85441,0.040692,1.52669,-1.91814,0.04458,1.49985,-1.97025,0.227516,1.42361,-2.04593,0.296123,1.15004,-1.7325,0.172713,1.08913,-1.74748,0.207584,1.01604,-1.77171,0.314337,0.938258,-1.76201,0.395906,0.767028,-1.75701,0.417649,0.695309,-1.77036,0.289021,0.734435,-1.77553,0.311481,0.666777,-1.78393,0.426393,0.458663,-1.80538,0.365362,0.363451,-1.89092,0.590029,0.484869,-1.83866,0.590409,0.415983,-1.77815,0.142245,1.10947,-2.07643,0.131103,1.02687,-2.05619,0.001817,1.13003,-2.04889,-0.006932,1.0487,-2.03118,0.002466,0.910206,-2.0309,-0.15853,0.809992,-2.02387,-0.188352,0.918998,-2.04341,-0.254603,0.89749,-2.03451,-0.470984,0.809947,-2.00906,-0.51096,0.902445,-1.95345,-0.567188,0.625496,-1.94691,-0.605054,0.676124,-2.00878,0.143178,1.35463,-1.79782,0.138388,1.34402,-2.01274},
/*1215*/{0.218088,1.91641,-1.69497,0.307416,1.85599,-1.8281,0.054602,1.83076,-1.64412,-0.070468,1.75908,-1.62844,0.056097,1.65925,-1.63342,0.12101,1.59174,-1.61879,0.265216,1.93272,-2.07451,0.320169,1.85786,-1.90148,0.124782,1.89799,-2.00933,0.116957,1.72567,-2.17898,0.163635,1.62952,-2.2181,0.320248,1.62545,-2.09674,0.380801,1.60457,-2.08818,0.2184,1.43983,-1.79619,0.035607,1.49752,-1.85506,0.040695,1.5227,-1.9176,0.045075,1.495,-1.97041,0.227972,1.42149,-2.04524,0.293703,1.14707,-1.73144,0.171088,1.08552,-1.74624,0.204872,1.01274,-1.77181,0.311775,0.935194,-1.76131,0.391226,0.761881,-1.7573,0.411437,0.690682,-1.77239,0.284689,0.72907,-1.77663,0.305949,0.660759,-1.7859,0.422317,0.45415,-1.80715,0.358759,0.358614,-1.89414,0.583474,0.476743,-1.83834,0.582879,0.408446,-1.78048,0.147775,1.10573,-2.07572,0.137984,1.02265,-2.05628,0.005642,1.12312,-2.0489,0.000261,1.04154,-2.03053,0.010571,0.905404,-2.03071,-0.152457,0.810795,-2.02359,-0.177877,0.920989,-2.04243,-0.245556,0.901637,-2.03424,-0.461628,0.822947,-2.01137,-0.501203,0.916498,-1.95116,-0.56654,0.640643,-1.95099,-0.60313,0.694218,-2.01149,0.143643,1.35128,-1.79745,0.139699,1.34077,-2.01239},
/*1216*/{0.218215,1.91124,-1.6941,0.30646,1.85302,-1.82831,0.056032,1.82463,-1.64116,-0.06719,1.75152,-1.6259,0.059856,1.65192,-1.63118,0.125031,1.58634,-1.61667,0.263328,1.92823,-2.0749,0.319304,1.8542,-1.90165,0.12357,1.89389,-2.00832,0.114639,1.72187,-2.17782,0.159088,1.62569,-2.21698,0.316821,1.61541,-2.09722,0.378375,1.59362,-2.08974,0.218191,1.43592,-1.79557,0.035651,1.49287,-1.85462,0.039696,1.51899,-1.91825,0.044759,1.49106,-1.9701,0.22863,1.41864,-2.04445,0.292578,1.14188,-1.72965,0.168412,1.0822,-1.74777,0.202243,1.00941,-1.77248,0.310067,0.931013,-1.76189,0.386764,0.7557,-1.75787,0.406027,0.684583,-1.77313,0.279712,0.724438,-1.77732,0.29974,0.65612,-1.78729,0.412191,0.444978,-1.80701,0.350019,0.354519,-1.89592,0.579594,0.471689,-1.83856,0.573578,0.399532,-1.78042,0.153892,1.10254,-2.07496,0.145207,1.01909,-2.05609,0.011198,1.11634,-2.04829,0.007381,1.03522,-2.03095,0.019253,0.900239,-2.03041,-0.145526,0.81202,-2.02486,-0.166041,0.921192,-2.04058,-0.235,0.905108,-2.03349,-0.45359,0.835296,-2.0115,-0.489422,0.928619,-1.94997,-0.564377,0.655593,-1.95457,-0.601817,0.712248,-2.01498,0.14362,1.3472,-1.79746,0.140499,1.3374,-2.01245},
/*1217*/{0.218,1.90634,-1.69412,0.306962,1.84764,-1.8286,0.057647,1.81727,-1.63949,-0.065263,1.74391,-1.62249,0.063066,1.64579,-1.62767,0.12949,1.58047,-1.615,0.262478,1.92445,-2.076,0.319297,1.85094,-1.90191,0.123329,1.8896,-2.00766,0.110926,1.71804,-2.17697,0.15538,1.62122,-2.21586,0.314341,1.60593,-2.09784,0.374737,1.58254,-2.09164,0.218318,1.43261,-1.79445,0.035706,1.48853,-1.85478,0.040137,1.51492,-1.91698,0.044921,1.48605,-1.97068,0.228361,1.41566,-2.04392,0.290125,1.13787,-1.72783,0.165314,1.08014,-1.74964,0.199956,1.00588,-1.77328,0.306729,0.927066,-1.76168,0.3812,0.74993,-1.75812,0.399314,0.677644,-1.77319,0.273417,0.71984,-1.778,0.293435,0.651312,-1.7873,0.403352,0.440433,-1.80807,0.339367,0.349647,-1.89749,0.567319,0.462711,-1.84064,0.565205,0.390503,-1.78218,0.157728,1.09847,-2.07718,0.1521,1.0152,-2.05639,0.017016,1.10976,-2.04793,0.013584,1.02855,-2.03056,0.028098,0.894584,-2.03018,-0.137844,0.811744,-2.02398,-0.156176,0.923417,-2.04103,-0.224906,0.908455,-2.03553,-0.44552,0.845624,-2.01146,-0.478842,0.940302,-1.94754,-0.559353,0.669857,-1.95785,-0.596895,0.727355,-2.01684,0.144289,1.34348,-1.79694,0.141428,1.33357,-2.01192},
/*1218*/{0.219174,1.90115,-1.69318,0.307664,1.8436,-1.82856,0.059096,1.80985,-1.63762,-0.062905,1.735,-1.6187,0.068684,1.63902,-1.62515,0.134491,1.57414,-1.61217,0.260142,1.91964,-2.0764,0.318802,1.8468,-1.90239,0.122027,1.8847,-2.00688,0.10682,1.71365,-2.17607,0.150648,1.61701,-2.2143,0.309886,1.59593,-2.09938,0.371381,1.57051,-2.09386,0.220561,1.4307,-1.79332,0.035306,1.48436,-1.8552,0.040461,1.51015,-1.91683,0.044633,1.48103,-1.97053,0.228782,1.41216,-2.04316,0.287559,1.1331,-1.72645,0.163747,1.07829,-1.7508,0.197224,1.00289,-1.77306,0.305348,0.921972,-1.76145,0.375285,0.743511,-1.75856,0.393966,0.670051,-1.77356,0.267368,0.714526,-1.77827,0.286255,0.646402,-1.78856,0.391798,0.434032,-1.80989,0.326049,0.35087,-1.89952,0.557886,0.452139,-1.8412,0.551569,0.380135,-1.78272,0.163557,1.09446,-2.07699,0.159011,1.01095,-2.05735,0.023048,1.10326,-2.0475,0.019954,1.02236,-2.03022,0.037615,0.889873,-2.03085,-0.130161,0.811989,-2.02468,-0.144457,0.924306,-2.04067,-0.213231,0.910555,-2.03468,-0.436066,0.855619,-2.01125,-0.467288,0.951112,-1.94684,-0.556169,0.682062,-1.96159,-0.590448,0.741597,-2.01989,0.146449,1.341,-1.7956,0.143239,1.32921,-2.01048},
/*1219*/{0.220213,1.89529,-1.69239,0.307607,1.83966,-1.82928,0.061033,1.80195,-1.63532,-0.059065,1.72617,-1.61486,0.071777,1.6312,-1.62186,0.140106,1.56907,-1.61003,0.258377,1.91486,-2.07692,0.319082,1.84232,-1.90279,0.120376,1.88012,-2.00573,0.104107,1.70921,-2.1756,0.146346,1.61288,-2.21293,0.30729,1.58571,-2.10068,0.367135,1.55851,-2.09588,0.220001,1.42492,-1.7916,0.034851,1.47917,-1.85541,0.040322,1.50637,-1.91691,0.044551,1.47626,-1.97096,0.229249,1.40909,-2.04257,0.285561,1.12953,-1.72594,0.163179,1.07471,-1.75178,0.195653,0.998611,-1.7744,0.303752,0.917901,-1.76127,0.369545,0.736773,-1.75862,0.386967,0.663436,-1.77317,0.26037,0.710353,-1.77929,0.27903,0.641342,-1.78879,0.379665,0.431995,-1.8103,0.308101,0.354278,-1.89924,0.546142,0.441201,-1.8426,0.533012,0.370254,-1.78443,0.169274,1.09001,-2.07765,0.166111,1.00698,-2.05808,0.028606,1.09673,-2.04701,0.027669,1.01592,-2.02947,0.04684,0.884765,-2.03136,-0.122095,0.812003,-2.02532,-0.133437,0.924672,-2.03975,-0.202125,0.912457,-2.03355,-0.420632,0.863264,-2.00876,-0.455261,0.960706,-1.94735,-0.549257,0.693542,-1.96509,-0.58245,0.754628,-2.02268,0.145488,1.33549,-1.79608,0.143885,1.32552,-2.01108},
/*1220*/{0.219858,1.88935,-1.69218,0.307343,1.83546,-1.82978,0.06377,1.79328,-1.63268,-0.056143,1.71663,-1.61082,0.076595,1.62365,-1.61842,0.146627,1.56205,-1.60806,0.256749,1.91029,-2.07748,0.318577,1.83775,-1.90336,0.119636,1.87464,-2.0042,0.099981,1.7047,-2.17475,0.142414,1.60817,-2.21202,0.303378,1.57465,-2.10175,0.362401,1.54573,-2.09827,0.219646,1.42131,-1.78998,0.036059,1.4765,-1.85484,0.042844,1.50037,-1.91706,0.045848,1.47295,-1.97033,0.229716,1.40544,-2.04132,0.285279,1.12433,-1.72368,0.161121,1.06972,-1.75194,0.193575,0.99459,-1.77599,0.301402,0.9118,-1.76066,0.361933,0.72972,-1.75823,0.378076,0.656606,-1.77381,0.253762,0.705074,-1.77917,0.269998,0.63609,-1.7897,0.37148,0.428693,-1.81221,0.29068,0.353522,-1.90278,0.531943,0.427805,-1.84407,0.517631,0.359181,-1.78658,0.173735,1.08714,-2.07892,0.172795,1.00316,-2.05956,0.033768,1.09038,-2.04511,0.035047,1.00893,-2.02911,0.056332,0.879099,-2.03211,-0.114008,0.811982,-2.02652,-0.120983,0.924569,-2.03906,-0.189275,0.912899,-2.03424,-0.418161,0.87428,-2.01091,-0.443849,0.969104,-1.94691,-0.542072,0.703773,-1.96871,-0.573623,0.766685,-2.02499,0.145822,1.3318,-1.79495,0.145105,1.32146,-2.00994},
/*1221*/{0.220957,1.88309,-1.69098,0.307278,1.83008,-1.83008,0.066212,1.78432,-1.62966,-0.053537,1.70601,-1.60625,0.081273,1.61593,-1.61552,0.151372,1.55555,-1.60679,0.255469,1.90533,-2.07882,0.319022,1.83338,-1.90376,0.118334,1.86989,-2.00332,0.096807,1.69846,-2.17417,0.137712,1.60359,-2.21082,0.29937,1.56465,-2.10352,0.357691,1.53262,-2.10043,0.217071,1.41659,-1.78803,0.034319,1.46921,-1.8545,0.039693,1.49604,-1.91552,0.043592,1.46634,-1.97042,0.229761,1.4012,-2.04013,0.282762,1.11935,-1.7221,0.158681,1.06521,-1.75316,0.191941,0.990897,-1.77435,0.29726,0.905975,-1.76015,0.354557,0.724087,-1.75915,0.372427,0.652233,-1.77527,0.246216,0.70134,-1.77975,0.262001,0.63177,-1.78936,0.352073,0.421203,-1.8145,0.271187,0.356305,-1.90577,0.517485,0.412573,-1.84536,0.49665,0.346152,-1.78547,0.179618,1.08253,-2.08009,0.179247,0.999219,-2.06116,0.040168,1.08382,-2.04474,0.041697,1.00262,-2.0288,0.065811,0.874211,-2.03369,-0.10495,0.811023,-2.02794,-0.108409,0.92542,-2.03885,-0.177148,0.913785,-2.0344,-0.405814,0.882107,-2.01137,-0.431798,0.977317,-1.94666,-0.533159,0.713178,-1.97077,-0.563221,0.775845,-2.02753,0.144279,1.32632,-1.79411,0.145118,1.31661,-2.00913},
/*1222*/{0.221826,1.87719,-1.69028,0.308159,1.82369,-1.8303,0.069576,1.77491,-1.62652,-0.047864,1.696,-1.60157,0.086894,1.60704,-1.61249,0.158171,1.54804,-1.60357,0.252925,1.90043,-2.07941,0.319003,1.82816,-1.90456,0.117596,1.86512,-2.00263,0.093726,1.69367,-2.17401,0.132554,1.59844,-2.20993,0.294997,1.55258,-2.10518,0.352438,1.51917,-2.10321,0.218245,1.4119,-1.78773,0.033564,1.46458,-1.85466,0.03979,1.49012,-1.91495,0.042582,1.46138,-1.97082,0.229662,1.39724,-2.04096,0.280172,1.11463,-1.72044,0.15654,1.06093,-1.75329,0.190246,0.985973,-1.77465,0.291782,0.899666,-1.75957,0.348071,0.716932,-1.76071,0.361047,0.643795,-1.77659,0.238025,0.697536,-1.78009,0.251709,0.627516,-1.79031,0.336855,0.41878,-1.81763,0.249837,0.35635,-1.9053,0.501022,0.400767,-1.84728,0.477633,0.337822,-1.78614,0.184733,1.0782,-2.08007,0.186287,0.994822,-2.06237,0.043692,1.078,-2.04478,0.047981,0.996651,-2.02827,0.076016,0.868957,-2.03436,-0.095346,0.81059,-2.02932,-0.095163,0.922685,-2.03786,-0.166935,0.918918,-2.03229,-0.393793,0.889581,-2.01367,-0.419723,0.98457,-1.94689,-0.521936,0.720529,-1.9737,-0.552372,0.784156,-2.0302,0.145205,1.3215,-1.79448,0.145457,1.31208,-2.00951},
/*1223*/{0.222463,1.87068,-1.68952,0.308874,1.81893,-1.83071,0.072973,1.76509,-1.62346,-0.043079,1.68541,-1.59647,0.093116,1.59851,-1.60894,0.164706,1.54216,-1.60265,0.251916,1.89577,-2.08047,0.319172,1.82328,-1.9055,0.116271,1.8591,-2.00121,0.090427,1.68826,-2.17358,0.127437,1.59352,-2.20936,0.290181,1.54116,-2.1073,0.346185,1.5052,-2.10548,0.217833,1.40735,-1.78596,0.032114,1.45923,-1.85454,0.038008,1.48553,-1.91502,0.041202,1.45605,-1.97106,0.230108,1.3938,-2.03881,0.278499,1.10816,-1.72001,0.155272,1.05856,-1.75316,0.187564,0.981567,-1.77548,0.286115,0.894083,-1.75891,0.340405,0.710717,-1.76164,0.351984,0.637462,-1.77832,0.230201,0.696139,-1.78041,0.24064,0.624663,-1.79181,0.318388,0.417923,-1.82073,0.227747,0.356723,-1.90414,0.480787,0.39515,-1.85395,0.456072,0.339205,-1.7874,0.188719,1.07463,-2.08126,0.192862,0.991067,-2.06385,0.049139,1.0704,-2.04402,0.055379,0.990098,-2.02825,0.085974,0.864157,-2.03664,-0.085414,0.8097,-2.03158,-0.083181,0.924415,-2.03819,-0.153505,0.919557,-2.03173,-0.383061,0.895068,-2.01217,-0.408133,0.989007,-1.94716,-0.511871,0.726785,-1.97637,-0.539899,0.790819,-2.03235,0.144405,1.31691,-1.7937,0.146254,1.30785,-2.00874},
/*1224*/{0.223488,1.8645,-1.68855,0.30923,1.81391,-1.83087,0.076445,1.7552,-1.62023,-0.036889,1.67417,-1.59172,0.099772,1.59054,-1.60631,0.172177,1.53513,-1.59944,0.250369,1.89094,-2.08131,0.320259,1.81812,-1.90591,0.115562,1.85507,-1.99915,0.085954,1.68393,-2.17291,0.122192,1.58855,-2.20879,0.285335,1.52927,-2.1093,0.339831,1.4922,-2.10864,0.216669,1.40223,-1.78386,0.029548,1.45544,-1.8553,0.035618,1.47974,-1.91531,0.04062,1.45039,-1.97032,0.229942,1.38816,-2.03872,0.275028,1.10593,-1.71743,0.150622,1.0549,-1.75296,0.18475,0.979792,-1.77601,0.279337,0.88785,-1.75958,0.33369,0.707808,-1.76377,0.340905,0.633896,-1.78114,0.222396,0.696351,-1.78086,0.23118,0.626249,-1.79316,0.299417,0.418646,-1.82393,0.204903,0.356615,-1.9056,0.458992,0.393676,-1.85774,0.433126,0.339654,-1.78809,0.193504,1.07064,-2.08289,0.199223,0.987141,-2.06522,0.055099,1.06361,-2.0438,0.063256,0.9832,-2.02744,0.096431,0.858846,-2.03868,-0.074377,0.80904,-2.03237,-0.070226,0.923589,-2.0395,-0.139732,0.919927,-2.03162,-0.368238,0.899088,-2.01332,-0.395391,0.995229,-1.94717,-0.49904,0.732344,-1.9782,-0.523092,0.796273,-2.03485,0.142506,1.31224,-1.79264,0.145506,1.30228,-2.00763},
/*1225*/{0.224408,1.85897,-1.6873,0.309508,1.80883,-1.83155,0.08058,1.7449,-1.61698,-0.031395,1.66238,-1.58678,0.107235,1.58153,-1.60221,0.1802,1.52891,-1.59799,0.2484,1.88677,-2.08189,0.32064,1.81302,-1.90726,0.114716,1.85099,-1.99697,0.082094,1.67968,-2.17289,0.116746,1.58379,-2.2083,0.278853,1.51713,-2.11192,0.332619,1.47826,-2.11089,0.214841,1.39738,-1.78359,0.026304,1.45142,-1.85521,0.033065,1.47472,-1.91607,0.038565,1.44539,-1.97143,0.228734,1.3841,-2.03815,0.271067,1.104,-1.71349,0.148573,1.05418,-1.75166,0.181919,0.978371,-1.77614,0.274627,0.882232,-1.76017,0.327165,0.707124,-1.76482,0.332161,0.634318,-1.78426,0.215258,0.700561,-1.78104,0.220524,0.62854,-1.7948,0.278013,0.420194,-1.82569,0.182646,0.357238,-1.9063,0.436384,0.392194,-1.86039,0.41048,0.340742,-1.79034,0.198537,1.06796,-2.08387,0.205917,0.983816,-2.06623,0.060092,1.05702,-2.04382,0.069802,0.976414,-2.02722,0.106862,0.850726,-2.03836,-0.062773,0.808052,-2.03429,-0.05692,0.922479,-2.03951,-0.126549,0.919517,-2.0319,-0.355513,0.904754,-2.01583,-0.382999,0.9987,-1.94726,-0.485588,0.736208,-1.98014,-0.510233,0.800174,-2.03665,0.140139,1.30766,-1.79277,0.14414,1.29786,-2.00774},
/*1226*/{0.226104,1.85365,-1.6866,0.310794,1.80317,-1.83176,0.08573,1.73419,-1.61385,-0.025079,1.6509,-1.58068,0.114857,1.57354,-1.59982,0.189061,1.52239,-1.59624,0.247321,1.88318,-2.08388,0.321593,1.80886,-1.909,0.113997,1.84809,-1.99525,0.078922,1.67498,-2.17156,0.111401,1.57922,-2.20803,0.272816,1.50494,-2.11432,0.32474,1.46514,-2.11361,0.211658,1.39414,-1.78251,0.022939,1.44798,-1.85547,0.030755,1.47015,-1.91663,0.036225,1.4412,-1.97173,0.228963,1.37888,-2.03581,0.26775,1.10424,-1.708,0.148311,1.05469,-1.75152,0.18156,0.979354,-1.77634,0.27316,0.884122,-1.7595,0.322244,0.707683,-1.7652,0.322175,0.633605,-1.78357,0.209266,0.707378,-1.78181,0.211371,0.63713,-1.79437,0.257006,0.422169,-1.82686,0.16055,0.358638,-1.90808,0.415443,0.390864,-1.86061,0.388667,0.34101,-1.78965,0.203453,1.06438,-2.08369,0.212481,0.981201,-2.06679,0.064008,1.04999,-2.04383,0.076227,0.969726,-2.02699,0.116863,0.847432,-2.04032,-0.050787,0.80785,-2.03411,-0.042645,0.921631,-2.04088,-0.112821,0.919475,-2.0323,-0.341843,0.907064,-2.01568,-0.368462,1.00106,-1.94915,-0.470989,0.738369,-1.98333,-0.496165,0.802557,-2.0398,0.136817,1.3044,-1.79113,0.143066,1.2931,-2.00598},
/*1227*/{0.226874,1.84968,-1.68602,0.311562,1.79905,-1.83237,0.091438,1.72356,-1.61054,-0.0168,1.63938,-1.57553,0.123069,1.56572,-1.59661,0.198737,1.51716,-1.59512,0.246509,1.87948,-2.08509,0.321478,1.805,-1.9108,0.113917,1.84568,-1.99193,0.075603,1.67189,-2.17141,0.10591,1.57513,-2.20675,0.266983,1.49334,-2.11694,0.31673,1.45241,-2.1165,0.210042,1.39117,-1.781,0.019834,1.4443,-1.85676,0.027663,1.46553,-1.91735,0.032839,1.43615,-1.97184,0.226429,1.37596,-2.03658,0.263355,1.10415,-1.70547,0.145607,1.05577,-1.75332,0.180362,0.978695,-1.77668,0.275002,0.888492,-1.75729,0.315436,0.706871,-1.76539,0.312853,0.634551,-1.78389,0.203086,0.713047,-1.78145,0.20147,0.642842,-1.79352,0.236958,0.424535,-1.82839,0.137991,0.359987,-1.9079,0.393727,0.388793,-1.85914,0.365524,0.339138,-1.78986,0.207789,1.06363,-2.08357,0.219662,0.980262,-2.06826,0.06933,1.04485,-2.04345,0.084311,0.965164,-2.02781,0.128305,0.843658,-2.0415,-0.037005,0.805792,-2.03477,-0.02877,0.919056,-2.04201,-0.098163,0.918569,-2.03342,-0.326641,0.910296,-2.01835,-0.357002,1.00307,-1.95088,-0.455152,0.739001,-1.98384,-0.480562,0.803112,-2.04114,0.135088,1.30127,-1.79095,0.141476,1.28923,-2.00575},
/*1228*/{0.227426,1.84576,-1.68533,0.312584,1.7944,-1.83435,0.097439,1.71341,-1.60759,-0.008259,1.6282,-1.57052,0.133356,1.55887,-1.59451,0.208553,1.51185,-1.59392,0.24618,1.87686,-2.08608,0.321942,1.80092,-1.91213,0.113539,1.84553,-1.99032,0.073875,1.67009,-2.16966,0.10122,1.57202,-2.20553,0.260148,1.48321,-2.11946,0.307649,1.44027,-2.11933,0.20791,1.38922,-1.77924,0.017097,1.44081,-1.8583,0.025756,1.46246,-1.91798,0.029547,1.43181,-1.97352,0.226011,1.37256,-2.03313,0.261392,1.10355,-1.70132,0.1442,1.05449,-1.75302,0.178528,0.978312,-1.77566,0.279782,0.89336,-1.75526,0.306207,0.707211,-1.76477,0.300984,0.632768,-1.78322,0.194773,0.716996,-1.78016,0.188838,0.645238,-1.79358,0.218866,0.425715,-1.82909,0.116885,0.361234,-1.90861,0.373166,0.387965,-1.85966,0.344491,0.338246,-1.78932,0.212187,1.06394,-2.08356,0.226926,0.981559,-2.06844,0.07456,1.0399,-2.04335,0.091898,0.961241,-2.0288,0.13942,0.840324,-2.04182,-0.022904,0.803523,-2.03499,-0.013832,0.917994,-2.0423,-0.083362,0.917587,-2.03426,-0.31903,0.912788,-2.0149,-0.343536,1.00345,-1.9513,-0.438757,0.738064,-1.98517,-0.464963,0.802509,-2.04287,0.132321,1.29923,-1.78931,0.141182,1.28543,-2.00392},
/*1229*/{0.228379,1.84241,-1.68489,0.311773,1.79046,-1.83515,0.103634,1.705,-1.60588,0.000572,1.61719,-1.56519,0.1436,1.55265,-1.59162,0.218914,1.50749,-1.59258,0.246344,1.87421,-2.08642,0.322373,1.79737,-1.91392,0.113705,1.84479,-1.98958,0.07013,1.66881,-2.16761,0.096919,1.5704,-2.20397,0.252367,1.47335,-2.12017,0.298375,1.42935,-2.12177,0.205219,1.38834,-1.77698,0.014355,1.43887,-1.86166,0.024036,1.46126,-1.91886,0.027389,1.42744,-1.97476,0.225143,1.37002,-2.0327,0.259702,1.10369,-1.7043,0.141428,1.05235,-1.75312,0.17737,0.977405,-1.77549,0.285659,0.896763,-1.75493,0.297153,0.707095,-1.7643,0.288295,0.633066,-1.78178,0.184444,0.718703,-1.77871,0.178142,0.648212,-1.79101,0.198607,0.425377,-1.82862,0.095547,0.36219,-1.90873,0.352348,0.387973,-1.86064,0.322115,0.33809,-1.7892,0.217541,1.06518,-2.08339,0.235237,0.983089,-2.06856,0.080365,1.03678,-2.04465,0.100506,0.958296,-2.02925,0.152375,0.838514,-2.04142,-0.008593,0.801649,-2.03446,0.001696,0.912883,-2.04247,-0.068636,0.91526,-2.03413,-0.299999,0.908351,-2.0169,-0.331886,1.0031,-1.95479,-0.424418,0.7353,-1.98796,-0.448454,0.79907,-2.04486,0.129482,1.29835,-1.78841,0.140506,1.28251,-2.00278},
/*1230*/{0.229204,1.84,-1.68421,0.312144,1.78775,-1.83643,0.109435,1.69745,-1.60479,0.010364,1.60714,-1.56036,0.154487,1.54674,-1.59073,0.230372,1.50416,-1.59177,0.247449,1.87209,-2.08625,0.322659,1.79416,-1.91498,0.114343,1.84357,-1.98932,0.066617,1.66925,-2.16473,0.091754,1.5705,-2.20211,0.243782,1.46609,-2.12089,0.288773,1.41905,-2.12476,0.202619,1.38837,-1.77407,0.012898,1.43772,-1.86166,0.023169,1.46096,-1.91899,0.025193,1.42426,-1.97672,0.224482,1.36789,-2.03139,0.256017,1.10301,-1.70415,0.139027,1.05056,-1.75291,0.174256,0.975633,-1.77447,0.291024,0.897643,-1.75617,0.285833,0.70562,-1.76211,0.276249,0.632097,-1.78073,0.174545,0.721434,-1.77814,0.164967,0.65094,-1.79065,0.180378,0.427108,-1.82806,0.073975,0.363,-1.90771,0.33043,0.386284,-1.85897,0.300064,0.337687,-1.78798,0.223813,1.06682,-2.0832,0.243258,0.984892,-2.06811,0.086301,1.0342,-2.04594,0.108823,0.955966,-2.03094,0.167477,0.838529,-2.04119,0.005402,0.800545,-2.03414,0.015842,0.912419,-2.04354,-0.053234,0.913944,-2.03584,-0.285493,0.906591,-2.01878,-0.318523,1.0014,-1.95688,-0.40527,0.732145,-1.9873,-0.432011,0.794463,-2.04674,0.127044,1.2983,-1.78656,0.139801,1.28031,-2.00066},
/*1231*/{0.230178,1.83803,-1.68461,0.311807,1.78533,-1.83778,0.11544,1.69267,-1.60344,0.021246,1.59903,-1.55647,0.16474,1.54286,-1.59036,0.242745,1.50194,-1.59145,0.24816,1.87028,-2.08621,0.322537,1.79281,-1.91524,0.114295,1.84222,-1.98995,0.063333,1.67049,-2.16134,0.086475,1.57246,-2.20099,0.235149,1.46007,-2.12163,0.278688,1.4104,-2.1276,0.200271,1.3882,-1.77167,0.011409,1.43667,-1.86326,0.022103,1.4601,-1.91878,0.023616,1.42281,-1.97692,0.218676,1.36501,-2.03298,0.252128,1.1008,-1.70335,0.13285,1.0481,-1.75351,0.169665,0.973605,-1.77464,0.288058,0.895255,-1.75645,0.273745,0.702614,-1.76038,0.260439,0.629081,-1.77927,0.163225,0.721786,-1.7771,0.152399,0.651954,-1.78918,0.156695,0.426809,-1.82683,0.052253,0.363669,-1.90764,0.309092,0.385858,-1.85671,0.278594,0.337137,-1.78782,0.230717,1.06801,-2.08311,0.252402,0.987174,-2.06724,0.094329,1.03167,-2.04789,0.11888,0.953975,-2.03244,0.18249,0.839426,-2.04103,0.01994,0.799887,-2.03358,0.03046,0.911084,-2.04458,-0.038526,0.912991,-2.03633,-0.269191,0.903634,-2.01972,-0.307172,0.996956,-1.95674,-0.38659,0.726702,-1.98784,-0.414868,0.787907,-2.04822,0.124237,1.29804,-1.78568,0.135969,1.27786,-1.99964},
/*1232*/{0.229803,1.83682,-1.68565,0.310706,1.78402,-1.83792,0.121365,1.68838,-1.60241,0.031918,1.59261,-1.55302,0.176583,1.53958,-1.58905,0.25505,1.50077,-1.59025,0.248686,1.86877,-2.08601,0.322159,1.79161,-1.91514,0.11491,1.84244,-1.99089,0.05935,1.673,-2.15807,0.081497,1.57456,-2.19969,0.226445,1.45562,-2.12306,0.267964,1.40437,-2.13104,0.197751,1.38733,-1.76934,0.010676,1.43618,-1.86341,0.020437,1.46005,-1.9193,0.022089,1.42279,-1.97707,0.220043,1.36522,-2.03084,0.245155,1.0971,-1.70218,0.126109,1.04602,-1.75503,0.163496,0.971521,-1.77563,0.279088,0.890687,-1.75498,0.260375,0.698655,-1.75926,0.247341,0.627013,-1.77735,0.150552,0.722125,-1.77677,0.137391,0.651809,-1.78964,0.13832,0.426938,-1.82632,0.030561,0.364765,-1.90653,0.287718,0.38559,-1.85758,0.257244,0.337145,-1.787,0.239209,1.07072,-2.08306,0.262872,0.990522,-2.06695,0.101899,1.03002,-2.04948,0.128945,0.953428,-2.03479,0.199381,0.841087,-2.041,0.035251,0.799435,-2.03329,0.046312,0.909662,-2.0452,-0.023499,0.911011,-2.03736,-0.25534,0.901136,-2.02168,-0.297999,0.993669,-1.9599,-0.367702,0.719863,-1.98866,-0.396142,0.779555,-2.04899,0.121755,1.29738,-1.78501,0.136201,1.27797,-1.99888},
/*1233*/{0.231063,1.83521,-1.68593,0.31059,1.78248,-1.83781,0.126653,1.68603,-1.60146,0.042986,1.58716,-1.54953,0.188471,1.53757,-1.58879,0.268535,1.50116,-1.59078,0.248979,1.86707,-2.08588,0.322763,1.7887,-1.91459,0.114995,1.84223,-1.99139,0.055943,1.67676,-2.15458,0.075511,1.57737,-2.1986,0.217895,1.45259,-2.12465,0.256931,1.39929,-2.13381,0.195687,1.38727,-1.76739,0.009733,1.43607,-1.86335,0.019789,1.45984,-1.91928,0.021678,1.42296,-1.97735,0.218263,1.36451,-2.03032,0.242414,1.09445,-1.70194,0.120835,1.04609,-1.75513,0.157445,0.96913,-1.77646,0.268639,0.886231,-1.75401,0.246505,0.694826,-1.7587,0.229648,0.622842,-1.77723,0.137979,0.721294,-1.77496,0.123198,0.652101,-1.78857,0.116846,0.427549,-1.82495,0.008933,0.365762,-1.90554,0.26573,0.384981,-1.85638,0.234992,0.336135,-1.78679,0.247523,1.07396,-2.08284,0.273061,0.994453,-2.06706,0.111309,1.03167,-2.05249,0.140055,0.952372,-2.03649,0.21593,0.843495,-2.04023,0.051554,0.796099,-2.03214,0.060722,0.90884,-2.04586,-0.008965,0.909047,-2.03779,-0.240968,0.895299,-2.02127,-0.28853,0.988007,-1.96155,-0.346317,0.712371,-1.98925,-0.377429,0.769217,-2.05081,0.119622,1.29732,-1.78424,0.134892,1.27748,-1.99801},
/*1234*/{0.23216,1.83472,-1.68659,0.310172,1.7817,-1.83814,0.131883,1.68445,-1.60026,0.05243,1.58303,-1.54697,0.200351,1.53711,-1.58814,0.281838,1.50288,-1.59123,0.248893,1.86627,-2.08559,0.320677,1.78839,-1.91488,0.114962,1.84215,-1.99158,0.051969,1.68123,-2.15172,0.06883,1.58061,-2.19817,0.209875,1.45194,-2.12678,0.246458,1.39685,-2.13654,0.194261,1.38682,-1.76572,0.008703,1.43566,-1.86296,0.019114,1.45985,-1.9185,0.020714,1.42358,-1.97682,0.218224,1.36508,-2.03013,0.234057,1.08909,-1.69923,0.115635,1.04455,-1.75493,0.147885,0.967979,-1.77781,0.25606,0.881525,-1.75366,0.232856,0.691183,-1.75852,0.214249,0.619777,-1.77731,0.124999,0.719923,-1.774,0.107224,0.650583,-1.7873,0.096896,0.428102,-1.82445,-0.012501,0.366304,-1.90455,0.244114,0.38482,-1.85761,0.21454,0.33684,-1.78558,0.256029,1.0769,-2.08229,0.284393,0.999243,-2.06699,0.121554,1.03053,-2.05391,0.152602,0.952669,-2.03785,0.23114,0.845967,-2.03976,0.067059,0.79478,-2.03175,0.075697,0.908214,-2.04673,0.004466,0.907239,-2.03881,-0.222296,0.887241,-2.01996,-0.27873,0.981266,-1.96445,-0.324026,0.702184,-1.9875,-0.358123,0.758898,-2.05176,0.1184,1.29676,-1.78402,0.134491,1.27802,-1.99783},
/*1235*/{0.233238,1.83444,-1.68663,0.309419,1.78106,-1.83809,0.136864,1.68316,-1.59951,0.063819,1.57904,-1.54415,0.212271,1.53756,-1.58743,0.294962,1.50561,-1.59169,0.248877,1.86541,-2.08526,0.319778,1.78783,-1.91493,0.115134,1.84237,-1.99213,0.048098,1.68633,-2.14907,0.061969,1.58496,-2.19805,0.200657,1.45138,-2.12912,0.23592,1.39514,-2.13935,0.191842,1.38724,-1.76354,0.007884,1.43573,-1.86309,0.018355,1.45934,-1.91864,0.020024,1.42435,-1.97622,0.216521,1.36594,-2.03042,0.228551,1.0842,-1.70094,0.108514,1.04005,-1.75539,0.138573,0.965524,-1.77822,0.244073,0.876254,-1.75294,0.217655,0.687118,-1.75886,0.198529,0.615701,-1.77723,0.10984,0.717606,-1.77478,0.092223,0.649121,-1.78819,0.073505,0.427755,-1.82304,-0.033513,0.366837,-1.90374,0.222736,0.38467,-1.85639,0.192093,0.336754,-1.7851,0.263644,1.08278,-2.08309,0.29513,1.00448,-2.06646,0.131908,1.03081,-2.05623,0.164724,0.953155,-2.03938,0.247527,0.849196,-2.03903,0.083235,0.79434,-2.03061,0.088619,0.90752,-2.04654,0.01938,0.905658,-2.04109,-0.212561,0.884378,-2.02318,-0.269999,0.97265,-1.96664,-0.301697,0.692051,-1.98817,-0.337461,0.746589,-2.05325,0.116724,1.29685,-1.78371,0.133641,1.27854,-1.99749},
/*1236*/{0.233505,1.83504,-1.68689,0.309421,1.78084,-1.83817,0.141835,1.68303,-1.59889,0.074228,1.57605,-1.54173,0.224217,1.53852,-1.5871,0.307656,1.50966,-1.59315,0.248704,1.86514,-2.08507,0.319221,1.78722,-1.91489,0.114717,1.84345,-1.99266,0.045131,1.69072,-2.1455,0.055181,1.58974,-2.19801,0.191798,1.45191,-2.13214,0.225149,1.39524,-2.14159,0.191627,1.38759,-1.76297,0.006809,1.43549,-1.86256,0.017198,1.45911,-1.91815,0.019517,1.42526,-1.97447,0.215974,1.36752,-2.03043,0.220297,1.08142,-1.69878,0.10261,1.04171,-1.75465,0.129729,0.963899,-1.77882,0.231277,0.87134,-1.7531,0.202435,0.682481,-1.75931,0.182751,0.611592,-1.77757,0.095555,0.715612,-1.77417,0.07657,0.646717,-1.78785,0.05441,0.427953,-1.82296,-0.055145,0.367011,-1.9031,0.201748,0.384397,-1.85595,0.171585,0.336794,-1.78439,0.272712,1.08837,-2.0828,0.306883,1.01099,-2.0657,0.141744,1.03163,-2.05745,0.176941,0.95827,-2.04282,0.262732,0.85303,-2.03939,0.098773,0.793409,-2.03023,0.101348,0.907599,-2.04722,0.032128,0.904375,-2.04088,-0.198203,0.876217,-2.02346,-0.260241,0.963667,-1.96773,-0.278657,0.681596,-1.98839,-0.315546,0.733098,-2.05354,0.116819,1.29686,-1.78364,0.133556,1.27967,-1.99754},
/*1237*/{0.234846,1.8364,-1.68723,0.308688,1.78107,-1.83827,0.145481,1.68371,-1.59835,0.084255,1.57287,-1.53944,0.235625,1.5407,-1.58718,0.320769,1.51493,-1.59522,0.248369,1.86507,-2.08546,0.3187,1.78763,-1.91486,0.114297,1.84496,-1.99268,0.039227,1.697,-2.14362,0.048332,1.59552,-2.19854,0.182653,1.454,-2.13494,0.21502,1.39726,-2.14364,0.189902,1.38819,-1.76126,0.006707,1.43546,-1.86247,0.017099,1.4616,-1.91812,0.017985,1.42621,-1.97408,0.215458,1.36969,-2.02983,0.213889,1.079,-1.70154,0.093578,1.04291,-1.75626,0.118318,0.964054,-1.77764,0.218271,0.86628,-1.75346,0.187457,0.678326,-1.76042,0.164544,0.608406,-1.77888,0.081074,0.712257,-1.77529,0.060563,0.645112,-1.78784,0.03432,0.428336,-1.82268,-0.075893,0.367619,-1.90376,0.180622,0.383821,-1.85593,0.149571,0.336408,-1.78379,0.280353,1.09444,-2.0827,0.317345,1.01857,-2.06588,0.151392,1.03306,-2.05916,0.189186,0.960675,-2.04336,0.277991,0.857189,-2.03983,0.115208,0.793805,-2.03021,0.115213,0.907683,-2.04818,0.046545,0.902921,-2.04126,-0.184868,0.868244,-2.02441,-0.253299,0.953464,-1.9699,-0.255154,0.670851,-1.98831,-0.29355,0.720024,-2.05449,0.115531,1.29744,-1.78359,0.133232,1.2814,-1.99749},
/*1238*/{0.236212,1.83795,-1.6875,0.309266,1.78196,-1.83874,0.150353,1.68425,-1.59752,0.094484,1.57064,-1.5366,0.246556,1.54405,-1.58746,0.332574,1.52119,-1.59674,0.246845,1.86569,-2.08574,0.318548,1.78809,-1.91522,0.113973,1.84558,-1.99213,0.036051,1.7037,-2.14249,0.041141,1.60189,-2.19893,0.174194,1.45752,-2.13718,0.205049,1.40039,-2.1455,0.189005,1.3875,-1.7603,0.005955,1.43598,-1.86221,0.01626,1.46032,-1.91722,0.017202,1.42763,-1.97376,0.215551,1.372,-2.02993,0.206914,1.0764,-1.70257,0.084571,1.04472,-1.75653,0.108538,0.964091,-1.77812,0.204034,0.862039,-1.75471,0.171792,0.67489,-1.76172,0.148617,0.604843,-1.77998,0.065089,0.711332,-1.77503,0.043763,0.643568,-1.78831,0.012875,0.428418,-1.82314,-0.097376,0.368016,-1.90339,0.159929,0.383989,-1.85537,0.12818,0.336214,-1.78417,0.28758,1.10088,-2.08215,0.327126,1.02643,-2.06586,0.161705,1.03558,-2.05981,0.200901,0.96431,-2.04471,0.292011,0.860903,-2.03985,0.131159,0.794738,-2.03049,0.128417,0.908316,-2.04952,0.05804,0.902735,-2.04333,-0.170657,0.859935,-2.02308,-0.244397,0.941737,-1.96956,-0.231422,0.659196,-1.98822,-0.271122,0.706283,-2.05595,0.115121,1.29672,-1.78429,0.133473,1.28299,-1.99831},
/*1239*/{0.236867,1.84013,-1.68781,0.309714,1.78357,-1.84015,0.154864,1.68566,-1.59636,0.104799,1.56954,-1.53452,0.257167,1.54805,-1.5882,0.344497,1.52808,-1.59931,0.246568,1.86648,-2.0861,0.318024,1.78863,-1.91596,0.113346,1.84782,-1.99211,0.031489,1.7092,-2.142,0.03411,1.60871,-2.19929,0.165709,1.4632,-2.13891,0.195215,1.40532,-2.14728,0.188819,1.3876,-1.76055,0.005694,1.43673,-1.86245,0.016008,1.46077,-1.916,0.016507,1.42836,-1.97307,0.215433,1.37442,-2.02963,0.204136,1.07684,-1.70432,0.075944,1.04679,-1.75602,0.097626,0.96487,-1.7773,0.189089,0.857968,-1.75553,0.154466,0.67235,-1.76263,0.130309,0.603159,-1.78233,0.048671,0.709605,-1.77504,0.025802,0.642716,-1.78875,-0.007661,0.429424,-1.8236,-0.117912,0.368609,-1.90395,0.13844,0.384168,-1.85581,0.107239,0.336697,-1.7835,0.295614,1.10811,-2.08237,0.336388,1.03498,-2.06535,0.169931,1.03819,-2.06039,0.212086,0.968724,-2.04625,0.306225,0.865988,-2.0405,0.147195,0.79582,-2.03084,0.141066,0.908608,-2.05006,0.07011,0.8996,-2.04368,-0.156721,0.850152,-2.02453,-0.234773,0.92844,-1.97096,-0.20651,0.646605,-1.98861,-0.248254,0.691903,-2.05598,0.115343,1.29686,-1.7848,0.133656,1.28468,-1.99891},
/*1240*/{0.238791,1.84287,-1.68854,0.308979,1.78463,-1.83988,0.16089,1.68705,-1.59538,0.116412,1.57032,-1.53258,0.268065,1.55356,-1.5891,0.355119,1.53605,-1.6021,0.244507,1.86809,-2.08601,0.31774,1.7902,-1.91697,0.112597,1.84902,-1.99147,0.027284,1.71643,-2.14153,0.026968,1.61591,-2.20002,0.156898,1.46887,-2.13994,0.185886,1.41064,-2.14837,0.188224,1.38801,-1.76072,0.006085,1.43753,-1.86186,0.016258,1.46152,-1.91549,0.016355,1.42883,-1.97254,0.214826,1.3761,-2.02946,0.196743,1.07545,-1.70524,0.066392,1.04563,-1.75558,0.086095,0.966059,-1.77868,0.171486,0.855301,-1.75631,0.138406,0.67172,-1.76378,0.113448,0.602286,-1.78253,0.032716,0.710402,-1.77556,0.008976,0.643669,-1.79025,-0.027274,0.429981,-1.82366,-0.139355,0.369466,-1.90429,0.116884,0.383587,-1.85573,0.086334,0.337206,-1.78397,0.301387,1.11599,-2.08214,0.344749,1.04396,-2.06549,0.179334,1.04183,-2.0618,0.222894,0.973626,-2.04618,0.319479,0.871546,-2.04092,0.163867,0.797244,-2.0308,0.152711,0.910173,-2.0489,0.083453,0.89969,-2.04543,-0.14234,0.840953,-2.02591,-0.225165,0.913765,-1.97283,-0.181133,0.634564,-1.98875,-0.223883,0.676927,-2.05674,0.115423,1.29727,-1.78492,0.133535,1.28586,-1.99908},
/*1241*/{0.240637,1.84596,-1.6891,0.309831,1.78693,-1.84063,0.166139,1.68854,-1.59449,0.12406,1.56986,-1.5315,0.277089,1.55886,-1.59019,0.365023,1.54498,-1.60519,0.242798,1.8701,-2.08605,0.317441,1.79195,-1.91726,0.111437,1.85068,-1.98944,0.021018,1.723,-2.14121,0.019294,1.62278,-2.20043,0.148777,1.47537,-2.14143,0.176896,1.41773,-2.14937,0.189358,1.3874,-1.7602,0.008423,1.44019,-1.86082,0.017614,1.46303,-1.91499,0.018401,1.43105,-1.97249,0.215364,1.37889,-2.02969,0.186803,1.07213,-1.70706,0.057469,1.04786,-1.75624,0.07605,0.966521,-1.77682,0.15482,0.854571,-1.75747,0.121136,0.670379,-1.76526,0.095067,0.601662,-1.78329,0.016774,0.711041,-1.77623,-0.006861,0.644558,-1.7887,-0.049373,0.428972,-1.82278,-0.160074,0.371102,-1.90373,0.096446,0.383071,-1.85564,0.064655,0.336761,-1.78414,0.306952,1.12359,-2.08224,0.352943,1.05291,-2.06592,0.187276,1.04578,-2.06175,0.233111,0.97893,-2.04643,0.333828,0.879952,-2.04166,0.179255,0.798113,-2.03118,0.164429,0.910108,-2.05048,0.096026,0.896026,-2.04623,-0.127977,0.829847,-2.02602,-0.217606,0.898563,-1.97331,-0.155312,0.622373,-1.98946,-0.199675,0.662419,-2.05694,0.116294,1.29761,-1.78577,0.13428,1.28825,-2.00005},
/*1242*/{0.242396,1.84905,-1.69011,0.310048,1.78887,-1.84177,0.172384,1.69123,-1.59409,0.134317,1.57186,-1.53014,0.286838,1.56496,-1.59139,0.374548,1.55387,-1.60866,0.240709,1.87274,-2.08611,0.317298,1.79399,-1.91856,0.110447,1.85263,-1.98845,0.015221,1.72988,-2.14089,0.012682,1.63025,-2.20045,0.140154,1.48243,-2.14135,0.168666,1.4254,-2.15012,0.189016,1.38635,-1.75975,0.007581,1.44141,-1.86053,0.017012,1.46457,-1.91456,0.017361,1.43219,-1.97202,0.21562,1.38014,-2.02935,0.17676,1.07144,-1.70959,0.049638,1.0505,-1.755,0.064903,0.968227,-1.7767,0.136644,0.853662,-1.7586,0.104942,0.671093,-1.76652,0.077829,0.602502,-1.78423,-0.000587,0.712535,-1.77773,-0.025883,0.646361,-1.79024,-0.069548,0.430053,-1.82348,-0.180713,0.372804,-1.90384,0.075842,0.383243,-1.85602,0.043424,0.336029,-1.78399,0.312698,1.13102,-2.08219,0.360052,1.06201,-2.06568,0.19492,1.04952,-2.06156,0.242546,0.984619,-2.04633,0.347027,0.888435,-2.04162,0.195262,0.800139,-2.03152,0.175882,0.910905,-2.0515,0.107373,0.894446,-2.04751,-0.115272,0.818786,-2.02448,-0.207589,0.881701,-1.97286,-0.128744,0.609821,-1.99087,-0.177188,0.646749,-2.05877,0.115097,1.29744,-1.78624,0.133436,1.28959,-2.00055},
/*1243*/{0.244599,1.85201,-1.68995,0.310973,1.79158,-1.84233,0.178592,1.69392,-1.59443,0.144352,1.57459,-1.52891,0.294784,1.57156,-1.59377,0.382864,1.5631,-1.61165,0.238237,1.87537,-2.0868,0.316828,1.79652,-1.91913,0.109776,1.85375,-1.98671,0.009766,1.73734,-2.14082,0.005503,1.63801,-2.20084,0.132874,1.49037,-2.14202,0.160409,1.43315,-2.15102,0.189502,1.38688,-1.76035,0.007795,1.4441,-1.85963,0.017824,1.46685,-1.91371,0.018343,1.43418,-1.97178,0.215991,1.38314,-2.02862,0.1711,1.0707,-1.71076,0.040309,1.05256,-1.75272,0.053222,0.971315,-1.77679,0.120322,0.853501,-1.76057,0.08577,0.67159,-1.76727,0.05795,0.60327,-1.78586,-0.017296,0.714364,-1.77896,-0.04424,0.648704,-1.79066,-0.090042,0.43154,-1.82377,-0.20168,0.375685,-1.9032,0.053878,0.382723,-1.85669,0.022681,0.33626,-1.78502,0.31778,1.13884,-2.08157,0.367249,1.07108,-2.06568,0.201805,1.05446,-2.06176,0.25187,0.990541,-2.04673,0.359343,0.898216,-2.04203,0.210661,0.802404,-2.03191,0.187073,0.91041,-2.05143,0.118968,0.891795,-2.04874,-0.094831,0.803641,-2.02392,-0.196039,0.864919,-1.97175,-0.101811,0.598631,-1.99233,-0.15286,0.632925,-2.05915,0.115359,1.2986,-1.78671,0.133724,1.29227,-2.00107},
/*1244*/{0.247077,1.85628,-1.69112,0.310924,1.79489,-1.84339,0.185249,1.69664,-1.59352,0.153425,1.57615,-1.52795,0.303238,1.57904,-1.59546,0.390251,1.57285,-1.61542,0.234084,1.87883,-2.08644,0.316308,1.79936,-1.92104,0.108343,1.85654,-1.9851,0.005182,1.7443,-2.14029,-0.000886,1.64548,-2.20074,0.125398,1.49911,-2.14277,0.153622,1.44149,-2.15182,0.191081,1.38679,-1.76032,0.009436,1.44589,-1.85924,0.018662,1.46902,-1.91257,0.019198,1.43639,-1.97167,0.216603,1.3865,-2.02796,0.1643,1.07042,-1.71285,0.031755,1.05476,-1.75274,0.042623,0.974752,-1.77646,0.104009,0.855859,-1.76197,0.068412,0.672952,-1.76876,0.039795,0.605638,-1.786,-0.035238,0.717107,-1.78053,-0.061896,0.651513,-1.79364,-0.110296,0.433878,-1.82373,-0.222464,0.379061,-1.90297,0.033498,0.382221,-1.85662,0.000437,0.336748,-1.78573,0.322625,1.14622,-2.08194,0.373745,1.08033,-2.06566,0.209219,1.05814,-2.06096,0.260342,0.996401,-2.04553,0.371399,0.909016,-2.04243,0.225727,0.80391,-2.03222,0.197864,0.909756,-2.05258,0.129201,0.889624,-2.04925,-0.084311,0.793379,-2.02621,-0.186457,0.846042,-1.97276,-0.073115,0.586602,-1.99354,-0.127592,0.617254,-2.06015,0.116426,1.29919,-1.78759,0.134651,1.29513,-2.00202},
/*1245*/{0.249596,1.86028,-1.69209,0.312252,1.79753,-1.84447,0.191955,1.69989,-1.59368,0.163075,1.58024,-1.52708,0.311004,1.58595,-1.59771,0.397737,1.58255,-1.61942,0.23209,1.88272,-2.08625,0.316379,1.80243,-1.92189,0.107375,1.85931,-1.98273,0.000561,1.75169,-2.14077,-0.00766,1.65306,-2.19993,0.118532,1.50681,-2.14293,0.146827,1.4509,-2.15271,0.192732,1.387,-1.76035,0.010675,1.44819,-1.85903,0.019862,1.47106,-1.91172,0.019893,1.43925,-1.97101,0.217136,1.38878,-2.02717,0.157308,1.0708,-1.71527,0.026544,1.05965,-1.75312,0.032177,0.978356,-1.77589,0.090647,0.857872,-1.76353,0.049929,0.674863,-1.76946,0.021016,0.60634,-1.78669,-0.052795,0.719697,-1.78096,-0.080036,0.654521,-1.79356,-0.129592,0.436821,-1.82304,-0.242662,0.383372,-1.90246,0.013177,0.382087,-1.85767,-0.019692,0.336739,-1.78528,0.326734,1.15408,-2.0826,0.379841,1.0894,-2.06589,0.215339,1.06354,-2.06132,0.268349,1.00227,-2.04515,0.38197,0.919146,-2.04223,0.240327,0.806363,-2.03235,0.205233,0.913201,-2.05518,0.139877,0.887491,-2.04971,-0.067024,0.78098,-2.02504,-0.173478,0.826196,-1.97122,-0.045116,0.575885,-1.99485,-0.101491,0.602229,-2.06093,0.117042,1.30019,-1.788,0.134972,1.29753,-2.00247},
/*1246*/{0.251521,1.86477,-1.6933,0.313484,1.8015,-1.84601,0.198941,1.70354,-1.5937,0.17136,1.58274,-1.52617,0.317407,1.59407,-1.59975,0.404309,1.59315,-1.62255,0.22924,1.88678,-2.08526,0.316547,1.80558,-1.92344,0.107072,1.86082,-1.98113,-0.003214,1.75979,-2.13972,-0.01319,1.66118,-2.19934,0.112016,1.51606,-2.14298,0.140194,1.46005,-2.15386,0.193253,1.38701,-1.75967,0.01147,1.45059,-1.85786,0.020438,1.47386,-1.91046,0.021451,1.44251,-1.97077,0.218273,1.39128,-2.02617,0.149799,1.07062,-1.71762,0.016141,1.06395,-1.75286,0.02056,0.982189,-1.77722,0.077295,0.860186,-1.76603,0.033062,0.6771,-1.77077,0.004023,0.610035,-1.78774,-0.069763,0.722039,-1.78273,-0.097428,0.657867,-1.79351,-0.149244,0.439678,-1.82205,-0.262331,0.388821,-1.90182,-0.007244,0.381484,-1.85796,-0.040837,0.337102,-1.78657,0.330586,1.16168,-2.08228,0.385405,1.09824,-2.06589,0.221657,1.0697,-2.06087,0.275683,1.0091,-2.04472,0.392577,0.929777,-2.04186,0.254734,0.80821,-2.03337,0.214103,0.914167,-2.05554,0.150167,0.884639,-2.05027,-0.049548,0.766843,-2.02472,-0.160944,0.806324,-1.97113,-0.017669,0.564042,-1.99585,-0.075642,0.587006,-2.06128,0.116798,1.30108,-1.78831,0.135354,1.3004,-2.00274},
/*1247*/{0.254061,1.86945,-1.69408,0.31394,1.8051,-1.84663,0.20532,1.70732,-1.59373,0.180087,1.58638,-1.52576,0.323921,1.60133,-1.60175,0.410118,1.60328,-1.62609,0.226789,1.89082,-2.08512,0.316688,1.8094,-1.92476,0.105856,1.86358,-1.97923,-0.007757,1.7668,-2.13932,-0.019478,1.66931,-2.19904,0.106117,1.52535,-2.1431,0.134606,1.46943,-2.15499,0.194511,1.38766,-1.75925,0.012953,1.45337,-1.8566,0.021943,1.47611,-1.90896,0.022132,1.44603,-1.97087,0.218887,1.39464,-2.02564,0.144451,1.07292,-1.72136,0.011991,1.06889,-1.75155,0.010897,0.986927,-1.77679,0.064648,0.864,-1.76786,0.014861,0.68085,-1.77103,-0.015149,0.612522,-1.78779,-0.087124,0.726442,-1.7838,-0.114138,0.66123,-1.79371,-0.169142,0.444049,-1.82207,-0.282105,0.395434,-1.90151,-0.026678,0.380914,-1.85745,-0.062185,0.337726,-1.78676,0.335086,1.16891,-2.08242,0.390311,1.10553,-2.06535,0.227077,1.07434,-2.05938,0.282483,1.01551,-2.04492,0.401817,0.940273,-2.04219,0.269505,0.811286,-2.03399,0.222706,0.913327,-2.05554,0.160383,0.880787,-2.04993,-0.036796,0.756105,-2.02717,-0.148206,0.786055,-1.9711,0.011886,0.55336,-1.99672,-0.048918,0.573573,-2.06285,0.117557,1.30241,-1.78882,0.135891,1.30368,-2.00327},
/*1248*/{0.256181,1.87368,-1.69551,0.314475,1.80842,-1.84801,0.211564,1.71128,-1.59406,0.188489,1.59023,-1.52415,0.329883,1.60926,-1.60392,0.415022,1.61312,-1.62938,0.224118,1.89498,-2.0847,0.316494,1.81356,-1.92632,0.105789,1.86633,-1.97784,-0.010529,1.77355,-2.14011,-0.025275,1.67736,-2.19743,0.100591,1.53483,-2.14261,0.129992,1.47875,-2.15587,0.196532,1.3884,-1.75893,0.015701,1.45579,-1.85708,0.023572,1.4786,-1.90831,0.024518,1.44912,-1.97028,0.220572,1.39778,-2.02479,0.13745,1.07399,-1.72285,0.002169,1.07348,-1.75278,0.002054,0.992522,-1.77802,0.051887,0.867011,-1.76909,-0.001126,0.684771,-1.77168,-0.031437,0.618763,-1.78836,-0.103375,0.731691,-1.78332,-0.13284,0.666223,-1.79537,-0.188413,0.448112,-1.82169,-0.301181,0.402621,-1.90059,-0.04658,0.379619,-1.85792,-0.08315,0.337984,-1.78716,0.338936,1.17617,-2.0828,0.394363,1.11594,-2.06629,0.232519,1.07985,-2.05956,0.289569,1.02112,-2.04462,0.410046,0.950373,-2.04225,0.283102,0.814224,-2.03618,0.230993,0.913077,-2.05624,0.170664,0.877812,-2.05039,-0.020738,0.742377,-2.02467,-0.131853,0.764658,-1.97023,0.040411,0.542268,-1.99851,-0.020789,0.559564,-2.06304,0.119075,1.30382,-1.78941,0.137791,1.30672,-2.00381},
/*1249*/{0.257929,1.8781,-1.69654,0.31506,1.81227,-1.84994,0.218762,1.71644,-1.59393,0.196449,1.59468,-1.52409,0.334471,1.61668,-1.60632,0.419608,1.62274,-1.63322,0.221546,1.89902,-2.08416,0.316924,1.81721,-1.92707,0.104578,1.86951,-1.97558,-0.015351,1.78086,-2.13913,-0.030436,1.68556,-2.19613,0.094026,1.54434,-2.1422,0.124965,1.48847,-2.15623,0.197415,1.38888,-1.75837,0.016683,1.45855,-1.85689,0.024938,1.48212,-1.90712,0.025677,1.45335,-1.97063,0.221325,1.40102,-2.02416,0.132315,1.07427,-1.72442,-0.0041,1.07987,-1.7522,-0.008074,0.998296,-1.77805,0.037925,0.871604,-1.76981,-0.018814,0.689474,-1.77166,-0.048837,0.622857,-1.7874,-0.119841,0.737012,-1.78383,-0.149257,0.672666,-1.79554,-0.205581,0.45295,-1.82159,-0.319247,0.410958,-1.89973,-0.066258,0.378142,-1.85812,-0.103905,0.338069,-1.78803,0.341902,1.18344,-2.08289,0.399059,1.12285,-2.06641,0.237485,1.08595,-2.05938,0.295311,1.02836,-2.04426,0.417341,0.960096,-2.04223,0.295877,0.817252,-2.03558,0.23868,0.913237,-2.05653,0.180162,0.873818,-2.04938,0.000569,0.726859,-2.0241,-0.116558,0.742688,-1.96887,0.070755,0.532903,-1.9992,0.008237,0.545801,-2.06401,0.118892,1.30529,-1.79031,0.138147,1.31034,-2.00463},
/*1250*/{0.260176,1.88361,-1.69878,0.316565,1.81681,-1.85171,0.224344,1.7208,-1.59458,0.203466,1.59966,-1.52339,0.33946,1.6252,-1.60814,0.423684,1.63232,-1.63711,0.22055,1.9034,-2.08405,0.31685,1.82107,-1.92926,0.104623,1.87287,-1.97441,-0.017907,1.788,-2.13853,-0.035308,1.6937,-2.19454,0.089823,1.55372,-2.14198,0.120293,1.49768,-2.15711,0.199414,1.3898,-1.75864,0.019213,1.46153,-1.85581,0.02712,1.48514,-1.90492,0.028033,1.45753,-1.97072,0.222642,1.4049,-2.02311,0.126191,1.07549,-1.72686,-0.009322,1.08502,-1.75249,-0.017179,1.00455,-1.77784,0.023615,0.876874,-1.76946,-0.033565,0.694907,-1.77111,-0.065733,0.628178,-1.7871,-0.135342,0.74351,-1.78447,-0.165357,0.679575,-1.79453,-0.222825,0.457811,-1.81898,-0.336773,0.419622,-1.89962,-0.086502,0.377314,-1.85766,-0.125108,0.338596,-1.78781,0.345976,1.19056,-2.08327,0.402945,1.13094,-2.06543,0.241468,1.09179,-2.05967,0.299718,1.0348,-2.04364,0.423147,0.969607,-2.04153,0.308406,0.819675,-2.03616,0.245509,0.912838,-2.05654,0.188839,0.870783,-2.05013,0.019083,0.713252,-2.02391,-0.101807,0.722716,-1.96931,0.10104,0.523629,-2.00082,0.036707,0.533172,-2.06491,0.120436,1.30689,-1.79105,0.139567,1.31432,-2.00531},
/*1251*/{0.261985,1.88844,-1.70026,0.317515,1.82049,-1.85308,0.229544,1.72541,-1.59447,0.210638,1.60462,-1.5232,0.343279,1.63173,-1.60991,0.427565,1.64166,-1.64123,0.218822,1.90751,-2.08427,0.316801,1.82494,-1.93072,0.104364,1.87596,-1.97237,-0.020406,1.79516,-2.13802,-0.040463,1.70227,-2.19331,0.085873,1.56285,-2.14066,0.115736,1.50705,-2.15771,0.201257,1.39023,-1.75884,0.021405,1.46392,-1.8555,0.029595,1.48783,-1.90397,0.030039,1.46232,-1.97054,0.224268,1.40892,-2.02237,0.119946,1.07631,-1.72952,-0.015143,1.09138,-1.75237,-0.024367,1.01194,-1.77715,0.009649,0.882584,-1.76978,-0.049938,0.700941,-1.77091,-0.083421,0.634037,-1.78599,-0.150621,0.750479,-1.7845,-0.181123,0.686689,-1.79524,-0.240187,0.463124,-1.81793,-0.354231,0.429131,-1.89941,-0.106467,0.376467,-1.85801,-0.147088,0.33919,-1.78826,0.348304,1.19719,-2.08285,0.405915,1.13879,-2.0651,0.24589,1.09758,-2.05939,0.304992,1.04096,-2.0427,0.427302,0.978642,-2.04097,0.320446,0.82235,-2.03698,0.252313,0.911887,-2.05622,0.198462,0.865674,-2.04901,0.03561,0.698924,-2.02357,-0.082927,0.700398,-1.96788,0.131498,0.515526,-2.0027,0.066135,0.521434,-2.06612,0.121679,1.30808,-1.79254,0.141228,1.31849,-2.00663},
/*1252*/{0.264219,1.89265,-1.70198,0.318373,1.82435,-1.85472,0.23416,1.73021,-1.59528,0.217117,1.60934,-1.5226,0.34654,1.63908,-1.61144,0.429944,1.65064,-1.64373,0.217785,1.9113,-2.08307,0.316924,1.82923,-1.93198,0.103633,1.87905,-1.97159,-0.02325,1.80238,-2.13669,-0.044568,1.71,-2.19076,0.080581,1.57113,-2.13995,0.111991,1.51574,-2.15778,0.203066,1.39038,-1.75922,0.023748,1.46737,-1.85484,0.031158,1.49148,-1.90269,0.032218,1.46664,-1.9706,0.225252,1.41251,-2.02216,0.115338,1.07943,-1.73122,-0.018619,1.10051,-1.75377,-0.033226,1.01885,-1.77832,-0.004546,0.888382,-1.7692,-0.065337,0.708179,-1.76925,-0.097938,0.640622,-1.78445,-0.165152,0.757525,-1.78539,-0.196309,0.69475,-1.7954,-0.258072,0.468379,-1.81667,-0.370835,0.439633,-1.89819,-0.127096,0.376023,-1.85852,-0.167918,0.33949,-1.78908,0.350708,1.20414,-2.08273,0.409393,1.14624,-2.06487,0.249402,1.10381,-2.0593,0.308637,1.04758,-2.04194,0.429754,0.986718,-2.04072,0.331822,0.824861,-2.03753,0.259119,0.910768,-2.05612,0.207682,0.861756,-2.0486,0.055215,0.6846,-2.02312,-0.063667,0.678793,-1.96604,0.161607,0.508322,-2.00465,0.096198,0.509812,-2.06726,0.122405,1.3096,-1.7939,0.141805,1.32249,-2.00787},
/*1253*/{0.265368,1.89682,-1.70376,0.318913,1.82886,-1.85622,0.238068,1.73521,-1.59595,0.222456,1.6136,-1.52134,0.350317,1.64675,-1.61319,0.432678,1.65926,-1.64685,0.216848,1.9148,-2.08275,0.317305,1.83334,-1.93273,0.104011,1.88299,-1.97155,-0.025762,1.80781,-2.13304,-0.049306,1.71741,-2.18953,0.07665,1.57959,-2.13937,0.108403,1.52389,-2.15828,0.204858,1.39148,-1.75999,0.02657,1.47066,-1.85488,0.032804,1.49514,-1.90151,0.033806,1.47177,-1.9707,0.227059,1.41642,-2.02188,0.110993,1.08108,-1.73157,-0.024471,1.10562,-1.75349,-0.039824,1.02561,-1.77927,-0.017816,0.896019,-1.76851,-0.079421,0.715469,-1.76823,-0.113853,0.648004,-1.78363,-0.179479,0.765907,-1.78468,-0.210047,0.703299,-1.79457,-0.272568,0.475377,-1.81452,-0.386554,0.450798,-1.89752,-0.146959,0.375267,-1.85821,-0.189832,0.339358,-1.78929,0.353412,1.21094,-2.08246,0.412948,1.15419,-2.06355,0.252463,1.10981,-2.05945,0.312134,1.0553,-2.04168,0.432691,0.994487,-2.04027,0.342486,0.82695,-2.03772,0.26503,0.9086,-2.05542,0.217217,0.856203,-2.04753,0.069914,0.672041,-2.02791,-0.044343,0.655313,-1.96516,0.192139,0.501898,-2.00731,0.125995,0.500294,-2.06847,0.123511,1.31162,-1.79542,0.142963,1.32694,-2.00922},
/*1254*/{0.266918,1.90157,-1.7048,0.320094,1.8328,-1.85802,0.242702,1.73979,-1.59583,0.227546,1.61845,-1.52112,0.353338,1.65278,-1.61475,0.435388,1.66709,-1.65015,0.21642,1.91856,-2.08289,0.316807,1.83711,-1.93452,0.103808,1.88633,-1.97093,-0.02674,1.81404,-2.13109,-0.052492,1.72497,-2.18677,0.073708,1.58727,-2.13834,0.105278,1.53201,-2.15855,0.20744,1.39209,-1.76115,0.028172,1.47402,-1.85417,0.035361,1.49893,-1.90085,0.035822,1.47538,-1.96976,0.22829,1.42046,-2.0221,0.10553,1.08506,-1.7331,-0.026666,1.11375,-1.75254,-0.047427,1.03375,-1.77866,-0.029888,0.90249,-1.76764,-0.093272,0.72248,-1.76656,-0.126822,0.656034,-1.7811,-0.192155,0.773922,-1.78515,-0.22291,0.711014,-1.79315,-0.290612,0.482061,-1.81302,-0.402432,0.464058,-1.89645,-0.16573,0.375977,-1.85769,-0.211386,0.340052,-1.78928,0.355254,1.21637,-2.0829,0.415847,1.15974,-2.06264,0.255527,1.11547,-2.05959,0.314462,1.06065,-2.04061,0.4323,1.00101,-2.03949,0.352905,0.828631,-2.03852,0.270702,0.905948,-2.05417,0.224586,0.850611,-2.04657,0.093155,0.656497,-2.02108,-0.021721,0.633144,-1.96123,0.222655,0.496314,-2.00855,0.156286,0.490128,-2.06891,0.125136,1.31337,-1.79691,0.143919,1.33108,-2.01059},
/*1255*/{0.268561,1.90557,-1.70613,0.321545,1.83734,-1.85983,0.246144,1.744,-1.59585,0.232968,1.62247,-1.52023,0.355812,1.65929,-1.61707,0.436571,1.67444,-1.65447,0.215256,1.92177,-2.08311,0.317206,1.84076,-1.9357,0.105817,1.88824,-1.96942,-0.029312,1.81946,-2.12884,-0.056104,1.73239,-2.18472,0.07085,1.59466,-2.13752,0.102402,1.53914,-2.15848,0.210072,1.3926,-1.76269,0.031272,1.47709,-1.85374,0.036729,1.50257,-1.89873,0.038035,1.48082,-1.97013,0.227741,1.42461,-2.02229,0.10138,1.08756,-1.73272,-0.03175,1.1186,-1.75304,-0.053534,1.04137,-1.77735,-0.040884,0.909758,-1.76744,-0.10419,0.730103,-1.76515,-0.139898,0.663765,-1.77873,-0.20439,0.781886,-1.78449,-0.235444,0.719303,-1.79292,-0.303289,0.490034,-1.81005,-0.415865,0.476038,-1.89474,-0.185117,0.375846,-1.8576,-0.232527,0.340897,-1.78926,0.357104,1.22221,-2.0821,0.417322,1.16588,-2.06158,0.257879,1.1209,-2.05952,0.316614,1.06696,-2.03961,0.433021,1.00747,-2.03981,0.362802,0.829478,-2.03899,0.27583,0.901293,-2.05268,0.23453,0.844852,-2.0459,0.113343,0.643084,-2.02125,-0.001126,0.611234,-1.9601,0.252825,0.491965,-2.00979,0.186228,0.481658,-2.07024,0.126454,1.31508,-1.79897,0.14387,1.33573,-2.01251},
/*1256*/{0.270002,1.9094,-1.70722,0.322228,1.84029,-1.86148,0.249608,1.74826,-1.59612,0.23772,1.62744,-1.5198,0.35799,1.66487,-1.61857,0.438273,1.68183,-1.6563,0.215149,1.92467,-2.08294,0.317688,1.8446,-1.93672,0.105892,1.89124,-1.96893,-0.029848,1.82515,-2.12636,-0.059032,1.73904,-2.18189,0.068582,1.60139,-2.13659,0.099921,1.54597,-2.15841,0.211424,1.39352,-1.76328,0.032562,1.4804,-1.85284,0.037982,1.5061,-1.89805,0.040423,1.48541,-1.97006,0.229662,1.42907,-2.0228,0.095835,1.08991,-1.7333,-0.034117,1.12574,-1.75257,-0.059126,1.04854,-1.77876,-0.050295,0.91732,-1.76701,-0.116617,0.737915,-1.76255,-0.150788,0.671758,-1.77663,-0.215143,0.78991,-1.78472,-0.246989,0.726635,-1.79192,-0.316161,0.496404,-1.80658,-0.428507,0.489872,-1.8921,-0.204566,0.375675,-1.85664,-0.254118,0.342367,-1.78927,0.358851,1.2278,-2.0817,0.41909,1.17095,-2.06085,0.258763,1.12566,-2.06108,0.318104,1.07203,-2.04011,0.432514,1.01249,-2.03946,0.372286,0.830614,-2.03873,0.281076,0.896946,-2.05174,0.243283,0.83766,-2.04455,0.133658,0.629925,-2.01952,0.022762,0.591009,-1.9588,0.282974,0.488255,-2.01001,0.216326,0.473876,-2.0705,0.127382,1.31696,-1.80079,0.145159,1.3405,-2.014},
/*1257*/{0.271527,1.91254,-1.70859,0.323246,1.84471,-1.86261,0.252353,1.75206,-1.59609,0.24194,1.63085,-1.51885,0.359482,1.67046,-1.61953,0.439591,1.68834,-1.65945,0.214887,1.92789,-2.08292,0.318338,1.84753,-1.93823,0.106169,1.89365,-1.96859,-0.029823,1.83132,-2.12424,-0.061718,1.74544,-2.17976,0.066138,1.60781,-2.13562,0.097125,1.55257,-2.158,0.213725,1.39439,-1.76443,0.03546,1.48371,-1.85298,0.040802,1.50932,-1.89675,0.042799,1.49012,-1.96923,0.229955,1.43273,-2.02274,0.092328,1.09236,-1.73373,-0.034454,1.13325,-1.75273,-0.06415,1.05606,-1.7793,-0.058225,0.92454,-1.76729,-0.12627,0.745795,-1.76166,-0.16109,0.679153,-1.77354,-0.22467,0.797941,-1.78334,-0.25718,0.734179,-1.79196,-0.328642,0.502199,-1.80267,-0.439773,0.504201,-1.88945,-0.223909,0.376204,-1.85593,-0.274132,0.344739,-1.78901,0.360397,1.23188,-2.0817,0.420692,1.17509,-2.05958,0.260404,1.13038,-2.06053,0.318311,1.07661,-2.04091,0.432251,1.01679,-2.03923,0.381644,0.830913,-2.03895,0.286896,0.892253,-2.05018,0.25205,0.830741,-2.04398,0.153162,0.617363,-2.02046,0.046634,0.570623,-1.95688,0.312083,0.485128,-2.01037,0.245142,0.467674,-2.07145,0.128767,1.31888,-1.80225,0.145743,1.3446,-2.01527},
/*1258*/{0.273719,1.91577,-1.70895,0.323356,1.84744,-1.86388,0.255273,1.75585,-1.59581,0.24575,1.63464,-1.51844,0.361691,1.67529,-1.62101,0.439967,1.69424,-1.66213,0.214684,1.93076,-2.0827,0.319049,1.85117,-1.939,0.106957,1.8959,-1.9681,-0.032655,1.83767,-2.12053,-0.0637,1.75194,-2.17742,0.064336,1.61275,-2.13466,0.095566,1.55812,-2.15803,0.216105,1.39557,-1.76529,0.037408,1.48679,-1.85156,0.042719,1.51267,-1.89552,0.044806,1.49474,-1.96815,0.231107,1.4366,-2.02337,0.088045,1.09562,-1.7332,-0.038849,1.14079,-1.75428,-0.067324,1.063,-1.77815,-0.065571,0.931715,-1.76648,-0.135053,0.752556,-1.75973,-0.169444,0.687091,-1.77113,-0.232111,0.805725,-1.78191,-0.265533,0.742466,-1.78909,-0.340136,0.510038,-1.80014,-0.449742,0.519336,-1.88701,-0.24166,0.377995,-1.85465,-0.295211,0.347522,-1.78798,0.361634,1.23637,-2.0808,0.420282,1.17868,-2.05802,0.260774,1.13515,-2.06163,0.318796,1.0802,-2.04174,0.431945,1.01953,-2.03901,0.390697,0.830656,-2.03869,0.292573,0.886945,-2.04917,0.261093,0.823577,-2.04275,0.171896,0.604624,-2.02162,0.070041,0.550133,-1.95511,0.340655,0.483642,-2.00977,0.276989,0.462327,-2.07037,0.13042,1.32091,-1.80351,0.146405,1.34895,-2.01632},
/*1259*/{0.274672,1.91874,-1.71035,0.32461,1.85128,-1.86467,0.257977,1.75878,-1.59524,0.24829,1.63711,-1.51758,0.362857,1.6796,-1.62185,0.440875,1.69955,-1.66465,0.215068,1.93344,-2.08242,0.319357,1.85421,-1.93963,0.107808,1.89869,-1.96714,-0.032053,1.84243,-2.11801,-0.065862,1.75756,-2.17453,0.062816,1.6183,-2.13385,0.093391,1.56373,-2.1578,0.217463,1.39686,-1.76676,0.039261,1.49006,-1.85153,0.043545,1.51594,-1.89474,0.0472,1.49886,-1.96801,0.230649,1.43993,-2.02303,0.085403,1.09919,-1.73154,-0.042838,1.14723,-1.75809,-0.071675,1.0692,-1.78035,-0.07128,0.937461,-1.76615,-0.141734,0.759566,-1.75827,-0.177881,0.693637,-1.76908,-0.238903,0.812649,-1.78034,-0.27181,0.750426,-1.78784,-0.349413,0.519482,-1.79693,-0.459327,0.536696,-1.88347,-0.259906,0.379152,-1.85389,-0.31556,0.351529,-1.78758,0.361766,1.23949,-2.07904,0.420341,1.18149,-2.05678,0.259691,1.13877,-2.06193,0.318124,1.08328,-2.04304,0.430839,1.02101,-2.03957,0.399496,0.829752,-2.03809,0.297812,0.88127,-2.04754,0.270533,0.816735,-2.04182,0.188772,0.589487,-2.01535,0.094562,0.531793,-1.95289,0.369067,0.482535,-2.00884,0.306749,0.457452,-2.06924,0.130909,1.32307,-1.80478,0.146392,1.35273,-2.0174},
/*1260*/{0.277066,1.92112,-1.71084,0.325329,1.85448,-1.86617,0.259785,1.76227,-1.59647,0.251507,1.63972,-1.51676,0.364689,1.68374,-1.62324,0.441896,1.7041,-1.66718,0.215304,1.93616,-2.08222,0.319721,1.8573,-1.94008,0.108532,1.90074,-1.96666,-0.031902,1.84775,-2.11419,-0.067098,1.76301,-2.17203,0.061494,1.6228,-2.13258,0.091705,1.56811,-2.15807,0.218996,1.39855,-1.76711,0.041812,1.49302,-1.84995,0.044976,1.51919,-1.89336,0.048943,1.50275,-1.96735,0.231996,1.44331,-2.02353,0.083149,1.1033,-1.73065,-0.044285,1.15271,-1.75732,-0.074604,1.07533,-1.78168,-0.075563,0.943196,-1.76662,-0.147418,0.765279,-1.75715,-0.184282,0.699738,-1.76713,-0.244594,0.819672,-1.77884,-0.27869,0.756652,-1.78514,-0.359538,0.527474,-1.79456,-0.466746,0.553248,-1.87869,-0.278225,0.381469,-1.85287,-0.336027,0.356249,-1.78798,0.362132,1.24219,-2.07798,0.419897,1.18341,-2.05532,0.25916,1.14211,-2.06293,0.317289,1.0856,-2.04482,0.430191,1.02131,-2.04008,0.407522,0.83034,-2.03915,0.303549,0.874077,-2.04726,0.278389,0.80849,-2.03991,0.209619,0.577811,-2.01368,0.118697,0.515841,-1.95358,0.396464,0.482895,-2.00708,0.334785,0.453565,-2.06753,0.132362,1.32532,-1.80537,0.147106,1.35649,-2.01783},
/*1261*/{0.277591,1.92361,-1.7114,0.326753,1.85796,-1.86655,0.261993,1.76471,-1.59657,0.254099,1.64286,-1.51699,0.365562,1.68659,-1.62459,0.442855,1.70791,-1.66941,0.215834,1.939,-2.08179,0.320208,1.85907,-1.94062,0.109289,1.9028,-1.96539,-0.030632,1.85237,-2.11145,-0.068269,1.76796,-2.16952,0.060046,1.62725,-2.13235,0.090287,1.5723,-2.15765,0.221074,1.40015,-1.76791,0.043086,1.49581,-1.84937,0.045872,1.52224,-1.89256,0.050242,1.50686,-1.96647,0.231655,1.44642,-2.02382,0.07999,1.1071,-1.72854,-0.044681,1.15752,-1.75949,-0.076996,1.07942,-1.78225,-0.077778,0.947933,-1.76645,-0.151541,0.770844,-1.75627,-0.189344,0.706283,-1.7653,-0.247653,0.826731,-1.77548,-0.283042,0.764109,-1.78097,-0.368719,0.535457,-1.79072,-0.472495,0.570977,-1.8728,-0.296943,0.383902,-1.85332,-0.355084,0.362755,-1.78813,0.361774,1.24407,-2.07651,0.419137,1.18444,-2.05431,0.257796,1.14472,-2.06358,0.313069,1.08689,-2.04502,0.428061,1.02093,-2.04082,0.415146,0.82663,-2.03919,0.309398,0.867413,-2.04603,0.287872,0.800156,-2.0383,0.23131,0.567603,-2.01271,0.14404,0.49604,-1.95024,0.422613,0.482166,-2.00455,0.36461,0.450357,-2.06516,0.133366,1.3276,-1.80614,0.146903,1.36004,-2.01849},
/*1262*/{0.279411,1.92587,-1.71208,0.32808,1.8605,-1.86756,0.264366,1.76758,-1.59654,0.256643,1.64512,-1.51592,0.365722,1.68952,-1.62587,0.443099,1.71119,-1.67153,0.216482,1.94096,-2.08185,0.321163,1.86219,-1.94174,0.111402,1.90429,-1.96562,-0.030361,1.85632,-2.10803,-0.069148,1.77244,-2.16745,0.059652,1.631,-2.13145,0.08949,1.57566,-2.15744,0.221897,1.40243,-1.76835,0.043976,1.49952,-1.84847,0.046825,1.5254,-1.89173,0.051017,1.50952,-1.9652,0.232314,1.44977,-2.02345,0.07717,1.11027,-1.72783,-0.045678,1.16275,-1.76116,-0.077154,1.08383,-1.78324,-0.079123,0.951513,-1.76737,-0.154788,0.775323,-1.75598,-0.194566,0.711188,-1.76534,-0.249806,0.832296,-1.77439,-0.286882,0.771982,-1.77856,-0.375055,0.545377,-1.78717,-0.478155,0.588739,-1.86709,-0.315973,0.388696,-1.85377,-0.375919,0.368949,-1.78952,0.36182,1.24511,-2.07533,0.417527,1.18487,-2.05376,0.255971,1.14608,-2.06417,0.312795,1.08753,-2.04588,0.426375,1.0199,-2.04174,0.421243,0.82311,-2.03907,0.313484,0.859787,-2.0449,0.295556,0.792068,-2.03744,0.255819,0.557998,-2.01157,0.168082,0.480087,-1.94847,0.447212,0.483228,-2.00131,0.391161,0.447071,-2.06291,0.134113,1.3303,-1.80606,0.147181,1.36338,-2.01834},
/*1263*/{0.280727,1.92747,-1.71272,0.328388,1.86307,-1.86831,0.266096,1.76979,-1.59696,0.258694,1.64712,-1.51612,0.367199,1.6921,-1.62634,0.443387,1.71332,-1.67365,0.216824,1.94347,-2.08137,0.322428,1.86443,-1.94205,0.112226,1.90608,-1.96519,-0.029836,1.85899,-2.10568,-0.069407,1.77571,-2.16465,0.059734,1.63436,-2.13099,0.088476,1.57844,-2.15724,0.22311,1.40463,-1.76903,0.046072,1.50128,-1.8477,0.048055,1.52816,-1.89118,0.052019,1.51322,-1.96432,0.23218,1.45245,-2.0231,0.076131,1.11384,-1.7269,-0.047376,1.16379,-1.76226,-0.077628,1.08633,-1.78506,-0.078418,0.954339,-1.7679,-0.156622,0.778977,-1.75573,-0.196719,0.716965,-1.76364,-0.251622,0.838823,-1.77092,-0.28928,0.779016,-1.77522,-0.382796,0.554515,-1.78404,-0.483306,0.606443,-1.85994,-0.334544,0.395833,-1.85484,-0.395655,0.37768,-1.79091,0.360195,1.24463,-2.07417,0.415744,1.18372,-2.05323,0.253594,1.14715,-2.06471,0.310046,1.08765,-2.04624,0.424692,1.01759,-2.04198,0.424704,0.819694,-2.03901,0.317957,0.852902,-2.04482,0.302473,0.784028,-2.0369,0.27678,0.547784,-2.00982,0.19201,0.466649,-1.94909,0.4717,0.485225,-1.99857,0.418538,0.444463,-2.0589,0.1352,1.3325,-1.80636,0.147383,1.36641,-2.01856},
/*1264*/{0.282422,1.92917,-1.71276,0.329644,1.86545,-1.8684,0.2674,1.77204,-1.59661,0.25903,1.64801,-1.51588,0.368231,1.69333,-1.62707,0.443542,1.71481,-1.67532,0.216942,1.94518,-2.08112,0.323451,1.86621,-1.94252,0.11293,1.90788,-1.96541,-0.025565,1.86158,-2.10527,-0.069655,1.77862,-2.16307,0.05942,1.63666,-2.13027,0.08784,1.58078,-2.15707,0.223974,1.40696,-1.76933,0.046729,1.50419,-1.848,0.04853,1.53116,-1.89143,0.05212,1.51572,-1.9635,0.233133,1.45505,-2.02312,0.077477,1.11691,-1.72635,-0.047618,1.1656,-1.76439,-0.076583,1.08846,-1.78392,-0.077101,0.955851,-1.76851,-0.158337,0.781675,-1.75607,-0.200572,0.720712,-1.76393,-0.250974,0.844267,-1.76879,-0.291797,0.784848,-1.77228,-0.389291,0.563601,-1.78029,-0.487878,0.623742,-1.85134,-0.352198,0.404769,-1.85813,-0.413144,0.386645,-1.79408,0.358106,1.24365,-2.07372,0.413287,1.18181,-2.05252,0.250588,1.14722,-2.06483,0.305342,1.08831,-2.04881,0.422376,1.01547,-2.04364,0.43335,0.81928,-2.03802,0.322149,0.845065,-2.04501,0.310078,0.776487,-2.03739,0.29497,0.538491,-2.00824,0.214784,0.451817,-1.94594,0.494156,0.486004,-1.99428,0.442201,0.441282,-2.05694,0.135795,1.3351,-1.80647,0.147841,1.36914,-2.01865},
/*1265*/{0.283553,1.93084,-1.71307,0.329877,1.8678,-1.86944,0.268666,1.77302,-1.59618,0.260981,1.6496,-1.51581,0.369023,1.69466,-1.62836,0.443763,1.71603,-1.67668,0.218754,1.94658,-2.08099,0.323791,1.86744,-1.9431,0.113889,1.91026,-1.96457,-0.026501,1.86356,-2.10274,-0.069394,1.78096,-2.16127,0.058608,1.63915,-2.13026,0.087661,1.58253,-2.15703,0.225717,1.40969,-1.76929,0.04835,1.50602,-1.84746,0.050094,1.53378,-1.8907,0.051317,1.51838,-1.96315,0.233303,1.45699,-2.0228,0.078417,1.11849,-1.72676,-0.044829,1.16829,-1.76379,-0.073918,1.08833,-1.78557,-0.074741,0.956879,-1.76962,-0.158726,0.785012,-1.75628,-0.20222,0.724255,-1.76338,-0.249438,0.849812,-1.76574,-0.292033,0.791517,-1.76951,-0.395694,0.571947,-1.77842,-0.492087,0.640877,-1.84199,-0.371261,0.413677,-1.86181,-0.431691,0.396296,-1.79655,0.355619,1.24172,-2.07303,0.410474,1.17914,-2.05232,0.247508,1.14599,-2.06535,0.301478,1.08692,-2.04954,0.419459,1.01195,-2.04443,0.437164,0.815881,-2.03826,0.325459,0.836958,-2.04501,0.316657,0.767911,-2.03743,0.313752,0.529174,-2.00695,0.237696,0.440201,-1.94377,0.514341,0.486582,-1.99148,0.466623,0.43893,-2.05155,0.137216,1.33768,-1.80582,0.148011,1.37121,-2.01815},
/*1266*/{0.285224,1.93169,-1.71307,0.331411,1.86926,-1.86984,0.269297,1.77453,-1.59614,0.261976,1.65081,-1.51592,0.369055,1.69455,-1.62921,0.443798,1.71674,-1.67891,0.219604,1.94827,-2.08093,0.324777,1.86904,-1.94348,0.114928,1.91128,-1.96547,-0.024832,1.86586,-2.10036,-0.069238,1.78272,-2.15941,0.058674,1.63985,-2.12995,0.086839,1.58361,-2.15725,0.226165,1.41174,-1.76918,0.048623,1.50835,-1.84695,0.049156,1.53571,-1.8899,0.051874,1.5203,-1.96246,0.232981,1.45891,-2.02242,0.080855,1.11929,-1.72782,-0.043958,1.16604,-1.7637,-0.072298,1.0889,-1.78404,-0.070466,0.95742,-1.76968,-0.158382,0.786052,-1.75659,-0.206729,0.726953,-1.76488,-0.246845,0.855109,-1.76378,-0.291329,0.798166,-1.76697,-0.402627,0.583424,-1.77702,-0.497417,0.657301,-1.8333,-0.38925,0.425871,-1.86597,-0.446991,0.409125,-1.79845,0.35312,1.23882,-2.07336,0.407865,1.17503,-2.05237,0.244391,1.14461,-2.06593,0.297237,1.08374,-2.04797,0.416484,1.00827,-2.04498,0.441158,0.813567,-2.03892,0.328182,0.828296,-2.04449,0.32339,0.75918,-2.03693,0.332129,0.521246,-2.00539,0.258875,0.430501,-1.94148,0.533809,0.485842,-1.98718,0.489019,0.435401,-2.04651,0.13746,1.33977,-1.80527,0.147769,1.37318,-2.01764},
/*1267*/{0.286705,1.9324,-1.71351,0.332351,1.87084,-1.8705,0.270251,1.77549,-1.59705,0.262194,1.65084,-1.51611,0.369819,1.69455,-1.63026,0.443459,1.71481,-1.68084,0.220551,1.94968,-2.08129,0.326237,1.87019,-1.94401,0.116964,1.91281,-1.96483,-0.023525,1.86671,-2.09924,-0.069052,1.78357,-2.15829,0.059812,1.64089,-2.12956,0.087124,1.58426,-2.15712,0.226647,1.41372,-1.76951,0.049422,1.50988,-1.84613,0.048989,1.53794,-1.8904,0.053791,1.5203,-1.96091,0.233739,1.46043,-2.02219,0.084569,1.11951,-1.72935,-0.04013,1.16518,-1.76331,-0.068626,1.08812,-1.78584,-0.065666,0.956434,-1.77005,-0.158,0.786693,-1.7578,-0.207521,0.729879,-1.76559,-0.243877,0.859439,-1.76071,-0.289071,0.804492,-1.76358,-0.410435,0.594398,-1.77621,-0.503543,0.673618,-1.82466,-0.404824,0.439116,-1.87041,-0.460969,0.42257,-1.80106,0.351202,1.23539,-2.07294,0.403334,1.1708,-2.05268,0.23986,1.14261,-2.06643,0.292781,1.08092,-2.0481,0.412393,1.00329,-2.04572,0.44457,0.810807,-2.03852,0.330252,0.821099,-2.04702,0.32915,0.751166,-2.03706,0.349016,0.513392,-2.00351,0.279055,0.421614,-1.9384,0.552314,0.486729,-1.98353,0.509096,0.432033,-2.04149,0.138542,1.34145,-1.80461,0.148617,1.37442,-2.01707},
/*1268*/{0.287562,1.93245,-1.71388,0.332172,1.87178,-1.87108,0.269983,1.7757,-1.59723,0.262194,1.65084,-1.51611,0.369792,1.69337,-1.63153,0.443775,1.71313,-1.68159,0.221925,1.95037,-2.08144,0.32706,1.87046,-1.94419,0.117546,1.91431,-1.96504,-0.022322,1.86742,-2.09752,-0.068363,1.78411,-2.15655,0.0613,1.64079,-2.12912,0.087154,1.58345,-2.15728,0.227155,1.41592,-1.76895,0.04905,1.51143,-1.84576,0.049652,1.53912,-1.88912,0.053325,1.5212,-1.96068,0.233255,1.46145,-2.02218,0.089775,1.11857,-1.73,-0.036488,1.16311,-1.76198,-0.06333,1.08579,-1.78638,-0.060855,0.954576,-1.77112,-0.156347,0.787262,-1.75856,-0.208577,0.733063,-1.76663,-0.239369,0.863626,-1.75852,-0.287922,0.811267,-1.76195,-0.416139,0.605373,-1.77533,-0.508869,0.689144,-1.81596,-0.420139,0.454105,-1.87394,-0.472761,0.43628,-1.80303,0.347131,1.23094,-2.07368,0.399741,1.16598,-2.05268,0.235781,1.1402,-2.06666,0.286247,1.07806,-2.04799,0.407778,0.998219,-2.04604,0.446794,0.808245,-2.03836,0.332678,0.812315,-2.0472,0.333813,0.741705,-2.03667,0.364395,0.506626,-2.00211,0.296716,0.414116,-1.93588,0.569324,0.486787,-1.98023,0.52868,0.42916,-2.03678,0.139073,1.34326,-1.80353,0.148317,1.3753,-2.01617},
/*1269*/{0.289059,1.93263,-1.71366,0.331845,1.87301,-1.87162,0.269837,1.77574,-1.59755,0.26076,1.65016,-1.51651,0.370334,1.69189,-1.63219,0.444145,1.71107,-1.68274,0.223029,1.95105,-2.08146,0.328062,1.87115,-1.94409,0.11902,1.9152,-1.96471,-0.021892,1.86771,-2.09563,-0.067603,1.78424,-2.1559,0.061628,1.6402,-2.12917,0.087382,1.58249,-2.15757,0.227888,1.41788,-1.76856,0.048923,1.5119,-1.84658,0.049133,1.54091,-1.89,0.054007,1.52195,-1.96017,0.233648,1.46262,-2.02185,0.095706,1.11721,-1.73214,-0.031822,1.16089,-1.7605,-0.058769,1.08274,-1.78567,-0.054158,0.951885,-1.77131,-0.155058,0.787179,-1.75976,-0.211102,0.734285,-1.76826,-0.234898,0.867507,-1.75621,-0.285192,0.816974,-1.7591,-0.420266,0.618586,-1.77413,-0.514458,0.705336,-1.80815,-0.433604,0.470134,-1.87772,-0.48284,0.450959,-1.80457,0.344295,1.22668,-2.0736,0.395253,1.16028,-2.05329,0.230779,1.1376,-2.06659,0.282137,1.07402,-2.04846,0.402487,0.99294,-2.04635,0.448764,0.806066,-2.03718,0.335087,0.804851,-2.04825,0.340763,0.736033,-2.03704,0.379368,0.500775,-1.99927,0.314776,0.407239,-1.9327,0.583177,0.487182,-1.97735,0.546193,0.427344,-2.03241,0.139722,1.34482,-1.80317,0.149243,1.37629,-2.01588},
/*1270*/{0.290349,1.932,-1.71372,0.333342,1.87361,-1.87241,0.269221,1.77511,-1.59838,0.260075,1.649,-1.51678,0.370299,1.68947,-1.63295,0.443359,1.70747,-1.68399,0.223785,1.95116,-2.08141,0.328484,1.8708,-1.94476,0.120769,1.91667,-1.96518,-0.021486,1.86671,-2.09456,-0.066259,1.78364,-2.15467,0.061842,1.6389,-2.12879,0.088385,1.5813,-2.15776,0.227939,1.41902,-1.76873,0.048988,1.5126,-1.84724,0.049188,1.54129,-1.88992,0.053426,1.52189,-1.96037,0.234556,1.46323,-2.0214,0.101576,1.11594,-1.73521,-0.026565,1.15715,-1.76124,-0.052452,1.07951,-1.78418,-0.047105,0.948346,-1.77215,-0.154393,0.787742,-1.76099,-0.211297,0.738951,-1.77015,-0.229077,0.871739,-1.75463,-0.282327,0.82352,-1.75743,-0.42766,0.630787,-1.77343,-0.519318,0.721388,-1.80139,-0.445187,0.486079,-1.88126,-0.49205,0.466484,-1.80625,0.340884,1.22162,-2.07449,0.390652,1.15496,-2.05417,0.226112,1.13435,-2.06706,0.275866,1.07026,-2.04898,0.396922,0.987652,-2.04671,0.450913,0.80375,-2.03539,0.33766,0.79779,-2.04953,0.344415,0.728421,-2.03788,0.391819,0.495744,-1.99803,0.32992,0.40141,-1.93013,0.596901,0.488149,-1.97343,0.561811,0.425304,-2.02854,0.140146,1.34562,-1.80295,0.149975,1.3767,-2.0157},
/*1271*/{0.291332,1.93118,-1.71367,0.334033,1.87335,-1.87261,0.268177,1.77469,-1.59945,0.259145,1.64807,-1.51826,0.369901,1.68665,-1.63372,0.443415,1.70393,-1.68456,0.225277,1.95101,-2.08178,0.329082,1.87083,-1.94518,0.121501,1.91721,-1.96521,-0.01962,1.86542,-2.09273,-0.06506,1.78205,-2.15393,0.063019,1.63681,-2.12886,0.088889,1.57905,-2.15816,0.229417,1.42004,-1.76822,0.048988,1.5126,-1.84724,0.049188,1.54129,-1.88992,0.053685,1.52071,-1.96045,0.234879,1.46327,-2.02104,0.1094,1.11267,-1.73777,-0.020954,1.1544,-1.75973,-0.046905,1.07568,-1.78369,-0.038487,0.944693,-1.77299,-0.152232,0.788629,-1.76192,-0.212274,0.742152,-1.7702,-0.223575,0.875755,-1.75288,-0.279061,0.831065,-1.75615,-0.432184,0.64478,-1.77199,-0.522838,0.738117,-1.79551,-0.456462,0.503184,-1.88211,-0.501901,0.482937,-1.80689,0.33758,1.21656,-2.07484,0.385717,1.15032,-2.05467,0.221322,1.13048,-2.06644,0.270332,1.06575,-2.04906,0.3912,0.981935,-2.04681,0.452939,0.801296,-2.03358,0.341091,0.791215,-2.05065,0.350239,0.722662,-2.03816,0.403155,0.490983,-1.9966,0.342998,0.395871,-1.92707,0.607976,0.488813,-1.97089,0.576166,0.425067,-2.02346,0.141546,1.34624,-1.80199,0.150926,1.37618,-2.01493},
/*1272*/{0.291916,1.92979,-1.7139,0.33413,1.87297,-1.87317,0.267254,1.77362,-1.59948,0.257585,1.64725,-1.51932,0.368801,1.68304,-1.63482,0.443078,1.69918,-1.68487,0.22671,1.95036,-2.08193,0.330146,1.87075,-1.94523,0.122503,1.91724,-1.96526,-0.017752,1.86387,-2.09242,-0.063577,1.78031,-2.15389,0.064175,1.63402,-2.12889,0.090369,1.57608,-2.15811,0.22971,1.42054,-1.76866,0.049235,1.51163,-1.84606,0.049487,1.54134,-1.89009,0.053527,1.51944,-1.96089,0.235291,1.46313,-2.02075,0.11496,1.10941,-1.74008,-0.014765,1.15018,-1.75834,-0.039473,1.07096,-1.78176,-0.029659,0.940845,-1.77401,-0.150583,0.789749,-1.76216,-0.212671,0.746799,-1.77044,-0.21772,0.879354,-1.75141,-0.275422,0.838119,-1.7553,-0.436231,0.659565,-1.77216,-0.523901,0.755936,-1.79238,-0.465941,0.521245,-1.88088,-0.510835,0.500761,-1.80616,0.333652,1.2107,-2.07453,0.38063,1.14298,-2.05608,0.215894,1.12795,-2.06536,0.264919,1.06106,-2.04936,0.385364,0.976537,-2.04648,0.45348,0.798362,-2.03068,0.342662,0.785666,-2.05091,0.353439,0.717395,-2.03839,0.412534,0.486115,-1.99506,0.353627,0.391804,-1.92599,0.617504,0.490182,-1.96823,0.587076,0.424321,-2.01986,0.142476,1.34616,-1.80162,0.151518,1.37568,-2.01463},
/*1273*/{0.293304,1.92852,-1.71465,0.334192,1.8715,-1.87314,0.266439,1.77222,-1.59987,0.25542,1.64425,-1.51971,0.368053,1.67958,-1.63548,0.443167,1.69354,-1.68558,0.227694,1.94969,-2.08221,0.330382,1.86962,-1.94509,0.124297,1.91703,-1.96609,-0.016541,1.86133,-2.09151,-0.06193,1.77739,-2.15347,0.065666,1.6303,-2.12908,0.091744,1.57287,-2.15835,0.230137,1.42055,-1.76871,0.049482,1.50983,-1.8466,0.051179,1.53968,-1.89033,0.053167,1.51747,-1.96039,0.235671,1.46261,-2.02023,0.122934,1.10626,-1.74259,-0.008202,1.14293,-1.75537,-0.03216,1.06599,-1.78123,-0.019697,0.935814,-1.77454,-0.148219,0.790914,-1.76299,-0.212227,0.751745,-1.77127,-0.210839,0.884145,-1.75031,-0.271107,0.84468,-1.75516,-0.439507,0.676122,-1.77032,-0.523602,0.775216,-1.7914,-0.474016,0.537487,-1.87938,-0.521299,0.519069,-1.80436,0.330828,1.20534,-2.07478,0.376988,1.13667,-2.0561,0.21186,1.1245,-2.06506,0.258796,1.05648,-2.04969,0.379181,0.971198,-2.04636,0.454126,0.796384,-2.02831,0.343797,0.780044,-2.04988,0.355763,0.712714,-2.03832,0.417604,0.48104,-1.99299,0.363802,0.388767,-1.92311,0.624819,0.492173,-1.96545,0.596517,0.423524,-2.01707,0.143826,1.34528,-1.80129,0.152782,1.37445,-2.01435},
/*1274*/{0.29382,1.92674,-1.71433,0.334592,1.87116,-1.87369,0.26587,1.77011,-1.60042,0.253761,1.64262,-1.52129,0.366247,1.67487,-1.63598,0.442398,1.6881,-1.68619,0.229055,1.9486,-2.08224,0.330764,1.86842,-1.94491,0.125006,1.91693,-1.96629,-0.015847,1.85917,-2.09064,-0.059818,1.77445,-2.15295,0.068165,1.62894,-2.12972,0.093375,1.56923,-2.15907,0.230617,1.42017,-1.76855,0.049396,1.50953,-1.84679,0.05057,1.53813,-1.89045,0.052745,1.51587,-1.96123,0.236102,1.46146,-2.02026,0.131643,1.10504,-1.74585,0.000268,1.13954,-1.75344,-0.023283,1.06036,-1.78024,-0.010698,0.929761,-1.77388,-0.144998,0.793603,-1.763,-0.210775,0.756771,-1.77052,-0.2035,0.889495,-1.75039,-0.264709,0.852019,-1.75353,-0.441481,0.69213,-1.76879,-0.520664,0.794963,-1.79227,-0.480476,0.553237,-1.87697,-0.529182,0.539317,-1.80137,0.327735,1.19948,-2.0755,0.372107,1.13052,-2.05725,0.207708,1.12056,-2.06493,0.253142,1.0539,-2.0488,0.373698,0.966279,-2.04629,0.453781,0.793643,-2.02616,0.343853,0.775095,-2.04876,0.357593,0.707724,-2.03624,0.425461,0.479561,-1.99159,0.370553,0.380893,-1.92314,0.629249,0.491835,-1.96534,0.603313,0.422762,-2.01466,0.144263,1.34479,-1.80084,0.153156,1.37303,-2.01403},
/*1275*/{0.293824,1.92372,-1.71453,0.334981,1.86896,-1.8735,0.264509,1.76833,-1.60129,0.250637,1.63939,-1.52194,0.364844,1.67064,-1.63665,0.440947,1.68153,-1.6863,0.230422,1.94753,-2.08237,0.330574,1.8668,-1.94495,0.12519,1.9153,-1.96734,-0.014261,1.8559,-2.09067,-0.05769,1.77052,-2.15316,0.071156,1.62326,-2.12963,0.094726,1.56477,-2.15918,0.231664,1.41956,-1.76841,0.04904,1.50688,-1.84764,0.050449,1.53615,-1.89132,0.053273,1.51365,-1.96148,0.236437,1.46027,-2.02027,0.141052,1.10427,-1.74786,0.005578,1.13266,-1.75259,-0.015631,1.05399,-1.77881,0.000867,0.925995,-1.77725,-0.141029,0.796568,-1.76271,-0.207797,0.761748,-1.7709,-0.195545,0.894399,-1.74953,-0.258759,0.860012,-1.75299,-0.445499,0.709616,-1.7618,-0.517143,0.814984,-1.79432,-0.486494,0.569562,-1.87202,-0.537666,0.559755,-1.79747,0.325259,1.19423,-2.07571,0.370008,1.12315,-2.05714,0.203802,1.11687,-2.06465,0.248481,1.04906,-2.04769,0.368276,0.96063,-2.04523,0.451894,0.791123,-2.0248,0.341341,0.771394,-2.04611,0.357216,0.703416,-2.03364,0.429382,0.476426,-1.99006,0.376582,0.377774,-1.91994,0.633812,0.49023,-1.9629,0.607298,0.421589,-2.01379,0.145535,1.34343,-1.80086,0.154544,1.37127,-2.01409},
/*1276*/{0.294397,1.92189,-1.71526,0.335533,1.86733,-1.87391,0.262079,1.76614,-1.60198,0.247211,1.63705,-1.52353,0.362987,1.66509,-1.63745,0.439412,1.67527,-1.68711,0.231241,1.94541,-2.08274,0.330635,1.86489,-1.94461,0.12636,1.91387,-1.96796,-0.012916,1.85232,-2.09142,-0.055296,1.76637,-2.15348,0.072784,1.61847,-2.13004,0.096968,1.56012,-2.15984,0.231818,1.41898,-1.76885,0.050253,1.50445,-1.84755,0.050305,1.5344,-1.89168,0.053883,1.5107,-1.96193,0.237215,1.45857,-2.02061,0.148024,1.10113,-1.74845,0.011672,1.12659,-1.75108,-0.008699,1.04846,-1.77911,0.010979,0.921009,-1.77759,-0.136882,0.799856,-1.76193,-0.205685,0.768483,-1.76958,-0.187335,0.900579,-1.75006,-0.250926,0.868094,-1.75232,-0.443468,0.725772,-1.76523,-0.511172,0.83485,-1.7971,-0.491463,0.586551,-1.86523,-0.544654,0.580558,-1.79344,0.322789,1.18897,-2.07658,0.366073,1.11723,-2.05798,0.200581,1.11319,-2.06274,0.243685,1.04546,-2.04618,0.362826,0.955961,-2.04456,0.449238,0.788185,-2.0244,0.338332,0.767041,-2.04307,0.354127,0.70007,-2.03134,0.430271,0.473224,-1.98781,0.38,0.374573,-1.91791,0.636216,0.489195,-1.96248,0.608959,0.420593,-2.0133,0.146853,1.34203,-1.80063,0.155663,1.36913,-2.01397},
/*1277*/{0.2952,1.91944,-1.71551,0.336415,1.86472,-1.87402,0.260542,1.76339,-1.60279,0.244414,1.63509,-1.52539,0.36111,1.65913,-1.63734,0.438211,1.66763,-1.68674,0.231441,1.9436,-2.08272,0.330111,1.86298,-1.94435,0.126219,1.91268,-1.96915,-0.011516,1.84782,-2.09167,-0.052591,1.76134,-2.15417,0.075431,1.61297,-2.13085,0.099559,1.5546,-2.16024,0.233207,1.41734,-1.76918,0.050561,1.5022,-1.84818,0.050769,1.53189,-1.89158,0.053914,1.50803,-1.96358,0.237359,1.456,-2.02108,0.155572,1.0974,-1.75079,0.018532,1.12333,-1.75051,-0.000452,1.04255,-1.77827,0.020728,0.915821,-1.77931,-0.131971,0.803637,-1.76114,-0.202076,0.774594,-1.76773,-0.179258,0.905009,-1.75085,-0.243936,0.876553,-1.75324,-0.439543,0.739698,-1.7699,-0.504191,0.853546,-1.80113,-0.493765,0.602186,-1.85876,-0.550304,0.601586,-1.78814,0.321234,1.18333,-2.07751,0.362265,1.1129,-2.05915,0.197769,1.10988,-2.06197,0.240289,1.04212,-2.04564,0.357451,0.950817,-2.04325,0.44503,0.785115,-2.02424,0.334029,0.762553,-2.03999,0.350941,0.695975,-2.02779,0.43184,0.470649,-1.98586,0.381627,0.372214,-1.9142,0.636589,0.487042,-1.96215,0.610055,0.419248,-2.01347,0.147907,1.34017,-1.80066,0.156199,1.36639,-2.01414},
/*1278*/{0.295705,1.91663,-1.71515,0.335974,1.86247,-1.87401,0.258396,1.76044,-1.60341,0.240522,1.63138,-1.52675,0.358674,1.65331,-1.6381,0.436719,1.65931,-1.68656,0.232358,1.94116,-2.08269,0.330705,1.86113,-1.94456,0.126274,1.91047,-1.97077,-0.01047,1.84367,-2.09275,-0.050083,1.75562,-2.15539,0.077448,1.60816,-2.13254,0.102398,1.54902,-2.16089,0.233798,1.4158,-1.76945,0.050917,1.49921,-1.8482,0.050902,1.52914,-1.89098,0.054082,1.50524,-1.96357,0.237616,1.45315,-2.02202,0.162047,1.09409,-1.75136,0.02636,1.11689,-1.75037,0.007728,1.03625,-1.77766,0.029905,0.910911,-1.77971,-0.126499,0.806987,-1.76055,-0.19779,0.780901,-1.7661,-0.169359,0.910862,-1.75207,-0.236235,0.884215,-1.75418,-0.436721,0.757565,-1.76829,-0.496046,0.871586,-1.80625,-0.495267,0.617588,-1.8523,-0.553213,0.622984,-1.78322,0.319823,1.17889,-2.07862,0.36002,1.10818,-2.06047,0.194958,1.10814,-2.06124,0.236955,1.03926,-2.04393,0.353737,0.946834,-2.04229,0.440167,0.781519,-2.02349,0.329556,0.758244,-2.03754,0.347166,0.691206,-2.02465,0.430195,0.467257,-1.98352,0.381441,0.367545,-1.91125,0.635718,0.484766,-1.96267,0.608264,0.416176,-2.01349,0.14898,1.33797,-1.80043,0.156461,1.36355,-2.01401},
/*1279*/{0.294592,1.91317,-1.71525,0.33596,1.85926,-1.87352,0.256524,1.75676,-1.60303,0.236379,1.62808,-1.52802,0.355969,1.64704,-1.63864,0.434394,1.65082,-1.68621,0.233133,1.93832,-2.08289,0.330623,1.85821,-1.94478,0.126074,1.90859,-1.97188,-0.008912,1.83809,-2.09327,-0.047409,1.74967,-2.15623,0.080117,1.60168,-2.13325,0.104902,1.54252,-2.16213,0.234635,1.4143,-1.77012,0.050575,1.49644,-1.84949,0.052147,1.52553,-1.89333,0.05434,1.50168,-1.9649,0.237066,1.4498,-2.02338,0.168468,1.09099,-1.75205,0.031762,1.10897,-1.74776,0.015752,1.03021,-1.7769,0.038736,0.906295,-1.77988,-0.121193,0.810396,-1.75938,-0.192831,0.786012,-1.76551,-0.159692,0.916322,-1.75274,-0.226645,0.892137,-1.7544,-0.432169,0.774219,-1.76491,-0.486324,0.888586,-1.81059,-0.495341,0.632828,-1.84572,-0.554497,0.643798,-1.77769,0.317643,1.17477,-2.08031,0.35948,1.10179,-2.06075,0.192918,1.1059,-2.06004,0.233834,1.0367,-2.04315,0.350338,0.94303,-2.04116,0.434813,0.777535,-2.0232,0.324659,0.75402,-2.03577,0.342878,0.687143,-2.02294,0.426714,0.463814,-1.98121,0.378886,0.364114,-1.90833,0.632587,0.480732,-1.96319,0.603854,0.413098,-2.01344,0.149903,1.33591,-1.80068,0.156941,1.35973,-2.01447},
/*1280*/{0.294661,1.90989,-1.71429,0.335929,1.85651,-1.87332,0.254255,1.75292,-1.60339,0.232271,1.6247,-1.52965,0.352928,1.64043,-1.63875,0.431564,1.64206,-1.68607,0.232134,1.93501,-2.08292,0.331047,1.85601,-1.94413,0.126204,1.90557,-1.97138,-0.006585,1.8325,-2.09487,-0.045123,1.74271,-2.15809,0.083009,1.59468,-2.1351,0.108155,1.53604,-2.16284,0.235722,1.4124,-1.7717,0.050415,1.49308,-1.84926,0.050763,1.52286,-1.89366,0.052795,1.49905,-1.96603,0.236868,1.44684,-2.02413,0.174243,1.08787,-1.75208,0.037374,1.10443,-1.74769,0.022473,1.02449,-1.77678,0.047013,0.90223,-1.77952,-0.114457,0.814636,-1.75771,-0.187047,0.792631,-1.76312,-0.149491,0.920932,-1.75471,-0.21729,0.899301,-1.75417,-0.429861,0.792518,-1.75785,-0.476281,0.903889,-1.81503,-0.493215,0.647511,-1.83952,-0.552326,0.663136,-1.77321,0.316238,1.1706,-2.08143,0.35628,1.09716,-2.0615,0.190746,1.1031,-2.05862,0.230961,1.03389,-2.04151,0.348116,0.94002,-2.04052,0.43118,0.773465,-2.02252,0.32041,0.749661,-2.03364,0.338417,0.683043,-2.02067,0.421441,0.458848,-1.97907,0.37455,0.360609,-1.90572,0.627107,0.476048,-1.96344,0.599902,0.408723,-2.01315,0.150687,1.33357,-1.80118,0.156485,1.35691,-2.01507},
/*1281*/{0.294202,1.90522,-1.71363,0.336315,1.85238,-1.87274,0.251776,1.74942,-1.60408,0.227617,1.62154,-1.53086,0.349205,1.63315,-1.63863,0.429955,1.63288,-1.68523,0.23288,1.93147,-2.08343,0.331479,1.85273,-1.94363,0.125687,1.90201,-1.97322,-0.006645,1.8263,-2.09708,-0.042492,1.7351,-2.15951,0.086229,1.5887,-2.13683,0.111409,1.52901,-2.16377,0.236017,1.41004,-1.7719,0.050669,1.48992,-1.85045,0.052383,1.51941,-1.89421,0.05198,1.49535,-1.96619,0.237397,1.44386,-2.02528,0.178867,1.08559,-1.75166,0.043081,1.09912,-1.748,0.029431,1.01872,-1.77641,0.055583,0.898346,-1.77878,-0.107561,0.817247,-1.75774,-0.180018,0.798755,-1.76286,-0.138226,0.925798,-1.75578,-0.207044,0.906772,-1.75537,-0.42273,0.807607,-1.75671,-0.465208,0.918214,-1.81841,-0.490612,0.661601,-1.83334,-0.549097,0.68163,-1.76803,0.314379,1.16652,-2.08278,0.354036,1.0933,-2.06325,0.188676,1.10094,-2.05738,0.228051,1.03097,-2.04072,0.345487,0.936377,-2.03931,0.425138,0.768515,-2.0255,0.315483,0.745355,-2.03327,0.333266,0.678728,-2.01886,0.417875,0.455482,-1.97669,0.370058,0.355931,-1.90161,0.622333,0.47018,-1.96289,0.594375,0.402714,-2.01193,0.151577,1.33079,-1.80146,0.15709,1.35355,-2.01542},
/*1282*/{0.293479,1.90192,-1.71386,0.336383,1.84951,-1.87256,0.248479,1.74513,-1.60423,0.223434,1.61838,-1.53281,0.345086,1.62568,-1.63858,0.426027,1.6232,-1.68535,0.232664,1.92765,-2.08383,0.331874,1.84972,-1.94372,0.125537,1.89858,-1.97447,-0.005787,1.81896,-2.09936,-0.039723,1.72731,-2.16155,0.089456,1.58133,-2.13864,0.115027,1.52196,-2.16483,0.236221,1.40794,-1.77259,0.050523,1.48615,-1.85011,0.05337,1.51563,-1.89448,0.052724,1.49178,-1.96628,0.236961,1.44136,-2.02591,0.18383,1.08357,-1.75134,0.048694,1.09371,-1.74749,0.037219,1.01363,-1.77558,0.064874,0.895344,-1.7776,-0.099219,0.821279,-1.7554,-0.173442,0.804199,-1.75943,-0.127146,0.929681,-1.75638,-0.196151,0.913269,-1.75671,-0.414322,0.822948,-1.75788,-0.454082,0.931694,-1.82163,-0.485486,0.675192,-1.82717,-0.544231,0.698714,-1.76275,0.31264,1.1624,-2.08423,0.351071,1.08896,-2.064,0.186275,1.09892,-2.05706,0.225331,1.02766,-2.03965,0.343336,0.933011,-2.03828,0.420456,0.763334,-2.02536,0.310546,0.740869,-2.03247,0.328057,0.673097,-2.01791,0.410549,0.450671,-1.97549,0.361549,0.352937,-1.89861,0.616963,0.462073,-1.96124,0.586393,0.393956,-2.00923,0.152753,1.32783,-1.80172,0.157708,1.35051,-2.0157},
/*1283*/{0.293197,1.89795,-1.7133,0.337337,1.84507,-1.8724,0.246245,1.74088,-1.60476,0.216699,1.61475,-1.53468,0.341143,1.61887,-1.639,0.42214,1.61297,-1.68375,0.232281,1.92321,-2.08432,0.331764,1.84607,-1.94364,0.125208,1.89503,-1.97645,-0.005068,1.8113,-2.102,-0.037606,1.71909,-2.16322,0.093742,1.5739,-2.14022,0.119426,1.51401,-2.16594,0.236829,1.40545,-1.77337,0.051462,1.48216,-1.84957,0.051656,1.51152,-1.89523,0.052095,1.48704,-1.96589,0.236736,1.43837,-2.02689,0.18964,1.07984,-1.75021,0.05442,1.08925,-1.74763,0.043837,1.00717,-1.77512,0.072553,0.892037,-1.7767,-0.091765,0.824562,-1.75312,-0.166326,0.809678,-1.75809,-0.115812,0.933878,-1.75941,-0.18646,0.918766,-1.75862,-0.404403,0.835467,-1.75554,-0.443325,0.943712,-1.82475,-0.47993,0.687166,-1.82236,-0.535648,0.71483,-1.75727,0.310754,1.15814,-2.08531,0.34894,1.0844,-2.06504,0.184024,1.09537,-2.05649,0.222887,1.02405,-2.03948,0.341986,0.92991,-2.03801,0.417376,0.757397,-2.02153,0.306492,0.736342,-2.03051,0.323578,0.669282,-2.01755,0.403037,0.443808,-1.97321,0.35189,0.350435,-1.89656,0.610115,0.452216,-1.95875,0.576861,0.384717,-2.00715,0.154284,1.32469,-1.80179,0.157964,1.34681,-2.01585},
/*1284*/{0.291399,1.89408,-1.71263,0.336931,1.84123,-1.87097,0.243111,1.73618,-1.6048,0.211342,1.61016,-1.53526,0.336286,1.61026,-1.63872,0.417894,1.6026,-1.68285,0.232132,1.91859,-2.08483,0.331931,1.84281,-1.94412,0.124854,1.88977,-1.97762,-0.003254,1.80299,-2.10414,-0.034289,1.7103,-2.16547,0.097728,1.56577,-2.14245,0.123543,1.50621,-2.1669,0.23794,1.40291,-1.77401,0.051977,1.47807,-1.84961,0.052332,1.50767,-1.89492,0.052017,1.48256,-1.96564,0.237549,1.43566,-2.02777,0.194088,1.07778,-1.74888,0.057133,1.08287,-1.74922,0.04981,1.00204,-1.77617,0.081332,0.888203,-1.77526,-0.082699,0.827367,-1.75194,-0.158621,0.814554,-1.75584,-0.104171,0.936595,-1.76105,-0.174652,0.924631,-1.75997,-0.396725,0.847091,-1.75637,-0.43303,0.95484,-1.82661,-0.472254,0.699134,-1.81809,-0.528262,0.728958,-1.75396,0.30869,1.15362,-2.08575,0.346731,1.0798,-2.06566,0.181782,1.0918,-2.05587,0.22032,1.02089,-2.03937,0.339213,0.925548,-2.03728,0.412234,0.750766,-2.02214,0.30089,0.731089,-2.03052,0.31735,0.664192,-2.01665,0.393491,0.438196,-1.97247,0.34088,0.346517,-1.89344,0.600919,0.442072,-1.95613,0.567752,0.374179,-2.00336,0.156291,1.32141,-1.80203,0.159128,1.34349,-2.01612},
/*1285*/{0.290377,1.88941,-1.71207,0.338184,1.83736,-1.87041,0.238726,1.73149,-1.60497,0.204636,1.60711,-1.53702,0.331732,1.60234,-1.63883,0.413351,1.59198,-1.68139,0.232476,1.91381,-2.08578,0.332443,1.83849,-1.94354,0.123929,1.88502,-1.97821,-0.003602,1.79398,-2.10641,-0.03175,1.70114,-2.16843,0.101531,1.55741,-2.14483,0.128085,1.49819,-2.16803,0.238415,1.39994,-1.77429,0.051169,1.4731,-1.84908,0.052764,1.50356,-1.89509,0.051387,1.47733,-1.9649,0.237449,1.4324,-2.02863,0.199546,1.07373,-1.74325,0.061902,1.07865,-1.75012,0.056484,0.99711,-1.77633,0.090747,0.885629,-1.77243,-0.073693,0.830188,-1.7492,-0.148794,0.819541,-1.75384,-0.091642,0.939574,-1.76267,-0.162848,0.928369,-1.76154,-0.384296,0.858362,-1.75518,-0.421704,0.965033,-1.82886,-0.464499,0.709402,-1.81335,-0.519078,0.742065,-1.7498,0.30761,1.14918,-2.08658,0.344762,1.07539,-2.06642,0.17949,1.08853,-2.05547,0.218193,1.01692,-2.03974,0.336403,0.920557,-2.03711,0.407004,0.744468,-2.02132,0.295411,0.726141,-2.02978,0.310833,0.658187,-2.01636,0.38452,0.434888,-1.96956,0.32491,0.35357,-1.89432,0.59028,0.430801,-1.95322,0.553836,0.36406,-1.99989,0.157607,1.31764,-1.80201,0.15959,1.33954,-2.01612},
/*1286*/{0.290173,1.88529,-1.71072,0.337964,1.83234,-1.86952,0.236687,1.72605,-1.60452,0.198797,1.60227,-1.53711,0.327028,1.59507,-1.63829,0.408495,1.58166,-1.67974,0.232644,1.90881,-2.08687,0.333314,1.83448,-1.94343,0.123313,1.88035,-1.97951,-0.002903,1.78464,-2.10947,-0.028886,1.69146,-2.17023,0.105378,1.54902,-2.14726,0.133287,1.48998,-2.16936,0.239458,1.39692,-1.77526,0.052056,1.46789,-1.84931,0.052152,1.49858,-1.8959,0.050812,1.4725,-1.96432,0.23729,1.42934,-2.02993,0.201969,1.07268,-1.74341,0.065885,1.07511,-1.75184,0.062833,0.99208,-1.77656,0.099552,0.882005,-1.76898,-0.065427,0.83151,-1.74747,-0.14065,0.823273,-1.75178,-0.078921,0.94178,-1.76415,-0.150785,0.932999,-1.76337,-0.372873,0.867102,-1.75358,-0.411073,0.973336,-1.82969,-0.455038,0.719488,-1.80998,-0.508429,0.753695,-1.74466,0.305663,1.14482,-2.08701,0.342849,1.07062,-2.06726,0.177911,1.08411,-2.05505,0.215935,1.01215,-2.03935,0.333074,0.915264,-2.03735,0.400722,0.737629,-2.02069,0.288793,0.720927,-2.03001,0.303232,0.653093,-2.01652,0.374513,0.430077,-1.96943,0.306206,0.352729,-1.89534,0.578106,0.417183,-1.94979,0.535936,0.352834,-1.99691,0.159677,1.31374,-1.80274,0.160354,1.33569,-2.01685},
/*1287*/{0.288316,1.87961,-1.71056,0.338895,1.82737,-1.86872,0.233598,1.72125,-1.60466,0.191648,1.5983,-1.53854,0.321737,1.58659,-1.63824,0.403242,1.57068,-1.67836,0.233144,1.90345,-2.08791,0.334073,1.83044,-1.94337,0.122256,1.8742,-1.98113,-0.001901,1.77517,-2.11336,-0.025101,1.68187,-2.17306,0.110014,1.53977,-2.14974,0.138391,1.48117,-2.17002,0.239717,1.39354,-1.77656,0.052093,1.46327,-1.84906,0.051405,1.49372,-1.89583,0.049887,1.46746,-1.96339,0.237496,1.42634,-2.03078,0.205597,1.06855,-1.7403,0.070727,1.06939,-1.75318,0.070064,0.985402,-1.77704,0.108631,0.878661,-1.76676,-0.054344,0.833529,-1.74504,-0.129457,0.826772,-1.7496,-0.06683,0.943247,-1.7667,-0.137688,0.936306,-1.76511,-0.36293,0.87615,-1.75455,-0.399503,0.981654,-1.83147,-0.444176,0.727125,-1.80609,-0.496691,0.763022,-1.74141,0.303786,1.14006,-2.08822,0.340556,1.06578,-2.06855,0.176231,1.07889,-2.05503,0.214253,1.00779,-2.03923,0.329585,0.908807,-2.03759,0.395137,0.731413,-2.02029,0.282387,0.715377,-2.03055,0.296157,0.648136,-2.01665,0.360089,0.423543,-1.96883,0.287317,0.355777,-1.8932,0.564549,0.399888,-1.94749,0.518643,0.340243,-1.99595,0.161066,1.30966,-1.80333,0.160697,1.33204,-2.0174},
/*1288*/{0.286159,1.87532,-1.7094,0.33859,1.82309,-1.86826,0.229045,1.71625,-1.60568,0.185764,1.59467,-1.53955,0.314996,1.57855,-1.63773,0.396742,1.56033,-1.67644,0.23363,1.89755,-2.08924,0.333762,1.82575,-1.94359,0.121168,1.86929,-1.98295,0.000689,1.76493,-2.11629,-0.021695,1.67168,-2.17537,0.116198,1.53098,-2.15179,0.144821,1.47296,-2.17086,0.239695,1.38973,-1.77762,0.051128,1.45841,-1.84789,0.051364,1.48867,-1.89539,0.049416,1.46287,-1.96252,0.23737,1.42228,-2.03215,0.207614,1.06362,-1.73745,0.074343,1.06407,-1.75471,0.074063,0.980285,-1.77755,0.117886,0.875899,-1.76544,-0.043476,0.835566,-1.74289,-0.118702,0.830368,-1.74806,-0.053971,0.943792,-1.76847,-0.125429,0.939069,-1.76657,-0.350613,0.88358,-1.75489,-0.387606,0.988123,-1.83297,-0.432922,0.734871,-1.80358,-0.484719,0.771389,-1.73757,0.301267,1.13595,-2.08945,0.339095,1.06089,-2.06983,0.173843,1.07488,-2.05568,0.212237,1.00376,-2.0395,0.325785,0.902504,-2.03817,0.387958,0.723832,-2.01933,0.27588,0.710199,-2.03021,0.287497,0.6421,-2.01661,0.343201,0.420194,-1.96355,0.266735,0.351502,-1.89086,0.550815,0.388155,-1.93502,0.498704,0.341819,-1.995,0.161839,1.30522,-1.80368,0.160293,1.32786,-2.01771},
/*1289*/{0.285167,1.8708,-1.7084,0.339186,1.81706,-1.86702,0.224978,1.71131,-1.60646,0.177932,1.5912,-1.54075,0.309045,1.57106,-1.63725,0.391495,1.55019,-1.67502,0.234336,1.89203,-2.09074,0.335341,1.82075,-1.9431,0.121542,1.86313,-1.98491,0.002224,1.75493,-2.12047,-0.01807,1.6614,-2.17851,0.121131,1.52254,-2.15336,0.152763,1.46552,-2.17161,0.240541,1.38572,-1.77793,0.050707,1.4529,-1.84702,0.05149,1.48331,-1.8952,0.048116,1.45753,-1.9618,0.236733,1.41784,-2.03441,0.213216,1.06046,-1.73394,0.078518,1.05806,-1.75561,0.080788,0.97365,-1.7777,0.126498,0.87306,-1.76139,-0.032832,0.835797,-1.74031,-0.108839,0.832459,-1.74529,-0.039359,0.945262,-1.76894,-0.111666,0.940919,-1.76769,-0.337506,0.890083,-1.75283,-0.375458,0.994171,-1.83326,-0.421647,0.740551,-1.79934,-0.471741,0.779216,-1.73528,0.29836,1.13151,-2.09121,0.336129,1.0569,-2.07284,0.172209,1.07136,-2.05605,0.209822,0.99942,-2.03989,0.321902,0.896557,-2.03948,0.381805,0.71659,-2.01586,0.268702,0.705833,-2.0301,0.27792,0.63806,-2.01577,0.327862,0.420377,-1.95717,0.244191,0.35364,-1.89312,0.526847,0.386068,-1.93451,0.476248,0.34229,-1.99463,0.163211,1.30062,-1.80397,0.159815,1.32301,-2.01802},
/*1290*/{0.284126,1.86607,-1.70738,0.339498,1.81245,-1.86605,0.220399,1.7064,-1.60663,0.17104,1.58762,-1.5411,0.302362,1.56336,-1.63646,0.384189,1.53964,-1.67255,0.235121,1.88678,-2.09188,0.336472,1.81634,-1.94258,0.120575,1.85609,-1.9863,0.002658,1.7446,-2.12483,-0.013364,1.65059,-2.18109,0.127512,1.51391,-2.15512,0.151644,1.45652,-2.17271,0.241268,1.38118,-1.77894,0.050372,1.44854,-1.846,0.05021,1.47836,-1.89497,0.04648,1.45343,-1.96155,0.236127,1.41311,-2.03574,0.217427,1.05825,-1.72979,0.08226,1.04946,-1.75624,0.086926,0.96708,-1.77904,0.136281,0.872151,-1.75251,-0.020816,0.837132,-1.73845,-0.097202,0.834054,-1.74354,-0.026662,0.944169,-1.77174,-0.097976,0.942774,-1.76896,-0.323233,0.895378,-1.75369,-0.362823,0.998393,-1.83476,-0.40882,0.745659,-1.79703,-0.45832,0.785018,-1.73183,0.294974,1.12859,-2.0956,0.333334,1.05421,-2.07678,0.168869,1.06861,-2.05613,0.207656,0.997276,-2.03964,0.316486,0.890253,-2.04072,0.374463,0.709692,-2.01194,0.262366,0.703946,-2.02944,0.26833,0.63534,-2.01194,0.307301,0.422379,-1.95168,0.222038,0.35215,-1.88714,0.500301,0.386772,-1.93146,0.45232,0.34276,-1.99416,0.163467,1.29614,-1.8044,0.158472,1.3185,-2.01842},
/*1291*/{0.282149,1.86139,-1.70666,0.34054,1.80679,-1.86501,0.216453,1.70267,-1.60729,0.164137,1.58416,-1.54226,0.295284,1.55575,-1.6354,0.377232,1.53026,-1.67069,0.236254,1.88158,-2.09413,0.336458,1.81094,-1.94283,0.120049,1.85076,-1.98772,0.00735,1.73328,-2.12834,-0.008669,1.63958,-2.18375,0.134584,1.50485,-2.15553,0.166206,1.4496,-2.1727,0.240729,1.37665,-1.78072,0.047689,1.44316,-1.84643,0.048271,1.47264,-1.89455,0.042873,1.44962,-1.96137,0.234418,1.40892,-2.0373,0.22144,1.05448,-1.72673,0.087508,1.04541,-1.75755,0.094095,0.961046,-1.77779,0.146355,0.868774,-1.75205,-0.008825,0.836981,-1.73726,-0.084405,0.835513,-1.73852,-0.011695,0.944625,-1.77112,-0.083737,0.943069,-1.76938,-0.309729,0.899492,-1.75359,-0.350334,1.00144,-1.83556,-0.395046,0.749418,-1.79336,-0.444266,0.789754,-1.72878,0.291981,1.12641,-2.09972,0.330125,1.05173,-2.0816,0.16647,1.06838,-2.05655,0.204309,0.996879,-2.03963,0.310442,0.885391,-2.04144,0.368581,0.70717,-2.0076,0.257146,0.705626,-2.02634,0.258983,0.638466,-2.00783,0.280046,0.422087,-1.94864,0.198005,0.354796,-1.88846,0.480928,0.382878,-1.92929,0.429777,0.342448,-1.99234,0.162642,1.29119,-1.80587,0.156246,1.31443,-2.01975},
/*1292*/{0.281477,1.85742,-1.70528,0.341997,1.80101,-1.86498,0.212071,1.69882,-1.60827,0.156344,1.58101,-1.54319,0.288337,1.54921,-1.63386,0.369024,1.52144,-1.66852,0.237103,1.8762,-2.09576,0.338728,1.8062,-1.94176,0.121253,1.84762,-1.9882,0.009028,1.72359,-2.13481,-0.002937,1.62899,-2.18605,0.141767,1.49723,-2.15649,0.174431,1.4424,-2.17239,0.240546,1.37176,-1.78231,0.046961,1.43879,-1.84565,0.046149,1.46711,-1.89358,0.03997,1.44564,-1.9612,0.231489,1.40608,-2.0385,0.223821,1.05206,-1.7247,0.09085,1.03822,-1.75916,0.102035,0.954365,-1.77882,0.157006,0.866857,-1.75231,0.003979,0.836462,-1.73457,-0.071341,0.836207,-1.73811,0.001854,0.942602,-1.77183,-0.070335,0.943049,-1.76958,-0.296519,0.902279,-1.7532,-0.337037,1.00388,-1.83681,-0.38054,0.75265,-1.79023,-0.430397,0.793579,-1.72577,0.288309,1.12481,-2.10578,0.326598,1.05031,-2.08618,0.16422,1.06905,-2.05659,0.202422,0.997617,-2.04064,0.305456,0.885574,-2.04268,0.361154,0.707114,-2.00524,0.249587,0.711135,-2.02353,0.248912,0.643563,-2.00481,0.26229,0.424008,-1.94639,0.175652,0.355109,-1.88451,0.457857,0.382638,-1.92893,0.406328,0.342669,-1.99254,0.162418,1.28635,-1.80741,0.153817,1.31105,-2.02105},
/*1293*/{0.280326,1.85361,-1.70445,0.342487,1.79605,-1.86326,0.206915,1.6956,-1.60802,0.147669,1.5794,-1.54472,0.281209,1.54313,-1.6333,0.361212,1.5132,-1.66647,0.238426,1.87188,-2.0981,0.339514,1.80134,-1.94151,0.122457,1.84552,-1.98828,0.013603,1.71263,-2.14022,0.003308,1.61757,-2.1885,0.150815,1.49164,-2.15691,0.183914,1.43558,-2.17265,0.239295,1.36702,-1.78393,0.044796,1.43453,-1.84478,0.043652,1.46288,-1.8931,0.036882,1.44252,-1.95982,0.228851,1.40341,-2.04026,0.226741,1.04835,-1.72208,0.097927,1.03165,-1.75824,0.109057,0.948024,-1.77969,0.16782,0.864724,-1.74875,0.01757,0.834929,-1.73347,-0.057939,0.835337,-1.73628,0.01714,0.941388,-1.77156,-0.054687,0.943302,-1.76724,-0.283008,0.904604,-1.75355,-0.323419,1.0047,-1.83734,-0.365579,0.753072,-1.78831,-0.414345,0.794978,-1.72351,0.285165,1.12392,-2.10831,0.324612,1.04999,-2.08794,0.161986,1.06874,-2.05703,0.201284,0.997473,-2.0398,0.303697,0.886568,-2.04335,0.351782,0.706331,-2.00446,0.239179,0.716563,-2.02206,0.234973,0.647936,-2.0041,0.246011,0.427384,-1.94309,0.153793,0.35734,-1.88344,0.436288,0.381176,-1.92598,0.384846,0.343368,-1.98959,0.161038,1.28175,-1.80912,0.150665,1.30832,-2.02245},
/*1294*/{0.280284,1.84987,-1.70245,0.343389,1.79282,-1.8624,0.201242,1.69401,-1.60878,0.140048,1.57869,-1.54615,0.272728,1.53759,-1.63216,0.351988,1.50659,-1.66389,0.239163,1.86791,-2.10006,0.341142,1.79698,-1.94086,0.122482,1.84414,-1.9881,0.01828,1.7032,-2.14585,0.010759,1.60763,-2.19122,0.159796,1.48537,-2.15593,0.194551,1.42961,-2.17161,0.238641,1.36313,-1.78735,0.042379,1.43023,-1.84417,0.042317,1.46047,-1.8921,0.033819,1.44001,-1.95848,0.22651,1.40225,-2.04215,0.230151,1.04805,-1.72181,0.100969,1.0258,-1.76119,0.117517,0.942315,-1.77974,0.178061,0.861829,-1.74694,0.031661,0.833403,-1.73186,-0.04435,0.834297,-1.7349,0.031611,0.940108,-1.77002,-0.04005,0.942156,-1.76656,-0.268612,0.904834,-1.75219,-0.310798,1.00449,-1.83838,-0.349937,0.754104,-1.78397,-0.398637,0.795662,-1.72136,0.281053,1.12331,-2.109,0.320808,1.05001,-2.08938,0.159338,1.06722,-2.05564,0.199043,0.996651,-2.03954,0.303807,0.887969,-2.04304,0.341311,0.706115,-2.00615,0.228709,0.721321,-2.0213,0.222221,0.653513,-2.0042,0.223581,0.427261,-1.94183,0.132336,0.3588,-1.8809,0.415879,0.379366,-1.92583,0.363085,0.343162,-1.98876,0.160374,1.27774,-1.81192,0.147697,1.30713,-2.02476},
/*1295*/{0.279966,1.8477,-1.70143,0.344661,1.78926,-1.86173,0.197067,1.69272,-1.60935,0.13036,1.57908,-1.54783,0.26401,1.53349,-1.63169,0.343228,1.49944,-1.66188,0.241182,1.86431,-2.10082,0.341177,1.79311,-1.94014,0.123534,1.84285,-1.98776,0.022969,1.6938,-2.15081,0.018888,1.59743,-2.19369,0.169357,1.4802,-2.15578,0.20564,1.42536,-2.17059,0.236897,1.35932,-1.78889,0.040448,1.4277,-1.84273,0.039973,1.45979,-1.89152,0.033067,1.43751,-1.95549,0.224131,1.40138,-2.04397,0.236282,1.0498,-1.71987,0.107541,1.02162,-1.76042,0.127413,0.93827,-1.77915,0.190131,0.861078,-1.74553,0.045243,0.832018,-1.73075,-0.030564,0.833147,-1.73608,0.046003,0.938906,-1.7685,-0.025087,0.941994,-1.7661,-0.25414,0.904044,-1.75157,-0.297921,1.00334,-1.83881,-0.333737,0.752434,-1.78197,-0.383495,0.794449,-1.7183,0.276704,1.12336,-2.1098,0.317237,1.04917,-2.09068,0.155741,1.06551,-2.05434,0.195883,0.995598,-2.03895,0.305585,0.889677,-2.04324,0.329153,0.705528,-2.0093,0.21663,0.72375,-2.02126,0.208909,0.655851,-2.00426,0.203986,0.42767,-1.94119,0.11122,0.360612,-1.8797,0.394826,0.379176,-1.92503,0.341041,0.343142,-1.98857,0.158717,1.2745,-1.81345,0.144511,1.30623,-2.02587},
/*1296*/{0.280537,1.84497,-1.70099,0.343431,1.78629,-1.86122,0.191832,1.69257,-1.60917,0.122067,1.58126,-1.54981,0.255265,1.53074,-1.63067,0.334045,1.49435,-1.65895,0.242339,1.86122,-2.1011,0.341265,1.79041,-1.9396,0.123209,1.84186,-1.98745,0.029661,1.68602,-2.15488,0.026815,1.58882,-2.19522,0.180245,1.47604,-2.15456,0.217207,1.42147,-2.1697,0.235463,1.35593,-1.7899,0.039408,1.42516,-1.84023,0.039315,1.45881,-1.89046,0.031559,1.43746,-1.95392,0.222429,1.40122,-2.04596,0.241845,1.05227,-1.71988,0.113106,1.01774,-1.75943,0.135721,0.936862,-1.77774,0.204677,0.860377,-1.7439,0.058642,0.830572,-1.72962,-0.016076,0.832122,-1.73556,0.060543,0.938152,-1.76644,-0.011227,0.939964,-1.76425,-0.237678,0.903616,-1.75186,-0.286208,1.00051,-1.83905,-0.316797,0.749679,-1.78013,-0.366313,0.791762,-1.71655,0.272044,1.12086,-2.11058,0.311924,1.047,-2.09185,0.151122,1.06469,-2.05363,0.191432,0.994221,-2.03873,0.305682,0.890208,-2.04267,0.316678,0.703487,-2.01263,0.20471,0.72406,-2.02244,0.195425,0.656701,-2.00278,0.18482,0.429212,-1.94072,0.090223,0.362332,-1.88065,0.373077,0.378116,-1.92467,0.319735,0.343401,-1.98774,0.157332,1.27157,-1.81538,0.141737,1.30637,-2.02721},
/*1297*/{0.280916,1.84154,-1.70023,0.344203,1.78469,-1.86011,0.187109,1.69258,-1.60929,0.113234,1.58395,-1.55158,0.246646,1.52855,-1.62984,0.323857,1.48914,-1.65637,0.243222,1.85954,-2.10036,0.341545,1.78857,-1.93921,0.123562,1.84097,-1.98756,0.034197,1.67887,-2.15685,0.036093,1.58176,-2.1964,0.191176,1.47306,-2.15322,0.229539,1.41835,-2.16762,0.234207,1.35332,-1.7917,0.038237,1.42396,-1.83838,0.038622,1.4585,-1.89074,0.030386,1.43724,-1.95092,0.220852,1.40077,-2.04767,0.248877,1.0545,-1.71957,0.120888,1.01509,-1.75749,0.146781,0.936817,-1.77557,0.218348,0.861199,-1.7424,0.073748,0.82944,-1.72878,-0.001952,0.831333,-1.73607,0.075105,0.937646,-1.76471,0.00292,0.939387,-1.76399,-0.225384,0.901151,-1.75121,-0.275027,0.99655,-1.83892,-0.298477,0.746417,-1.77717,-0.348392,0.786597,-1.7145,0.266922,1.1185,-2.1109,0.306532,1.04356,-2.09288,0.147274,1.06143,-2.05106,0.185537,0.993212,-2.03762,0.302468,0.890121,-2.04184,0.303739,0.700959,-2.0154,0.192865,0.724725,-2.02292,0.181659,0.657127,-2.00264,0.164131,0.429043,-1.9406,0.068406,0.362183,-1.87965,0.351928,0.377765,-1.92489,0.2984,0.342585,-1.9877,0.155911,1.26951,-1.81686,0.138796,1.30636,-2.02822},
/*1298*/{0.282644,1.83944,-1.70003,0.344578,1.78304,-1.86036,0.181683,1.69391,-1.60983,0.105551,1.58789,-1.55342,0.237176,1.52758,-1.62892,0.313553,1.4852,-1.65402,0.245269,1.85854,-2.09965,0.342108,1.78711,-1.93871,0.124147,1.84063,-1.98751,0.040507,1.67257,-2.15869,0.045727,1.57635,-2.19771,0.202819,1.4706,-2.1516,0.242028,1.41743,-2.16564,0.232431,1.35094,-1.79188,0.036823,1.42407,-1.83694,0.036611,1.45839,-1.89045,0.029455,1.43738,-1.94909,0.219173,1.40059,-2.04878,0.256193,1.05779,-1.71936,0.128352,1.01483,-1.756,0.157582,0.936541,-1.77355,0.233765,0.8635,-1.7421,0.087408,0.828701,-1.72857,0.011689,0.829576,-1.73497,0.088488,0.937349,-1.76326,0.01707,0.938692,-1.76328,-0.210018,0.897681,-1.75133,-0.265645,0.991736,-1.83898,-0.280587,0.740504,-1.77627,-0.331384,0.780329,-1.71234,0.261359,1.11483,-2.11153,0.299971,1.04004,-2.09386,0.14046,1.06032,-2.05138,0.178828,0.991056,-2.03696,0.294734,0.887188,-2.04273,0.291452,0.696795,-2.01597,0.1811,0.724433,-2.02441,0.167335,0.658088,-2.00442,0.148222,0.43114,-1.94167,0.04691,0.363808,-1.88102,0.331334,0.376421,-1.92473,0.276526,0.34239,-1.98841,0.153572,1.26812,-1.81755,0.135963,1.30654,-2.0286},
/*1299*/{0.28314,1.83722,-1.69973,0.344514,1.78144,-1.86007,0.175891,1.69584,-1.61163,0.096165,1.59261,-1.55593,0.227697,1.52839,-1.62847,0.304307,1.48373,-1.65152,0.24678,1.85745,-2.09879,0.341624,1.7856,-1.93802,0.124382,1.84057,-1.98769,0.04842,1.66837,-2.15895,0.054007,1.57076,-2.198,0.213989,1.46986,-2.15003,0.255231,1.41812,-2.16311,0.230659,1.34889,-1.7922,0.036118,1.42427,-1.83701,0.035621,1.45815,-1.89,0.028101,1.43793,-1.94737,0.217816,1.40046,-2.04979,0.265314,1.06157,-1.71878,0.139422,1.01649,-1.75336,0.16764,0.937089,-1.77208,0.249217,0.86449,-1.73913,0.102192,0.829347,-1.72832,0.026548,0.82913,-1.73418,0.101911,0.937432,-1.76172,0.030249,0.938305,-1.76258,-0.196328,0.89265,-1.75114,-0.256096,0.985522,-1.83768,-0.262175,0.733585,-1.77558,-0.312376,0.771936,-1.70974,0.255217,1.11224,-2.11236,0.29323,1.03666,-2.09496,0.135675,1.05915,-2.05052,0.17211,0.986735,-2.03496,0.286056,0.883548,-2.04449,0.278614,0.691628,-2.016,0.171045,0.722753,-2.02574,0.153787,0.655714,-2.00526,0.124918,0.431728,-1.94311,0.026311,0.364019,-1.88208,0.309685,0.375749,-1.92502,0.255363,0.342658,-1.98916,0.151444,1.26688,-1.81851,0.133513,1.30685,-2.02923},
/*1300*/{0.283555,1.8365,-1.69932,0.342557,1.78055,-1.85912,0.171787,1.69784,-1.61098,0.087391,1.59947,-1.55895,0.219458,1.5278,-1.62717,0.293527,1.48223,-1.64917,0.24804,1.85733,-2.09796,0.342133,1.78441,-1.93746,0.125202,1.84033,-1.98808,0.054611,1.66514,-2.16016,0.063062,1.56687,-2.19898,0.225456,1.47042,-2.14736,0.267931,1.4208,-2.15991,0.230046,1.3479,-1.79208,0.036072,1.42499,-1.83682,0.035512,1.45862,-1.89026,0.028323,1.43845,-1.94725,0.217099,1.40083,-2.05065,0.272697,1.06519,-1.71989,0.149755,1.01725,-1.75177,0.179815,0.938378,-1.76921,0.263234,0.868353,-1.73989,0.115952,0.82939,-1.7275,0.042421,0.828332,-1.73507,0.114192,0.938164,-1.76043,0.042136,0.938466,-1.7614,-0.187527,0.889568,-1.75207,-0.247688,0.977861,-1.83805,-0.242091,0.726549,-1.77429,-0.292384,0.762627,-1.70876,0.250595,1.10889,-2.1135,0.285905,1.0326,-2.09611,0.128627,1.05814,-2.05068,0.165597,0.984876,-2.03566,0.276249,0.878395,-2.04505,0.265657,0.687219,-2.01551,0.157805,0.72008,-2.02675,0.139466,0.654289,-2.00685,0.107011,0.432149,-1.94324,0.004974,0.364537,-1.88254,0.289076,0.376198,-1.92688,0.233506,0.341709,-1.98999,0.150464,1.26662,-1.81913,0.132545,1.30732,-2.02972},
/*1301*/{0.28271,1.83615,-1.69928,0.343291,1.78026,-1.85825,0.166654,1.70037,-1.61163,0.077987,1.6049,-1.56116,0.209973,1.52975,-1.62603,0.283433,1.48163,-1.64711,0.24871,1.85667,-2.09696,0.342096,1.78413,-1.93638,0.125539,1.84034,-1.98904,0.059513,1.66218,-2.16006,0.072022,1.56362,-2.19947,0.236898,1.47229,-2.14501,0.28144,1.42429,-2.1562,0.22912,1.34742,-1.79157,0.03557,1.42557,-1.83672,0.034675,1.45859,-1.89128,0.028086,1.4393,-1.94772,0.217422,1.40067,-2.05156,0.281587,1.07096,-1.71726,0.15785,1.01817,-1.74981,0.19159,0.940832,-1.7676,0.277775,0.871738,-1.74144,0.130273,0.830085,-1.72697,0.055593,0.82713,-1.73457,0.126432,0.939234,-1.75865,0.054092,0.937763,-1.75989,-0.174399,0.883086,-1.75356,-0.239733,0.96913,-1.83679,-0.221563,0.718247,-1.77386,-0.271958,0.752568,-1.7061,0.24546,1.10597,-2.11341,0.279603,1.0286,-2.09607,0.12256,1.05801,-2.05227,0.156742,0.984373,-2.03694,0.266025,0.874092,-2.04534,0.2527,0.682539,-2.01444,0.145099,0.717511,-2.02707,0.125858,0.651719,-2.00734,0.085136,0.43265,-1.94545,-0.016043,0.365593,-1.88264,0.266618,0.375757,-1.92788,0.212096,0.341798,-1.99076,0.149261,1.26659,-1.81942,0.132108,1.30744,-2.03005},
/*1302*/{0.28152,1.83592,-1.69909,0.342804,1.78041,-1.85814,0.161715,1.70425,-1.61239,0.069449,1.61095,-1.56247,0.201156,1.53247,-1.62524,0.273973,1.4821,-1.64471,0.251117,1.85751,-2.09679,0.342012,1.78425,-1.93607,0.126588,1.84106,-1.99032,0.064741,1.65981,-2.16049,0.080915,1.56116,-2.20024,0.247868,1.4747,-2.14187,0.29387,1.42951,-2.15263,0.227217,1.34829,-1.78995,0.03496,1.42623,-1.83698,0.03442,1.45951,-1.89152,0.028243,1.4399,-1.94865,0.216325,1.40013,-2.05221,0.28858,1.07632,-1.71859,0.168509,1.02002,-1.74687,0.202578,0.943547,-1.76594,0.292658,0.874782,-1.74211,0.144795,0.832097,-1.72697,0.070157,0.82611,-1.73587,0.137408,0.941017,-1.7579,0.065589,0.936128,-1.75787,-0.157753,0.872595,-1.75436,-0.231546,0.958665,-1.83605,-0.20065,0.709229,-1.774,-0.251418,0.740967,-1.70535,0.240518,1.10337,-2.11311,0.27182,1.02512,-2.09621,0.11619,1.05841,-2.05294,0.14904,0.983286,-2.03753,0.254175,0.86969,-2.04521,0.238676,0.678083,-2.01293,0.131831,0.715067,-2.02748,0.110706,0.649613,-2.00818,0.064764,0.432366,-1.94623,-0.036454,0.36644,-1.88398,0.24635,0.375598,-1.92861,0.19086,0.341525,-1.99144,0.147683,1.26743,-1.81855,0.131268,1.30711,-2.02945},
/*1303*/{0.279985,1.83694,-1.69831,0.341474,1.78019,-1.85722,0.156165,1.70838,-1.61347,0.061358,1.61723,-1.56436,0.192591,1.5352,-1.62385,0.263636,1.48357,-1.64264,0.253057,1.85935,-2.09669,0.342202,1.78502,-1.93479,0.126752,1.84101,-1.99094,0.070003,1.65734,-2.16078,0.089841,1.5598,-2.2003,0.25876,1.4795,-2.13888,0.306574,1.43594,-2.148,0.226816,1.34946,-1.78968,0.034528,1.42717,-1.83739,0.033784,1.45982,-1.89183,0.027646,1.44068,-1.9501,0.21652,1.39988,-2.05243,0.297831,1.08215,-1.71755,0.178069,1.0237,-1.74578,0.214158,0.947124,-1.76477,0.305378,0.879304,-1.74116,0.157737,0.833591,-1.72801,0.083228,0.825609,-1.73554,0.147869,0.941849,-1.75598,0.076581,0.93542,-1.75681,-0.144193,0.863741,-1.75351,-0.223578,0.947169,-1.83543,-0.179177,0.699353,-1.77463,-0.228912,0.729309,-1.70346,0.235181,1.10094,-2.11277,0.264215,1.02174,-2.09614,0.108304,1.0593,-2.05432,0.14025,0.983985,-2.03905,0.241123,0.864444,-2.04463,0.223404,0.674234,-2.01226,0.117745,0.713467,-2.02848,0.094869,0.649821,-2.00965,0.046291,0.434316,-1.94671,-0.058472,0.366371,-1.88555,0.224952,0.375338,-1.92925,0.169622,0.340759,-1.99215,0.14718,1.26845,-1.81816,0.131205,1.30709,-2.0293},
/*1304*/{0.278327,1.83862,-1.69751,0.341232,1.78124,-1.85557,0.149974,1.71388,-1.61396,0.053686,1.62389,-1.56527,0.184364,1.53899,-1.62246,0.253696,1.48631,-1.64094,0.255303,1.86158,-2.0965,0.342251,1.78641,-1.93385,0.127146,1.84119,-1.99174,0.074789,1.65571,-2.16078,0.097633,1.55878,-2.20018,0.269486,1.48527,-2.13552,0.319362,1.4439,-2.14396,0.226793,1.35171,-1.79001,0.033647,1.42805,-1.83944,0.0333,1.46042,-1.89233,0.026937,1.44066,-1.95158,0.215771,1.39961,-2.05367,0.304115,1.08956,-1.71869,0.18749,1.02712,-1.74405,0.225363,0.952028,-1.76341,0.319332,0.884905,-1.74159,0.173028,0.835023,-1.72801,0.097088,0.825021,-1.7359,0.157998,0.943468,-1.75504,0.086547,0.933998,-1.75601,-0.128926,0.85469,-1.75361,-0.215284,0.934722,-1.83627,-0.156727,0.690495,-1.77315,-0.206974,0.717657,-1.70207,0.229027,1.09896,-2.11234,0.257156,1.01892,-2.09561,0.101483,1.05924,-2.05499,0.131525,0.983307,-2.0398,0.227565,0.860674,-2.04452,0.207485,0.670798,-2.01152,0.102494,0.711615,-2.02857,0.078879,0.646584,-2.00921,0.02582,0.435332,-1.94637,-0.080258,0.367249,-1.88537,0.203774,0.375644,-1.92852,0.148962,0.341531,-1.99301,0.147275,1.27008,-1.818,0.130979,1.30676,-2.02946},
/*1305*/{0.275845,1.84055,-1.6968,0.339972,1.78233,-1.85448,0.144308,1.71875,-1.61409,0.046514,1.63073,-1.56728,0.174828,1.5434,-1.62154,0.244257,1.48927,-1.63893,0.257014,1.86462,-2.09522,0.342506,1.78763,-1.93283,0.127506,1.84149,-1.99264,0.079905,1.65482,-2.16037,0.106306,1.55856,-2.2006,0.279497,1.49203,-2.1325,0.330947,1.4525,-2.13944,0.225839,1.35439,-1.7892,0.033353,1.42923,-1.84086,0.033757,1.46147,-1.89347,0.027279,1.44131,-1.9528,0.215852,1.39929,-2.05418,0.313365,1.0965,-1.71777,0.1957,1.0304,-1.74323,0.23604,0.957486,-1.76137,0.331874,0.891268,-1.74163,0.186036,0.836262,-1.72899,0.111532,0.822655,-1.7375,0.167506,0.944813,-1.75369,0.09653,0.932426,-1.75436,-0.116163,0.846323,-1.75583,-0.206663,0.920572,-1.83628,-0.134139,0.680019,-1.77236,-0.184751,0.704552,-1.70173,0.223143,1.09673,-2.11236,0.248663,1.01597,-2.09483,0.09493,1.0615,-2.05546,0.12032,0.986836,-2.04233,0.212976,0.857121,-2.04403,0.19103,0.668388,-2.01129,0.086829,0.711144,-2.02822,0.063372,0.648697,-2.00945,0.003557,0.435782,-1.94759,-0.09971,0.368202,-1.88375,0.182827,0.375305,-1.92959,0.127814,0.340792,-1.9925,0.146999,1.27207,-1.81705,0.131477,1.30656,-2.02893},
/*1306*/{0.272634,1.84288,-1.69612,0.338911,1.78417,-1.85251,0.1387,1.72416,-1.6144,0.037902,1.63757,-1.56868,0.167043,1.54881,-1.6212,0.235045,1.49307,-1.63741,0.257167,1.86764,-2.09436,0.34303,1.78976,-1.93149,0.127729,1.84196,-1.99346,0.084614,1.65456,-2.15987,0.114175,1.55901,-2.20044,0.28933,1.50002,-2.12914,0.34205,1.46261,-2.13466,0.225675,1.35711,-1.78879,0.032888,1.43074,-1.84219,0.034265,1.46212,-1.89541,0.027653,1.44221,-1.95528,0.216282,1.39949,-2.05423,0.318379,1.10527,-1.71966,0.203607,1.03569,-1.74287,0.246373,0.962646,-1.7614,0.343511,0.900201,-1.74086,0.199898,0.838168,-1.72989,0.126257,0.821777,-1.73753,0.176486,0.94578,-1.75268,0.106306,0.930575,-1.75416,-0.101585,0.837051,-1.75589,-0.197747,0.905719,-1.8364,-0.111982,0.669865,-1.77257,-0.163379,0.691997,-1.7008,0.217102,1.09438,-2.1113,0.239963,1.01408,-2.09379,0.087039,1.06285,-2.05593,0.111591,0.984922,-2.04129,0.197528,0.854294,-2.04337,0.174346,0.668514,-2.0103,0.071424,0.711729,-2.02778,0.045677,0.649394,-2.00957,-0.017495,0.43726,-1.94796,-0.12099,0.36969,-1.88741,0.162088,0.374981,-1.92993,0.106872,0.341253,-1.9924,0.147074,1.27424,-1.81653,0.132626,1.30667,-2.02881},
/*1307*/{0.269785,1.84651,-1.69574,0.338861,1.78728,-1.85157,0.13322,1.72948,-1.61496,0.030445,1.6439,-1.57017,0.158575,1.55498,-1.62133,0.226333,1.49727,-1.63704,0.258243,1.87084,-2.09384,0.342982,1.79248,-1.92964,0.127596,1.84364,-1.9942,0.090083,1.65388,-2.15949,0.122885,1.55978,-2.20072,0.298297,1.50765,-2.12553,0.352798,1.47291,-2.1299,0.224981,1.35961,-1.78785,0.033245,1.43168,-1.84443,0.035259,1.46383,-1.89581,0.028308,1.4436,-1.95681,0.215573,1.40023,-2.05554,0.324167,1.11321,-1.72042,0.212329,1.04047,-1.74219,0.256041,0.968751,-1.76026,0.355329,0.908925,-1.74162,0.213171,0.839562,-1.72998,0.140912,0.819875,-1.73709,0.184124,0.946513,-1.75219,0.113992,0.928167,-1.75343,-0.088014,0.827398,-1.756,-0.189136,0.889797,-1.83793,-0.089428,0.65963,-1.77239,-0.14154,0.679996,-1.70072,0.210093,1.094,-2.11015,0.231235,1.01178,-2.09226,0.07832,1.06473,-2.05571,0.10155,0.986655,-2.04092,0.181895,0.853456,-2.04252,0.157494,0.666619,-2.00894,0.054964,0.712588,-2.02628,0.028213,0.651008,-2.00904,-0.034666,0.438465,-1.94717,-0.141472,0.371671,-1.88826,0.141356,0.373997,-1.92995,0.08659,0.341443,-1.99269,0.146953,1.27621,-1.81652,0.132943,1.3074,-2.02902},
/*1308*/{0.266156,1.84894,-1.69434,0.337771,1.7908,-1.84935,0.12752,1.73548,-1.61541,0.023497,1.65136,-1.57187,0.151567,1.56092,-1.62117,0.217216,1.50345,-1.63581,0.259466,1.87499,-2.09323,0.343208,1.79554,-1.92789,0.128095,1.8448,-1.99507,0.093775,1.65425,-2.15933,0.130663,1.56173,-2.20103,0.30621,1.51559,-2.12128,0.362247,1.4844,-2.1252,0.224978,1.36271,-1.78725,0.034284,1.43323,-1.84665,0.035224,1.46629,-1.89776,0.029172,1.44545,-1.95854,0.216403,1.4004,-2.05629,0.333686,1.12189,-1.71773,0.219716,1.04489,-1.74144,0.266239,0.974802,-1.76076,0.367092,0.917677,-1.7422,0.226337,0.841411,-1.73032,0.155551,0.818691,-1.73873,0.192625,0.946951,-1.75032,0.123913,0.924591,-1.75204,-0.073527,0.815103,-1.75613,-0.178323,0.873173,-1.83891,-0.065664,0.64958,-1.77171,-0.118673,0.666731,-1.69979,0.204127,1.09326,-2.10865,0.222041,1.01056,-2.09048,0.070218,1.06814,-2.05644,0.090172,0.989263,-2.04104,0.166171,0.853918,-2.04171,0.1399,0.668177,-2.00695,0.038347,0.714857,-2.02523,0.009931,0.653714,-2.00866,-0.054483,0.440954,-1.94632,-0.16044,0.374532,-1.88716,0.119584,0.374112,-1.929,0.065239,0.341025,-1.99239,0.147003,1.27893,-1.81614,0.133957,1.30803,-2.029},
/*1309*/{0.26274,1.85273,-1.69379,0.33668,1.79366,-1.84778,0.122748,1.74167,-1.61545,0.016209,1.65823,-1.57348,0.142864,1.56851,-1.62306,0.208434,1.50893,-1.63534,0.260195,1.8798,-2.09247,0.342994,1.79924,-1.92591,0.128411,1.84704,-1.99548,0.098713,1.655,-2.15905,0.137892,1.56343,-2.20104,0.314443,1.52528,-2.11786,0.371751,1.49625,-2.11993,0.225876,1.36596,-1.78625,0.034292,1.43613,-1.84863,0.035548,1.46806,-1.89951,0.030308,1.44759,-1.95992,0.218393,1.40084,-2.05554,0.335659,1.12973,-1.71945,0.226075,1.05003,-1.74195,0.274119,0.980437,-1.76068,0.377667,0.926484,-1.7423,0.238602,0.842711,-1.73098,0.167388,0.817792,-1.739,0.200748,0.946555,-1.74883,0.132187,0.922473,-1.75184,-0.059936,0.804707,-1.75825,-0.167476,0.855716,-1.84014,-0.041782,0.639103,-1.77102,-0.096029,0.653286,-1.70005,0.197479,1.09273,-2.10661,0.212957,1.00999,-2.08827,0.063275,1.07113,-2.05604,0.080607,0.991099,-2.04019,0.149875,0.854308,-2.0406,0.122918,0.669701,-2.00644,0.019944,0.717554,-2.02436,-0.006846,0.65359,-2.00676,-0.074921,0.444314,-1.94699,-0.179958,0.377442,-1.88507,0.100523,0.374919,-1.92901,0.044772,0.341644,-1.9923,0.147247,1.28205,-1.81501,0.135832,1.30889,-2.02826},
/*1310*/{0.25949,1.8571,-1.69353,0.33683,1.79836,-1.84598,0.117357,1.74755,-1.61636,0.009787,1.66601,-1.57479,0.135991,1.57546,-1.62273,0.200944,1.51546,-1.63459,0.260722,1.88376,-2.09146,0.343155,1.80318,-1.92459,0.12892,1.84887,-1.99677,0.103265,1.6561,-2.15802,0.145819,1.56657,-2.20136,0.321317,1.53483,-2.11429,0.380252,1.50881,-2.11509,0.225516,1.36979,-1.78668,0.034475,1.43893,-1.85004,0.03818,1.47065,-1.90064,0.032089,1.45006,-1.96229,0.220518,1.40071,-2.05566,0.340246,1.1374,-1.72019,0.234884,1.05541,-1.74136,0.282491,0.986913,-1.76025,0.387965,0.936122,-1.74298,0.251417,0.844601,-1.73095,0.181391,0.815516,-1.73938,0.207221,0.946177,-1.74954,0.140493,0.918867,-1.75112,-0.046365,0.79228,-1.75808,-0.15563,0.837859,-1.8409,-0.018317,0.628973,-1.77048,-0.074157,0.640545,-1.70048,0.190476,1.09244,-2.10466,0.203253,1.00923,-2.08604,0.054667,1.07486,-2.05675,0.070034,0.994402,-2.0399,0.134862,0.856095,-2.03941,0.105455,0.671073,-2.00516,0.003616,0.720437,-2.02323,-0.024597,0.657249,-2.0053,-0.093921,0.446635,-1.94676,-0.200304,0.381477,-1.88615,0.079402,0.374432,-1.92903,0.023942,0.341316,-1.99211,0.147275,1.28527,-1.81428,0.13727,1.30975,-2.02788},
/*1311*/{0.255362,1.86199,-1.69328,0.336459,1.8025,-1.84378,0.112194,1.75338,-1.61732,0.003916,1.67366,-1.5768,0.129099,1.58143,-1.62273,0.192357,1.5218,-1.63413,0.262313,1.88852,-2.09062,0.343483,1.80719,-1.92237,0.129362,1.85202,-1.9978,0.109102,1.65832,-2.15817,0.153591,1.56973,-2.20216,0.329209,1.54581,-2.1104,0.387921,1.52125,-2.11017,0.226426,1.37379,-1.78593,0.035212,1.4421,-1.85072,0.03856,1.47331,-1.90315,0.034233,1.45273,-1.96361,0.222422,1.40179,-2.05424,0.345691,1.14486,-1.72032,0.241428,1.0612,-1.74188,0.289887,0.993248,-1.76294,0.397357,0.944767,-1.74409,0.263556,0.846561,-1.73129,0.194341,0.813595,-1.73964,0.213955,0.946015,-1.74934,0.149655,0.914866,-1.75178,-0.031381,0.779081,-1.75716,-0.143214,0.818751,-1.84223,0.006218,0.619715,-1.76991,-0.052103,0.627304,-1.70036,0.184101,1.09236,-2.10313,0.195347,1.00911,-2.08355,0.048196,1.07881,-2.05648,0.060546,0.997928,-2.03979,0.119377,0.858646,-2.03776,0.088455,0.673622,-2.00477,-0.012727,0.723445,-2.02151,-0.039729,0.660407,-2.00382,-0.113433,0.450226,-1.94463,-0.219123,0.386879,-1.88405,0.059501,0.374722,-1.92824,0.003465,0.341544,-1.99167,0.147796,1.28906,-1.81294,0.139403,1.31121,-2.02687},
/*1312*/{0.251676,1.86653,-1.69325,0.336061,1.80751,-1.84246,0.107938,1.75978,-1.61779,-0.003537,1.6813,-1.57831,0.122333,1.58853,-1.62361,0.185845,1.52809,-1.6343,0.263651,1.89326,-2.08939,0.344549,1.81175,-1.92133,0.130015,1.85491,-1.99891,0.113555,1.66031,-2.15969,0.160386,1.57331,-2.20331,0.335435,1.55625,-2.10625,0.395241,1.53407,-2.10492,0.228918,1.37771,-1.78626,0.037213,1.44523,-1.85303,0.040233,1.47651,-1.90376,0.035506,1.45621,-1.96532,0.224237,1.40231,-2.05425,0.348639,1.15344,-1.72116,0.246506,1.0662,-1.7422,0.298884,1.00078,-1.76136,0.406201,0.954647,-1.74449,0.275115,0.84842,-1.7315,0.207974,0.812206,-1.74005,0.220771,0.945137,-1.74847,0.156528,0.911035,-1.7526,-0.016667,0.768195,-1.75856,-0.129501,0.800368,-1.84348,0.030134,0.609515,-1.76969,-0.027417,0.614487,-1.70033,0.178667,1.09291,-2.1006,0.186501,1.00956,-2.08084,0.039724,1.08376,-2.05628,0.050761,1.00206,-2.03965,0.106116,0.861069,-2.03538,0.072698,0.676343,-2.00284,-0.027894,0.727266,-2.01967,-0.057069,0.665407,-2.00359,-0.133585,0.454713,-1.94686,-0.239289,0.39393,-1.88822,0.038039,0.374754,-1.92848,-0.015627,0.342743,-1.99123,0.149209,1.29287,-1.81243,0.140903,1.31274,-2.02659},
/*1313*/{0.247445,1.87138,-1.69339,0.334606,1.8116,-1.84052,0.103168,1.76612,-1.61838,-0.009157,1.6893,-1.58106,0.116534,1.59595,-1.62438,0.179628,1.53435,-1.63387,0.265859,1.89857,-2.08838,0.344706,1.8166,-1.91923,0.131328,1.85895,-2.00035,0.11972,1.66343,-2.16097,0.167751,1.577,-2.20351,0.340799,1.56685,-2.10268,0.400888,1.54733,-2.10036,0.22885,1.38141,-1.78645,0.038425,1.44975,-1.85446,0.041583,1.47928,-1.90582,0.037543,1.45921,-1.96686,0.226091,1.40291,-2.05459,0.353047,1.16057,-1.72059,0.252828,1.07173,-1.74228,0.304515,1.00726,-1.76311,0.414838,0.96308,-1.74492,0.286513,0.850278,-1.73172,0.221592,0.810648,-1.74045,0.227398,0.944936,-1.74865,0.166571,0.906038,-1.75241,-0.003017,0.755331,-1.75949,-0.115869,0.780458,-1.84503,0.054828,0.600049,-1.76922,-0.003928,0.601422,-1.70022,0.173297,1.09467,-2.09786,0.1783,1.01049,-2.07794,0.034163,1.08844,-2.05722,0.042157,1.0071,-2.03879,0.092787,0.864199,-2.03347,0.055779,0.68016,-2.00209,-0.043942,0.732049,-2.01835,-0.073619,0.670068,-2.00252,-0.152435,0.459967,-1.95005,-0.25759,0.399988,-1.88515,0.017328,0.375293,-1.92852,-0.037647,0.342297,-1.99118,0.14909,1.2967,-1.81181,0.141958,1.3142,-2.02622},
/*1314*/{0.244286,1.87622,-1.69356,0.333461,1.81694,-1.83867,0.09925,1.77197,-1.61939,-0.015629,1.6976,-1.58245,0.11005,1.60357,-1.6257,0.172631,1.54176,-1.63466,0.267625,1.90328,-2.08727,0.345288,1.82065,-1.9168,0.131626,1.86204,-2.0017,0.12324,1.66823,-2.16403,0.175045,1.58156,-2.20457,0.344652,1.57599,-2.09906,0.406649,1.55908,-2.09487,0.231847,1.38622,-1.78689,0.039381,1.45385,-1.85555,0.044327,1.48281,-1.90742,0.04022,1.46277,-1.968,0.228072,1.40314,-2.05439,0.357893,1.16881,-1.72078,0.257011,1.07741,-1.74378,0.311458,1.01452,-1.76307,0.421409,0.972379,-1.74557,0.297538,0.851763,-1.73184,0.23537,0.809878,-1.7408,0.2338,0.943057,-1.74933,0.175159,0.901802,-1.75374,0.018125,0.742332,-1.7595,-0.100513,0.760858,-1.84671,0.080146,0.591039,-1.76912,0.020871,0.589266,-1.69994,0.167725,1.09491,-2.09514,0.17007,1.0119,-2.07484,0.028095,1.0933,-2.05628,0.032841,1.01297,-2.03941,0.08008,0.867775,-2.0307,0.04011,0.684835,-2.00178,-0.058657,0.737852,-2.01786,-0.089672,0.674206,-2.00234,-0.197601,0.499288,-1.98545,-0.274902,0.406732,-1.88649,-0.002466,0.375547,-1.92753,-0.058311,0.342443,-1.99073,0.150807,1.30138,-1.81053,0.143672,1.31561,-2.02517},
/*1315*/{0.241482,1.8811,-1.69354,0.334054,1.82186,-1.83754,0.094995,1.778,-1.62066,-0.019475,1.70582,-1.58521,0.104636,1.61117,-1.62697,0.166609,1.5488,-1.6351,0.270261,1.90867,-2.0862,0.345025,1.82514,-1.91511,0.13286,1.86611,-2.00287,0.129616,1.67261,-2.16675,0.182101,1.58617,-2.20565,0.349607,1.58779,-2.09557,0.411133,1.57173,-2.09076,0.232707,1.39051,-1.78725,0.041654,1.45828,-1.85753,0.045683,1.48648,-1.90944,0.043229,1.46647,-1.96989,0.229902,1.40407,-2.05491,0.360807,1.17517,-1.7217,0.263422,1.08372,-1.74347,0.316837,1.0215,-1.76387,0.428569,0.980716,-1.74683,0.308068,0.852824,-1.73172,0.248076,0.80724,-1.74052,0.239974,0.941096,-1.74977,0.183391,0.896338,-1.755,0.031185,0.730922,-1.76143,-0.084985,0.741419,-1.84725,0.10614,0.582437,-1.7687,0.045943,0.576749,-1.70058,0.162969,1.09669,-2.09288,0.162962,1.01373,-2.07149,0.022761,1.09891,-2.05657,0.024885,1.01802,-2.03919,0.068573,0.87231,-2.02894,0.02446,0.689179,-2.00088,-0.074538,0.742678,-2.01692,-0.10579,0.680375,-2.0013,-0.19127,0.469042,-1.94742,-0.292767,0.413804,-1.88948,-0.022599,0.375781,-1.92708,-0.078987,0.343202,-1.99121,0.151368,1.30577,-1.81018,0.145103,1.31756,-2.02501},
/*1316*/{0.238211,1.88582,-1.69439,0.332764,1.82688,-1.8358,0.090866,1.78413,-1.62182,-0.025158,1.71389,-1.5877,0.098672,1.61794,-1.62805,0.161072,1.55612,-1.63501,0.271994,1.91388,-2.08463,0.34551,1.83002,-1.9134,0.133718,1.8698,-2.00397,0.133428,1.67891,-2.16921,0.188934,1.59103,-2.20684,0.352526,1.59709,-2.09229,0.415588,1.58315,-2.08512,0.234907,1.39447,-1.78858,0.043418,1.46328,-1.85724,0.047006,1.49027,-1.91101,0.046474,1.46964,-1.96992,0.232574,1.4048,-2.05501,0.364165,1.1833,-1.72194,0.268796,1.09023,-1.743,0.323267,1.02878,-1.7636,0.433176,0.988268,-1.74742,0.318583,0.85428,-1.73162,0.260931,0.805642,-1.74061,0.246054,0.939094,-1.75048,0.191708,0.892216,-1.75482,0.048572,0.717796,-1.76188,-0.067567,0.720979,-1.84785,0.131898,0.574757,-1.76933,0.072668,0.565681,-1.70155,0.15837,1.09857,-2.09,0.155976,1.01501,-2.06849,0.017243,1.10443,-2.05655,0.017403,1.02327,-2.03844,0.056174,0.87793,-2.02725,0.009968,0.69443,-2.00082,-0.088945,0.749339,-2.01671,-0.120537,0.687213,-2.00031,-0.201099,0.475955,-1.94845,-0.310429,0.424506,-1.88827,-0.043231,0.375822,-1.92721,-0.096814,0.343035,-1.98985,0.152906,1.3101,-1.80925,0.146437,1.31951,-2.02419},
/*1317*/{0.235984,1.89052,-1.69449,0.331908,1.83112,-1.83457,0.087764,1.79072,-1.62316,-0.031052,1.72174,-1.59059,0.093717,1.62535,-1.63004,0.155161,1.5622,-1.63496,0.273525,1.91885,-2.08381,0.345559,1.83461,-1.91134,0.135124,1.87345,-2.00588,0.140025,1.68336,-2.17256,0.195764,1.59619,-2.20777,0.356588,1.60807,-2.08909,0.419029,1.59514,-2.08118,0.236549,1.39852,-1.78894,0.045098,1.46744,-1.85788,0.050042,1.4938,-1.91249,0.04943,1.47385,-1.97121,0.23456,1.40602,-2.05496,0.367133,1.19036,-1.7223,0.271578,1.09619,-1.74429,0.326231,1.03583,-1.76468,0.438251,0.995886,-1.74868,0.328619,0.855608,-1.73177,0.2734,0.804068,-1.74128,0.251787,0.935396,-1.7522,0.198729,0.887563,-1.75768,0.065328,0.702819,-1.76223,-0.050653,0.700916,-1.84907,0.157441,0.565671,-1.76952,0.098514,0.553668,-1.70173,0.154249,1.10094,-2.08772,0.148751,1.01809,-2.06547,0.012558,1.11149,-2.05666,0.010324,1.0304,-2.03896,0.043823,0.882945,-2.02633,-0.005261,0.700365,-2.0007,-0.102901,0.755084,-2.01652,-0.134785,0.696414,-2.00165,-0.22082,0.481749,-1.9504,-0.326302,0.435028,-1.88825,-0.063512,0.376402,-1.92686,-0.116853,0.344479,-1.9899,0.153961,1.31424,-1.80876,0.148009,1.32182,-2.02378},
/*1318*/{0.233739,1.89539,-1.69457,0.332398,1.835,-1.83267,0.084408,1.7969,-1.62527,-0.035367,1.7296,-1.59386,0.088141,1.63214,-1.63101,0.150174,1.56909,-1.63591,0.276053,1.92424,-2.08268,0.345457,1.84049,-1.91047,0.135917,1.87713,-2.00655,0.145631,1.68872,-2.1747,0.203123,1.60131,-2.20889,0.359019,1.617,-2.08595,0.421847,1.60616,-2.07757,0.239098,1.40243,-1.78922,0.047568,1.47214,-1.85858,0.052165,1.49794,-1.91454,0.052063,1.4769,-1.97179,0.236178,1.40662,-2.05463,0.369701,1.19735,-1.72271,0.273624,1.09852,-1.74255,0.330603,1.04236,-1.76512,0.441645,1.00351,-1.74917,0.338017,0.856433,-1.73214,0.286701,0.802007,-1.74109,0.257539,0.932657,-1.75321,0.208472,0.880775,-1.75734,0.083534,0.690335,-1.76274,-0.031818,0.679599,-1.84833,0.183645,0.558703,-1.77111,0.125994,0.542104,-1.70332,0.149516,1.10347,-2.084,0.141682,1.02048,-2.06243,0.008292,1.11718,-2.05592,0.00269,1.03636,-2.03811,0.031359,0.888643,-2.02578,-0.019548,0.706142,-2.00105,-0.116611,0.762753,-2.01591,-0.149163,0.701185,-2.00008,-0.235689,0.488241,-1.95173,-0.340375,0.445435,-1.88855,-0.084807,0.376075,-1.9267,-0.140147,0.34405,-1.98959,0.155345,1.31879,-1.80762,0.149178,1.32345,-2.02271},
/*1319*/{0.232178,1.89962,-1.69507,0.330269,1.84138,-1.83183,0.080774,1.80378,-1.62707,-0.039422,1.73753,-1.59694,0.084149,1.63942,-1.63273,0.14597,1.57592,-1.63569,0.277367,1.9287,-2.08104,0.345232,1.84413,-1.90826,0.13723,1.88068,-2.00788,0.15185,1.69345,-2.17858,0.209784,1.60703,-2.21041,0.361299,1.62608,-2.08324,0.423455,1.61796,-2.07544,0.241221,1.40667,-1.79046,0.049811,1.47771,-1.85844,0.05439,1.50188,-1.91552,0.055342,1.48092,-1.97222,0.239067,1.40719,-2.0547,0.371446,1.20359,-1.72369,0.275404,1.10653,-1.74466,0.33285,1.04795,-1.76687,0.443785,1.00914,-1.75037,0.347009,0.856632,-1.73257,0.299264,0.800741,-1.74175,0.263596,0.929397,-1.75493,0.217053,0.875437,-1.75923,0.10253,0.676352,-1.76327,-0.012244,0.660041,-1.84875,0.210161,0.55131,-1.77283,0.153806,0.531674,-1.70432,0.145741,1.10574,-2.08228,0.135113,1.02351,-2.05969,0.003788,1.12658,-2.05732,-0.004655,1.04351,-2.03862,0.01945,0.894647,-2.02584,-0.032617,0.713266,-2.00186,-0.129856,0.769897,-2.01599,-0.162972,0.709179,-2.00072,-0.25075,0.493988,-1.95276,-0.355697,0.457262,-1.8886,-0.105707,0.37601,-1.92619,-0.161225,0.344495,-1.98967,0.156834,1.32351,-1.80661,0.150439,1.32567,-2.02174},
/*1320*/{0.230672,1.90397,-1.69547,0.330033,1.84566,-1.83095,0.078201,1.80987,-1.62912,-0.042829,1.74555,-1.60089,0.079999,1.64644,-1.63398,0.140886,1.58244,-1.63629,0.279709,1.93396,-2.08036,0.345652,1.84905,-1.90742,0.1384,1.88434,-2.0096,0.157138,1.69826,-2.18173,0.215226,1.61204,-2.21152,0.362625,1.63549,-2.0809,0.426382,1.6283,-2.07053,0.242719,1.41114,-1.78981,0.052714,1.48194,-1.85832,0.056759,1.5059,-1.91762,0.057861,1.48478,-1.97272,0.241073,1.40882,-2.05397,0.374156,1.20984,-1.72405,0.282489,1.11437,-1.74256,0.335079,1.05437,-1.76571,0.444373,1.01506,-1.75075,0.356341,0.857094,-1.73318,0.310843,0.796679,-1.74239,0.26867,0.924732,-1.75619,0.225533,0.867395,-1.75914,0.122259,0.662816,-1.76371,0.007922,0.640181,-1.84785,0.236624,0.544634,-1.77466,0.182743,0.521196,-1.70569,0.141467,1.10775,-2.08,0.12829,1.02604,-2.05732,0.000153,1.13137,-2.0562,-0.010933,1.05104,-2.0388,0.008421,0.900656,-2.02574,-0.044447,0.719662,-2.00266,-0.14383,0.777238,-2.01609,-0.175903,0.716295,-2.00083,-0.261127,0.501333,-1.95405,-0.369817,0.468121,-1.88991,-0.125939,0.376454,-1.92696,-0.181452,0.345313,-1.98918,0.158082,1.32818,-1.80537,0.152191,1.3281,-2.02053},
/*1321*/{0.229319,1.90804,-1.69579,0.330206,1.84945,-1.82984,0.075091,1.81624,-1.63087,-0.047929,1.75335,-1.60475,0.075296,1.65237,-1.63576,0.136726,1.58871,-1.63626,0.281103,1.93822,-2.07945,0.345726,1.85325,-1.90597,0.140678,1.88704,-2.01001,0.162321,1.70312,-2.18489,0.221669,1.6171,-2.21315,0.364535,1.64447,-2.07883,0.426931,1.63926,-2.0684,0.244484,1.41539,-1.79076,0.054623,1.48814,-1.85824,0.058377,1.50986,-1.91875,0.061196,1.48764,-1.97276,0.243686,1.40976,-2.05357,0.376452,1.21573,-1.72425,0.279796,1.11705,-1.74383,0.337482,1.05978,-1.76562,0.44472,1.01993,-1.75105,0.366127,0.856477,-1.73373,0.323082,0.794274,-1.74201,0.273906,0.918409,-1.75801,0.234217,0.860903,-1.76125,0.143036,0.648444,-1.76367,0.02876,0.620039,-1.84796,0.263754,0.538208,-1.77627,0.211348,0.511281,-1.70746,0.13778,1.11049,-2.07786,0.122038,1.02951,-2.05527,-0.002434,1.13824,-2.05654,-0.015568,1.05878,-2.03867,-0.002661,0.90743,-2.02608,-0.057998,0.727379,-2.00443,-0.155237,0.785721,-2.01692,-0.187639,0.723847,-2.00196,-0.278012,0.507963,-1.9569,-0.382849,0.480164,-1.89068,-0.146168,0.377241,-1.92728,-0.201133,0.345923,-1.98896,0.159419,1.33314,-1.80399,0.153457,1.33024,-2.01912},
/*1322*/{0.227651,1.91213,-1.69614,0.329571,1.85458,-1.8294,0.071957,1.82251,-1.63319,-0.051305,1.76061,-1.60823,0.072508,1.65884,-1.63704,0.133205,1.59392,-1.63711,0.282216,1.94233,-2.07788,0.345921,1.85802,-1.90474,0.14188,1.89082,-2.01093,0.168136,1.70768,-2.18817,0.226585,1.62228,-2.2151,0.365684,1.65192,-2.0769,0.42904,1.64798,-2.06489,0.246517,1.4199,-1.79107,0.057935,1.49227,-1.85846,0.06108,1.51413,-1.91927,0.063662,1.49164,-1.97336,0.245924,1.41071,-2.05297,0.37778,1.22079,-1.72458,0.284292,1.12526,-1.74215,0.339387,1.06497,-1.76434,0.444095,1.02539,-1.75191,0.374458,0.855391,-1.73424,0.334541,0.791827,-1.74317,0.280138,0.91342,-1.75861,0.242298,0.85245,-1.76119,0.163976,0.63611,-1.7644,0.050226,0.601153,-1.84701,0.291064,0.532945,-1.77878,0.24127,0.502088,-1.70938,0.134488,1.11321,-2.07671,0.116127,1.03301,-2.05337,-0.004664,1.14518,-2.0565,-0.020938,1.066,-2.03823,-0.012604,0.915582,-2.02677,-0.072945,0.734172,-2.00572,-0.166284,0.794256,-2.01791,-0.199399,0.731591,-2.00272,-0.285077,0.514212,-1.95794,-0.3924,0.493601,-1.89128,-0.166325,0.377426,-1.92835,-0.223073,0.346364,-1.9894,0.161156,1.33781,-1.80279,0.154929,1.33255,-2.01787},
/*1323*/{0.226977,1.91594,-1.69645,0.329594,1.85731,-1.82826,0.070318,1.82867,-1.63531,-0.05449,1.76754,-1.61195,0.068383,1.66457,-1.63835,0.129928,1.59991,-1.63688,0.283963,1.94659,-2.0772,0.346348,1.86138,-1.90416,0.143143,1.89384,-2.01171,0.172968,1.71197,-2.19059,0.2319,1.62754,-2.2166,0.366182,1.65898,-2.07596,0.429757,1.6567,-2.06206,0.247796,1.42464,-1.79174,0.060321,1.49742,-1.85812,0.064047,1.51743,-1.92061,0.066706,1.49454,-1.97314,0.248165,1.41197,-2.05217,0.380487,1.22542,-1.72531,0.283335,1.1307,-1.74217,0.338985,1.06922,-1.76491,0.443197,1.02799,-1.75316,0.382518,0.854552,-1.73469,0.346206,0.788085,-1.74309,0.285534,0.907168,-1.75854,0.251143,0.843778,-1.76176,0.183963,0.623181,-1.76459,0.071938,0.582939,-1.84598,0.316763,0.527962,-1.7816,0.270036,0.492822,-1.71171,0.131533,1.11573,-2.07538,0.10905,1.03696,-2.05279,-0.006999,1.15201,-2.05701,-0.026971,1.07345,-2.0384,-0.022551,0.922205,-2.02752,-0.081835,0.742937,-2.0084,-0.177966,0.800905,-2.01861,-0.21029,0.739419,-2.0035,-0.296273,0.520801,-1.96181,-0.402887,0.508915,-1.89181,-0.185493,0.37754,-1.92979,-0.244245,0.348189,-1.98966,0.16287,1.34266,-1.80127,0.156609,1.33465,-2.01627},
/*1324*/{0.226421,1.91978,-1.69686,0.329567,1.86057,-1.82732,0.06853,1.83463,-1.63793,-0.05736,1.77461,-1.61644,0.065027,1.66999,-1.63965,0.125491,1.60469,-1.63801,0.285227,1.95044,-2.07633,0.347425,1.86521,-1.90324,0.144544,1.89731,-2.0134,0.178429,1.71696,-2.19411,0.23646,1.63198,-2.2182,0.366888,1.66652,-2.07431,0.430248,1.66544,-2.05992,0.249957,1.42895,-1.79119,0.063326,1.50169,-1.85768,0.06659,1.52188,-1.92096,0.069315,1.49809,-1.97347,0.250461,1.41348,-2.05169,0.38181,1.22975,-1.72554,0.284313,1.13522,-1.74064,0.340189,1.07281,-1.7636,0.442038,1.03059,-1.7537,0.391317,0.852797,-1.73468,0.359154,0.784693,-1.74373,0.291689,0.900676,-1.75874,0.260808,0.835837,-1.76235,0.205422,0.610588,-1.76516,0.094864,0.564121,-1.84522,0.344168,0.523505,-1.78405,0.298962,0.484962,-1.71496,0.128627,1.1188,-2.07476,0.104936,1.03947,-2.05129,-0.008489,1.15873,-2.05774,-0.029844,1.08066,-2.03898,-0.031018,0.930227,-2.02824,-0.089723,0.751036,-2.01082,-0.18802,0.808075,-2.0192,-0.21863,0.747379,-2.00496,-0.306888,0.528364,-1.96375,-0.411288,0.523474,-1.89232,-0.203424,0.377608,-1.93186,-0.264309,0.350333,-1.98976,0.164702,1.34726,-1.79992,0.158277,1.33723,-2.01482},
/*1325*/{0.225625,1.92315,-1.69761,0.330107,1.86523,-1.82682,0.066506,1.84086,-1.64039,-0.06094,1.77996,-1.6199,0.062246,1.67535,-1.6411,0.12268,1.60978,-1.63761,0.286676,1.95406,-2.07559,0.347309,1.86824,-1.902,0.145731,1.90064,-2.01439,0.18303,1.72075,-2.1963,0.240868,1.63651,-2.22012,0.366671,1.6746,-2.07366,0.431046,1.67285,-2.05836,0.251131,1.43272,-1.79036,0.066125,1.50601,-1.85831,0.069798,1.52537,-1.92187,0.071638,1.5013,-1.97333,0.252563,1.41485,-2.05064,0.382031,1.2329,-1.72662,0.283524,1.13702,-1.73937,0.337669,1.07653,-1.76235,0.441081,1.03216,-1.75476,0.398839,0.850621,-1.73605,0.368821,0.78083,-1.74397,0.296529,0.893514,-1.76053,0.269177,0.827165,-1.76161,0.226282,0.59739,-1.76508,0.118278,0.546845,-1.84524,0.368975,0.519002,-1.78675,0.328477,0.477004,-1.71653,0.1261,1.12143,-2.07417,0.100709,1.04269,-2.0509,-0.010241,1.1655,-2.05768,-0.033581,1.08789,-2.03963,-0.0398,0.937973,-2.02944,-0.098266,0.758831,-2.01322,-0.19534,0.816779,-2.02042,-0.228139,0.754137,-2.00629,-0.315848,0.535304,-1.96695,-0.419189,0.537839,-1.89521,-0.220245,0.377479,-1.93312,-0.284837,0.354205,-1.98972,0.165742,1.35146,-1.79855,0.159873,1.33942,-2.01337},
/*1326*/{0.225224,1.927,-1.69767,0.32949,1.86767,-1.82624,0.06474,1.84667,-1.64274,-0.06353,1.78616,-1.624,0.059379,1.68011,-1.64267,0.120481,1.61414,-1.63825,0.288763,1.95701,-2.07473,0.348262,1.87139,-1.90078,0.14708,1.90291,-2.0146,0.187045,1.72516,-2.19903,0.245147,1.64096,-2.22184,0.367285,1.68009,-2.07309,0.430764,1.67935,-2.05602,0.252408,1.43613,-1.79026,0.067619,1.51012,-1.85799,0.070414,1.52885,-1.92225,0.074199,1.50433,-1.9737,0.254624,1.41632,-2.04946,0.382979,1.2353,-1.72795,0.284015,1.14338,-1.73842,0.336373,1.07926,-1.75996,0.43957,1.03321,-1.75565,0.405828,0.84838,-1.73522,0.380609,0.778063,-1.74441,0.301861,0.886262,-1.76142,0.27786,0.817634,-1.76336,0.24758,0.587447,-1.76604,0.142307,0.530096,-1.84535,0.394658,0.515901,-1.78742,0.357086,0.470628,-1.71981,0.123336,1.12403,-2.07378,0.097032,1.04478,-2.05022,-0.011928,1.17067,-2.05777,-0.037099,1.09399,-2.03943,-0.047273,0.945001,-2.03022,-0.106082,0.76694,-2.01557,-0.204264,0.823259,-2.02135,-0.236017,0.761669,-2.00861,-0.329799,0.543133,-1.9697,-0.424688,0.552693,-1.89572,-0.237512,0.377526,-1.93496,-0.303671,0.358563,-1.98978,0.166528,1.35532,-1.79745,0.161166,1.34179,-2.01219},
/*1327*/{0.224852,1.92983,-1.69803,0.330721,1.87173,-1.82543,0.063547,1.85126,-1.64461,-0.065423,1.79168,-1.62833,0.056985,1.68469,-1.64421,0.117636,1.61788,-1.63819,0.289874,1.96046,-2.07335,0.348516,1.87436,-1.90035,0.148424,1.9058,-2.01506,0.191494,1.72962,-2.20101,0.248596,1.64509,-2.22382,0.367249,1.68456,-2.07221,0.429761,1.6869,-2.0559,0.253204,1.43948,-1.78982,0.067978,1.51387,-1.85902,0.072405,1.53209,-1.92249,0.076014,1.50763,-1.97361,0.25674,1.4178,-2.04887,0.384631,1.23772,-1.72903,0.28378,1.14619,-1.73764,0.335679,1.08192,-1.75892,0.437825,1.03295,-1.75527,0.412953,0.846352,-1.73547,0.391151,0.773557,-1.744,0.307561,0.877965,-1.7611,0.28715,0.808605,-1.76419,0.267221,0.57525,-1.76684,0.166279,0.514021,-1.84512,0.419497,0.512728,-1.79071,0.384966,0.463426,-1.72253,0.122173,1.12726,-2.07394,0.092156,1.05141,-2.05225,-0.013667,1.1757,-2.0582,-0.039326,1.0996,-2.0393,-0.052885,0.952222,-2.03067,-0.112787,0.77339,-2.01746,-0.210695,0.830838,-2.02248,-0.242938,0.769797,-2.0108,-0.332486,0.551667,-1.97333,-0.430911,0.568842,-1.89776,-0.25357,0.377815,-1.9369,-0.321859,0.364226,-1.98898,0.166858,1.35892,-1.79669,0.162391,1.34422,-2.01138},
/*1328*/{0.224958,1.93277,-1.69876,0.33021,1.87389,-1.82502,0.062,1.85618,-1.64676,-0.066753,1.79689,-1.63192,0.05464,1.68921,-1.64573,0.115895,1.62166,-1.63773,0.291344,1.96329,-2.07292,0.349716,1.87705,-1.89935,0.150348,1.90884,-2.01637,0.19596,1.7327,-2.203,0.25184,1.64869,-2.22536,0.368864,1.69106,-2.07297,0.432562,1.68995,-2.05358,0.255645,1.44382,-1.79006,0.070668,1.51777,-1.85827,0.074968,1.53507,-1.92283,0.077744,1.51065,-1.97379,0.258155,1.41992,-2.04779,0.385056,1.23875,-1.72984,0.282641,1.14848,-1.73681,0.333352,1.08325,-1.75866,0.436042,1.03252,-1.75534,0.420062,0.843512,-1.73539,0.401222,0.770244,-1.74415,0.312362,0.870451,-1.76285,0.29455,0.800464,-1.76521,0.289521,0.564061,-1.7662,0.189616,0.49924,-1.84557,0.443323,0.509419,-1.79214,0.41211,0.458053,-1.72584,0.120291,1.1307,-2.07501,0.089301,1.05376,-2.05273,-0.014631,1.18053,-2.05817,-0.040913,1.10452,-2.03884,-0.057248,0.958041,-2.03103,-0.118893,0.779745,-2.01929,-0.215654,0.837778,-2.02391,-0.248732,0.777388,-2.01285,-0.340856,0.56038,-1.97533,-0.435778,0.584041,-1.90079,-0.270047,0.37795,-1.93892,-0.341893,0.370318,-1.98932,0.169304,1.36329,-1.79543,0.164048,1.34662,-2.00996},
/*1329*/{0.224584,1.93602,-1.69892,0.331287,1.87641,-1.824,0.061629,1.85966,-1.64998,-0.069955,1.80089,-1.63557,0.052708,1.69278,-1.64703,0.113524,1.62559,-1.63788,0.29271,1.9658,-2.07263,0.349628,1.8796,-1.89886,0.152068,1.91051,-2.01696,0.199515,1.7369,-2.20448,0.253235,1.65221,-2.22718,0.368397,1.69315,-2.07193,0.42997,1.69571,-2.05303,0.25597,1.44689,-1.78992,0.072188,1.52098,-1.85823,0.076189,1.53841,-1.92287,0.080573,1.51346,-1.97339,0.258978,1.42169,-2.04708,0.38488,1.23926,-1.73137,0.281818,1.15073,-1.73712,0.330857,1.08432,-1.75791,0.433822,1.03084,-1.75484,0.425705,0.840508,-1.73482,0.41088,0.76581,-1.74355,0.31778,0.862362,-1.76364,0.302945,0.791869,-1.76617,0.309991,0.554206,-1.76701,0.213491,0.485418,-1.84624,0.467941,0.507345,-1.79452,0.438597,0.453339,-1.72859,0.118161,1.13358,-2.07513,0.087784,1.05766,-2.0537,-0.01579,1.18499,-2.05733,-0.042416,1.10925,-2.03845,-0.059126,0.962722,-2.03095,-0.124294,0.785378,-2.02047,-0.218914,0.847084,-2.02603,-0.254038,0.784135,-2.01445,-0.352083,0.571107,-1.98213,-0.439922,0.598691,-1.90292,-0.285694,0.3774,-1.93894,-0.360034,0.378183,-1.98892,0.169757,1.36649,-1.79467,0.164811,1.34902,-2.00914},
/*1330*/{0.2252,1.939,-1.6991,0.331418,1.87887,-1.82326,0.060567,1.86405,-1.65278,-0.070886,1.80501,-1.63972,0.051964,1.69682,-1.64828,0.111626,1.62876,-1.63852,0.294568,1.96839,-2.07223,0.351172,1.88254,-1.89758,0.153172,1.91332,-2.01761,0.202534,1.74004,-2.20553,0.255106,1.65477,-2.22816,0.368653,1.69663,-2.07219,0.430158,1.69893,-2.05223,0.25566,1.44973,-1.78969,0.072821,1.52339,-1.85857,0.077394,1.54178,-1.92286,0.081827,1.51642,-1.97383,0.260303,1.42435,-2.04636,0.382272,1.23939,-1.73222,0.281101,1.1508,-1.73657,0.328437,1.08353,-1.75679,0.431374,1.02891,-1.75395,0.43051,0.837434,-1.73438,0.42003,0.763056,-1.74358,0.322124,0.851498,-1.76376,0.311952,0.781088,-1.76561,0.330703,0.545247,-1.76857,0.236677,0.472497,-1.84739,0.490454,0.506515,-1.79748,0.463897,0.449442,-1.73199,0.117905,1.13644,-2.07582,0.086433,1.06121,-2.05612,-0.01522,1.18864,-2.05559,-0.043146,1.11275,-2.03753,-0.059191,0.965987,-2.03068,-0.128097,0.789656,-2.02134,-0.222219,0.853541,-2.02731,-0.258235,0.791537,-2.01742,-0.361147,0.578546,-1.98239,-0.444451,0.614231,-1.9081,-0.302718,0.377188,-1.93866,-0.377576,0.386465,-1.98942,0.16968,1.36921,-1.79462,0.165866,1.35191,-2.00912},
/*1331*/{0.225863,1.94177,-1.69964,0.331771,1.88052,-1.8227,0.059982,1.86778,-1.6547,-0.072966,1.80891,-1.64257,0.051051,1.69997,-1.64934,0.109964,1.63126,-1.63886,0.29506,1.97043,-2.07101,0.351119,1.88404,-1.89746,0.154877,1.91515,-2.01764,0.20314,1.74327,-2.20686,0.257677,1.65769,-2.23039,0.368734,1.69872,-2.07199,0.429638,1.70118,-2.05106,0.259252,1.45524,-1.78946,0.074847,1.52663,-1.85809,0.078626,1.54443,-1.92261,0.082857,1.51959,-1.97411,0.261055,1.42652,-2.04584,0.382329,1.23801,-1.73267,0.277413,1.15161,-1.73685,0.325351,1.08344,-1.75664,0.42863,1.02555,-1.75287,0.434767,0.833902,-1.73417,0.426588,0.75827,-1.74295,0.325808,0.843648,-1.76365,0.319233,0.772485,-1.76751,0.350975,0.535867,-1.76916,0.260345,0.460617,-1.84839,0.511245,0.504969,-1.80037,0.488565,0.445209,-1.73377,0.117118,1.13958,-2.07677,0.085957,1.06281,-2.05617,-0.015339,1.19112,-2.05439,-0.043101,1.11545,-2.0372,-0.057705,0.968368,-2.03052,-0.131826,0.793825,-2.02205,-0.224333,0.857726,-2.02838,-0.26158,0.798318,-2.01844,-0.368637,0.587438,-1.98446,-0.450826,0.629042,-1.91218,-0.321502,0.377157,-1.93873,-0.393187,0.395677,-1.98798,0.17302,1.3742,-1.79305,0.167572,1.35423,-2.00728},
/*1332*/{0.226014,1.94379,-1.70002,0.333321,1.88266,-1.8228,0.060126,1.87092,-1.65656,-0.073812,1.81193,-1.64646,0.048972,1.70217,-1.65105,0.108712,1.63336,-1.639,0.296669,1.97228,-2.07048,0.352148,1.8858,-1.89693,0.156524,1.91784,-2.01821,0.205816,1.7465,-2.20701,0.259383,1.6601,-2.23159,0.368803,1.70202,-2.07255,0.429943,1.70232,-2.05069,0.259386,1.45466,-1.78979,0.075148,1.52798,-1.85838,0.079156,1.54698,-1.92268,0.084625,1.52161,-1.97393,0.261942,1.42873,-2.04554,0.380087,1.23573,-1.73281,0.274313,1.15095,-1.73668,0.321227,1.08134,-1.75672,0.424722,1.02171,-1.75191,0.438725,0.830214,-1.73354,0.436246,0.754744,-1.74285,0.329514,0.83434,-1.76367,0.326368,0.762949,-1.76673,0.370119,0.528148,-1.76979,0.282752,0.449637,-1.84986,0.53188,0.50391,-1.80119,0.512075,0.443877,-1.73734,0.118488,1.1418,-2.07734,0.086899,1.06554,-2.05731,-0.015215,1.19414,-2.05454,-0.041738,1.1179,-2.03668,-0.056192,0.970162,-2.03061,-0.134037,0.796144,-2.02272,-0.223944,0.864309,-2.03014,-0.263365,0.805437,-2.02133,-0.375219,0.595858,-1.98806,-0.455178,0.642958,-1.91714,-0.339161,0.387133,-1.93612,-0.411517,0.406191,-1.9884,0.172428,1.37437,-1.79416,0.167964,1.35653,-2.00861},
/*1333*/{0.226593,1.94533,-1.70047,0.333629,1.88443,-1.82247,0.060413,1.87352,-1.65846,-0.073547,1.81489,-1.64912,0.048533,1.7044,-1.65248,0.107486,1.63507,-1.63864,0.298401,1.97395,-2.06994,0.353156,1.8877,-1.89658,0.157052,1.91903,-2.01816,0.205931,1.74866,-2.20752,0.2604,1.66177,-2.23259,0.369738,1.70375,-2.07284,0.429628,1.70306,-2.04986,0.258036,1.45562,-1.78978,0.076068,1.53026,-1.85783,0.080222,1.54909,-1.92249,0.085164,1.52423,-1.97385,0.262892,1.43125,-2.04481,0.377916,1.23187,-1.73345,0.27305,1.14995,-1.73602,0.316651,1.07925,-1.75642,0.421775,1.01773,-1.75163,0.441921,0.826168,-1.73387,0.444826,0.750807,-1.74358,0.332922,0.824848,-1.76171,0.33369,0.753412,-1.76619,0.388322,0.521143,-1.77169,0.305114,0.439512,-1.85057,0.551898,0.505326,-1.80401,0.534466,0.442148,-1.73942,0.119397,1.1441,-2.07819,0.089297,1.06694,-2.05822,-0.012687,1.19546,-2.05426,-0.039902,1.11895,-2.0362,-0.053221,0.970777,-2.03095,-0.135523,0.79809,-2.02303,-0.223431,0.869063,-2.03152,-0.264451,0.810238,-2.02291,-0.377954,0.604751,-1.98963,-0.462839,0.656978,-1.92191,-0.356636,0.398433,-1.93474,-0.424963,0.417123,-1.98718,0.171556,1.37559,-1.79452,0.16822,1.35913,-2.0091},
/*1334*/{0.227348,1.94796,-1.70048,0.335262,1.88592,-1.82241,0.060641,1.8749,-1.66069,-0.073449,1.81689,-1.65197,0.047946,1.70574,-1.65336,0.107304,1.63624,-1.63844,0.299571,1.97516,-2.06979,0.353675,1.8892,-1.89622,0.158536,1.92059,-2.01847,0.20813,1.75078,-2.20845,0.261493,1.66329,-2.23375,0.369748,1.70409,-2.07316,0.42948,1.70293,-2.04968,0.258696,1.45781,-1.79002,0.077301,1.53201,-1.8582,0.080417,1.55145,-1.92155,0.085977,1.52611,-1.9732,0.26368,1.43314,-2.04435,0.375938,1.22797,-1.73356,0.266971,1.14486,-1.73639,0.312918,1.07661,-1.75659,0.417918,1.01267,-1.75098,0.445633,0.822382,-1.73421,0.45022,0.746612,-1.7435,0.335516,0.815844,-1.76042,0.340152,0.744904,-1.76502,0.406006,0.515016,-1.77194,0.325984,0.430023,-1.85278,0.570224,0.506516,-1.80451,0.555489,0.443668,-1.74207,0.121597,1.14508,-2.0789,0.091805,1.06802,-2.05912,-0.01091,1.19639,-2.05314,-0.037939,1.11962,-2.03622,-0.049832,0.970545,-2.03125,-0.136458,0.798375,-2.02307,-0.223395,0.871187,-2.03281,-0.265011,0.815697,-2.02465,-0.393108,0.613799,-1.99125,-0.47099,0.671415,-1.9274,-0.371836,0.407721,-1.93194,-0.438775,0.428762,-1.98681,0.172473,1.37766,-1.7942,0.168923,1.36111,-2.00877},
/*1335*/{0.228075,1.94937,-1.70077,0.335212,1.88659,-1.82205,0.061151,1.87733,-1.66186,-0.073513,1.81799,-1.65594,0.048167,1.70717,-1.65441,0.107017,1.63737,-1.63871,0.301119,1.97589,-2.06974,0.355131,1.89031,-1.89606,0.159462,1.9226,-2.01839,0.20843,1.75371,-2.20849,0.261621,1.66449,-2.23482,0.369386,1.70365,-2.0732,0.42938,1.70121,-2.04959,0.259204,1.45927,-1.7904,0.077221,1.53266,-1.85748,0.080537,1.55331,-1.92148,0.085933,1.52775,-1.97302,0.26418,1.43574,-2.04408,0.373156,1.22398,-1.73333,0.261467,1.14153,-1.73609,0.306051,1.07284,-1.75689,0.413724,1.00716,-1.75057,0.450293,0.818768,-1.73474,0.456686,0.743298,-1.74477,0.339055,0.80719,-1.75804,0.346549,0.737006,-1.76358,0.422455,0.50924,-1.77264,0.345539,0.422126,-1.85413,0.586754,0.50913,-1.80666,0.575838,0.443732,-1.74265,0.124713,1.14632,-2.07904,0.095821,1.0685,-2.05915,-0.008405,1.19598,-2.053,-0.033992,1.1194,-2.03622,-0.045726,0.969898,-2.03157,-0.137537,0.799082,-2.0225,-0.219939,0.876095,-2.03493,-0.265877,0.820902,-2.02644,-0.39739,0.624798,-1.99384,-0.477872,0.684837,-1.93223,-0.386839,0.418783,-1.92985,-0.451233,0.439857,-1.9858,0.173158,1.37881,-1.7946,0.169663,1.36324,-2.00924},
/*1336*/{0.228806,1.95085,-1.70086,0.336338,1.88821,-1.82206,0.06182,1.87818,-1.66279,-0.072706,1.81883,-1.6581,0.048379,1.70776,-1.65573,0.106931,1.63775,-1.63863,0.301977,1.97638,-2.06943,0.355689,1.89192,-1.89589,0.160382,1.92362,-2.01836,0.208069,1.75422,-2.20819,0.26091,1.66477,-2.23552,0.3696,1.70202,-2.07367,0.429187,1.69908,-2.04954,0.260174,1.46033,-1.79008,0.077134,1.5331,-1.85692,0.080354,1.55383,-1.92074,0.086307,1.52885,-1.97234,0.264325,1.43782,-2.04395,0.370308,1.21824,-1.7334,0.258189,1.13972,-1.73624,0.301221,1.06959,-1.75739,0.408973,1.00177,-1.75029,0.453447,0.815097,-1.73599,0.463063,0.739966,-1.74602,0.343234,0.799372,-1.75561,0.353391,0.728891,-1.76192,0.43823,0.504467,-1.7741,0.363939,0.414067,-1.8562,0.600875,0.510379,-1.80819,0.594076,0.44541,-1.74541,0.128331,1.1461,-2.07897,0.098864,1.06868,-2.05932,-0.004938,1.19536,-2.05299,-0.03014,1.11786,-2.03603,-0.041221,0.968217,-2.03167,-0.13747,0.799167,-2.02234,-0.217304,0.878996,-2.0373,-0.264593,0.825807,-2.02791,-0.404604,0.635142,-1.99579,-0.484999,0.698489,-1.93796,-0.398914,0.430403,-1.92695,-0.464845,0.452042,-1.98599,0.174215,1.3795,-1.7946,0.170471,1.36471,-2.00929},
/*1337*/{0.230405,1.95151,-1.70073,0.337577,1.88743,-1.8215,0.062615,1.87909,-1.66497,-0.072135,1.81887,-1.66063,0.048811,1.70771,-1.65673,0.106971,1.63742,-1.6384,0.302626,1.97625,-2.06918,0.355999,1.89243,-1.89597,0.161529,1.92448,-2.01822,0.20647,1.75582,-2.20761,0.259267,1.66511,-2.23593,0.370355,1.69895,-2.07359,0.428926,1.69594,-2.05013,0.263216,1.46307,-1.79024,0.076969,1.53379,-1.85696,0.080093,1.55482,-1.91963,0.0863,1.53002,-1.97206,0.265501,1.43962,-2.04356,0.366795,1.21249,-1.73288,0.256883,1.13816,-1.73651,0.297006,1.06574,-1.75747,0.403722,0.996186,-1.75014,0.45692,0.812157,-1.73674,0.468664,0.737458,-1.74772,0.346462,0.792092,-1.75389,0.360433,0.72123,-1.76035,0.451961,0.501171,-1.77556,0.381365,0.40836,-1.85788,0.614441,0.512297,-1.80927,0.611068,0.447376,-1.74722,0.13217,1.14643,-2.0791,0.104106,1.06789,-2.05935,-0.001973,1.19383,-2.05347,-0.026217,1.11618,-2.03618,-0.035636,0.966268,-2.03192,-0.138002,0.799567,-2.02188,-0.214228,0.882366,-2.03904,-0.264168,0.830745,-2.02993,-0.40645,0.646411,-1.99722,-0.491208,0.712567,-1.94365,-0.413229,0.44263,-1.92476,-0.475242,0.465101,-1.98655,0.176913,1.3816,-1.794,0.17222,1.36607,-2.00862},
/*1338*/{0.231752,1.95259,-1.70101,0.338094,1.88768,-1.8218,0.06292,1.87926,-1.66594,-0.071161,1.81873,-1.66276,0.050707,1.70781,-1.65724,0.107031,1.63635,-1.63814,0.303397,1.97576,-2.06876,0.356501,1.89252,-1.89598,0.162228,1.92539,-2.01793,0.205152,1.75618,-2.20658,0.257546,1.66495,-2.23598,0.369243,1.69761,-2.07413,0.429081,1.69313,-2.05026,0.262643,1.46219,-1.79033,0.077395,1.53322,-1.85568,0.080532,1.55514,-1.91911,0.086151,1.53072,-1.97126,0.265353,1.44119,-2.04342,0.364034,1.20737,-1.73282,0.247551,1.13207,-1.73755,0.289194,1.06173,-1.75852,0.398271,0.990931,-1.7505,0.460007,0.809136,-1.7384,0.474153,0.73551,-1.75011,0.350576,0.785688,-1.7519,0.366292,0.715508,-1.75863,0.463899,0.497733,-1.77624,0.39611,0.403291,-1.85872,0.625867,0.514353,-1.81094,0.623969,0.448562,-1.74898,0.137113,1.14533,-2.07827,0.110431,1.06703,-2.05939,0.001544,1.19148,-2.05407,-0.021238,1.11341,-2.03629,-0.029751,0.963958,-2.03218,-0.137711,0.799899,-2.02153,-0.210773,0.884764,-2.04008,-0.262278,0.836603,-2.03178,-0.422121,0.655709,-1.99757,-0.496216,0.726742,-1.94756,-0.424844,0.455012,-1.92218,-0.483298,0.478356,-1.98556,0.176797,1.38062,-1.79466,0.172177,1.36718,-2.00942},
/*1339*/{0.23321,1.95267,-1.70092,0.338406,1.88789,-1.82192,0.064823,1.87879,-1.66596,-0.069843,1.81822,-1.66523,0.050997,1.70633,-1.65765,0.107492,1.63453,-1.63716,0.304287,1.97483,-2.06865,0.35683,1.89229,-1.89613,0.162304,1.92565,-2.01775,0.203034,1.75784,-2.206,0.256007,1.66507,-2.23572,0.370374,1.69368,-2.0748,0.428665,1.68853,-2.05092,0.262885,1.46196,-1.79065,0.076545,1.53261,-1.85525,0.079545,1.5549,-1.91839,0.085842,1.53052,-1.97031,0.265971,1.44242,-2.04308,0.359419,1.20098,-1.73249,0.243976,1.12992,-1.73738,0.283056,1.05708,-1.7592,0.392251,0.985595,-1.75012,0.462807,0.807186,-1.74018,0.479468,0.732969,-1.75203,0.353349,0.779797,-1.75163,0.371562,0.711155,-1.75805,0.473904,0.495215,-1.7769,0.409716,0.399862,-1.85956,0.63738,0.516615,-1.81203,0.637344,0.450116,-1.7512,0.141428,1.14476,-2.07807,0.115569,1.06596,-2.05949,0.005605,1.18775,-2.05341,-0.016183,1.11019,-2.03671,-0.023776,0.961391,-2.03244,-0.137029,0.800907,-2.02126,-0.206733,0.888563,-2.042,-0.259959,0.842984,-2.0333,-0.417181,0.669656,-2.0001,-0.500871,0.741207,-1.95207,-0.435652,0.468863,-1.92062,-0.494474,0.492155,-1.98613,0.177296,1.38008,-1.79493,0.172808,1.36783,-2.00977},
/*1340*/{0.234723,1.95213,-1.70081,0.339101,1.88934,-1.82229,0.065577,1.87751,-1.66702,-0.067308,1.81742,-1.66573,0.051668,1.7051,-1.65792,0.108883,1.6336,-1.63632,0.30549,1.97355,-2.06816,0.357525,1.89217,-1.89648,0.162339,1.92631,-2.01758,0.199882,1.75764,-2.20483,0.252939,1.66434,-2.23537,0.369938,1.6904,-2.07582,0.427525,1.68357,-2.05138,0.262889,1.46171,-1.79107,0.076102,1.53126,-1.85479,0.079398,1.55414,-1.91788,0.086319,1.52969,-1.97003,0.266223,1.44297,-2.04319,0.356992,1.1948,-1.73187,0.23873,1.12454,-1.73812,0.276811,1.05195,-1.75968,0.386405,0.98,-1.75022,0.464034,0.806028,-1.74184,0.483435,0.732644,-1.75327,0.354882,0.77503,-1.75123,0.374477,0.70541,-1.75811,0.484663,0.49431,-1.77785,0.420155,0.396604,-1.85978,0.646258,0.518051,-1.81404,0.64729,0.450945,-1.75258,0.146838,1.14347,-2.07734,0.121505,1.06378,-2.05915,0.010569,1.18463,-2.05402,-0.010574,1.1057,-2.03635,-0.017144,0.957895,-2.03161,-0.136429,0.801489,-2.02126,-0.201527,0.892037,-2.04278,-0.256655,0.848722,-2.034,-0.422978,0.682652,-2.00119,-0.504726,0.757533,-1.95602,-0.445615,0.483314,-1.91943,-0.5026,0.506332,-1.98621,0.178006,1.37919,-1.79529,0.173578,1.36778,-2.01018},
/*1341*/{0.23579,1.95119,-1.70078,0.339689,1.88857,-1.82233,0.066835,1.87657,-1.66755,-0.065301,1.81517,-1.66721,0.053676,1.7033,-1.65775,0.110427,1.63165,-1.63567,0.305798,1.9724,-2.06807,0.357269,1.89189,-1.89646,0.162842,1.926,-2.01654,0.196965,1.75747,-2.20338,0.250917,1.66397,-2.23504,0.369395,1.6862,-2.07615,0.427479,1.67851,-2.05217,0.262463,1.46047,-1.79138,0.077127,1.52913,-1.85434,0.079211,1.55339,-1.91777,0.085198,1.52801,-1.96905,0.266925,1.44379,-2.0433,0.353927,1.18805,-1.73128,0.232662,1.12034,-1.73908,0.270453,1.04796,-1.76076,0.379708,0.974171,-1.75067,0.463616,0.804349,-1.74261,0.484232,0.731142,-1.75409,0.355627,0.770994,-1.75185,0.3766,0.702825,-1.75921,0.493638,0.49273,-1.77868,0.428778,0.394972,-1.86046,0.653817,0.519472,-1.81468,0.656038,0.451939,-1.75516,0.151344,1.14195,-2.07659,0.128329,1.06191,-2.05848,0.013937,1.18099,-2.05368,-0.004823,1.10192,-2.03638,-0.009438,0.954434,-2.0314,-0.13494,0.802753,-2.02159,-0.19654,0.895657,-2.04429,-0.254517,0.855175,-2.03465,-0.425194,0.695764,-2.00252,-0.505982,0.772458,-1.95926,-0.455275,0.498021,-1.91948,-0.511211,0.523073,-1.98851,0.178793,1.37748,-1.79597,0.174397,1.36759,-2.01093},
/*1342*/{0.237633,1.95062,-1.70044,0.340856,1.88785,-1.82274,0.06876,1.87451,-1.66756,-0.063895,1.81234,-1.66784,0.055793,1.70124,-1.65787,0.112302,1.62907,-1.63446,0.30624,1.97056,-2.06809,0.357458,1.89026,-1.89636,0.16337,1.92541,-2.01538,0.193979,1.75734,-2.20199,0.24713,1.66297,-2.23463,0.368393,1.68161,-2.0768,0.426206,1.67273,-2.05362,0.267354,1.4618,-1.79101,0.076587,1.52784,-1.85326,0.079332,1.55185,-1.91699,0.085486,1.52692,-1.9686,0.2673,1.44389,-2.0432,0.348887,1.18221,-1.73098,0.230823,1.11807,-1.73886,0.264198,1.04369,-1.76229,0.373141,0.968471,-1.75232,0.461663,0.802708,-1.74356,0.484506,0.730814,-1.75487,0.355119,0.766845,-1.7536,0.377639,0.699759,-1.75923,0.496022,0.490579,-1.77899,0.435683,0.39225,-1.86056,0.658831,0.519501,-1.81751,0.662573,0.452582,-1.75636,0.157021,1.14024,-2.07557,0.134509,1.05974,-2.05826,0.018495,1.17539,-2.05333,0.000972,1.09602,-2.03578,-0.001922,0.95028,-2.031,-0.133503,0.804118,-2.02169,-0.190766,0.900071,-2.04454,-0.249205,0.861606,-2.03537,-0.42694,0.709479,-2.00401,-0.506729,0.788394,-1.95928,-0.463856,0.513067,-1.9201,-0.518544,0.538827,-1.988,0.182805,1.37808,-1.79493,0.17641,1.36682,-2.00977},
/*1343*/{0.238792,1.94954,-1.70023,0.340628,1.88716,-1.82287,0.069193,1.87289,-1.66759,-0.060805,1.81065,-1.66831,0.057632,1.69736,-1.65693,0.114536,1.62563,-1.63363,0.306016,1.96916,-2.06806,0.35798,1.88913,-1.89673,0.163239,1.9243,-2.01494,0.190917,1.75664,-2.20083,0.243825,1.66211,-2.23344,0.367923,1.67642,-2.07733,0.425619,1.66618,-2.05484,0.26727,1.45896,-1.79338,0.076724,1.52515,-1.85292,0.078794,1.55007,-1.916,0.085202,1.52486,-1.96807,0.267808,1.44382,-2.04307,0.346149,1.17592,-1.7292,0.223602,1.11304,-1.73998,0.258372,1.03882,-1.7633,0.367234,0.962784,-1.75195,0.459827,0.801174,-1.74307,0.484401,0.729126,-1.75528,0.353808,0.763001,-1.75544,0.377853,0.695465,-1.7611,0.501962,0.4893,-1.77945,0.440589,0.389445,-1.86092,0.662672,0.520555,-1.81901,0.667898,0.453195,-1.75844,0.162428,1.13786,-2.07515,0.14164,1.05718,-2.0582,0.023373,1.16997,-2.05299,0.00764,1.09054,-2.03539,0.006819,0.946002,-2.03094,-0.130281,0.80663,-2.02295,-0.183687,0.904205,-2.04485,-0.244363,0.867996,-2.03542,-0.431934,0.724267,-2.00689,-0.505644,0.806063,-1.96213,-0.470894,0.528955,-1.92157,-0.525105,0.55606,-1.9892,0.183474,1.375,-1.79643,0.176739,1.36607,-2.01137},
/*1344*/{0.240457,1.94791,-1.69967,0.34123,1.88534,-1.82341,0.070919,1.86987,-1.66714,-0.058377,1.80583,-1.66787,0.059517,1.69398,-1.65608,0.116752,1.62256,-1.63258,0.305254,1.96625,-2.06816,0.358062,1.8876,-1.89681,0.163269,1.92391,-2.01488,0.187253,1.75583,-2.19897,0.239626,1.66038,-2.23212,0.366506,1.67096,-2.07851,0.424756,1.65923,-2.05636,0.265411,1.45727,-1.79093,0.075947,1.52239,-1.85179,0.078286,1.54752,-1.91645,0.084369,1.52285,-1.96787,0.268487,1.44292,-2.04295,0.34334,1.16997,-1.72791,0.220576,1.11137,-1.7404,0.254569,1.03576,-1.76321,0.36211,0.957923,-1.75144,0.456676,0.79839,-1.74362,0.482045,0.72686,-1.75549,0.3513,0.759333,-1.75723,0.376148,0.691095,-1.7631,0.50286,0.486537,-1.78127,0.44445,0.386966,-1.86222,0.664176,0.519758,-1.8201,0.67021,0.453249,-1.76005,0.167791,1.13477,-2.07458,0.149695,1.05317,-2.05717,0.028233,1.16457,-2.05229,0.013325,1.08439,-2.0343,0.014369,0.940699,-2.03076,-0.127466,0.808216,-2.02356,-0.176277,0.908799,-2.04492,-0.238949,0.874155,-2.0351,-0.432251,0.738836,-2.01024,-0.502756,0.822753,-1.96372,-0.477242,0.544618,-1.92398,-0.53059,0.57401,-1.99106,0.182559,1.3727,-1.796,0.177487,1.36457,-2.01103},
/*1345*/{0.241586,1.94577,-1.69986,0.341611,1.88402,-1.82326,0.072508,1.86615,-1.66578,-0.05644,1.80033,-1.66701,0.062533,1.69037,-1.65485,0.119435,1.61841,-1.63083,0.305295,1.96409,-2.06824,0.35847,1.88565,-1.89701,0.162718,1.92162,-2.01406,0.183056,1.75419,-2.1979,0.237057,1.65855,-2.23214,0.365587,1.66488,-2.07976,0.422,1.65124,-2.05799,0.264637,1.45457,-1.79099,0.076269,1.51851,-1.85164,0.077952,1.54481,-1.91571,0.084568,1.51983,-1.96719,0.268753,1.44167,-2.04308,0.340866,1.16557,-1.7264,0.216656,1.1081,-1.74098,0.249876,1.03264,-1.76478,0.359185,0.954319,-1.75186,0.453608,0.794946,-1.74405,0.479638,0.723408,-1.75562,0.348787,0.754818,-1.75858,0.374347,0.689038,-1.76573,0.504686,0.484302,-1.78251,0.446256,0.38404,-1.86416,0.66506,0.518568,-1.82245,0.672376,0.451641,-1.7623,0.172662,1.13194,-2.07489,0.156064,1.04976,-2.05724,0.032245,1.15887,-2.05155,0.019461,1.07817,-2.03361,0.023854,0.93608,-2.03009,-0.123339,0.810682,-2.02517,-0.168673,0.912823,-2.04461,-0.231118,0.881881,-2.03576,-0.431847,0.754353,-2.01109,-0.499215,0.839772,-1.9635,-0.482503,0.560569,-1.927,-0.536445,0.592426,-1.99301,0.182972,1.36934,-1.79654,0.178202,1.36263,-2.01161},
/*1346*/{0.24251,1.94304,-1.69922,0.341902,1.88147,-1.8237,0.073873,1.86232,-1.66532,-0.054245,1.79553,-1.66561,0.065008,1.68585,-1.65406,0.122553,1.61484,-1.62908,0.305732,1.96112,-2.06863,0.358397,1.88304,-1.89711,0.162915,1.92022,-2.01365,0.179453,1.7525,-2.19577,0.232545,1.65649,-2.23089,0.363831,1.66009,-2.08121,0.421145,1.64346,-2.05995,0.264805,1.45155,-1.79117,0.075528,1.51626,-1.85128,0.078242,1.54183,-1.91515,0.08401,1.51621,-1.96687,0.269139,1.44058,-2.04275,0.33802,1.16151,-1.72433,0.214688,1.10465,-1.74127,0.247329,1.02984,-1.76468,0.358256,0.951377,-1.75135,0.4505,0.791107,-1.74373,0.476263,0.720021,-1.75551,0.345746,0.750365,-1.76104,0.372318,0.683593,-1.76724,0.505143,0.482968,-1.78602,0.445527,0.381223,-1.86615,0.664213,0.515942,-1.82446,0.672353,0.449461,-1.76371,0.177564,1.128,-2.07546,0.163397,1.04646,-2.0567,0.03721,1.1531,-2.05102,0.02578,1.07179,-2.03301,0.032642,0.931007,-2.03043,-0.118967,0.812487,-2.02604,-0.159589,0.916431,-2.04472,-0.223414,0.887829,-2.0359,-0.430404,0.76934,-2.01296,-0.493514,0.857128,-1.96349,-0.488931,0.576688,-1.93124,-0.539976,0.611815,-1.99605,0.183438,1.36637,-1.79681,0.178793,1.36059,-2.01192},
/*1347*/{0.243787,1.94035,-1.69907,0.342611,1.87713,-1.82421,0.075277,1.85742,-1.6633,-0.051669,1.7904,-1.66363,0.067856,1.68103,-1.65181,0.125199,1.61062,-1.62793,0.304144,1.95802,-2.06855,0.35774,1.88005,-1.89781,0.162487,1.9178,-2.01276,0.174682,1.74974,-2.19447,0.22779,1.65392,-2.23027,0.360938,1.65205,-2.08201,0.419209,1.63447,-2.06215,0.263973,1.44831,-1.79088,0.07542,1.51241,-1.85122,0.077432,1.53785,-1.91507,0.083394,1.51297,-1.96625,0.269792,1.43804,-2.0429,0.334978,1.1593,-1.7229,0.212587,1.10113,-1.74105,0.246251,1.02732,-1.76555,0.35894,0.950534,-1.75116,0.447827,0.787124,-1.74472,0.474189,0.716393,-1.75663,0.342783,0.745774,-1.76262,0.369386,0.679469,-1.76867,0.503048,0.478686,-1.78687,0.443796,0.377784,-1.86879,0.661891,0.513053,-1.82657,0.669938,0.445515,-1.76675,0.182695,1.12457,-2.07587,0.169749,1.04189,-2.05677,0.042437,1.14613,-2.04995,0.032587,1.06563,-2.03185,0.041659,0.925174,-2.02996,-0.113146,0.814079,-2.02731,-0.150624,0.920568,-2.04527,-0.215646,0.895234,-2.03688,-0.422532,0.78178,-2.01324,-0.485713,0.873259,-1.96322,-0.492192,0.592903,-1.93503,-0.54306,0.630114,-1.99819,0.183397,1.36271,-1.79703,0.179259,1.35769,-2.01217},
/*1348*/{0.244945,1.93675,-1.69869,0.34358,1.87415,-1.82434,0.076725,1.85285,-1.66224,-0.048966,1.78463,-1.66227,0.070474,1.67506,-1.65068,0.129237,1.60602,-1.62584,0.303033,1.95437,-2.06938,0.358427,1.8774,-1.89798,0.161819,1.91463,-2.01193,0.173887,1.74768,-2.19384,0.224106,1.65061,-2.2291,0.359662,1.64486,-2.08286,0.417587,1.62585,-2.065,0.265033,1.44473,-1.79021,0.074593,1.50947,-1.85106,0.07767,1.5337,-1.91492,0.083647,1.50907,-1.96663,0.269879,1.43614,-2.04242,0.333811,1.15592,-1.72022,0.211204,1.09967,-1.7418,0.244707,1.02438,-1.76685,0.360353,0.950195,-1.75164,0.444735,0.782646,-1.7451,0.471603,0.711791,-1.75731,0.340405,0.742428,-1.76316,0.366073,0.675876,-1.77072,0.499081,0.473871,-1.78897,0.439573,0.374889,-1.8718,0.65911,0.507883,-1.82786,0.665401,0.439942,-1.76926,0.18746,1.12045,-2.07631,0.176659,1.03808,-2.05721,0.047244,1.13906,-2.04884,0.037981,1.05912,-2.03061,0.050003,0.919397,-2.03019,-0.106723,0.815326,-2.02784,-0.139739,0.923806,-2.0452,-0.206707,0.897751,-2.03605,-0.421742,0.79859,-2.01596,-0.475749,0.887917,-1.96181,-0.49439,0.608757,-1.93982,-0.545219,0.649861,-2.00147,0.184065,1.35924,-1.79713,0.180241,1.35481,-2.01228},
/*1349*/{0.245874,1.93325,-1.69859,0.342674,1.87216,-1.82474,0.078002,1.8469,-1.66051,-0.046477,1.77763,-1.65935,0.073825,1.66986,-1.64737,0.133272,1.60103,-1.62413,0.302743,1.95085,-2.06997,0.358329,1.87392,-1.89824,0.160942,1.91117,-2.0108,0.169154,1.74456,-2.1919,0.219415,1.64728,-2.22822,0.357768,1.63861,-2.08466,0.415343,1.61677,-2.06712,0.264185,1.44145,-1.78948,0.074603,1.5048,-1.85136,0.076796,1.5301,-1.9159,0.082853,1.50461,-1.96726,0.270144,1.43345,-2.04212,0.332672,1.15355,-1.71951,0.210281,1.09726,-1.74312,0.24542,1.02249,-1.7667,0.361332,0.949028,-1.75295,0.441864,0.777326,-1.74592,0.468205,0.707061,-1.75865,0.337375,0.738679,-1.76477,0.363554,0.672809,-1.77108,0.494078,0.468089,-1.79117,0.434248,0.371177,-1.87473,0.654095,0.502471,-1.82947,0.66052,0.432881,-1.77155,0.192788,1.11636,-2.07618,0.183266,1.03383,-2.05736,0.051575,1.13245,-2.04769,0.045659,1.05194,-2.0304,0.059759,0.913657,-2.03066,-0.100339,0.815572,-2.02855,-0.129228,0.925873,-2.04505,-0.196844,0.902826,-2.03702,-0.415465,0.812493,-2.0174,-0.466026,0.903714,-1.9605,-0.496789,0.624203,-1.94441,-0.546639,0.670174,-2.00546,0.183879,1.35556,-1.79731,0.18105,1.35134,-2.01248},
/*1350*/{0.246604,1.9293,-1.69808,0.343139,1.8667,-1.8249,0.079559,1.84095,-1.65859,-0.045744,1.76997,-1.65693,0.077118,1.66372,-1.64469,0.137978,1.59583,-1.62242,0.302106,1.94719,-2.07083,0.358176,1.87043,-1.89888,0.160272,1.90774,-2.01029,0.165502,1.74176,-2.19075,0.213336,1.6435,-2.22725,0.35392,1.62993,-2.086,0.412906,1.60718,-2.06966,0.262935,1.43789,-1.7893,0.073802,1.50087,-1.85132,0.076438,1.52567,-1.91544,0.083061,1.50065,-1.9673,0.27039,1.43037,-2.04178,0.330966,1.15195,-1.71864,0.209848,1.09411,-1.7433,0.242524,1.0198,-1.76643,0.360686,0.946236,-1.75411,0.43935,0.772568,-1.74634,0.462941,0.702295,-1.75994,0.333898,0.734112,-1.7659,0.358947,0.667419,-1.77342,0.486734,0.463229,-1.79299,0.426687,0.367556,-1.87805,0.648037,0.495348,-1.83069,0.654958,0.425301,-1.7728,0.197571,1.1127,-2.07658,0.19062,1.02963,-2.05739,0.056516,1.12574,-2.04679,0.052314,1.04519,-2.02988,0.068584,0.908018,-2.03094,-0.093242,0.816425,-2.029,-0.11833,0.927046,-2.04414,-0.185943,0.906112,-2.03684,-0.408806,0.825685,-2.01918,-0.45387,0.918027,-1.95914,-0.496765,0.638417,-1.95004,-0.544734,0.68722,-2.00857,0.183449,1.35157,-1.79732,0.181466,1.34789,-2.01252},
/*1351*/{0.24734,1.92458,-1.69773,0.344298,1.86266,-1.82545,0.08099,1.83415,-1.65637,-0.042168,1.7625,-1.65297,0.080913,1.65732,-1.64176,0.141901,1.59026,-1.62026,0.300201,1.94248,-2.07195,0.358145,1.86626,-1.89931,0.159462,1.9037,-2.01009,0.160962,1.73704,-2.18944,0.208984,1.63949,-2.22655,0.351759,1.62134,-2.08784,0.410532,1.59733,-2.07333,0.261925,1.43447,-1.78796,0.072984,1.49614,-1.85133,0.076867,1.52222,-1.9157,0.082367,1.49561,-1.96758,0.270567,1.42742,-2.0415,0.328662,1.14938,-1.71833,0.207235,1.09288,-1.74553,0.24193,1.01749,-1.76709,0.358489,0.941635,-1.75454,0.435922,0.767965,-1.74798,0.460097,0.696106,-1.76135,0.329316,0.729252,-1.76845,0.354726,0.663927,-1.77564,0.479669,0.457891,-1.79563,0.41888,0.363277,-1.88102,0.642585,0.488871,-1.83149,0.646552,0.418133,-1.77561,0.202298,1.10875,-2.07736,0.197038,1.0256,-2.05742,0.06188,1.11843,-2.04575,0.059142,1.03739,-2.02923,0.077388,0.902185,-2.03126,-0.084658,0.814725,-2.02877,-0.105917,0.92665,-2.04317,-0.175559,0.909864,-2.03794,-0.399552,0.837213,-2.01933,-0.441765,0.93168,-1.95855,-0.495753,0.653534,-1.95446,-0.54184,0.705746,-2.01326,0.183167,1.34774,-1.79704,0.18221,1.34418,-2.01224},
/*1352*/{0.248008,1.92,-1.69748,0.343469,1.86049,-1.8261,0.083516,1.82743,-1.65356,-0.039157,1.75464,-1.64832,0.084436,1.65112,-1.63909,0.147329,1.58415,-1.61779,0.299439,1.93776,-2.07291,0.358228,1.8621,-1.90011,0.158667,1.89947,-2.00945,0.15652,1.73278,-2.18791,0.203425,1.63462,-2.22461,0.348326,1.61275,-2.08972,0.407318,1.5868,-2.07621,0.25991,1.43047,-1.78791,0.071906,1.4919,-1.85255,0.075378,1.51723,-1.91606,0.082696,1.49027,-1.96782,0.270919,1.42397,-2.04085,0.328806,1.14546,-1.71759,0.207787,1.08962,-1.74631,0.24078,1.01417,-1.76898,0.356468,0.936746,-1.75481,0.432451,0.761582,-1.74955,0.455589,0.689653,-1.76224,0.327328,0.726664,-1.76751,0.349595,0.658677,-1.77564,0.471846,0.451449,-1.79654,0.409012,0.358169,-1.88401,0.63322,0.480953,-1.83415,0.637347,0.408522,-1.77694,0.207484,1.10442,-2.07753,0.204051,1.02098,-2.05809,0.066659,1.11182,-2.04559,0.06531,1.03014,-2.02886,0.086618,0.896288,-2.03164,-0.078809,0.818138,-2.03064,-0.094431,0.927719,-2.04368,-0.163856,0.913316,-2.03853,-0.389649,0.848386,-2.02099,-0.428486,0.943576,-1.9582,-0.491165,0.667692,-1.95951,-0.53594,0.722211,-2.0175,0.182193,1.34339,-1.79715,0.182876,1.34002,-2.01235},
/*1353*/{0.247819,1.91445,-1.69705,0.344235,1.85406,-1.82672,0.084847,1.81962,-1.6511,-0.038084,1.74597,-1.64471,0.088481,1.64377,-1.63576,0.152277,1.5783,-1.61642,0.298382,1.93314,-2.07391,0.358378,1.85813,-1.90057,0.158175,1.89479,-2.00894,0.152127,1.7284,-2.18755,0.198307,1.63021,-2.2237,0.345362,1.60337,-2.09141,0.404309,1.57599,-2.07913,0.259236,1.4274,-1.78739,0.071099,1.48654,-1.85213,0.076116,1.51337,-1.91583,0.081353,1.48523,-1.96862,0.270805,1.42035,-2.04044,0.327238,1.14292,-1.71847,0.20683,1.086,-1.74797,0.240508,1.01087,-1.76992,0.353482,0.93157,-1.75448,0.428606,0.755608,-1.75032,0.449081,0.684082,-1.76458,0.321296,0.723292,-1.76907,0.342709,0.655329,-1.77711,0.461887,0.444659,-1.79719,0.397983,0.353975,-1.88479,0.625161,0.471078,-1.83407,0.626385,0.399412,-1.77793,0.21273,1.10103,-2.07777,0.211697,1.01682,-2.05851,0.072018,1.10493,-2.0453,0.072396,1.02286,-2.02805,0.096621,0.890676,-2.03228,-0.070445,0.815285,-2.03029,-0.083369,0.928278,-2.04313,-0.152307,0.915903,-2.03897,-0.380288,0.85993,-2.02261,-0.415788,0.954249,-1.95876,-0.485408,0.681651,-1.96343,-0.52712,0.736682,-2.02092,0.18234,1.33958,-1.79673,0.183366,1.33585,-2.01193},
/*1354*/{0.248564,1.90881,-1.69657,0.344862,1.84952,-1.82693,0.086985,1.81172,-1.64858,-0.035143,1.73703,-1.6409,0.094204,1.63725,-1.63254,0.158134,1.57246,-1.61453,0.297178,1.92757,-2.07485,0.358604,1.85362,-1.90121,0.157103,1.8899,-2.00902,0.148675,1.72293,-2.18608,0.193179,1.6255,-2.2227,0.340751,1.59403,-2.09369,0.400156,1.5647,-2.08275,0.259266,1.42417,-1.78612,0.070592,1.48185,-1.85296,0.07486,1.50851,-1.91666,0.081281,1.47965,-1.9686,0.270256,1.41673,-2.04002,0.326692,1.13845,-1.71725,0.204978,1.08086,-1.7493,0.239413,1.00725,-1.7716,0.350726,0.926859,-1.75544,0.423597,0.749591,-1.75168,0.443938,0.677011,-1.76494,0.316062,0.719072,-1.76986,0.336667,0.649905,-1.77902,0.450531,0.438099,-1.79904,0.385777,0.348695,-1.88749,0.615788,0.461563,-1.83507,0.615242,0.390133,-1.77875,0.218559,1.09621,-2.07819,0.218993,1.01302,-2.05908,0.077855,1.0973,-2.04442,0.080571,1.0162,-2.02827,0.106385,0.885162,-2.03293,-0.061849,0.815322,-2.03071,-0.071167,0.929162,-2.04329,-0.141174,0.918153,-2.03953,-0.368474,0.869735,-2.02327,-0.402568,0.964375,-1.95887,-0.480062,0.693013,-1.96866,-0.52182,0.750321,-2.02486,0.182672,1.33597,-1.79608,0.184211,1.33128,-2.01126},
/*1355*/{0.249416,1.90288,-1.69606,0.344833,1.84583,-1.82761,0.089123,1.80321,-1.6452,-0.031297,1.72758,-1.63551,0.098181,1.62943,-1.62939,0.16411,1.56553,-1.61227,0.295953,1.92246,-2.07607,0.358015,1.84847,-1.90229,0.156952,1.88429,-2.00831,0.145174,1.71807,-2.18491,0.187861,1.62107,-2.22131,0.33808,1.58413,-2.0954,0.395612,1.55307,-2.08601,0.259291,1.42181,-1.78567,0.070204,1.47792,-1.85459,0.075451,1.50339,-1.91638,0.080695,1.4739,-1.9696,0.269911,1.41298,-2.04077,0.325193,1.13428,-1.71736,0.205743,1.07884,-1.75034,0.239775,1.00371,-1.77156,0.347431,0.921567,-1.75541,0.418046,0.743782,-1.75217,0.437706,0.670347,-1.76719,0.310639,0.714228,-1.77109,0.329483,0.645352,-1.78007,0.440397,0.434805,-1.80044,0.369062,0.351966,-1.88822,0.603855,0.450103,-1.83632,0.60115,0.380218,-1.77939,0.224794,1.09298,-2.07864,0.226594,1.00903,-2.06003,0.083913,1.09047,-2.04435,0.088453,1.00973,-2.02778,0.116737,0.880083,-2.03349,-0.052446,0.814867,-2.0318,-0.059219,0.93001,-2.04327,-0.128375,0.921182,-2.04231,-0.357635,0.879528,-2.02463,-0.390002,0.974544,-1.96,-0.473922,0.70356,-1.97411,-0.511616,0.763544,-2.02915,0.18364,1.33292,-1.7957,0.185102,1.32665,-2.01084},
/*1356*/{0.24984,1.89681,-1.69521,0.34528,1.83934,-1.82762,0.09116,1.79506,-1.64247,-0.028141,1.71761,-1.63046,0.103949,1.62182,-1.62596,0.170684,1.56001,-1.61018,0.294326,1.9171,-2.07786,0.358444,1.84372,-1.90339,0.155562,1.87905,-2.00837,0.140386,1.7123,-2.18392,0.181822,1.61561,-2.2201,0.333614,1.57405,-2.09814,0.391085,1.54094,-2.08996,0.258579,1.41838,-1.78385,0.069451,1.4702,-1.85506,0.073781,1.49766,-1.91669,0.07922,1.46799,-1.97048,0.270903,1.40912,-2.03809,0.32495,1.12991,-1.7171,0.203592,1.07458,-1.75238,0.23838,0.998558,-1.77341,0.34486,0.916959,-1.75557,0.412298,0.737157,-1.75246,0.431039,0.664348,-1.76628,0.304011,0.709745,-1.77289,0.322452,0.640434,-1.78109,0.427183,0.431291,-1.80153,0.351429,0.353634,-1.88981,0.592039,0.438243,-1.83831,0.581216,0.367723,-1.77999,0.230814,1.08831,-2.07918,0.233658,1.00459,-2.06066,0.090345,1.08372,-2.04432,0.09714,1.00293,-2.02692,0.126912,0.874588,-2.03501,-0.042715,0.81466,-2.03315,-0.04593,0.928138,-2.0449,-0.11575,0.92161,-2.04056,-0.345334,0.887671,-2.02586,-0.377489,0.983396,-1.96118,-0.465005,0.71277,-1.97788,-0.501112,0.773991,-2.03274,0.183737,1.32826,-1.79465,0.187316,1.32173,-2.00976},
/*1357*/{0.250199,1.89041,-1.69482,0.345409,1.83585,-1.82902,0.094122,1.7864,-1.63924,-0.024235,1.70736,-1.62521,0.108271,1.61359,-1.62272,0.176733,1.55369,-1.60862,0.292607,1.91148,-2.07852,0.358637,1.83816,-1.90439,0.154542,1.87392,-2.00727,0.136169,1.70766,-2.18329,0.176812,1.61056,-2.21933,0.329264,1.56354,-2.10013,0.38643,1.52869,-2.09372,0.256932,1.41395,-1.78232,0.068203,1.46585,-1.85555,0.073964,1.49286,-1.91664,0.079073,1.46253,-1.97137,0.270062,1.40395,-2.03953,0.324036,1.124,-1.7176,0.202223,1.06737,-1.75217,0.23661,0.993741,-1.77407,0.342434,0.912158,-1.75623,0.406767,0.72966,-1.75322,0.417762,0.655874,-1.76778,0.297246,0.704785,-1.77379,0.314303,0.635655,-1.78337,0.411556,0.423891,-1.80287,0.333305,0.35436,-1.89356,0.57768,0.424334,-1.83976,0.563778,0.354379,-1.78209,0.237017,1.08401,-2.07918,0.241215,1.00044,-2.06133,0.09615,1.07689,-2.04346,0.104669,0.996425,-2.02776,0.137,0.869161,-2.03594,-0.032752,0.813779,-2.03391,-0.032083,0.927706,-2.04635,-0.102309,0.922849,-2.04006,-0.332888,0.895372,-2.02688,-0.364176,0.990192,-1.96253,-0.453529,0.722028,-1.981,-0.488877,0.783107,-2.03617,0.182523,1.32373,-1.79444,0.18667,1.31656,-2.00952},
/*1358*/{0.251088,1.88373,-1.6937,0.345695,1.82887,-1.82959,0.097088,1.77702,-1.6362,-0.020579,1.69591,-1.61947,0.113816,1.60574,-1.6201,0.183989,1.54828,-1.60695,0.292084,1.90549,-2.07986,0.357804,1.83392,-1.90573,0.153308,1.86744,-2.00736,0.132668,1.70192,-2.18223,0.17112,1.60547,-2.21813,0.325225,1.55343,-2.10323,0.381102,1.51577,-2.0972,0.256562,1.4104,-1.78169,0.067817,1.45992,-1.85675,0.073035,1.48701,-1.91658,0.078745,1.45599,-1.97164,0.27063,1.40016,-2.03679,0.3232,1.11897,-1.71646,0.20011,1.06256,-1.75338,0.235028,0.988415,-1.775,0.340658,0.906659,-1.75651,0.399604,0.722804,-1.75346,0.415099,0.649335,-1.7685,0.290764,0.699216,-1.77279,0.306581,0.630621,-1.78341,0.397268,0.420659,-1.80721,0.313768,0.355949,-1.89491,0.562151,0.408953,-1.84161,0.544172,0.342348,-1.78273,0.243477,1.07992,-2.07988,0.249286,0.997096,-2.06228,0.102601,1.07004,-2.0439,0.111822,0.989255,-2.0278,0.148062,0.863514,-2.03814,-0.022355,0.813128,-2.03585,-0.018408,0.928921,-2.04582,-0.089082,0.922991,-2.04108,-0.319855,0.903284,-2.02883,-0.352395,0.99693,-1.9636,-0.441288,0.729236,-1.98514,-0.476546,0.790769,-2.0402,0.182977,1.31943,-1.79338,0.188659,1.31155,-2.0084},
/*1359*/{0.251759,1.87728,-1.69315,0.345374,1.82423,-1.83018,0.100764,1.76694,-1.63272,-0.015625,1.6845,-1.61318,0.121343,1.59896,-1.61666,0.191914,1.54163,-1.60501,0.29015,1.90003,-2.08101,0.357823,1.82761,-1.90607,0.152501,1.8624,-2.00645,0.12799,1.6971,-2.1813,0.165194,1.60026,-2.21734,0.319931,1.54179,-2.10606,0.374792,1.50316,-2.10105,0.25648,1.40676,-1.78054,0.066003,1.45383,-1.85852,0.071907,1.48004,-1.91613,0.077313,1.45045,-1.97327,0.269218,1.3953,-2.03809,0.319744,1.11097,-1.7173,0.199658,1.0586,-1.75246,0.23341,0.983297,-1.77584,0.337224,0.900984,-1.75621,0.393425,0.716445,-1.75541,0.406424,0.642689,-1.77016,0.283169,0.696722,-1.77477,0.296596,0.626209,-1.78432,0.382102,0.417565,-1.8105,0.292504,0.356493,-1.89422,0.547061,0.397603,-1.84522,0.523944,0.337364,-1.78271,0.248225,1.07542,-2.08096,0.257309,0.992257,-2.06287,0.109076,1.06208,-2.04383,0.121193,0.981924,-2.02796,0.159709,0.856245,-2.03913,-0.010976,0.812452,-2.03702,-0.004797,0.925171,-2.04546,-0.074671,0.924579,-2.04109,-0.306356,0.907553,-2.02957,-0.340119,1.0029,-1.96472,-0.428603,0.734302,-1.98754,-0.461791,0.796472,-2.04396,0.183088,1.31485,-1.79351,0.188753,1.30614,-2.0085},
/*1360*/{0.253061,1.87108,-1.69227,0.346715,1.8169,-1.83108,0.104556,1.75655,-1.62902,-0.009156,1.67378,-1.60727,0.127408,1.5908,-1.61383,0.200067,1.53608,-1.60273,0.287921,1.89441,-2.08212,0.358572,1.82248,-1.90746,0.150774,1.856,-2.00615,0.12406,1.69155,-2.18057,0.159708,1.59453,-2.21657,0.314594,1.52974,-2.10892,0.368899,1.49042,-2.1047,0.255806,1.40254,-1.77947,0.065333,1.44858,-1.85827,0.070154,1.47426,-1.91645,0.075934,1.44418,-1.97472,0.269949,1.38953,-2.03629,0.318138,1.10644,-1.71568,0.195088,1.05269,-1.75215,0.230175,0.97868,-1.7757,0.333502,0.894087,-1.7555,0.386528,0.710355,-1.75758,0.397555,0.636848,-1.77408,0.276164,0.694392,-1.77574,0.287942,0.623554,-1.78597,0.36399,0.41601,-1.81265,0.269811,0.356795,-1.89365,0.52568,0.393239,-1.85257,0.501077,0.338837,-1.78321,0.255186,1.07202,-2.08098,0.265156,0.98882,-2.06383,0.114926,1.05621,-2.04428,0.128279,0.975306,-2.02831,0.171039,0.852686,-2.04,0.000671,0.810678,-2.03787,0.009667,0.923731,-2.04552,-0.06136,0.924193,-2.04138,-0.292102,0.912031,-2.03074,-0.327438,1.00734,-1.96625,-0.415964,0.739047,-1.99029,-0.448113,0.801797,-2.04787,0.182338,1.31045,-1.79217,0.189247,1.30022,-2.00705},
/*1361*/{0.254203,1.86524,-1.69151,0.34759,1.81262,-1.83227,0.108713,1.74611,-1.6256,-0.003138,1.66236,-1.60146,0.136058,1.58276,-1.60986,0.208208,1.53061,-1.60237,0.287772,1.88993,-2.08347,0.358848,1.81677,-1.90875,0.149312,1.8514,-2.00511,0.120078,1.68734,-2.17986,0.153924,1.58941,-2.2162,0.309471,1.51862,-2.11193,0.36217,1.47777,-2.10851,0.253245,1.39812,-1.7787,0.061102,1.44378,-1.86001,0.068061,1.46854,-1.91826,0.074221,1.43795,-1.97496,0.268696,1.38513,-2.03665,0.312782,1.10408,-1.71051,0.19326,1.05056,-1.75238,0.226821,0.976223,-1.77683,0.328114,0.886295,-1.75666,0.381051,0.70689,-1.75979,0.388003,0.634071,-1.77709,0.269862,0.696054,-1.77554,0.277968,0.624936,-1.78753,0.343147,0.417334,-1.81634,0.246875,0.356915,-1.89469,0.502751,0.391971,-1.85622,0.480551,0.340335,-1.78503,0.260159,1.06827,-2.08143,0.272894,0.985583,-2.06477,0.121634,1.04793,-2.0447,0.135922,0.968301,-2.02795,0.182179,0.848245,-2.04103,0.013328,0.810195,-2.03959,0.023415,0.921979,-2.0466,-0.045767,0.923367,-2.04098,-0.273207,0.913088,-2.02905,-0.314108,1.01183,-1.96943,-0.400567,0.741968,-1.992,-0.431057,0.803336,-2.05085,0.179892,1.30587,-1.79229,0.188383,1.29515,-2.0071},
/*1362*/{0.255044,1.8598,-1.69091,0.347824,1.80639,-1.83293,0.113453,1.73589,-1.62175,0.002551,1.65095,-1.5951,0.143467,1.57548,-1.60668,0.216857,1.52578,-1.60016,0.285875,1.8854,-2.08528,0.358793,1.8114,-1.91018,0.14844,1.84784,-2.00402,0.115212,1.68209,-2.17911,0.148129,1.58406,-2.21623,0.303357,1.50651,-2.11553,0.354879,1.46534,-2.11219,0.250468,1.39476,-1.77973,0.05888,1.43911,-1.86139,0.066796,1.46214,-1.91962,0.072037,1.43281,-1.97643,0.265277,1.379,-2.03827,0.309846,1.101,-1.70959,0.188773,1.04761,-1.75222,0.225389,0.975667,-1.7783,0.322993,0.881887,-1.75823,0.376635,0.707321,-1.76176,0.380205,0.632991,-1.77965,0.264376,0.701033,-1.77656,0.269065,0.630103,-1.7885,0.321061,0.419918,-1.81809,0.22338,0.358106,-1.89606,0.480968,0.391062,-1.85687,0.455299,0.340467,-1.78595,0.265611,1.06473,-2.08224,0.280149,0.982616,-2.06588,0.127633,1.04077,-2.04465,0.144572,0.962282,-2.02833,0.193867,0.844198,-2.04188,0.026473,0.807986,-2.03991,0.038065,0.921669,-2.04777,-0.031877,0.922742,-2.042,-0.258901,0.915789,-2.03125,-0.300714,1.01433,-1.97086,-0.385794,0.743738,-1.99439,-0.414744,0.804969,-2.05344,0.177867,1.30191,-1.7926,0.185905,1.28916,-2.00731},
/*1363*/{0.255865,1.85516,-1.68972,0.349312,1.80076,-1.83398,0.118513,1.72563,-1.61873,0.010263,1.63967,-1.58846,0.151122,1.56829,-1.60443,0.226528,1.52145,-1.59935,0.284772,1.88161,-2.08648,0.359928,1.80698,-1.91178,0.147455,1.84512,-2.00153,0.112583,1.67849,-2.17884,0.142567,1.57971,-2.2151,0.297538,1.49561,-2.11937,0.347357,1.45365,-2.1161,0.247616,1.39147,-1.77983,0.056409,1.43474,-1.86154,0.063137,1.45791,-1.92139,0.06943,1.42651,-1.97795,0.265462,1.37461,-2.03636,0.309654,1.10102,-1.70644,0.190657,1.05208,-1.7536,0.226396,0.976164,-1.77699,0.32188,0.88518,-1.757,0.372248,0.707562,-1.76329,0.37137,0.632949,-1.78004,0.259719,0.708011,-1.77578,0.260316,0.636804,-1.78943,0.302814,0.423507,-1.82006,0.202196,0.359754,-1.89771,0.458441,0.389587,-1.85674,0.43336,0.339207,-1.78466,0.270621,1.06248,-2.08255,0.287181,0.980609,-2.06646,0.132048,1.03404,-2.0455,0.151992,0.955542,-2.02971,0.205136,0.8406,-2.04302,0.039667,0.805972,-2.04066,0.053669,0.917963,-2.0477,-0.015857,0.92158,-2.04308,-0.24829,0.918573,-2.03367,-0.286243,1.01528,-1.97382,-0.36907,0.744594,-1.99613,-0.398831,0.804818,-2.05628,0.175411,1.29852,-1.79179,0.185433,1.28433,-2.00632},
/*1364*/{0.256803,1.85046,-1.68898,0.348287,1.79743,-1.83679,0.124998,1.71575,-1.61582,0.017608,1.62906,-1.58291,0.160752,1.56199,-1.6021,0.237155,1.51717,-1.59782,0.283075,1.878,-2.08853,0.360162,1.80233,-1.91404,0.146899,1.84306,-2.00021,0.108811,1.67518,-2.17792,0.137172,1.57602,-2.2135,0.291268,1.48547,-2.12223,0.338901,1.44254,-2.11992,0.245121,1.38894,-1.77936,0.052552,1.43153,-1.86377,0.060764,1.45262,-1.92306,0.066587,1.42124,-1.97848,0.264413,1.37014,-2.03528,0.308458,1.10219,-1.70541,0.190717,1.05292,-1.75462,0.226491,0.976159,-1.77495,0.325655,0.891006,-1.75612,0.365219,0.706921,-1.76396,0.360287,0.6331,-1.78149,0.252401,0.713364,-1.77519,0.249496,0.642669,-1.78773,0.282075,0.424456,-1.82085,0.1799,0.360856,-1.8972,0.436938,0.389078,-1.85665,0.411288,0.338231,-1.78472,0.27459,1.06201,-2.08275,0.294543,0.980724,-2.06718,0.137489,1.02926,-2.04606,0.160665,0.951118,-2.02955,0.217693,0.837192,-2.04286,0.054126,0.803799,-2.04074,0.067032,0.914582,-2.04886,-0.002242,0.919806,-2.0439,-0.233255,0.919566,-2.03643,-0.273675,1.01481,-1.97615,-0.353102,0.743618,-1.99797,-0.38189,0.803163,-2.05828,0.172709,1.29588,-1.79088,0.18436,1.27952,-2.00518},
/*1365*/{0.257917,1.84676,-1.68801,0.349293,1.7928,-1.83743,0.130675,1.70644,-1.61392,0.027145,1.61868,-1.57762,0.170875,1.55686,-1.60012,0.247446,1.51361,-1.59703,0.282621,1.87496,-2.08905,0.360259,1.79867,-1.91629,0.145878,1.84151,-1.9994,0.105989,1.67304,-2.17605,0.132214,1.57381,-2.21197,0.284731,1.4784,-2.12432,0.329466,1.43222,-2.12414,0.242993,1.3869,-1.77779,0.049424,1.4277,-1.86621,0.059053,1.45038,-1.92293,0.063743,1.4155,-1.98048,0.265211,1.36572,-2.03247,0.30714,1.10398,-1.70589,0.190006,1.0494,-1.75298,0.226971,0.975261,-1.77441,0.332991,0.896067,-1.7549,0.356464,0.706115,-1.76426,0.350213,0.633509,-1.7803,0.244442,0.717908,-1.77352,0.236159,0.647529,-1.78712,0.262228,0.425245,-1.82118,0.15792,0.361651,-1.89843,0.415522,0.387728,-1.85641,0.389114,0.33768,-1.78488,0.280045,1.06297,-2.08271,0.301789,0.982192,-2.06717,0.145053,1.0259,-2.0467,0.168786,0.948501,-2.03106,0.230685,0.835134,-2.04277,0.06815,0.801824,-2.04059,0.082413,0.912165,-2.04981,0.014115,0.91869,-2.04546,-0.218221,0.916799,-2.03647,-0.261047,1.01369,-1.97973,-0.336774,0.740977,-1.99905,-0.365334,0.799957,-2.06055,0.169886,1.29377,-1.78917,0.184252,1.27512,-2.00311},
/*1366*/{0.2585,1.84368,-1.68843,0.348294,1.79124,-1.83961,0.136932,1.69942,-1.61215,0.036756,1.60965,-1.57229,0.181095,1.55196,-1.59846,0.258129,1.51105,-1.59615,0.282237,1.87265,-2.08957,0.359709,1.79513,-1.91735,0.14579,1.84086,-2.00003,0.10207,1.67237,-2.17277,0.126491,1.5734,-2.21038,0.277912,1.47222,-2.12613,0.321062,1.42378,-2.12802,0.240573,1.38566,-1.77597,0.047769,1.42632,-1.86761,0.057524,1.4498,-1.92374,0.060916,1.41246,-1.98194,0.263003,1.36236,-2.03197,0.307005,1.10478,-1.7062,0.188786,1.04574,-1.75022,0.227656,0.973803,-1.77296,0.340664,0.898193,-1.75504,0.346825,0.706976,-1.76131,0.337651,0.632411,-1.77861,0.234991,0.720328,-1.77302,0.2264,0.650199,-1.78489,0.24238,0.42549,-1.8205,0.136288,0.361561,-1.89789,0.394584,0.386543,-1.85581,0.365866,0.338019,-1.78463,0.285868,1.06456,-2.08294,0.310183,0.984183,-2.06712,0.151195,1.0234,-2.04742,0.17736,0.946205,-2.0323,0.244999,0.834048,-2.04201,0.083439,0.799901,-2.04025,0.097789,0.910858,-2.05051,0.028195,0.917122,-2.04663,-0.20386,0.914029,-2.03886,-0.248474,1.01058,-1.98203,-0.319836,0.737416,-2.00074,-0.349132,0.794875,-2.06254,0.166634,1.29291,-1.78818,0.18187,1.27212,-2.00186},
/*1367*/{0.259355,1.84133,-1.689,0.347917,1.7877,-1.83986,0.142342,1.69425,-1.61109,0.047274,1.6018,-1.56699,0.192165,1.54831,-1.59718,0.270548,1.50923,-1.59547,0.282617,1.87122,-2.0896,0.35907,1.79401,-1.9183,0.145825,1.84013,-2.00059,0.097908,1.67397,-2.16956,0.120842,1.5745,-2.20917,0.270027,1.46739,-2.12746,0.311796,1.41642,-2.13202,0.237667,1.3835,-1.77473,0.046287,1.42582,-1.86809,0.055893,1.45022,-1.92381,0.059325,1.41034,-1.98248,0.262211,1.35976,-2.03211,0.304371,1.10308,-1.70658,0.185287,1.04452,-1.75021,0.224611,0.972175,-1.77112,0.343684,0.897343,-1.75571,0.335391,0.705227,-1.75922,0.324158,0.631105,-1.77655,0.225123,0.722574,-1.77219,0.213214,0.652191,-1.78495,0.22085,0.425549,-1.82066,0.115045,0.363025,-1.89695,0.373685,0.385667,-1.85492,0.344311,0.337292,-1.78431,0.292347,1.06669,-2.08275,0.319167,0.986978,-2.06704,0.157617,1.02125,-2.05008,0.185767,0.944934,-2.03409,0.260397,0.834685,-2.04172,0.09802,0.797977,-2.03933,0.112997,0.909559,-2.05157,0.044935,0.914162,-2.04914,-0.189857,0.910992,-2.04115,-0.236316,1.00678,-1.9853,-0.302696,0.731132,-2.00153,-0.332022,0.788493,-2.06457,0.163335,1.2915,-1.7878,0.179552,1.2702,-2.00136},
/*1368*/{0.259335,1.83996,-1.69043,0.346572,1.78671,-1.8409,0.148205,1.69013,-1.60967,0.056869,1.59516,-1.56307,0.203039,1.54534,-1.59635,0.282153,1.5085,-1.59521,0.282171,1.86875,-2.08986,0.357037,1.79247,-1.91879,0.145092,1.83858,-2.00115,0.093248,1.67535,-2.16618,0.114839,1.57664,-2.20802,0.262017,1.4636,-2.12972,0.302948,1.41057,-2.13528,0.236188,1.38291,-1.77274,0.045651,1.42436,-1.86918,0.054888,1.44901,-1.92361,0.057703,1.40997,-1.98328,0.260547,1.35806,-2.03207,0.299619,1.10053,-1.70529,0.181074,1.04455,-1.75037,0.219646,0.969828,-1.77043,0.339608,0.893531,-1.75532,0.323138,0.701495,-1.75767,0.31222,0.629981,-1.7746,0.212797,0.722395,-1.77095,0.20035,0.652333,-1.78263,0.201358,0.426785,-1.81913,0.093203,0.363473,-1.89627,0.351899,0.385514,-1.85511,0.323351,0.33637,-1.78274,0.29905,1.0698,-2.08265,0.328445,0.990664,-2.06673,0.165498,1.02018,-2.05145,0.197759,0.944268,-2.03591,0.277502,0.836311,-2.04094,0.114089,0.796267,-2.03854,0.128293,0.908171,-2.05288,0.058707,0.91183,-2.04928,-0.176207,0.905986,-2.04122,-0.224133,1.0009,-1.98797,-0.283214,0.725017,-2.00305,-0.314043,0.779355,-2.06592,0.161489,1.2907,-1.78736,0.178262,1.26883,-2.00082},
/*1369*/{0.25986,1.83895,-1.69138,0.34577,1.78409,-1.84051,0.154732,1.6877,-1.60866,0.067921,1.59048,-1.55878,0.215531,1.54393,-1.59502,0.295271,1.50878,-1.5953,0.282162,1.86764,-2.09017,0.357126,1.79094,-1.91829,0.144783,1.83833,-2.00255,0.090029,1.67907,-2.16277,0.108159,1.57926,-2.20743,0.254039,1.46155,-2.1316,0.292988,1.40677,-2.13871,0.233869,1.38212,-1.77154,0.044718,1.42405,-1.8692,0.053163,1.44787,-1.92424,0.057275,1.40985,-1.9829,0.257655,1.35716,-2.03291,0.296757,1.09717,-1.70474,0.175908,1.04153,-1.75013,0.214889,0.967592,-1.77043,0.33244,0.889348,-1.75437,0.310968,0.697654,-1.75559,0.293206,0.624476,-1.77319,0.200364,0.721424,-1.77112,0.18554,0.652679,-1.78316,0.181672,0.427463,-1.81887,0.071744,0.364274,-1.89568,0.329776,0.385057,-1.85489,0.301062,0.336123,-1.78205,0.306942,1.0733,-2.0827,0.338344,0.995145,-2.06619,0.174288,1.02157,-2.05514,0.207761,0.944457,-2.03779,0.293386,0.838107,-2.03987,0.129643,0.795099,-2.03773,0.143007,0.907085,-2.05422,0.072398,0.911152,-2.05104,-0.158364,0.897863,-2.04121,-0.214704,0.995704,-1.99015,-0.264789,0.716646,-2.00356,-0.296261,0.769536,-2.06714,0.159374,1.28994,-1.78732,0.17618,1.26802,-2.00078},
/*1370*/{0.260593,1.83793,-1.69229,0.344841,1.78431,-1.84197,0.159168,1.68584,-1.6082,0.078232,1.58543,-1.55411,0.22672,1.54223,-1.59316,0.307101,1.51,-1.59534,0.281866,1.86676,-2.09044,0.356515,1.79022,-1.91844,0.144368,1.83823,-2.00382,0.084843,1.68236,-2.16025,0.101921,1.58209,-2.20714,0.246469,1.46028,-2.13389,0.284119,1.40493,-2.14206,0.2328,1.38187,-1.77111,0.043744,1.42347,-1.86913,0.052544,1.447,-1.92353,0.05557,1.40961,-1.98235,0.25607,1.35747,-2.03354,0.291192,1.09379,-1.70376,0.170855,1.04031,-1.7502,0.208061,0.965906,-1.77097,0.321203,0.884404,-1.75238,0.295934,0.693313,-1.75522,0.277696,0.621012,-1.77307,0.187444,0.721138,-1.76972,0.170788,0.652259,-1.78163,0.160819,0.427094,-1.81696,0.050306,0.365177,-1.8948,0.308403,0.384403,-1.85333,0.27932,0.335833,-1.78074,0.314968,1.07782,-2.08264,0.348224,1.00087,-2.06601,0.183692,1.02067,-2.05589,0.219766,0.945986,-2.0395,0.30973,0.845485,-2.04025,0.144608,0.79487,-2.03774,0.156187,0.906172,-2.05518,0.08584,0.909094,-2.05185,-0.148605,0.893614,-2.04405,-0.206281,0.987323,-1.99365,-0.242458,0.706848,-2.0025,-0.277453,0.758486,-2.06883,0.158781,1.28942,-1.78742,0.175101,1.26798,-2.00096},
/*1371*/{0.261483,1.83705,-1.69263,0.343421,1.78283,-1.84244,0.164927,1.68404,-1.60649,0.088062,1.58085,-1.55072,0.237833,1.5429,-1.59273,0.320324,1.51323,-1.59659,0.281454,1.86673,-2.09053,0.355511,1.78956,-1.91834,0.143768,1.83883,-2.00477,0.081174,1.68745,-2.15779,0.095101,1.58636,-2.20753,0.238392,1.45995,-2.13642,0.274385,1.40409,-2.145,0.231683,1.38114,-1.76954,0.04305,1.42248,-1.86907,0.051547,1.44668,-1.92368,0.054829,1.41036,-1.98174,0.254594,1.35893,-2.0348,0.285146,1.09081,-1.70547,0.165294,1.03924,-1.75157,0.200047,0.963516,-1.7716,0.309365,0.879418,-1.75207,0.282479,0.68861,-1.75591,0.262208,0.61699,-1.77256,0.174052,0.719012,-1.76877,0.155487,0.649877,-1.78182,0.14005,0.427719,-1.81617,0.029491,0.366461,-1.89469,0.287848,0.383976,-1.85292,0.258497,0.336948,-1.7814,0.322774,1.08295,-2.08269,0.358899,1.00686,-2.06538,0.19358,1.02195,-2.05735,0.231379,0.947736,-2.04026,0.326176,0.850259,-2.04008,0.160361,0.794287,-2.03586,0.16974,0.906957,-2.05596,0.099168,0.907262,-2.05281,-0.137241,0.887043,-2.04447,-0.197881,0.979247,-1.99506,-0.221418,0.696588,-2.00261,-0.257859,0.745732,-2.06909,0.158042,1.28842,-1.78824,0.174518,1.2689,-2.00196},
/*1372*/{0.262141,1.8376,-1.69325,0.342938,1.7828,-1.84247,0.170219,1.6844,-1.60532,0.099076,1.57801,-1.5474,0.249363,1.54423,-1.59244,0.332757,1.51707,-1.59719,0.280305,1.86687,-2.09109,0.352687,1.7899,-1.9197,0.142839,1.83941,-2.00499,0.07654,1.69176,-2.15477,0.088803,1.59105,-2.20697,0.231062,1.46135,-2.13944,0.265318,1.40477,-2.14781,0.230249,1.3815,-1.76961,0.042264,1.42245,-1.86881,0.050538,1.44629,-1.92386,0.053679,1.41097,-1.98034,0.253431,1.36048,-2.03523,0.280883,1.08717,-1.70449,0.157971,1.03789,-1.75203,0.191041,0.960243,-1.77168,0.296849,0.873726,-1.75205,0.267491,0.68451,-1.75555,0.246582,0.612854,-1.77272,0.160653,0.716768,-1.76883,0.139274,0.648688,-1.78259,0.118347,0.427979,-1.81581,0.00771,0.367523,-1.89306,0.266057,0.384417,-1.85229,0.236928,0.335848,-1.7803,0.330639,1.08878,-2.08264,0.369688,1.01468,-2.06562,0.203183,1.02368,-2.0588,0.243311,0.952639,-2.04354,0.341536,0.8567,-2.04012,0.175778,0.795,-2.03555,0.182048,0.907171,-2.05705,0.11183,0.906823,-2.05397,-0.121429,0.878609,-2.0449,-0.189427,0.969818,-1.9971,-0.199865,0.685839,-2.00134,-0.237564,0.733264,-2.07044,0.15758,1.28844,-1.78856,0.173895,1.26989,-2.00237},
/*1373*/{0.262324,1.83873,-1.6941,0.341988,1.78528,-1.84299,0.174713,1.68443,-1.60432,0.109525,1.57637,-1.54525,0.26019,1.54653,-1.5926,0.345096,1.5225,-1.59962,0.279224,1.86766,-2.09185,0.352071,1.79009,-1.92003,0.141587,1.84063,-2.00542,0.07285,1.69735,-2.15274,0.081651,1.59656,-2.20817,0.22266,1.46311,-2.14248,0.255988,1.40628,-2.15056,0.229415,1.38134,-1.76894,0.042018,1.42239,-1.86859,0.049734,1.44613,-1.92382,0.052861,1.41175,-1.97966,0.252708,1.36235,-2.03593,0.27478,1.08186,-1.70544,0.151253,1.0372,-1.75253,0.182907,0.959771,-1.77279,0.283392,0.867901,-1.75129,0.253276,0.679071,-1.75625,0.230772,0.60991,-1.77391,0.146667,0.714412,-1.77063,0.125558,0.646135,-1.78245,0.098704,0.427461,-1.81456,-0.013078,0.367892,-1.89338,0.245013,0.383988,-1.85106,0.21561,0.335355,-1.78055,0.339035,1.09495,-2.08177,0.378999,1.02276,-2.06568,0.213297,1.02586,-2.05987,0.255181,0.957378,-2.0447,0.354842,0.862364,-2.04083,0.191743,0.796063,-2.03602,0.195102,0.909176,-2.05782,0.124497,0.90626,-2.05553,-0.109462,0.870327,-2.04444,-0.180966,0.958263,-1.99992,-0.178014,0.674215,-2.00145,-0.216811,0.719102,-2.07082,0.157361,1.28813,-1.78921,0.173694,1.27113,-2.00315},
/*1374*/{0.263141,1.84074,-1.69444,0.340598,1.78607,-1.84436,0.179532,1.68519,-1.60293,0.119908,1.57491,-1.54155,0.271146,1.5498,-1.59226,0.356447,1.52858,-1.60143,0.277436,1.86884,-2.09185,0.350165,1.7916,-1.92151,0.140275,1.84195,-2.00532,0.067812,1.70263,-2.15172,0.075347,1.60284,-2.2087,0.2141,1.46646,-2.14462,0.247178,1.40962,-2.15265,0.228921,1.382,-1.76951,0.040831,1.4227,-1.86896,0.049122,1.44704,-1.92378,0.05208,1.41205,-1.97888,0.252446,1.36429,-2.03689,0.26551,1.07861,-1.70662,0.142965,1.0378,-1.75421,0.172265,0.958235,-1.77437,0.26967,0.861497,-1.75166,0.237387,0.675208,-1.75752,0.213517,0.604787,-1.77479,0.131831,0.711868,-1.77091,0.109434,0.646044,-1.78354,0.078814,0.427163,-1.8141,-0.034191,0.368635,-1.89285,0.223827,0.383615,-1.85173,0.193492,0.335382,-1.77958,0.34514,1.10356,-2.08362,0.388717,1.03169,-2.06602,0.222366,1.02962,-2.0613,0.266741,0.961805,-2.0463,0.369047,0.867679,-2.04167,0.207067,0.797422,-2.03621,0.206693,0.910229,-2.05896,0.136255,0.905127,-2.0571,-0.095908,0.862555,-2.04792,-0.173386,0.94519,-1.99993,-0.155072,0.662614,-2.00137,-0.195411,0.705186,-2.07244,0.157426,1.28859,-1.78994,0.173538,1.27255,-2.00397},
/*1375*/{0.264216,1.84324,-1.69498,0.340482,1.78786,-1.84516,0.183899,1.68786,-1.60292,0.129936,1.57408,-1.53923,0.281509,1.55514,-1.59302,0.367269,1.53536,-1.60358,0.275866,1.87058,-2.09207,0.349127,1.79253,-1.92186,0.138593,1.84408,-2.00502,0.061476,1.71151,-2.15343,0.069263,1.60872,-2.2094,0.207365,1.47095,-2.14671,0.238793,1.41385,-2.15412,0.228433,1.38198,-1.76965,0.040983,1.423,-1.86939,0.049833,1.44769,-1.92347,0.051597,1.41358,-1.97932,0.252219,1.36684,-2.03771,0.258339,1.07618,-1.70769,0.136296,1.03753,-1.75451,0.16189,0.958145,-1.77535,0.254777,0.855937,-1.75285,0.22169,0.672795,-1.75812,0.197782,0.603309,-1.77548,0.116,0.711093,-1.77088,0.092791,0.643763,-1.78298,0.057668,0.428527,-1.81493,-0.055547,0.370251,-1.89368,0.202348,0.383507,-1.85193,0.172978,0.33578,-1.7799,0.350767,1.11159,-2.08423,0.39712,1.0411,-2.06622,0.231232,1.03318,-2.06242,0.277722,0.967424,-2.04757,0.382241,0.873003,-2.04188,0.222621,0.798877,-2.03641,0.217148,0.913304,-2.05932,0.148306,0.905124,-2.0579,-0.083085,0.852843,-2.04733,-0.164498,0.931432,-2.00148,-0.131917,0.650443,-2.00267,-0.173339,0.69076,-2.07296,0.157531,1.28846,-1.79136,0.173799,1.27451,-2.00552},
/*1376*/{0.264544,1.8463,-1.69596,0.33937,1.7902,-1.84681,0.188379,1.6901,-1.60178,0.139117,1.57471,-1.53786,0.290509,1.56021,-1.59414,0.377426,1.54327,-1.60658,0.273075,1.8729,-2.09203,0.348112,1.79495,-1.92312,0.137553,1.84517,-2.00436,0.056257,1.71817,-2.15343,0.062204,1.61549,-2.21055,0.199809,1.47606,-2.14838,0.230545,1.41873,-2.15572,0.22889,1.38308,-1.77061,0.041199,1.42432,-1.86956,0.049697,1.44887,-1.92363,0.052357,1.41423,-1.97921,0.252,1.36943,-2.03819,0.251103,1.0744,-1.70888,0.128264,1.03868,-1.7563,0.152195,0.957754,-1.77651,0.239979,0.852047,-1.7531,0.205631,0.671627,-1.75905,0.179623,0.602921,-1.77628,0.100869,0.7115,-1.77127,0.076706,0.644469,-1.78437,0.037083,0.429093,-1.81463,-0.076078,0.371627,-1.89346,0.180912,0.382718,-1.8515,0.151174,0.335571,-1.77917,0.356519,1.11967,-2.08477,0.404794,1.05071,-2.06694,0.239408,1.03825,-2.06319,0.287897,0.973021,-2.04787,0.394555,0.879902,-2.04248,0.237858,0.801119,-2.03701,0.229404,0.913865,-2.05948,0.15914,0.902923,-2.05933,-0.069033,0.841417,-2.04741,-0.156989,0.917166,-2.00139,-0.107184,0.638267,-2.00345,-0.151283,0.675894,-2.07385,0.158456,1.28955,-1.79215,0.174386,1.27638,-2.00639},
/*1377*/{0.265793,1.84973,-1.69641,0.339313,1.79298,-1.84812,0.193504,1.69222,-1.60148,0.148768,1.57614,-1.5356,0.299677,1.56603,-1.59576,0.387105,1.55183,-1.6097,0.269346,1.87538,-2.09274,0.346625,1.79715,-1.92464,0.135515,1.84808,-2.00355,0.050937,1.72383,-2.15369,0.055615,1.62188,-2.21184,0.191978,1.48203,-2.14983,0.222473,1.42442,-2.1561,0.228726,1.38277,-1.77075,0.041236,1.42617,-1.86957,0.049816,1.44981,-1.9235,0.05216,1.41519,-1.97894,0.253348,1.37242,-2.03925,0.244206,1.07264,-1.70963,0.117436,1.03824,-1.75716,0.141561,0.958492,-1.77747,0.223533,0.851072,-1.75485,0.189551,0.670102,-1.76027,0.162341,0.601019,-1.77746,0.086083,0.711259,-1.77145,0.060697,0.645802,-1.78393,0.017077,0.429969,-1.81505,-0.096415,0.373082,-1.89358,0.161141,0.38297,-1.8511,0.130484,0.335853,-1.78,0.361361,1.12784,-2.08553,0.41141,1.06018,-2.06774,0.247432,1.04213,-2.06351,0.297496,0.978623,-2.04798,0.406231,0.888148,-2.04346,0.253237,0.803491,-2.0381,0.239646,0.915239,-2.06115,0.170086,0.901952,-2.0603,-0.056356,0.832067,-2.04882,-0.148912,0.901178,-2.00183,-0.082768,0.625202,-2.00374,-0.12815,0.660956,-2.07497,0.158785,1.28969,-1.79344,0.175016,1.27867,-2.00778},
/*1378*/{0.267406,1.85361,-1.69722,0.339685,1.79562,-1.84898,0.198665,1.69531,-1.60061,0.158372,1.57832,-1.5349,0.307856,1.57226,-1.59717,0.395282,1.56058,-1.61282,0.266425,1.87844,-2.09284,0.345064,1.7995,-1.92556,0.133474,1.8492,-2.00196,0.045267,1.73051,-2.15425,0.049718,1.6284,-2.21247,0.184869,1.48804,-2.15097,0.215071,1.43124,-2.15769,0.229628,1.38359,-1.77179,0.041636,1.42816,-1.86909,0.051136,1.45121,-1.92334,0.051957,1.41762,-1.98054,0.252497,1.37505,-2.0395,0.236011,1.07138,-1.7109,0.10897,1.04035,-1.75837,0.131269,0.959548,-1.77694,0.207276,0.8488,-1.7567,0.173552,0.668992,-1.76076,0.145224,0.60122,-1.77881,0.06988,0.712114,-1.77371,0.04302,0.647763,-1.78507,-0.003224,0.430217,-1.81526,-0.118032,0.375086,-1.89335,0.139526,0.382691,-1.85195,0.108318,0.33564,-1.78109,0.36649,1.13582,-2.08623,0.418599,1.07007,-2.06862,0.254266,1.04757,-2.06439,0.306675,0.985697,-2.04777,0.417947,0.897641,-2.04414,0.268049,0.806088,-2.03914,0.249878,0.916168,-2.06225,0.180562,0.900648,-2.06084,-0.04284,0.820422,-2.04837,-0.139577,0.882882,-2.00121,-0.057897,0.612372,-2.00503,-0.105415,0.646434,-2.0766,0.159271,1.29078,-1.79468,0.17485,1.28097,-2.00913},
/*1379*/{0.269044,1.85704,-1.69832,0.33831,1.79845,-1.8505,0.204096,1.69852,-1.59998,0.166486,1.58017,-1.53336,0.315866,1.57939,-1.59918,0.402819,1.56978,-1.61654,0.262438,1.88212,-2.09293,0.3445,1.8027,-1.92737,0.13157,1.85126,-2.00044,0.04043,1.73702,-2.15487,0.042891,1.63495,-2.21333,0.178028,1.49536,-2.1516,0.207624,1.43827,-2.15889,0.229804,1.38387,-1.77209,0.043584,1.42876,-1.86962,0.050938,1.45306,-1.92382,0.053506,1.41913,-1.98034,0.253404,1.37871,-2.03933,0.228687,1.06951,-1.71204,0.100509,1.04186,-1.7584,0.119727,0.961235,-1.7792,0.190402,0.84968,-1.75828,0.157786,0.66934,-1.76265,0.12681,0.601433,-1.77945,0.054787,0.714194,-1.77536,0.026874,0.648975,-1.78562,-0.02357,0.432244,-1.81516,-0.138584,0.37759,-1.89311,0.118929,0.382355,-1.85118,0.08788,0.335554,-1.77953,0.370471,1.14379,-2.08715,0.424649,1.07971,-2.06877,0.261067,1.05288,-2.06488,0.314385,0.992162,-2.04879,0.428591,0.90754,-2.04474,0.282414,0.80799,-2.0398,0.258776,0.916531,-2.06295,0.190427,0.898256,-2.06218,-0.028944,0.808307,-2.0492,-0.129677,0.865953,-2.0006,-0.031162,0.600563,-2.00745,-0.082298,0.631106,-2.07666,0.160233,1.29116,-1.79608,0.176532,1.28376,-2.01057},
/*1380*/{0.271173,1.86133,-1.699,0.338251,1.80136,-1.85217,0.209692,1.70166,-1.59969,0.176592,1.58312,-1.53233,0.322557,1.58668,-1.60105,0.409927,1.57994,-1.61942,0.258967,1.8857,-2.09276,0.342944,1.8059,-1.92888,0.129126,1.85323,-1.99872,0.036208,1.74366,-2.15469,0.036942,1.64156,-2.21419,0.171386,1.5028,-2.15164,0.200943,1.44621,-2.16,0.231283,1.38444,-1.77261,0.043595,1.4317,-1.86911,0.051064,1.45475,-1.92356,0.053992,1.42043,-1.98071,0.254693,1.38216,-2.03918,0.222177,1.06867,-1.71602,0.092424,1.04431,-1.75991,0.109226,0.963819,-1.7794,0.17652,0.850734,-1.76093,0.140251,0.670175,-1.76374,0.109391,0.602392,-1.77998,0.038381,0.716165,-1.77673,0.009668,0.651463,-1.787,-0.044728,0.434571,-1.81533,-0.158986,0.380585,-1.89309,0.098931,0.381811,-1.85089,0.067213,0.335801,-1.78004,0.375695,1.15129,-2.08716,0.430257,1.08808,-2.06947,0.267626,1.05681,-2.06436,0.322344,0.998115,-2.04909,0.43859,0.918169,-2.04521,0.296072,0.810895,-2.04093,0.267452,0.917512,-2.06449,0.199385,0.895708,-2.06259,-0.014407,0.794195,-2.05017,-0.118813,0.847454,-1.99999,-0.004243,0.587686,-2.00913,-0.060296,0.614948,-2.07779,0.161213,1.29243,-1.7969,0.177506,1.28651,-2.01144},
/*1381*/{0.272974,1.86571,-1.70009,0.338926,1.80537,-1.85338,0.215035,1.70541,-1.6001,0.183641,1.58599,-1.53165,0.329558,1.5936,-1.60298,0.416452,1.58858,-1.62411,0.254099,1.88961,-2.09254,0.342262,1.80975,-1.93083,0.12723,1.85504,-1.99695,0.031354,1.75026,-2.15558,0.031056,1.6484,-2.21469,0.164607,1.51036,-2.15281,0.194869,1.4535,-2.16115,0.232313,1.38504,-1.77218,0.044991,1.43257,-1.86898,0.052903,1.45725,-1.92269,0.055785,1.42319,-1.98191,0.254632,1.38546,-2.03865,0.21444,1.06987,-1.71803,0.085078,1.04894,-1.75994,0.100537,0.966651,-1.77964,0.163242,0.852664,-1.76319,0.122697,0.671127,-1.76562,0.091196,0.603576,-1.78077,0.021016,0.718339,-1.77748,-0.008251,0.65368,-1.78868,-0.063532,0.437886,-1.81516,-0.179446,0.384809,-1.89268,0.077669,0.381055,-1.85223,0.045725,0.335524,-1.78015,0.379741,1.15806,-2.08815,0.435863,1.09718,-2.07032,0.273875,1.06214,-2.06444,0.329299,1.00406,-2.04912,0.448335,0.92945,-2.04611,0.309508,0.813942,-2.04295,0.27256,0.920748,-2.06615,0.208697,0.89375,-2.06285,0.002061,0.781613,-2.04585,-0.107038,0.826685,-1.99769,0.022402,0.575851,-2.01089,-0.034187,0.601301,-2.07955,0.162067,1.29315,-1.79797,0.178724,1.28944,-2.01253},
/*1382*/{0.274618,1.86987,-1.70114,0.339381,1.80949,-1.85485,0.221417,1.70925,-1.60055,0.189869,1.5902,-1.53188,0.335744,1.60122,-1.60566,0.422207,1.59868,-1.62783,0.250697,1.89392,-2.09256,0.342012,1.81377,-1.93231,0.12469,1.85738,-1.99497,0.026236,1.75627,-2.1562,0.025407,1.65511,-2.21528,0.158133,1.51842,-2.15359,0.188749,1.46187,-2.16233,0.232788,1.38537,-1.7714,0.048131,1.43604,-1.86844,0.053276,1.45888,-1.9219,0.056413,1.42662,-1.98229,0.256328,1.38894,-2.03844,0.211101,1.06923,-1.71914,0.07866,1.05371,-1.76031,0.089195,0.969483,-1.78003,0.15082,0.854281,-1.76568,0.105979,0.672524,-1.7658,0.072864,0.605137,-1.7825,0.00486,0.721117,-1.77887,-0.025447,0.656397,-1.78958,-0.082773,0.439203,-1.81581,-0.199272,0.389913,-1.89252,0.057698,0.38033,-1.85199,0.024846,0.336096,-1.78119,0.382722,1.16524,-2.0887,0.44107,1.10544,-2.07085,0.279181,1.06749,-2.0649,0.336704,1.01015,-2.04892,0.456434,0.939643,-2.04714,0.322307,0.817183,-2.04411,0.280187,0.921028,-2.06603,0.217673,0.890262,-2.0628,0.013642,0.769465,-2.04749,-0.094892,0.806854,-1.99621,0.048855,0.565457,-2.01371,-0.008152,0.586834,-2.08064,0.162668,1.29433,-1.79875,0.179735,1.29269,-2.0133},
/*1383*/{0.276025,1.87503,-1.70284,0.338838,1.81343,-1.85665,0.226996,1.71373,-1.60106,0.199301,1.5934,-1.53118,0.340498,1.60878,-1.60779,0.42696,1.60883,-1.63165,0.24718,1.89814,-2.09235,0.341193,1.8181,-1.93414,0.123465,1.85962,-1.99266,0.021692,1.76276,-2.15643,0.019506,1.66174,-2.21528,0.151706,1.52688,-2.15412,0.183813,1.46988,-2.1633,0.234094,1.38678,-1.77145,0.048291,1.43749,-1.86881,0.054989,1.46201,-1.92146,0.058733,1.42996,-1.98239,0.257871,1.39268,-2.03748,0.203959,1.06964,-1.72287,0.072331,1.05524,-1.75895,0.079734,0.973172,-1.77971,0.138644,0.855943,-1.76671,0.08906,0.675155,-1.7672,0.056315,0.607205,-1.78292,-0.011346,0.72361,-1.7806,-0.042682,0.66039,-1.79157,-0.102852,0.444283,-1.81526,-0.218357,0.395435,-1.89214,0.03795,0.379702,-1.85294,0.00377,0.336197,-1.78227,0.386814,1.1725,-2.08974,0.445131,1.11338,-2.07122,0.28381,1.07302,-2.06454,0.342185,1.0168,-2.04884,0.463902,0.949843,-2.04794,0.334726,0.820674,-2.04754,0.28686,0.921455,-2.0665,0.225744,0.88739,-2.06278,0.033347,0.754486,-2.04487,-0.082272,0.78638,-1.99268,0.077452,0.553553,-2.01633,0.017931,0.573479,-2.08234,0.163618,1.2958,-1.79966,0.181676,1.2963,-2.01414},
/*1384*/{0.277865,1.88041,-1.704,0.339907,1.81748,-1.8585,0.232855,1.71799,-1.60159,0.205035,1.59764,-1.53066,0.345788,1.61589,-1.6101,0.430293,1.61814,-1.63559,0.242737,1.90243,-2.09168,0.34082,1.82187,-1.93531,0.1219,1.8625,-1.99137,0.018927,1.7675,-2.15686,0.014132,1.66876,-2.21514,0.146005,1.53373,-2.15434,0.178526,1.47811,-2.1646,0.236412,1.38762,-1.77046,0.048922,1.4409,-1.86926,0.056144,1.46466,-1.92057,0.060996,1.43401,-1.98234,0.258533,1.39616,-2.03668,0.198894,1.07129,-1.7254,0.066021,1.06177,-1.75885,0.070937,0.977699,-1.78065,0.126762,0.858654,-1.76797,0.072898,0.677398,-1.76857,0.039593,0.610966,-1.78405,-0.027351,0.72756,-1.78187,-0.059227,0.664838,-1.79178,-0.120879,0.447692,-1.81457,-0.237359,0.402384,-1.8918,0.018029,0.377835,-1.85311,-0.01787,0.336403,-1.78221,0.389908,1.17959,-2.0896,0.44891,1.1219,-2.07245,0.288411,1.07915,-2.06543,0.346959,1.02302,-2.04995,0.470702,0.959558,-2.04828,0.346516,0.823537,-2.04863,0.293799,0.92213,-2.06711,0.232411,0.884735,-2.06329,0.049586,0.740592,-2.04387,-0.068449,0.765545,-1.99048,0.104626,0.543173,-2.01897,0.04245,0.559391,-2.0847,0.164277,1.29755,-1.80024,0.182695,1.29981,-2.01467},
/*1385*/{0.279826,1.88561,-1.70507,0.340028,1.82296,-1.8605,0.237838,1.7229,-1.60223,0.211357,1.6024,-1.53094,0.350045,1.62349,-1.61223,0.435081,1.62817,-1.63833,0.239499,1.90649,-2.09147,0.339915,1.82722,-1.93727,0.119408,1.8658,-1.98946,0.014213,1.77404,-2.15701,0.008729,1.67539,-2.21512,0.140791,1.54138,-2.15398,0.173853,1.48646,-2.16575,0.237422,1.38881,-1.76997,0.051614,1.44379,-1.87001,0.057364,1.46814,-1.92049,0.060661,1.43896,-1.98315,0.260264,1.40034,-2.03601,0.193658,1.06963,-1.72871,0.060456,1.06647,-1.75904,0.063867,0.982239,-1.77972,0.113986,0.861626,-1.77028,0.057989,0.681689,-1.7691,0.024193,0.615915,-1.78474,-0.042742,0.732255,-1.7827,-0.07377,0.668617,-1.79183,-0.138553,0.451597,-1.81386,-0.256097,0.410403,-1.891,-0.00177,0.377538,-1.85298,-0.038759,0.33713,-1.78269,0.392881,1.1866,-2.09034,0.452637,1.12973,-2.07295,0.292843,1.08508,-2.06571,0.352685,1.03015,-2.04972,0.47634,0.969008,-2.04948,0.358422,0.825906,-2.04914,0.29913,0.922309,-2.06784,0.241212,0.881554,-2.06285,0.061236,0.728967,-2.04338,-0.051914,0.743286,-1.98774,0.134518,0.533745,-2.02281,0.070937,0.548246,-2.0873,0.164675,1.29948,-1.80163,0.183858,1.30409,-2.01596},
/*1386*/{0.280248,1.89104,-1.70722,0.34017,1.82688,-1.86168,0.242395,1.72814,-1.60311,0.217835,1.60762,-1.53098,0.3539,1.63227,-1.61456,0.438097,1.63699,-1.64165,0.236085,1.91062,-2.09105,0.339041,1.83148,-1.93902,0.118235,1.8685,-1.98791,0.012296,1.77939,-2.15716,0.003448,1.68235,-2.2146,0.135605,1.54984,-2.15467,0.168975,1.49505,-2.16685,0.238444,1.39012,-1.76993,0.052801,1.44717,-1.86977,0.059358,1.47167,-1.91928,0.062578,1.44401,-1.98356,0.261703,1.40444,-2.03484,0.189302,1.07184,-1.7301,0.053983,1.07231,-1.75947,0.055344,0.98751,-1.78008,0.101807,0.865815,-1.77166,0.041591,0.686402,-1.76976,0.006785,0.620213,-1.78503,-0.057443,0.737319,-1.78378,-0.08984,0.674286,-1.79238,-0.156148,0.45679,-1.81314,-0.273244,0.418806,-1.89097,-0.021266,0.376636,-1.85289,-0.058723,0.337628,-1.78311,0.395698,1.19357,-2.09121,0.456035,1.13694,-2.07319,0.296542,1.0919,-2.06713,0.356822,1.03617,-2.04991,0.480887,0.977655,-2.04949,0.369114,0.829108,-2.05049,0.30365,0.921518,-2.06767,0.248903,0.877595,-2.06216,0.080579,0.715101,-2.04159,-0.037381,0.722768,-1.98563,0.163898,0.525214,-2.02669,0.098346,0.536441,-2.08945,0.165069,1.30145,-1.80259,0.185057,1.30847,-2.01678},
/*1387*/{0.281361,1.89655,-1.70857,0.340849,1.83187,-1.86403,0.246129,1.73338,-1.60443,0.222934,1.61274,-1.53146,0.356192,1.64012,-1.61745,0.440744,1.64704,-1.64681,0.234082,1.91476,-2.0913,0.338651,1.8368,-1.94071,0.116798,1.87185,-1.98615,0.006806,1.78501,-2.15725,-0.001243,1.68917,-2.21391,0.129649,1.55775,-2.15474,0.164463,1.50285,-2.16778,0.240652,1.39156,-1.76999,0.05532,1.44987,-1.87,0.061867,1.47469,-1.91823,0.064708,1.44885,-1.98454,0.262964,1.40845,-2.03406,0.185854,1.07395,-1.73434,0.050017,1.07438,-1.75828,0.047708,0.993204,-1.78053,0.088738,0.868597,-1.77359,0.027249,0.691197,-1.77055,-0.009384,0.624998,-1.78486,-0.072574,0.74331,-1.7843,-0.103369,0.680079,-1.79234,-0.173023,0.462188,-1.81189,-0.290544,0.428214,-1.88986,-0.041205,0.375992,-1.85372,-0.080425,0.337753,-1.78394,0.39846,1.19987,-2.09169,0.45903,1.14351,-2.07326,0.300055,1.09704,-2.06715,0.360268,1.04305,-2.05038,0.483674,0.986565,-2.05082,0.379547,0.831609,-2.052,0.309189,0.919526,-2.06661,0.256808,0.873374,-2.06144,0.098742,0.701861,-2.04059,-0.019839,0.701693,-1.98316,0.192226,0.516657,-2.03002,0.126001,0.525604,-2.09189,0.166634,1.30336,-1.80383,0.186885,1.31258,-2.01791},
/*1388*/{0.281969,1.90148,-1.71042,0.34143,1.83704,-1.86608,0.250335,1.73881,-1.60481,0.227473,1.61759,-1.53176,0.359163,1.64707,-1.61989,0.441992,1.65522,-1.65159,0.232667,1.91919,-2.09128,0.33857,1.84132,-1.94266,0.118049,1.87436,-1.98489,0.003616,1.79025,-2.15651,-0.006328,1.69606,-2.21286,0.126363,1.56531,-2.15482,0.161155,1.51053,-2.16934,0.242391,1.39276,-1.77033,0.057297,1.45386,-1.86937,0.064048,1.47889,-1.91704,0.066963,1.45352,-1.98477,0.263436,1.41288,-2.03306,0.181498,1.07616,-1.73573,0.044934,1.08497,-1.76016,0.040538,0.999544,-1.78099,0.076689,0.875144,-1.77429,0.013016,0.696998,-1.77077,-0.023219,0.631146,-1.78533,-0.085904,0.749988,-1.78471,-0.1188,0.687367,-1.79347,-0.188979,0.469019,-1.81159,-0.307788,0.438561,-1.88906,-0.061372,0.375416,-1.85408,-0.101798,0.338069,-1.78319,0.400698,1.2068,-2.09191,0.461534,1.15088,-2.07337,0.302858,1.10363,-2.06808,0.36337,1.04955,-2.05054,0.484969,0.994534,-2.05138,0.389514,0.834376,-2.05374,0.313881,0.918994,-2.06634,0.263714,0.869029,-2.06054,0.110776,0.689793,-2.04243,-0.002294,0.678624,-1.98026,0.220653,0.510109,-2.03389,0.153557,0.515528,-2.09458,0.167467,1.30561,-1.80487,0.187698,1.31708,-2.01885},
/*1389*/{0.283071,1.90691,-1.71228,0.341314,1.84117,-1.86768,0.253479,1.74401,-1.6057,0.231704,1.62304,-1.53179,0.361816,1.65373,-1.62165,0.44435,1.6641,-1.65274,0.230154,1.92272,-2.09125,0.337412,1.84537,-1.94397,0.116867,1.87769,-1.98463,0.001287,1.79644,-2.15614,-0.011086,1.70242,-2.2116,0.121813,1.57241,-2.15459,0.157208,1.51848,-2.17022,0.244545,1.39387,-1.7718,0.060439,1.45754,-1.87011,0.066744,1.48277,-1.91597,0.068509,1.45877,-1.98491,0.264038,1.4168,-2.03282,0.177409,1.07809,-1.73775,0.041011,1.09082,-1.76006,0.033689,1.00602,-1.78107,0.064646,0.881165,-1.77471,-0.000604,0.703077,-1.77099,-0.037552,0.636959,-1.7839,-0.099259,0.756628,-1.78512,-0.133394,0.693497,-1.79446,-0.206585,0.474492,-1.81059,-0.322754,0.449384,-1.88836,-0.081736,0.374905,-1.85432,-0.122391,0.339284,-1.78359,0.40278,1.21301,-2.09297,0.463473,1.15769,-2.07349,0.305738,1.10963,-2.0695,0.366034,1.05574,-2.05113,0.48548,1.00172,-2.05181,0.397745,0.8359,-2.05441,0.31735,0.914795,-2.06474,0.27083,0.86233,-2.05888,0.132865,0.674493,-2.03774,0.017975,0.656539,-1.97601,0.250424,0.504193,-2.03832,0.180873,0.5062,-2.09695,0.16869,1.30768,-1.8067,0.188324,1.32144,-2.0206},
/*1390*/{0.283983,1.91222,-1.71377,0.342466,1.84509,-1.86925,0.256499,1.7497,-1.60623,0.235863,1.6281,-1.53146,0.36308,1.66121,-1.62418,0.446119,1.67279,-1.65665,0.228079,1.92604,-2.09135,0.336977,1.85018,-1.94587,0.11652,1.88079,-1.98305,-0.00338,1.80081,-2.15526,-0.015137,1.70857,-2.2108,0.118026,1.57909,-2.15444,0.156013,1.5247,-2.17051,0.24789,1.3956,-1.77264,0.061743,1.46172,-1.86952,0.069087,1.48717,-1.91526,0.070595,1.46424,-1.98512,0.265384,1.42107,-2.03307,0.173692,1.08049,-1.74136,0.038244,1.09635,-1.75986,0.026817,1.01205,-1.78279,0.053451,0.88845,-1.77689,-0.012495,0.709269,-1.77128,-0.050519,0.643527,-1.78494,-0.111104,0.763641,-1.78642,-0.146771,0.700985,-1.79513,-0.219553,0.481391,-1.80846,-0.33812,0.461437,-1.88794,-0.100182,0.375695,-1.85461,-0.14321,0.340207,-1.7839,0.404928,1.2192,-2.09313,0.46612,1.16479,-2.07268,0.307135,1.11536,-2.07048,0.366889,1.06105,-2.05235,0.485092,1.00806,-2.05261,0.406728,0.837399,-2.05639,0.321805,0.911623,-2.06308,0.279304,0.856334,-2.05788,0.150323,0.661065,-2.03693,0.038336,0.634211,-1.97227,0.279736,0.499588,-2.04187,0.209019,0.497807,-2.09904,0.170318,1.31044,-1.80815,0.18924,1.3262,-2.02197},
/*1391*/{0.285254,1.91709,-1.71509,0.342954,1.85012,-1.87095,0.258526,1.75481,-1.60713,0.239089,1.6331,-1.53211,0.365115,1.66796,-1.6266,0.445669,1.68111,-1.66163,0.227151,1.92985,-2.09096,0.336555,1.85434,-1.94736,0.117132,1.88292,-1.98249,-0.005115,1.80618,-2.15348,-0.019282,1.71454,-2.20905,0.115024,1.58594,-2.15445,0.151054,1.53178,-2.17164,0.250166,1.39712,-1.7742,0.064954,1.46561,-1.86957,0.070994,1.49154,-1.91431,0.07297,1.46945,-1.98559,0.266153,1.42525,-2.03321,0.169336,1.08271,-1.74275,0.033453,1.10055,-1.75976,0.020403,1.01998,-1.78455,0.043628,0.894774,-1.77808,-0.024882,0.715813,-1.77107,-0.061937,0.650905,-1.78394,-0.122224,0.77072,-1.78655,-0.157957,0.708573,-1.79554,-0.233355,0.486657,-1.80648,-0.351791,0.473848,-1.88658,-0.11878,0.375274,-1.85477,-0.164615,0.341529,-1.78462,0.406293,1.22417,-2.09308,0.467298,1.16947,-2.07225,0.309134,1.12169,-2.07219,0.369087,1.06727,-2.05289,0.484636,1.0143,-2.05343,0.41514,0.838737,-2.05763,0.326267,0.908443,-2.06232,0.285603,0.85008,-2.05646,0.171814,0.64784,-2.0353,0.061017,0.611654,-1.96692,0.307226,0.495417,-2.04545,0.237282,0.4892,-2.10091,0.171759,1.31292,-1.80997,0.189994,1.33083,-2.02369},
/*1392*/{0.286306,1.92213,-1.71682,0.342567,1.85449,-1.8725,0.26153,1.7596,-1.6075,0.241785,1.63854,-1.5326,0.366179,1.6747,-1.62869,0.44665,1.68838,-1.66464,0.22622,1.93294,-2.09123,0.336828,1.85877,-1.94856,0.117238,1.88571,-1.98229,-0.005756,1.81154,-2.15217,-0.022863,1.72021,-2.20741,0.112677,1.59209,-2.15411,0.148627,1.53795,-2.17281,0.252074,1.39833,-1.7758,0.06709,1.47018,-1.86808,0.072399,1.49564,-1.91327,0.075193,1.47455,-1.98473,0.266147,1.42906,-2.03358,0.165524,1.08538,-1.74416,0.033268,1.10847,-1.75985,0.015677,1.02667,-1.78538,0.037521,0.900397,-1.77922,-0.034567,0.722312,-1.77123,-0.073016,0.657798,-1.78338,-0.132684,0.778535,-1.78663,-0.167957,0.716198,-1.79391,-0.247164,0.493771,-1.80454,-0.364919,0.487101,-1.88572,-0.139217,0.374928,-1.85452,-0.186113,0.342753,-1.78445,0.407871,1.2295,-2.09312,0.468362,1.17399,-2.07214,0.309298,1.1264,-2.07314,0.368502,1.07104,-2.05435,0.481445,1.01876,-2.05393,0.423139,0.839322,-2.05918,0.329499,0.903965,-2.06079,0.293142,0.844674,-2.05599,0.184741,0.633699,-2.03403,0.083434,0.591142,-1.96415,0.336365,0.492759,-2.04793,0.265067,0.481626,-2.10224,0.172609,1.31534,-1.81127,0.1895,1.33523,-2.02492},
/*1393*/{0.286381,1.92636,-1.71866,0.343111,1.85813,-1.87437,0.262921,1.76486,-1.60817,0.244955,1.6425,-1.53213,0.366845,1.68093,-1.6307,0.447174,1.69547,-1.66754,0.225377,1.93609,-2.09162,0.336881,1.86265,-1.95012,0.11732,1.88869,-1.98224,-0.006501,1.81677,-2.15085,-0.025957,1.72518,-2.2053,0.109479,1.59735,-2.15394,0.147347,1.54294,-2.17253,0.255318,1.40021,-1.77738,0.069454,1.47416,-1.8673,0.074409,1.49893,-1.9127,0.077765,1.47968,-1.98416,0.267343,1.43302,-2.03452,0.164213,1.08826,-1.74534,0.030811,1.11425,-1.76014,0.009751,1.03371,-1.78598,0.030864,0.90572,-1.78029,-0.044136,0.728986,-1.77111,-0.082013,0.664336,-1.78216,-0.141086,0.785657,-1.78675,-0.176723,0.724277,-1.7939,-0.2591,0.50146,-1.80316,-0.375504,0.500873,-1.88464,-0.158866,0.375513,-1.8548,-0.206489,0.344753,-1.78478,0.407445,1.2339,-2.09317,0.469046,1.17762,-2.07152,0.308814,1.13132,-2.0748,0.369131,1.07637,-2.05564,0.480731,1.02225,-2.05457,0.430745,0.838719,-2.06011,0.334281,0.898287,-2.05929,0.301165,0.836116,-2.05235,0.199162,0.618648,-2.0317,0.106099,0.571037,-1.96251,0.36391,0.489482,-2.04917,0.292785,0.475623,-2.10316,0.174886,1.31795,-1.81279,0.19041,1.33964,-2.02637},
/*1394*/{0.289066,1.93014,-1.72037,0.343948,1.86191,-1.87591,0.264703,1.76954,-1.60892,0.247663,1.64751,-1.53173,0.366811,1.68642,-1.63248,0.447702,1.70171,-1.67132,0.224999,1.93868,-2.09225,0.336505,1.86579,-1.95153,0.116985,1.89142,-1.98232,-0.007984,1.82018,-2.14677,-0.028673,1.73059,-2.20371,0.106685,1.60182,-2.15332,0.145288,1.54793,-2.17337,0.258124,1.40126,-1.77792,0.071839,1.47861,-1.86749,0.075408,1.50305,-1.91069,0.079467,1.48501,-1.98431,0.267089,1.43667,-2.03502,0.160107,1.09031,-1.74739,0.02709,1.12061,-1.7619,0.00653,1.04043,-1.78708,0.025475,0.910509,-1.78143,-0.053105,0.735061,-1.77154,-0.092271,0.67069,-1.78241,-0.149646,0.792062,-1.78654,-0.186069,0.731313,-1.79327,-0.26995,0.509623,-1.80211,-0.386844,0.516008,-1.88316,-0.175809,0.376182,-1.854,-0.225599,0.348097,-1.78439,0.408614,1.23802,-2.09261,0.46859,1.18089,-2.07081,0.308535,1.13598,-2.07577,0.368144,1.0796,-2.05744,0.479487,1.02392,-2.05626,0.438055,0.838622,-2.06101,0.339394,0.893034,-2.05847,0.309051,0.828687,-2.05167,0.221457,0.606708,-2.03028,0.129345,0.552278,-1.96095,0.391453,0.487313,-2.05022,0.320686,0.469691,-2.10326,0.175734,1.32049,-1.81411,0.189961,1.34396,-2.02759},
/*1395*/{0.289649,1.93418,-1.72177,0.344689,1.86564,-1.87773,0.266927,1.77366,-1.60846,0.250072,1.65167,-1.53135,0.367409,1.69172,-1.6344,0.446735,1.70797,-1.6743,0.224578,1.9418,-2.09209,0.337136,1.86916,-1.95263,0.118394,1.89315,-1.98215,-0.009303,1.82478,-2.14484,-0.031307,1.73529,-2.20127,0.105456,1.60546,-2.1532,0.14396,1.55247,-2.17355,0.259882,1.40306,-1.78023,0.073253,1.48226,-1.86645,0.077595,1.50681,-1.91086,0.081442,1.4895,-1.98366,0.267982,1.44039,-2.03608,0.157235,1.09252,-1.74948,0.026044,1.12498,-1.76113,0.002784,1.04578,-1.78742,0.020459,0.915992,-1.78208,-0.06056,0.741172,-1.77141,-0.100549,0.677021,-1.78241,-0.155536,0.799679,-1.78518,-0.192779,0.737876,-1.79195,-0.280743,0.517248,-1.80025,-0.395266,0.531435,-1.88138,-0.193345,0.37793,-1.85387,-0.245897,0.351311,-1.78488,0.408378,1.24136,-2.09211,0.468135,1.1837,-2.07084,0.307619,1.13868,-2.07731,0.365331,1.08313,-2.05889,0.478516,1.0249,-2.057,0.445379,0.836931,-2.06222,0.344517,0.886694,-2.05762,0.317067,0.820833,-2.05075,0.244249,0.596303,-2.03104,0.152262,0.536207,-1.96128,0.41912,0.48654,-2.04991,0.348227,0.463935,-2.10321,0.177014,1.32294,-1.81585,0.190208,1.34817,-2.0292},
/*1396*/{0.291052,1.93741,-1.7227,0.345623,1.86969,-1.87867,0.267483,1.77805,-1.60922,0.250969,1.65609,-1.53209,0.367389,1.6967,-1.63598,0.446364,1.71295,-1.677,0.223776,1.94296,-2.09201,0.338185,1.87236,-1.95371,0.118557,1.89587,-1.98199,-0.00915,1.82854,-2.14111,-0.032698,1.7397,-2.19946,0.104889,1.60962,-2.1523,0.14266,1.55665,-2.17331,0.262175,1.40514,-1.781,0.076161,1.48561,-1.86563,0.078726,1.51072,-1.90894,0.083392,1.49364,-1.98231,0.267951,1.44404,-2.03654,0.15409,1.09539,-1.74982,0.024117,1.13032,-1.76274,-0.000722,1.05196,-1.78979,0.015534,0.920652,-1.78297,-0.066659,0.747218,-1.77173,-0.107213,0.683625,-1.78102,-0.162644,0.805742,-1.78549,-0.198886,0.745321,-1.79046,-0.289279,0.523008,-1.79839,-0.402482,0.545812,-1.87968,-0.211054,0.379207,-1.85342,-0.265496,0.355195,-1.78401,0.408292,1.24398,-2.09141,0.466614,1.18575,-2.07084,0.306793,1.14112,-2.0786,0.365913,1.08559,-2.06118,0.478207,1.02519,-2.05891,0.451853,0.835426,-2.0636,0.348558,0.878794,-2.05753,0.324902,0.813355,-2.0495,0.26606,0.585807,-2.02919,0.177039,0.518029,-1.95919,0.445396,0.48489,-2.04817,0.376409,0.459026,-2.10245,0.178796,1.32559,-1.81642,0.190254,1.35215,-2.0297},
/*1397*/{0.292983,1.94031,-1.72468,0.346569,1.87259,-1.88039,0.26836,1.78174,-1.60972,0.252825,1.66009,-1.53134,0.367461,1.70062,-1.63767,0.445711,1.7181,-1.68004,0.223537,1.94605,-2.0933,0.338641,1.87493,-1.95481,0.119446,1.89721,-1.98279,-0.009883,1.83283,-2.13947,-0.034101,1.74404,-2.19718,0.104431,1.61376,-2.15183,0.142112,1.56067,-2.17345,0.264562,1.40641,-1.78278,0.077706,1.48903,-1.86509,0.080298,1.51444,-1.90708,0.083867,1.49782,-1.98138,0.268567,1.44737,-2.03738,0.152958,1.09942,-1.74935,0.020326,1.13402,-1.76311,-0.004478,1.05601,-1.79151,0.010501,0.924942,-1.78471,-0.07189,0.75374,-1.77187,-0.113071,0.688845,-1.77997,-0.167249,0.812401,-1.78508,-0.205286,0.751874,-1.78985,-0.298859,0.530371,-1.79552,-0.408054,0.560833,-1.87756,-0.229335,0.380799,-1.85268,-0.284165,0.360484,-1.78394,0.407366,1.2458,-2.09147,0.466306,1.18667,-2.07141,0.305091,1.14352,-2.07971,0.363645,1.08726,-2.06281,0.476108,1.02423,-2.06087,0.45856,0.833351,-2.06411,0.353008,0.871711,-2.05433,0.333216,0.804587,-2.04845,0.284666,0.57382,-2.02968,0.200316,0.504048,-1.95972,0.469781,0.483842,-2.04659,0.403568,0.454028,-2.10072,0.180072,1.32774,-1.81778,0.18982,1.35614,-2.03091},
/*1398*/{0.294261,1.94341,-1.72564,0.347202,1.87597,-1.88185,0.269945,1.78581,-1.60972,0.253896,1.66401,-1.53159,0.367656,1.70485,-1.63876,0.444948,1.72179,-1.68234,0.22462,1.9489,-2.09335,0.339317,1.87734,-1.95604,0.120314,1.89949,-1.98187,-0.008797,1.83636,-2.13602,-0.034755,1.748,-2.19515,0.103716,1.6167,-2.15181,0.142649,1.56411,-2.17306,0.266154,1.40814,-1.7837,0.079362,1.49229,-1.86321,0.081443,1.51722,-1.90639,0.084705,1.5016,-1.97951,0.268774,1.45013,-2.03777,0.151332,1.1018,-1.75091,0.019691,1.13803,-1.76355,-0.005679,1.06204,-1.79154,0.006829,0.930683,-1.78657,-0.076661,0.758405,-1.7727,-0.118859,0.694919,-1.78038,-0.172048,0.818555,-1.78485,-0.209404,0.75785,-1.78847,-0.305867,0.538227,-1.79363,-0.412604,0.576126,-1.87483,-0.245607,0.382167,-1.85238,-0.302445,0.365849,-1.78361,0.406581,1.24649,-2.09159,0.464212,1.1867,-2.07241,0.30369,1.14529,-2.08064,0.360713,1.08786,-2.06407,0.473824,1.02348,-2.06241,0.464225,0.831031,-2.06545,0.35701,0.864501,-2.05507,0.340315,0.795906,-2.04789,0.304611,0.563222,-2.02922,0.223823,0.486039,-1.95882,0.49347,0.482861,-2.04318,0.430417,0.449858,-2.09832,0.181164,1.33002,-1.81802,0.189355,1.35936,-2.03109},
/*1399*/{0.295576,1.94628,-1.72755,0.348615,1.87876,-1.8829,0.271191,1.78937,-1.61032,0.255557,1.6678,-1.53123,0.367328,1.70788,-1.64004,0.444231,1.72581,-1.68511,0.225651,1.95043,-2.09372,0.339701,1.87952,-1.95717,0.121207,1.90109,-1.98208,-0.009303,1.83892,-2.13458,-0.03493,1.75134,-2.19362,0.103707,1.61903,-2.15112,0.142297,1.56687,-2.17324,0.26728,1.41005,-1.78504,0.080885,1.49512,-1.86222,0.082347,1.52049,-1.90523,0.084965,1.50533,-1.97794,0.268798,1.45309,-2.03813,0.150947,1.10417,-1.75233,0.023198,1.1438,-1.76306,-0.006538,1.06626,-1.79222,0.004481,0.934834,-1.78813,-0.080929,0.764064,-1.77287,-0.124005,0.700119,-1.78039,-0.174588,0.823376,-1.78441,-0.214226,0.764353,-1.78818,-0.312955,0.546485,-1.79168,-0.415861,0.59181,-1.87049,-0.262482,0.385856,-1.85339,-0.320298,0.371429,-1.78542,0.404407,1.24645,-2.09193,0.461765,1.18586,-2.07307,0.300609,1.14604,-2.08184,0.357775,1.08835,-2.06516,0.470859,1.02129,-2.06402,0.469371,0.828528,-2.06629,0.36131,0.856881,-2.05491,0.347922,0.788331,-2.04819,0.324,0.553308,-2.02968,0.245721,0.472326,-1.95951,0.517707,0.483707,-2.04064,0.456323,0.445231,-2.09589,0.181981,1.33229,-1.81863,0.188714,1.36283,-2.03159},
/*1400*/{0.297318,1.94856,-1.72893,0.349692,1.88121,-1.88447,0.272357,1.79301,-1.61174,0.255889,1.67003,-1.5301,0.367018,1.71153,-1.64167,0.443619,1.72883,-1.68721,0.225702,1.9518,-2.09397,0.340621,1.88163,-1.95809,0.122781,1.90231,-1.9826,-0.008241,1.84191,-2.1313,-0.035532,1.75314,-2.19096,0.104093,1.6215,-2.15095,0.142451,1.56887,-2.17311,0.268498,1.41215,-1.78526,0.082423,1.49777,-1.86119,0.082978,1.52388,-1.90409,0.084964,1.50928,-1.97648,0.268463,1.45568,-2.03867,0.151173,1.10624,-1.75391,0.021118,1.14488,-1.76438,-0.007021,1.06947,-1.7936,0.003348,0.938981,-1.78929,-0.084557,0.767889,-1.77366,-0.126588,0.706314,-1.7799,-0.177499,0.83003,-1.78408,-0.21716,0.770764,-1.7869,-0.318882,0.552676,-1.7903,-0.417161,0.607458,-1.86536,-0.279001,0.390422,-1.85495,-0.336731,0.379108,-1.78668,0.401581,1.24538,-2.09262,0.45911,1.18423,-2.07407,0.297073,1.14537,-2.08244,0.354046,1.08801,-2.06571,0.467803,1.01944,-2.06589,0.4747,0.825665,-2.06759,0.36532,0.849046,-2.0557,0.35402,0.780223,-2.04834,0.341971,0.543703,-2.03013,0.267157,0.460744,-1.96161,0.539705,0.482941,-2.03663,0.481586,0.440805,-2.09211,0.182605,1.33481,-1.81871,0.187851,1.36598,-2.03161},
/*1401*/{0.299084,1.9507,-1.73006,0.350894,1.8825,-1.88522,0.272816,1.79563,-1.61187,0.255611,1.67308,-1.53057,0.366241,1.71367,-1.64277,0.443333,1.73093,-1.68896,0.227086,1.95422,-2.09454,0.341567,1.88236,-1.95981,0.123589,1.90539,-1.98244,-0.008059,1.84371,-2.12969,-0.035406,1.75535,-2.18924,0.105613,1.62363,-2.15064,0.141729,1.5724,-2.17418,0.269043,1.41434,-1.78651,0.084057,1.50036,-1.85948,0.083722,1.52729,-1.90395,0.084483,1.51181,-1.97497,0.269565,1.45818,-2.03917,0.152367,1.10706,-1.75476,0.021615,1.14808,-1.76612,-0.006262,1.07319,-1.79399,0.001401,0.939642,-1.79071,-0.08635,0.772214,-1.77376,-0.131186,0.710593,-1.77972,-0.178665,0.835817,-1.78362,-0.220612,0.776794,-1.78625,-0.322055,0.561543,-1.78672,-0.419434,0.622784,-1.85895,-0.293769,0.397591,-1.85739,-0.352392,0.386834,-1.78882,0.399106,1.24326,-2.09362,0.45542,1.18219,-2.07566,0.293448,1.14535,-2.08317,0.349209,1.08671,-2.06684,0.463057,1.01656,-2.06642,0.479209,0.823453,-2.06877,0.368622,0.841542,-2.05813,0.360436,0.772514,-2.04944,0.359768,0.535603,-2.03022,0.287939,0.448714,-1.96066,0.560939,0.483572,-2.03337,0.505192,0.436341,-2.08789,0.183474,1.33716,-1.81888,0.187584,1.36883,-2.03173},
/*1402*/{0.300585,1.95147,-1.73123,0.35126,1.8839,-1.88673,0.274234,1.79817,-1.61242,0.256119,1.67586,-1.53027,0.366091,1.71541,-1.64487,0.44241,1.73292,-1.69071,0.228474,1.9551,-2.09511,0.342759,1.88337,-1.96036,0.124695,1.90694,-1.98267,-0.006556,1.84491,-2.12764,-0.035045,1.75641,-2.1879,0.105909,1.62504,-2.15021,0.144046,1.57293,-2.17344,0.269285,1.41615,-1.78681,0.085005,1.50311,-1.85966,0.083538,1.52936,-1.90352,0.083766,1.51477,-1.97358,0.269491,1.46042,-2.03927,0.152964,1.10906,-1.757,0.025332,1.15129,-1.7672,-0.004855,1.07455,-1.79351,0.003167,0.942955,-1.79093,-0.088389,0.775877,-1.77382,-0.132413,0.715382,-1.78015,-0.178805,0.840535,-1.78293,-0.220763,0.78256,-1.78359,-0.325256,0.57009,-1.78644,-0.421174,0.637741,-1.85095,-0.309782,0.405444,-1.86224,-0.365762,0.394668,-1.79357,0.39636,1.24091,-2.09473,0.450903,1.17874,-2.07636,0.289746,1.14389,-2.08342,0.344303,1.08482,-2.06743,0.4592,1.01311,-2.06705,0.482976,0.82053,-2.06939,0.370455,0.833878,-2.05967,0.367408,0.765541,-2.05222,0.379191,0.527527,-2.0307,0.307949,0.439397,-1.96029,0.580552,0.483461,-2.02917,0.528404,0.432613,-2.08402,0.183497,1.33929,-1.81899,0.186952,1.37135,-2.0318},
/*1403*/{0.302086,1.95341,-1.73219,0.351919,1.88521,-1.88774,0.275243,1.79987,-1.613,0.256116,1.67844,-1.52975,0.365396,1.71599,-1.64413,0.441457,1.73305,-1.6914,0.228939,1.95572,-2.09606,0.343379,1.88436,-1.96237,0.125784,1.90842,-1.98316,-0.006366,1.84617,-2.12532,-0.034413,1.75727,-2.18693,0.106815,1.62672,-2.14978,0.143917,1.57456,-2.1741,0.270317,1.41809,-1.78757,0.086123,1.50497,-1.85753,0.084368,1.53223,-1.90226,0.087698,1.51545,-1.97306,0.269294,1.4627,-2.03953,0.153644,1.11054,-1.75884,0.024499,1.15158,-1.76816,-0.002856,1.07551,-1.79473,0.005718,0.943869,-1.79251,-0.088635,0.77769,-1.77461,-0.134222,0.718466,-1.78027,-0.177126,0.844966,-1.78189,-0.221257,0.788697,-1.78451,-0.329197,0.575363,-1.78491,-0.421792,0.652091,-1.84194,-0.326188,0.413683,-1.86764,-0.381495,0.403388,-1.7974,0.392987,1.23788,-2.09557,0.447439,1.17532,-2.07801,0.284692,1.14299,-2.08529,0.339053,1.08241,-2.06818,0.455627,1.01019,-2.06899,0.48694,0.818195,-2.06967,0.373209,0.825858,-2.06327,0.371921,0.756591,-2.05476,0.396539,0.520537,-2.0293,0.326738,0.431376,-1.95994,0.598573,0.48398,-2.02561,0.549723,0.430139,-2.07976,0.185086,1.34107,-1.81871,0.187521,1.37338,-2.0315},
/*1404*/{0.303912,1.95394,-1.73281,0.353507,1.88679,-1.88954,0.276019,1.80191,-1.61414,0.256749,1.68008,-1.52963,0.365259,1.71699,-1.64435,0.440454,1.7328,-1.69308,0.229647,1.95589,-2.09723,0.345137,1.88467,-1.96272,0.12764,1.91013,-1.98349,-0.004824,1.84678,-2.12423,-0.033637,1.75776,-2.1854,0.108499,1.62763,-2.14974,0.145034,1.57579,-2.17393,0.271837,1.41944,-1.78967,0.086175,1.50748,-1.85675,0.084383,1.53486,-1.90202,0.088153,1.51635,-1.9731,0.269237,1.46385,-2.04031,0.159299,1.1116,-1.75959,0.02781,1.15185,-1.77008,0.001091,1.07513,-1.79569,0.00926,0.943891,-1.79372,-0.087497,0.778755,-1.77642,-0.136026,0.720495,-1.7811,-0.17487,0.848956,-1.78126,-0.219619,0.793885,-1.78229,-0.333049,0.582381,-1.78286,-0.425485,0.665621,-1.83315,-0.340584,0.425678,-1.87439,-0.392866,0.414147,-1.8012,0.388882,1.23427,-2.09644,0.442633,1.17055,-2.07885,0.279616,1.14084,-2.08596,0.332911,1.0804,-2.06899,0.451618,1.00551,-2.06991,0.489426,0.815437,-2.06947,0.375643,0.818796,-2.06616,0.37851,0.749075,-2.05763,0.409422,0.512361,-2.03092,0.343167,0.424255,-1.96224,0.615455,0.484571,-2.02261,0.569302,0.427201,-2.07582,0.185806,1.34284,-1.81908,0.186725,1.37484,-2.03192},
/*1405*/{0.305575,1.95392,-1.73471,0.354325,1.88744,-1.89052,0.276332,1.80295,-1.61435,0.254391,1.68142,-1.52999,0.364581,1.71695,-1.64531,0.44052,1.73219,-1.69407,0.231735,1.95743,-2.09795,0.345832,1.88489,-1.96396,0.129014,1.91113,-1.98365,-0.003153,1.84656,-2.12261,-0.032686,1.75713,-2.18464,0.109332,1.62751,-2.14936,0.146731,1.57589,-2.17478,0.271373,1.42132,-1.78979,0.086512,1.50862,-1.85636,0.084652,1.53668,-1.9028,0.087174,1.51812,-1.97205,0.269708,1.46538,-2.04039,0.161818,1.11081,-1.76151,0.029721,1.15104,-1.7709,0.003982,1.07519,-1.79683,0.014204,0.943016,-1.7948,-0.085469,0.779059,-1.77746,-0.135374,0.722078,-1.78421,-0.171415,0.852473,-1.77934,-0.217973,0.797888,-1.77961,-0.337499,0.591088,-1.78362,-0.428132,0.678587,-1.82419,-0.354027,0.437953,-1.88077,-0.402605,0.424061,-1.80668,0.385847,1.23033,-2.09792,0.438091,1.16549,-2.07992,0.274301,1.13973,-2.08436,0.32589,1.07816,-2.06968,0.447242,1.00068,-2.07044,0.492503,0.813057,-2.06849,0.378905,0.811889,-2.07072,0.383527,0.741536,-2.06124,0.424526,0.507415,-2.03118,0.360649,0.416093,-1.9598,0.62976,0.485401,-2.01931,0.590544,0.426171,-2.07093,0.185817,1.34448,-1.819,0.186666,1.37648,-2.03184},
/*1406*/{0.306616,1.95432,-1.73511,0.354861,1.88749,-1.89186,0.276305,1.80341,-1.61497,0.253903,1.6826,-1.52964,0.363596,1.71606,-1.64575,0.439441,1.73167,-1.6957,0.233242,1.95724,-2.09972,0.346446,1.88485,-1.96494,0.130581,1.91082,-1.98572,-0.003362,1.84597,-2.12198,-0.031998,1.75611,-2.18392,0.112148,1.62821,-2.14917,0.148753,1.57555,-2.17486,0.272017,1.42265,-1.79111,0.086061,1.50885,-1.85559,0.084572,1.53682,-1.90259,0.08708,1.5181,-1.97195,0.269541,1.46629,-2.04065,0.16554,1.11057,-1.76292,0.033889,1.15015,-1.77141,0.007462,1.07311,-1.79805,0.019944,0.941167,-1.79618,-0.083707,0.778901,-1.77933,-0.135978,0.723954,-1.78567,-0.16606,0.855146,-1.77709,-0.214326,0.802174,-1.77783,-0.340462,0.600824,-1.78431,-0.430735,0.690668,-1.81411,-0.363788,0.451726,-1.88657,-0.411288,0.43474,-1.81041,0.382015,1.22556,-2.09837,0.433269,1.16093,-2.08074,0.268912,1.13722,-2.08457,0.321349,1.07302,-2.06981,0.442543,0.995793,-2.07162,0.495638,0.810675,-2.06651,0.381411,0.806178,-2.07385,0.389646,0.736936,-2.06383,0.437217,0.502131,-2.03033,0.375601,0.410322,-1.95958,0.642518,0.486762,-2.01583,0.60502,0.425447,-2.06769,0.186897,1.34516,-1.81915,0.186755,1.3771,-2.03201},
/*1407*/{0.30879,1.95365,-1.73585,0.355479,1.88721,-1.89212,0.276063,1.80376,-1.61626,0.251857,1.68306,-1.52932,0.362978,1.71432,-1.64653,0.439249,1.72854,-1.69642,0.235314,1.95681,-2.1006,0.348203,1.88459,-1.96561,0.132133,1.91214,-1.98629,-0.002148,1.84476,-2.12124,-0.030766,1.75461,-2.18369,0.1137,1.62685,-2.14884,0.151123,1.57473,-2.1751,0.272309,1.42354,-1.79177,0.086014,1.50897,-1.85488,0.08398,1.53805,-1.90288,0.086824,1.5181,-1.97166,0.269708,1.46688,-2.04089,0.169877,1.10977,-1.7648,0.038271,1.14747,-1.77183,0.012939,1.07071,-1.80034,0.0261,0.938641,-1.79721,-0.080634,0.777538,-1.78179,-0.135878,0.725174,-1.78762,-0.160951,0.857255,-1.77503,-0.211843,0.80691,-1.77568,-0.34495,0.609049,-1.78519,-0.43418,0.702498,-1.80763,-0.376053,0.466891,-1.89278,-0.419243,0.446554,-1.81551,0.377726,1.22085,-2.09981,0.427247,1.15487,-2.08249,0.263437,1.13416,-2.08446,0.315085,1.06933,-2.07029,0.437629,0.990984,-2.07205,0.497342,0.808332,-2.06482,0.384507,0.799718,-2.07618,0.394031,0.7307,-2.06559,0.448301,0.497061,-2.03097,0.387397,0.404069,-1.95916,0.653946,0.487743,-2.01173,0.617584,0.424858,-2.06414,0.187335,1.34585,-1.81916,0.186665,1.37765,-2.03203},
/*1408*/{0.309757,1.95258,-1.73648,0.355443,1.88734,-1.89315,0.276057,1.80346,-1.61705,0.251037,1.68268,-1.5292,0.362436,1.7131,-1.6472,0.437706,1.7249,-1.69777,0.2366,1.95602,-2.10212,0.348527,1.88418,-1.96629,0.133326,1.91218,-1.98724,-0.000628,1.84169,-2.11905,-0.028927,1.7528,-2.18358,0.116902,1.6258,-2.14888,0.153069,1.57329,-2.17554,0.271998,1.42433,-1.79187,0.08562,1.509,-1.85529,0.083482,1.53845,-1.90315,0.086537,1.51782,-1.97085,0.269709,1.46691,-2.04088,0.174547,1.1087,-1.7663,0.044252,1.14487,-1.77161,0.017176,1.06706,-1.80078,0.033622,0.935026,-1.79831,-0.078297,0.776662,-1.78416,-0.135811,0.726588,-1.79058,-0.154166,0.858933,-1.77262,-0.206593,0.811455,-1.77289,-0.348846,0.617862,-1.78541,-0.436665,0.7147,-1.8006,-0.384755,0.481491,-1.89785,-0.426225,0.459491,-1.8197,0.373508,1.21581,-2.10036,0.42249,1.14895,-2.08366,0.258303,1.1307,-2.08419,0.308025,1.06661,-2.07028,0.432654,0.98517,-2.0724,0.499323,0.806198,-2.06208,0.386925,0.793135,-2.07836,0.398572,0.725258,-2.06836,0.457429,0.493898,-2.0303,0.398427,0.399643,-1.95863,0.663254,0.489136,-2.00964,0.630406,0.424664,-2.06093,0.187326,1.34631,-1.81883,0.186608,1.37764,-2.03177},
/*1409*/{0.311036,1.95156,-1.73784,0.356123,1.88626,-1.89399,0.275363,1.8027,-1.61792,0.248919,1.68338,-1.53013,0.360674,1.71073,-1.64704,0.43591,1.72112,-1.69842,0.237879,1.95496,-2.10342,0.348773,1.88379,-1.96674,0.134753,1.91293,-1.9892,0.001556,1.84042,-2.119,-0.027352,1.75015,-2.18392,0.118822,1.62409,-2.14945,0.156152,1.57111,-2.17654,0.272073,1.42533,-1.79216,0.085545,1.50867,-1.85619,0.082554,1.53776,-1.90338,0.085098,1.51708,-1.97172,0.269708,1.46688,-2.04089,0.180688,1.10833,-1.76812,0.047095,1.14254,-1.77304,0.023615,1.06313,-1.80124,0.04103,0.931484,-1.80037,-0.075006,0.775713,-1.78626,-0.135046,0.729121,-1.7931,-0.146707,0.861317,-1.77039,-0.201499,0.81559,-1.77127,-0.352322,0.629343,-1.78549,-0.438103,0.727029,-1.79608,-0.392725,0.496335,-1.89997,-0.432629,0.472738,-1.82305,0.370759,1.21083,-2.10135,0.418201,1.14264,-2.08428,0.252987,1.12729,-2.08357,0.301547,1.06285,-2.07012,0.428276,0.980084,-2.07276,0.50055,0.803579,-2.05985,0.389368,0.788353,-2.0802,0.401634,0.720223,-2.06995,0.464697,0.489022,-2.0307,0.407775,0.393885,-1.96086,0.670511,0.49048,-2.00816,0.639938,0.424447,-2.05886,0.18782,1.34671,-1.81871,0.186906,1.37719,-2.03177},
/*1410*/{0.311613,1.95039,-1.73805,0.357136,1.88546,-1.89485,0.274524,1.80166,-1.61872,0.247434,1.68138,-1.52956,0.359263,1.70701,-1.64717,0.434483,1.71661,-1.69841,0.239634,1.95347,-2.10471,0.34908,1.88281,-1.9677,0.136271,1.91231,-1.99027,0.002485,1.83684,-2.11828,-0.025558,1.74723,-2.18405,0.122189,1.62176,-2.14958,0.15878,1.56892,-2.17757,0.271996,1.42536,-1.79249,0.084674,1.5076,-1.85636,0.082555,1.53741,-1.90412,0.085135,1.51556,-1.97264,0.27018,1.46676,-2.04118,0.185775,1.10683,-1.77242,0.055076,1.13601,-1.77103,0.030516,1.05862,-1.80202,0.04953,0.927466,-1.80248,-0.072442,0.77518,-1.78821,-0.132762,0.731355,-1.79453,-0.140038,0.863337,-1.76875,-0.196766,0.819801,-1.76985,-0.354528,0.64121,-1.7855,-0.439122,0.740315,-1.79332,-0.399287,0.510116,-1.90146,-0.439642,0.486398,-1.82489,0.366296,1.20571,-2.10232,0.413481,1.13692,-2.08575,0.248244,1.12359,-2.08303,0.296493,1.05842,-2.06949,0.421714,0.974557,-2.07257,0.499936,0.800762,-2.05796,0.390078,0.783542,-2.08093,0.40299,0.715167,-2.07033,0.470929,0.486022,-2.03084,0.414584,0.390244,-1.96114,0.676498,0.489645,-2.00673,0.64604,0.422852,-2.05817,0.188196,1.34632,-1.81901,0.187676,1.37663,-2.0321},
/*1411*/{0.312207,1.94806,-1.73891,0.35693,1.88533,-1.89493,0.273717,1.80018,-1.61959,0.244138,1.6804,-1.52994,0.358111,1.704,-1.6478,0.433425,1.71171,-1.69912,0.240949,1.95201,-2.1059,0.349228,1.8819,-1.96789,0.136913,1.91142,-1.99272,0.003893,1.83352,-2.11881,-0.023005,1.74384,-2.18432,0.124842,1.61928,-2.15052,0.162591,1.56619,-2.17807,0.272052,1.42524,-1.79329,0.084257,1.50667,-1.85609,0.081695,1.53548,-1.90464,0.084119,1.51385,-1.97328,0.270441,1.46558,-2.04141,0.191456,1.10504,-1.77387,0.055594,1.13189,-1.77408,0.036264,1.05443,-1.80218,0.058157,0.922862,-1.80427,-0.06865,0.775121,-1.79054,-0.132194,0.734073,-1.79545,-0.132514,0.865633,-1.76765,-0.191491,0.824805,-1.7698,-0.35612,0.653314,-1.78316,-0.437546,0.755952,-1.79146,-0.404692,0.52515,-1.90187,-0.445881,0.501543,-1.82566,0.363899,1.20046,-2.10301,0.409254,1.13166,-2.08642,0.24407,1.12066,-2.08323,0.290768,1.05442,-2.06851,0.41593,0.969681,-2.0724,0.49872,0.798513,-2.05642,0.388383,0.779365,-2.07967,0.403575,0.711375,-2.06978,0.473904,0.483364,-2.03043,0.419701,0.387327,-1.95984,0.680446,0.488594,-2.00688,0.650474,0.42096,-2.05794,0.188706,1.34568,-1.81887,0.187805,1.37516,-2.03208},
/*1412*/{0.312823,1.94637,-1.74024,0.356168,1.88366,-1.89562,0.271396,1.79854,-1.6205,0.241643,1.68017,-1.53145,0.356193,1.6991,-1.64817,0.432307,1.70554,-1.69935,0.242102,1.95041,-2.10741,0.35039,1.88006,-1.96827,0.137875,1.91056,-1.99357,0.008494,1.83127,-2.118,-0.020625,1.73985,-2.18537,0.129075,1.61594,-2.15154,0.166333,1.56232,-2.17958,0.272047,1.4249,-1.79362,0.08307,1.50427,-1.85657,0.081569,1.53384,-1.90475,0.084216,1.51122,-1.97364,0.269372,1.4639,-2.04133,0.197103,1.10311,-1.7752,0.061386,1.12704,-1.7734,0.042232,1.04871,-1.8019,0.066921,0.918911,-1.8059,-0.064409,0.776331,-1.79127,-0.129355,0.737998,-1.79703,-0.123957,0.86897,-1.76717,-0.184537,0.830855,-1.76854,-0.35755,0.667504,-1.78241,-0.435936,0.7717,-1.79312,-0.40933,0.538896,-1.90029,-0.4532,0.517697,-1.82441,0.360075,1.19462,-2.10415,0.405446,1.12606,-2.08795,0.240141,1.11742,-2.08302,0.285738,1.05093,-2.06825,0.410903,0.965183,-2.07195,0.495017,0.795837,-2.05659,0.385163,0.77555,-2.07793,0.402173,0.708152,-2.06771,0.475469,0.479604,-2.0301,0.423389,0.384919,-1.95687,0.683274,0.487833,-2.00733,0.652811,0.4191,-2.05825,0.189108,1.34452,-1.81851,0.187861,1.37307,-2.03184},
/*1413*/{0.312567,1.94308,-1.74112,0.356814,1.88131,-1.89681,0.270497,1.79685,-1.62113,0.237568,1.67738,-1.53227,0.353493,1.69473,-1.6484,0.430069,1.69909,-1.69892,0.243186,1.94842,-2.10847,0.350501,1.87839,-1.9686,0.138189,1.90968,-1.99573,0.007406,1.82562,-2.11801,-0.01758,1.73539,-2.18619,0.13203,1.61211,-2.15282,0.169843,1.55902,-2.18075,0.272193,1.42438,-1.79414,0.082508,1.50239,-1.85818,0.080808,1.53227,-1.90588,0.082893,1.50822,-1.97427,0.26936,1.46245,-2.04262,0.201701,1.10183,-1.77655,0.066812,1.12144,-1.77331,0.048408,1.04349,-1.80316,0.075775,0.91485,-1.80761,-0.059551,0.778114,-1.79143,-0.125536,0.741987,-1.79835,-0.115722,0.872638,-1.76717,-0.177962,0.836847,-1.76875,-0.360906,0.682767,-1.78226,-0.432335,0.788222,-1.79628,-0.412035,0.552008,-1.89686,-0.459543,0.534323,-1.82167,0.358208,1.19016,-2.10572,0.401256,1.12013,-2.08888,0.236614,1.11471,-2.082,0.281113,1.04728,-2.06666,0.404709,0.960565,-2.07127,0.491316,0.793385,-2.05739,0.380696,0.771361,-2.07534,0.397771,0.70427,-2.06534,0.476284,0.476833,-2.02982,0.423732,0.380124,-1.95823,0.683287,0.485764,-2.009,0.653652,0.417306,-2.05908,0.189669,1.34352,-1.81888,0.188094,1.37103,-2.03234},
/*1414*/{0.313,1.94041,-1.74149,0.356622,1.87959,-1.8973,0.267747,1.79414,-1.62185,0.233285,1.67551,-1.53378,0.351174,1.6893,-1.64829,0.427254,1.69156,-1.69862,0.244964,1.94588,-2.10967,0.350535,1.87657,-1.96892,0.13879,1.90716,-1.99734,0.011501,1.82104,-2.11975,-0.014345,1.73067,-2.18804,0.136583,1.60805,-2.15374,0.173763,1.5547,-2.18205,0.271797,1.42336,-1.79423,0.083079,1.49955,-1.85895,0.080018,1.53027,-1.90674,0.083566,1.50597,-1.97511,0.268711,1.45971,-2.04355,0.20601,1.10005,-1.77772,0.071713,1.11711,-1.7751,0.0555,1.03823,-1.80323,0.084436,0.911016,-1.80865,-0.054843,0.779934,-1.7912,-0.123492,0.746068,-1.79654,-0.107504,0.877117,-1.76788,-0.170513,0.843356,-1.76909,-0.360237,0.694254,-1.78218,-0.427744,0.804805,-1.80022,-0.414478,0.565339,-1.89301,-0.464087,0.552108,-1.81892,0.355336,1.18553,-2.10731,0.398698,1.11445,-2.09022,0.233154,1.11211,-2.08114,0.277274,1.04479,-2.06632,0.399099,0.957048,-2.07106,0.485003,0.790304,-2.05822,0.37472,0.767211,-2.07323,0.392819,0.699707,-2.06298,0.474383,0.473535,-2.0289,0.424677,0.376166,-1.9565,0.682367,0.483184,-2.00991,0.651604,0.415113,-2.06008,0.189824,1.3419,-1.81885,0.188111,1.3683,-2.03246},
/*1415*/{0.312853,1.93768,-1.74165,0.356424,1.87772,-1.89771,0.265673,1.7916,-1.62237,0.229906,1.67339,-1.53529,0.348133,1.68306,-1.6482,0.425692,1.68433,-1.69836,0.245681,1.94323,-2.11068,0.350321,1.87372,-1.96914,0.139224,1.90615,-1.9992,0.013586,1.81663,-2.1205,-0.01123,1.7254,-2.18945,0.139997,1.60366,-2.15606,0.178437,1.55028,-2.18345,0.271961,1.42236,-1.79453,0.082949,1.49693,-1.85997,0.080897,1.52686,-1.90635,0.082776,1.50293,-1.97649,0.267785,1.45687,-2.04439,0.212703,1.09648,-1.77866,0.076952,1.11297,-1.7751,0.062432,1.03187,-1.8044,0.094391,0.907503,-1.81003,-0.049876,0.782641,-1.79136,-0.118752,0.75145,-1.79649,-0.09952,0.882343,-1.76893,-0.162906,0.850332,-1.76984,-0.353237,0.703371,-1.7834,-0.421527,0.821905,-1.80501,-0.414447,0.577664,-1.88801,-0.4679,0.569742,-1.8157,0.353535,1.18122,-2.10876,0.39493,1.10995,-2.09157,0.230206,1.10975,-2.08078,0.272963,1.04205,-2.06568,0.394421,0.953137,-2.07079,0.480321,0.786467,-2.05899,0.368803,0.762401,-2.07178,0.387871,0.69535,-2.06099,0.472716,0.470319,-2.02718,0.422484,0.374793,-1.94843,0.679649,0.480074,-2.01148,0.648318,0.411924,-2.06109,0.190588,1.34011,-1.81866,0.188099,1.36509,-2.03243},
/*1416*/{0.311915,1.93348,-1.74174,0.356391,1.87396,-1.8975,0.262992,1.78825,-1.62363,0.224596,1.67007,-1.53656,0.345235,1.67691,-1.6479,0.422813,1.67648,-1.69729,0.246735,1.94002,-2.11126,0.350133,1.87081,-1.96946,0.139645,1.90348,-2.00069,0.015726,1.81069,-2.12224,-0.007772,1.71965,-2.19106,0.144298,1.59899,-2.15745,0.182581,1.54593,-2.18559,0.271759,1.42083,-1.79494,0.082433,1.49426,-1.86105,0.080421,1.52452,-1.90821,0.082388,1.4997,-1.97683,0.268126,1.45411,-2.04546,0.217535,1.09446,-1.77885,0.081134,1.10522,-1.7756,0.070278,1.02642,-1.80563,0.103015,0.903634,-1.81042,-0.043867,0.786071,-1.78853,-0.113855,0.75743,-1.79332,-0.090322,0.887547,-1.77061,-0.154917,0.857852,-1.77171,-0.355536,0.724539,-1.77688,-0.414002,0.837607,-1.80984,-0.412668,0.589763,-1.88208,-0.46899,0.586822,-1.81176,0.350785,1.17744,-2.11019,0.393418,1.10483,-2.09166,0.227509,1.108,-2.08046,0.270285,1.03978,-2.06466,0.390422,0.949531,-2.07052,0.47337,0.782296,-2.06072,0.364269,0.756518,-2.06598,0.382383,0.6911,-2.05917,0.469013,0.466835,-2.02503,0.418769,0.371054,-1.94664,0.675871,0.475533,-2.01122,0.64358,0.408526,-2.06186,0.190734,1.3382,-1.81888,0.188422,1.36213,-2.03277},
/*1417*/{0.311681,1.92973,-1.74183,0.355584,1.87095,-1.89793,0.260022,1.78489,-1.62412,0.220052,1.66682,-1.538,0.341076,1.67062,-1.64774,0.41875,1.66772,-1.69618,0.247072,1.93692,-2.11224,0.349949,1.86769,-1.96985,0.138864,1.90124,-2.00322,0.014319,1.80825,-2.12577,-0.004633,1.71285,-2.19345,0.148108,1.59364,-2.16028,0.186779,1.54051,-2.18718,0.272486,1.41854,-1.79529,0.081792,1.49102,-1.86218,0.07973,1.52096,-1.90789,0.081285,1.49618,-1.97867,0.267537,1.45126,-2.04652,0.224319,1.0899,-1.77679,0.086974,1.09928,-1.77664,0.076274,1.01998,-1.80712,0.11238,0.899784,-1.81123,-0.038266,0.789273,-1.78736,-0.1086,0.761912,-1.79226,-0.080478,0.893186,-1.77246,-0.146888,0.864969,-1.77204,-0.347612,0.735324,-1.78316,-0.406261,0.852917,-1.81573,-0.411169,0.602069,-1.87715,-0.468341,0.604451,-1.80802,0.348887,1.17343,-2.11169,0.390242,1.10094,-2.09314,0.225081,1.10628,-2.07983,0.266853,1.03684,-2.06434,0.38705,0.946305,-2.07054,0.46784,0.777756,-2.06133,0.357903,0.751977,-2.06532,0.376396,0.686656,-2.05817,0.464055,0.462599,-2.02392,0.413192,0.368074,-1.9442,0.669707,0.470419,-2.01297,0.638266,0.403158,-2.06028,0.19129,1.33558,-1.81938,0.188396,1.35891,-2.03333},
/*1418*/{0.310555,1.92572,-1.742,0.356341,1.86787,-1.89839,0.256693,1.78149,-1.62416,0.215124,1.66324,-1.53997,0.337039,1.66406,-1.64764,0.416767,1.65838,-1.69495,0.247265,1.93334,-2.11299,0.350381,1.86464,-1.97004,0.139683,1.89846,-2.00401,0.015956,1.8022,-2.12831,-0.001044,1.70613,-2.1962,0.153005,1.58792,-2.16221,0.191986,1.53525,-2.189,0.272654,1.41649,-1.79624,0.081797,1.48738,-1.8626,0.08032,1.51769,-1.9083,0.081682,1.49176,-1.97857,0.266943,1.44865,-2.04796,0.230189,1.08586,-1.7758,0.091978,1.09339,-1.77721,0.084333,1.01341,-1.8063,0.121529,0.895451,-1.81098,-0.031427,0.793234,-1.78542,-0.103252,0.768635,-1.7893,-0.070963,0.897415,-1.77551,-0.137844,0.872928,-1.77457,-0.346225,0.753252,-1.77796,-0.396788,0.86732,-1.82067,-0.408094,0.614101,-1.87211,-0.467081,0.621548,-1.80332,0.346913,1.17014,-2.11256,0.387973,1.09764,-2.09455,0.222805,1.10441,-2.08017,0.263735,1.03438,-2.06529,0.384007,0.942894,-2.0706,0.462574,0.772772,-2.06239,0.35233,0.747659,-2.06475,0.370369,0.6822,-2.05657,0.455361,0.457573,-2.02235,0.405732,0.363278,-1.94153,0.662865,0.463884,-2.01246,0.634014,0.397015,-2.05866,0.192563,1.33279,-1.81984,0.188723,1.35564,-2.03382},
/*1419*/{0.310073,1.92146,-1.74168,0.356539,1.8637,-1.8985,0.252639,1.7775,-1.6248,0.208748,1.66006,-1.54211,0.332638,1.65687,-1.64703,0.412866,1.6486,-1.69366,0.24846,1.92906,-2.11374,0.350558,1.86085,-1.97025,0.138949,1.89495,-2.00655,0.019582,1.79164,-2.12936,0.003238,1.6992,-2.198,0.157196,1.58159,-2.16506,0.197166,1.52926,-2.19077,0.27302,1.41416,-1.79659,0.080925,1.48337,-1.86341,0.078534,1.51412,-1.9097,0.080396,1.48812,-1.97994,0.265714,1.44615,-2.04888,0.234213,1.08364,-1.77537,0.096815,1.09005,-1.77833,0.090918,1.00741,-1.80876,0.131119,0.891805,-1.81017,-0.024455,0.796397,-1.78413,-0.096798,0.774358,-1.78739,-0.060341,0.902686,-1.7782,-0.128587,0.879582,-1.77612,-0.338916,0.766742,-1.7769,-0.386239,0.880401,-1.82566,-0.403779,0.625566,-1.86632,-0.462895,0.637611,-1.79933,0.345391,1.16662,-2.11316,0.384371,1.09368,-2.09539,0.220102,1.10177,-2.08023,0.260964,1.0312,-2.06568,0.381183,0.939319,-2.07066,0.457488,0.76721,-2.06282,0.345535,0.745312,-2.06704,0.364436,0.677646,-2.056,0.448791,0.452022,-2.02062,0.396568,0.360258,-1.93687,0.656481,0.456362,-2.01063,0.621708,0.387788,-2.05693,0.192854,1.33004,-1.82062,0.188607,1.35252,-2.03464},
/*1420*/{0.309171,1.91651,-1.74099,0.355885,1.86033,-1.89873,0.248804,1.77343,-1.6251,0.204682,1.65622,-1.54361,0.327976,1.64935,-1.64743,0.408765,1.63908,-1.69174,0.247689,1.92492,-2.11417,0.351105,1.85694,-1.97059,0.139162,1.89155,-2.00773,0.020639,1.78432,-2.13284,0.006347,1.69101,-2.20089,0.161579,1.57616,-2.16814,0.201966,1.52319,-2.19283,0.272733,1.41133,-1.7969,0.080928,1.47933,-1.86297,0.07933,1.51011,-1.90945,0.079681,1.48339,-1.98008,0.265036,1.44343,-2.04964,0.239268,1.08181,-1.77394,0.101724,1.08198,-1.77873,0.097857,1.00186,-1.80868,0.14056,0.888185,-1.80915,-0.015771,0.799527,-1.78322,-0.088259,0.77928,-1.78777,-0.050191,0.907455,-1.78068,-0.118663,0.887563,-1.78026,-0.331013,0.77977,-1.77542,-0.376634,0.892663,-1.8301,-0.398319,0.637246,-1.86128,-0.457984,0.65254,-1.79474,0.342485,1.16297,-2.11353,0.382442,1.08993,-2.0959,0.217607,1.09892,-2.08027,0.258032,1.02886,-2.0664,0.378079,0.935615,-2.07105,0.451026,0.761696,-2.06359,0.3394,0.74075,-2.06733,0.357694,0.673032,-2.05553,0.439849,0.447427,-2.01958,0.385654,0.357849,-1.9393,0.647098,0.446564,-2.01012,0.615219,0.379473,-2.05423,0.19377,1.32662,-1.8208,0.188752,1.34901,-2.03481},
/*1421*/{0.308099,1.91213,-1.74073,0.356655,1.85537,-1.89784,0.244951,1.76915,-1.62533,0.196721,1.6528,-1.54627,0.323177,1.64164,-1.64659,0.404076,1.6283,-1.69011,0.247923,1.92039,-2.1152,0.350716,1.85288,-1.97041,0.138573,1.88708,-2.01046,0.022922,1.77577,-2.13588,0.010084,1.68317,-2.20434,0.166778,1.5691,-2.17167,0.207603,1.51621,-2.19497,0.272856,1.40856,-1.79757,0.08005,1.47547,-1.86456,0.079382,1.50544,-1.91034,0.078336,1.47888,-1.97973,0.264722,1.44042,-2.05075,0.243025,1.07972,-1.77377,0.10663,1.07627,-1.7798,0.104861,0.996295,-1.80893,0.150153,0.884381,-1.80747,-0.008951,0.803667,-1.78097,-0.082407,0.785427,-1.7843,-0.039893,0.911733,-1.7836,-0.108167,0.893071,-1.78134,-0.323263,0.793041,-1.77725,-0.36568,0.903883,-1.8342,-0.39195,0.648046,-1.85624,-0.451764,0.666398,-1.79091,0.340733,1.15951,-2.11401,0.379747,1.08587,-2.09685,0.215093,1.09568,-2.08051,0.254978,1.02451,-2.06686,0.374681,0.931041,-2.07137,0.445942,0.75476,-2.06302,0.333323,0.736172,-2.06696,0.350414,0.668249,-2.05542,0.427978,0.439821,-2.01859,0.37533,0.352951,-1.94002,0.636826,0.438212,-2.00819,0.602647,0.368522,-2.05061,0.194486,1.32329,-1.82143,0.189004,1.34533,-2.03547},
/*1422*/{0.307227,1.90708,-1.73981,0.356165,1.85028,-1.89767,0.240432,1.76443,-1.62533,0.189887,1.64922,-1.54806,0.31812,1.634,-1.64667,0.399782,1.61735,-1.68802,0.247919,1.9155,-2.11613,0.350576,1.84842,-1.97081,0.138464,1.88209,-2.01141,0.024201,1.76827,-2.13991,0.013624,1.67445,-2.20775,0.171678,1.56231,-2.17438,0.213489,1.51004,-2.19667,0.272675,1.40578,-1.79815,0.079665,1.47125,-1.86435,0.079074,1.50068,-1.91019,0.077476,1.47443,-1.97958,0.264058,1.43751,-2.05169,0.24788,1.07536,-1.77209,0.112096,1.07213,-1.78059,0.11302,0.989386,-1.80945,0.15918,0.881072,-1.80584,0.00085,0.807878,-1.77866,-0.073214,0.789352,-1.78288,-0.027763,0.915671,-1.78638,-0.097486,0.898516,-1.78502,-0.314371,0.804585,-1.77819,-0.355091,0.914396,-1.83792,-0.384837,0.658217,-1.85184,-0.443485,0.679636,-1.7864,0.338374,1.15563,-2.1142,0.377306,1.08156,-2.09724,0.212627,1.09184,-2.08048,0.252916,1.02084,-2.06781,0.371507,0.925858,-2.07223,0.439991,0.749063,-2.06328,0.327033,0.731497,-2.06755,0.343509,0.663259,-2.05584,0.416597,0.435162,-2.01786,0.360293,0.353109,-1.93689,0.626295,0.426801,-2.00483,0.589085,0.358496,-2.04766,0.1954,1.31978,-1.82177,0.18904,1.34177,-2.03578},
/*1423*/{0.305883,1.90234,-1.73928,0.356139,1.84629,-1.89771,0.236161,1.75944,-1.62549,0.183486,1.64541,-1.55003,0.311758,1.62586,-1.6467,0.393921,1.60652,-1.68599,0.24834,1.91061,-2.11678,0.350168,1.84377,-1.97147,0.137643,1.8772,-2.01374,0.02633,1.75932,-2.14362,0.017728,1.66553,-2.21127,0.176753,1.55461,-2.17786,0.219317,1.50232,-2.19895,0.272365,1.40213,-1.79861,0.079522,1.46603,-1.86484,0.078428,1.49609,-1.9107,0.076646,1.46988,-1.97956,0.262981,1.43395,-2.05273,0.253481,1.07382,-1.77039,0.118199,1.06587,-1.78164,0.120968,0.9836,-1.80922,0.167439,0.877527,-1.80466,0.010294,0.8114,-1.77724,-0.065556,0.794356,-1.78142,-0.015836,0.919333,-1.79041,-0.086358,0.904463,-1.78862,-0.30323,0.813452,-1.7766,-0.34442,0.923576,-1.84163,-0.376002,0.666692,-1.84804,-0.434092,0.691301,-1.78274,0.335999,1.15179,-2.11518,0.375805,1.07806,-2.09844,0.210206,1.08708,-2.08096,0.250341,1.01698,-2.06858,0.367184,0.919605,-2.07281,0.433463,0.742804,-2.0635,0.320576,0.725772,-2.06785,0.335332,0.658075,-2.05601,0.40769,0.432344,-2.01679,0.342603,0.356857,-1.93904,0.614571,0.414732,-1.99992,0.571564,0.349402,-2.04443,0.195789,1.31558,-1.8225,0.188784,1.33776,-2.03648},
/*1424*/{0.304231,1.89715,-1.7391,0.356006,1.83949,-1.89702,0.231833,1.75441,-1.62632,0.176459,1.64068,-1.55103,0.306009,1.61732,-1.64668,0.388262,1.59538,-1.68396,0.248776,1.90595,-2.11811,0.350262,1.83872,-1.97073,0.135916,1.87241,-2.01532,0.026289,1.75284,-2.14891,0.022336,1.65608,-2.21515,0.181626,1.54646,-2.18081,0.225366,1.49499,-2.20033,0.272549,1.39848,-1.79921,0.078273,1.4611,-1.86516,0.077892,1.49131,-1.9113,0.075107,1.464,-1.97971,0.263137,1.43075,-2.05404,0.260394,1.07004,-1.76827,0.123051,1.06035,-1.78332,0.127905,0.977834,-1.81053,0.177578,0.874828,-1.80149,0.019884,0.814576,-1.77586,-0.054714,0.799809,-1.77959,-0.003529,0.922249,-1.79364,-0.074129,0.907868,-1.79095,-0.293754,0.823207,-1.77713,-0.33286,0.9321,-1.84457,-0.366385,0.675466,-1.84361,-0.42389,0.702102,-1.77902,0.333441,1.14723,-2.11569,0.373238,1.07352,-2.09948,0.207908,1.08317,-2.08199,0.248093,1.0118,-2.0691,0.362893,0.91321,-2.07351,0.428079,0.736156,-2.06171,0.313977,0.720442,-2.06778,0.327847,0.652487,-2.0564,0.394639,0.426731,-2.01678,0.323792,0.357365,-1.93809,0.60139,0.398701,-1.99709,0.552947,0.338589,-2.04219,0.196668,1.31146,-1.82323,0.189195,1.33369,-2.03719},
/*1425*/{0.302258,1.89114,-1.73839,0.356051,1.83453,-1.89642,0.227448,1.74946,-1.62702,0.168577,1.63649,-1.55306,0.30067,1.60913,-1.64685,0.38168,1.5843,-1.68184,0.2478,1.9,-2.11846,0.350875,1.83419,-1.97078,0.136021,1.86679,-2.01725,0.028875,1.74332,-2.15364,0.026339,1.64679,-2.219,0.1882,1.53805,-2.18331,0.231423,1.48785,-2.20297,0.273102,1.39514,-1.80011,0.078394,1.45504,-1.86535,0.076609,1.48602,-1.91206,0.074049,1.45917,-1.97993,0.261863,1.42693,-2.05593,0.265338,1.06713,-1.76615,0.128297,1.05335,-1.78476,0.137157,0.972446,-1.81049,0.186686,0.872346,-1.80062,0.030239,0.816939,-1.77514,-0.043367,0.804232,-1.77728,0.00949,0.925108,-1.79683,-0.060763,0.912081,-1.7938,-0.281189,0.832633,-1.77729,-0.321288,0.939332,-1.84781,-0.356641,0.683163,-1.84067,-0.412094,0.711303,-1.77524,0.33077,1.14314,-2.11704,0.370924,1.06907,-2.10104,0.205391,1.07887,-2.0833,0.245642,1.007,-2.06991,0.359657,0.907906,-2.07411,0.420461,0.729112,-2.06086,0.307787,0.715274,-2.06845,0.319508,0.646724,-2.05686,0.378062,0.42217,-2.01181,0.303225,0.355959,-1.93524,0.583521,0.388874,-1.98549,0.533157,0.339984,-2.04288,0.197973,1.30723,-1.82425,0.189025,1.32933,-2.03816},
/*1426*/{0.300201,1.88583,-1.73662,0.356799,1.82911,-1.89554,0.223454,1.74415,-1.62799,0.162034,1.6331,-1.55432,0.293561,1.60036,-1.6464,0.374967,1.57305,-1.68038,0.248323,1.8948,-2.11972,0.351516,1.8291,-1.97088,0.135404,1.86014,-2.0193,0.030735,1.73313,-2.15779,0.031176,1.63772,-2.22303,0.194146,1.53012,-2.18664,0.238328,1.47994,-2.20455,0.272664,1.3912,-1.80147,0.077796,1.44967,-1.86535,0.075389,1.48115,-1.91258,0.072323,1.45424,-1.97952,0.260717,1.42328,-2.0579,0.270562,1.06366,-1.76372,0.134046,1.04728,-1.78519,0.143318,0.966676,-1.81106,0.19578,0.870804,-1.79827,0.041522,0.81896,-1.77328,-0.032623,0.807778,-1.7761,0.022851,0.926451,-1.79996,-0.048424,0.915284,-1.79725,-0.268923,0.840178,-1.77785,-0.310001,0.945861,-1.85093,-0.344491,0.689083,-1.83712,-0.400705,0.719401,-1.77209,0.328026,1.13928,-2.11909,0.367644,1.06441,-2.10375,0.202617,1.07494,-2.08395,0.242496,1.00324,-2.07035,0.35428,0.902066,-2.07497,0.413497,0.72125,-2.0578,0.300816,0.711009,-2.06878,0.310564,0.642196,-2.05575,0.359676,0.421659,-2.0055,0.280753,0.353594,-1.93551,0.560962,0.386714,-1.98438,0.509641,0.341352,-2.04282,0.198374,1.30277,-1.82549,0.188076,1.32526,-2.0393},
/*1427*/{0.299791,1.88124,-1.73596,0.356695,1.82252,-1.89453,0.218664,1.73962,-1.62838,0.156132,1.62957,-1.55628,0.28747,1.59283,-1.6463,0.368386,1.56236,-1.67803,0.249669,1.88967,-2.12103,0.351892,1.82412,-1.97068,0.13487,1.8549,-2.02069,0.03336,1.72322,-2.16241,0.036543,1.6276,-2.22751,0.200509,1.52174,-2.18974,0.245273,1.47263,-2.20631,0.272189,1.3866,-1.8026,0.076044,1.44465,-1.86556,0.074458,1.47588,-1.91257,0.070271,1.44959,-1.97926,0.25965,1.41888,-2.05997,0.275396,1.06042,-1.76252,0.140086,1.04133,-1.78602,0.152136,0.960469,-1.81014,0.206601,0.868607,-1.79563,0.053375,0.821328,-1.77118,-0.021231,0.810999,-1.77404,0.036657,0.927447,-1.8032,-0.034255,0.917813,-1.79958,-0.256948,0.84612,-1.77907,-0.298638,0.951156,-1.8531,-0.33285,0.695199,-1.83431,-0.38631,0.726337,-1.76861,0.323166,1.13593,-2.12316,0.363038,1.06077,-2.10752,0.198903,1.07183,-2.08409,0.239497,1.00152,-2.07095,0.348183,0.89576,-2.07575,0.407871,0.714499,-2.05312,0.29429,0.707343,-2.06875,0.301414,0.638828,-2.05303,0.33434,0.421058,-1.99869,0.257134,0.352886,-1.93107,0.535121,0.388298,-1.98349,0.485938,0.341714,-2.04254,0.198,1.29794,-1.8266,0.186572,1.32079,-2.04032},
/*1428*/{0.298065,1.87519,-1.73527,0.356499,1.81615,-1.89352,0.214492,1.73461,-1.62924,0.147056,1.62639,-1.55912,0.280624,1.5841,-1.64621,0.360939,1.5514,-1.67616,0.250828,1.88486,-2.12303,0.351587,1.81842,-1.97015,0.133724,1.84809,-2.02211,0.036288,1.71284,-2.16771,0.041739,1.61799,-2.23157,0.208373,1.51333,-2.19218,0.251963,1.46524,-2.20848,0.271897,1.38199,-1.80354,0.074899,1.43841,-1.8652,0.073921,1.46967,-1.91266,0.066878,1.44538,-1.97944,0.256282,1.41505,-2.06138,0.279727,1.05681,-1.76097,0.145437,1.0353,-1.78628,0.158931,0.954665,-1.81128,0.216197,0.865599,-1.79315,0.065669,0.822011,-1.76919,-0.009856,0.812663,-1.77367,0.050893,0.927734,-1.80637,-0.021479,0.919921,-1.8018,-0.243998,0.852311,-1.77927,-0.28678,0.95603,-1.8551,-0.319273,0.700013,-1.83123,-0.373012,0.732589,-1.76556,0.318346,1.13256,-2.12878,0.358613,1.0584,-2.11297,0.194919,1.07136,-2.08421,0.234935,1.00076,-2.07043,0.34172,0.889619,-2.07655,0.401938,0.710552,-2.04773,0.28921,0.70829,-2.0661,0.291484,0.640676,-2.0484,0.314897,0.423886,-1.9946,0.234537,0.353679,-1.93021,0.514323,0.383789,-1.97947,0.463262,0.341975,-2.04114,0.197908,1.29279,-1.82807,0.184491,1.31649,-2.04157},
/*1429*/{0.29674,1.87016,-1.73415,0.35736,1.81011,-1.89235,0.209932,1.72988,-1.63008,0.1406,1.62391,-1.56046,0.273707,1.57639,-1.64528,0.353086,1.54134,-1.67348,0.251926,1.87969,-2.12436,0.353362,1.81334,-1.97019,0.132795,1.84282,-2.02363,0.040092,1.70223,-2.172,0.048216,1.60766,-2.23559,0.215187,1.50554,-2.19493,0.260067,1.45722,-2.20979,0.27055,1.37742,-1.80545,0.073147,1.43334,-1.86603,0.07094,1.46484,-1.91161,0.063709,1.44126,-1.97932,0.254408,1.41223,-2.063,0.283675,1.05453,-1.75995,0.153059,1.03082,-1.78671,0.168184,0.949438,-1.8114,0.227229,0.862813,-1.79102,0.079185,0.822752,-1.77003,0.003198,0.814591,-1.77366,0.065389,0.928253,-1.80714,-0.005997,0.921246,-1.80133,-0.230057,0.857099,-1.77889,-0.274808,0.959432,-1.85783,-0.304754,0.703997,-1.82742,-0.35826,0.737068,-1.76257,0.314323,1.13073,-2.13437,0.353783,1.05629,-2.11664,0.191927,1.07145,-2.08401,0.231467,1.00007,-2.07065,0.335634,0.888874,-2.07731,0.392841,0.709705,-2.0441,0.281037,0.712994,-2.06249,0.281048,0.645225,-2.04554,0.296826,0.425029,-1.99134,0.212052,0.355414,-1.92725,0.492794,0.382641,-1.97973,0.440265,0.342631,-2.03972,0.196939,1.28797,-1.83013,0.182275,1.3134,-2.04336},
/*1430*/{0.295425,1.86529,-1.73315,0.3575,1.80418,-1.8908,0.206254,1.7263,-1.63084,0.134837,1.62174,-1.56282,0.266258,1.56922,-1.64421,0.345368,1.53152,-1.67162,0.252793,1.87534,-2.12649,0.354199,1.80774,-1.96953,0.133592,1.84,-2.02305,0.043948,1.69219,-2.17808,0.055245,1.59809,-2.23982,0.223586,1.49839,-2.19706,0.268752,1.45061,-2.21112,0.269847,1.37291,-1.80802,0.070345,1.42886,-1.86497,0.068612,1.45939,-1.91169,0.059789,1.43709,-1.97928,0.251061,1.40982,-2.06523,0.291299,1.05346,-1.7585,0.158683,1.02574,-1.78787,0.17525,0.944089,-1.81287,0.238879,0.860973,-1.78803,0.091355,0.822447,-1.76938,0.017914,0.816308,-1.77212,0.079549,0.928703,-1.80685,0.008444,0.922877,-1.80329,-0.215311,0.86039,-1.77929,-0.262045,0.961922,-1.85909,-0.288803,0.706415,-1.82572,-0.342651,0.740586,-1.75896,0.31005,1.12835,-2.138,0.350429,1.05521,-2.11904,0.188565,1.07083,-2.08476,0.229051,0.999645,-2.07053,0.333047,0.889162,-2.07761,0.38345,0.709288,-2.04294,0.27079,0.717857,-2.05926,0.267417,0.649607,-2.04339,0.27845,0.426751,-1.98818,0.190346,0.356563,-1.92388,0.470027,0.382061,-1.97522,0.417592,0.342773,-2.03796,0.196203,1.28337,-1.83249,0.179122,1.31034,-2.04535},
/*1431*/{0.294363,1.86115,-1.73217,0.358118,1.79863,-1.8908,0.201789,1.72273,-1.63167,0.127495,1.61918,-1.56478,0.259337,1.56272,-1.64401,0.337041,1.52261,-1.6696,0.253958,1.87099,-2.12811,0.355311,1.80242,-1.96889,0.134548,1.83901,-2.02252,0.053444,1.67831,-2.18356,0.063611,1.58762,-2.24354,0.231942,1.49128,-2.19915,0.27774,1.44452,-2.21253,0.268258,1.36818,-1.81022,0.068287,1.42384,-1.86536,0.065845,1.45613,-1.91134,0.055996,1.43471,-1.97776,0.248041,1.40751,-2.06807,0.293385,1.05179,-1.75826,0.163322,1.02055,-1.78898,0.185262,0.939366,-1.81267,0.250969,0.859667,-1.78781,0.105656,0.822973,-1.76849,0.030913,0.815594,-1.77254,0.095256,0.928124,-1.80792,0.022998,0.923123,-1.80314,-0.20096,0.864832,-1.78055,-0.250144,0.963408,-1.861,-0.273204,0.707512,-1.8231,-0.326889,0.742842,-1.75748,0.305153,1.12774,-2.13899,0.34682,1.05404,-2.12015,0.185003,1.06926,-2.08382,0.226319,0.998826,-2.07022,0.333386,0.890261,-2.07796,0.371353,0.708938,-2.04477,0.258646,0.722551,-2.05783,0.254483,0.654128,-2.04242,0.257508,0.427765,-1.98547,0.168162,0.357299,-1.92143,0.450327,0.380617,-1.97649,0.39632,0.343036,-2.03709,0.194404,1.27872,-1.83535,0.175277,1.30821,-2.0477},
/*1432*/{0.293481,1.85738,-1.73091,0.357979,1.79474,-1.88894,0.197724,1.72036,-1.63306,0.120511,1.61794,-1.56703,0.25252,1.55638,-1.64387,0.328607,1.51489,-1.66768,0.256063,1.86741,-2.13056,0.355866,1.79825,-1.96779,0.134675,1.83691,-2.02252,0.061697,1.67013,-2.19096,0.073352,1.57857,-2.24725,0.24168,1.4857,-2.1996,0.287363,1.4389,-2.21242,0.266747,1.36419,-1.81294,0.064961,1.42042,-1.86424,0.063253,1.45434,-1.91182,0.054445,1.43348,-1.97583,0.244849,1.40662,-2.07048,0.296877,1.05495,-1.75814,0.168696,1.01598,-1.79013,0.193389,0.936547,-1.81192,0.264481,0.858369,-1.78657,0.119445,0.822215,-1.76828,0.044568,0.816264,-1.77196,0.109297,0.928062,-1.80765,0.038004,0.923566,-1.80199,-0.186698,0.865826,-1.78202,-0.237589,0.963106,-1.86262,-0.255644,0.708027,-1.81963,-0.30983,0.743093,-1.7555,0.300362,1.12692,-2.13946,0.341311,1.0527,-2.12155,0.180045,1.06761,-2.08307,0.221422,0.997403,-2.06882,0.333476,0.891121,-2.0776,0.358408,0.707828,-2.04768,0.245856,0.724872,-2.05692,0.239317,0.65699,-2.04211,0.24267,0.429143,-1.98363,0.146892,0.357798,-1.92096,0.427211,0.380863,-1.97453,0.374456,0.343187,-2.03564,0.192345,1.27508,-1.83823,0.171449,1.3075,-2.04998},
/*1433*/{0.292952,1.85411,-1.73009,0.357269,1.79164,-1.8883,0.193754,1.71846,-1.63383,0.112238,1.61821,-1.5699,0.244999,1.55176,-1.64303,0.320404,1.50778,-1.66571,0.257879,1.86399,-2.13059,0.355755,1.79517,-1.96726,0.134898,1.83627,-2.02316,0.066778,1.6623,-2.19797,0.083661,1.56997,-2.24946,0.251101,1.48054,-2.1998,0.298325,1.43493,-2.21317,0.265281,1.36026,-1.81459,0.064965,1.41788,-1.86108,0.062515,1.45363,-1.90991,0.052795,1.43249,-1.97348,0.242147,1.4062,-2.07286,0.302512,1.05698,-1.75739,0.175037,1.01277,-1.78895,0.201996,0.935203,-1.81149,0.278134,0.858999,-1.78579,0.133737,0.82129,-1.76898,0.058359,0.816744,-1.7735,0.123774,0.928745,-1.80597,0.053364,0.925086,-1.80266,-0.172923,0.86604,-1.78218,-0.225913,0.962185,-1.86274,-0.238374,0.707587,-1.81745,-0.292305,0.74182,-1.7535,0.295701,1.125,-2.13975,0.336307,1.05084,-2.12357,0.175982,1.06696,-2.08236,0.216579,0.996565,-2.06846,0.332785,0.892317,-2.07637,0.345721,0.706224,-2.05126,0.233141,0.725631,-2.05827,0.224807,0.656157,-2.03891,0.216648,0.428859,-1.98378,0.12446,0.358495,-1.92085,0.405624,0.379446,-1.97446,0.352158,0.343015,-2.03572,0.191206,1.2718,-1.84018,0.167621,1.3072,-2.05117},
/*1434*/{0.293052,1.85194,-1.72927,0.357407,1.78909,-1.88717,0.188601,1.71757,-1.635,0.105045,1.6192,-1.57241,0.237631,1.54831,-1.64303,0.311265,1.50153,-1.66307,0.259885,1.86168,-2.1303,0.355766,1.7926,-1.96647,0.135451,1.83584,-2.02314,0.074524,1.65577,-2.20401,0.094542,1.56355,-2.25178,0.261873,1.47708,-2.20006,0.309083,1.43194,-2.2133,0.264138,1.35721,-1.8174,0.062793,1.41746,-1.85986,0.060603,1.45368,-1.90987,0.051137,1.43171,-1.97119,0.240004,1.40604,-2.0753,0.309113,1.06066,-1.75848,0.182811,1.0143,-1.7885,0.212536,0.935563,-1.81051,0.292151,0.861385,-1.7869,0.147835,0.821562,-1.76919,0.073124,0.815937,-1.77301,0.138894,0.929057,-1.80533,0.06748,0.925107,-1.8008,-0.158966,0.865084,-1.78331,-0.21558,0.960402,-1.86388,-0.220052,0.705022,-1.81622,-0.274322,0.738449,-1.7518,0.289989,1.12231,-2.14083,0.32992,1.0477,-2.12454,0.171097,1.0631,-2.0794,0.211629,0.992848,-2.06596,0.328985,0.89283,-2.07582,0.331272,0.703336,-2.05405,0.219383,0.725131,-2.05932,0.209544,0.657412,-2.04006,0.196007,0.429261,-1.98401,0.10447,0.359213,-1.92041,0.384491,0.379228,-1.97295,0.329826,0.342456,-2.03522,0.189248,1.26974,-1.84243,0.163739,1.3073,-2.05282},
/*1435*/{0.292351,1.84935,-1.72895,0.357233,1.78808,-1.88699,0.1846,1.71765,-1.6357,0.098115,1.62152,-1.5751,0.228951,1.54522,-1.64245,0.303083,1.49719,-1.66028,0.261687,1.86013,-2.12924,0.355941,1.79147,-1.96564,0.135704,1.83478,-2.0236,0.082491,1.65066,-2.20866,0.106158,1.55804,-2.25322,0.272512,1.47437,-2.19931,0.32144,1.4302,-2.2123,0.261557,1.35444,-1.81784,0.062003,1.41734,-1.85902,0.058952,1.45334,-1.91004,0.050507,1.43182,-1.96923,0.23757,1.40531,-2.07728,0.313034,1.06477,-1.75896,0.188866,1.01343,-1.78791,0.222198,0.93606,-1.80957,0.306347,0.864652,-1.78729,0.161557,0.82262,-1.76967,0.08698,0.816663,-1.77417,0.152621,0.93103,-1.80386,0.08054,0.925651,-1.80149,-0.145595,0.862983,-1.78364,-0.205647,0.956573,-1.86367,-0.202528,0.701544,-1.81584,-0.255967,0.733095,-1.75023,0.283737,1.1189,-2.14243,0.322568,1.0443,-2.12592,0.16472,1.06221,-2.07964,0.203729,0.991214,-2.06534,0.319465,0.88944,-2.07756,0.317502,0.698626,-2.05523,0.207626,0.725322,-2.06005,0.195881,0.657183,-2.04093,0.176879,0.429593,-1.98505,0.082008,0.361372,-1.92048,0.362449,0.378036,-1.9744,0.307815,0.342299,-2.03546,0.186533,1.26791,-1.84351,0.160288,1.30697,-2.05354},
/*1436*/{0.29178,1.84755,-1.72882,0.355662,1.78705,-1.88604,0.179979,1.71827,-1.6367,0.091665,1.62456,-1.57748,0.22181,1.54493,-1.64172,0.294141,1.49352,-1.65847,0.264163,1.85905,-2.12861,0.355642,1.7895,-1.96515,0.136382,1.83314,-2.0245,0.091487,1.64647,-2.21138,0.116802,1.55448,-2.25398,0.283951,1.47315,-2.19802,0.333101,1.42948,-2.21104,0.260367,1.35195,-1.81916,0.060922,1.41742,-1.85895,0.057396,1.45276,-1.91074,0.049018,1.4323,-1.96821,0.235345,1.40519,-2.07913,0.320429,1.06972,-1.75943,0.199351,1.01386,-1.78605,0.231957,0.93852,-1.8086,0.321148,0.868831,-1.78783,0.175672,0.824223,-1.76905,0.101066,0.817094,-1.77448,0.165128,0.932167,-1.80343,0.093792,0.926884,-1.80033,-0.128175,0.859238,-1.78622,-0.196485,0.951927,-1.86359,-0.181677,0.697462,-1.81479,-0.235923,0.727939,-1.74824,0.277238,1.1157,-2.14301,0.314698,1.04014,-2.1273,0.157868,1.06095,-2.07878,0.197142,0.989507,-2.06513,0.309685,0.884869,-2.07988,0.305006,0.694258,-2.05555,0.195136,0.723124,-2.0625,0.181353,0.655109,-2.04249,0.151446,0.428312,-1.98523,0.059891,0.361576,-1.92218,0.340632,0.377827,-1.97361,0.285985,0.341698,-2.03602,0.184417,1.26642,-1.84537,0.157237,1.30713,-2.05497},
/*1437*/{0.290921,1.84668,-1.72832,0.355399,1.78481,-1.8852,0.175636,1.71945,-1.63733,0.08435,1.6283,-1.58021,0.214061,1.54406,-1.64146,0.285096,1.49119,-1.65679,0.266777,1.85809,-2.12781,0.355762,1.78884,-1.96373,0.137162,1.83354,-2.02587,0.09977,1.64466,-2.21251,0.127253,1.55184,-2.2547,0.296464,1.47275,-2.19594,0.345189,1.43048,-2.20971,0.259522,1.35033,-1.8207,0.059736,1.41804,-1.85746,0.056366,1.45316,-1.91053,0.047697,1.43339,-1.96816,0.232581,1.40466,-2.08052,0.325839,1.07426,-1.75916,0.205868,1.01571,-1.78557,0.242823,0.939823,-1.80692,0.334827,0.87363,-1.78768,0.189189,0.826248,-1.7694,0.114302,0.819586,-1.77562,0.177425,0.934145,-1.80194,0.106173,0.928283,-1.7995,-0.114843,0.856012,-1.78418,-0.188115,0.945381,-1.86336,-0.16142,0.692105,-1.81502,-0.21326,0.720527,-1.74601,0.271911,1.11239,-2.14393,0.307505,1.03667,-2.12839,0.151677,1.06086,-2.07999,0.188624,0.987646,-2.06613,0.298506,0.880315,-2.08157,0.292324,0.689223,-2.05521,0.184015,0.721239,-2.06428,0.167345,0.654081,-2.04376,0.130543,0.429058,-1.98684,0.038447,0.361021,-1.92436,0.319432,0.377893,-1.97458,0.264924,0.341595,-2.03679,0.182315,1.26569,-1.84647,0.153683,1.30726,-2.0557},
/*1438*/{0.290757,1.84664,-1.72785,0.353735,1.78424,-1.88464,0.171255,1.72107,-1.63816,0.076795,1.63278,-1.58246,0.206565,1.54533,-1.6407,0.276879,1.49045,-1.65616,0.268206,1.85785,-2.12731,0.355282,1.78822,-1.9635,0.138282,1.83401,-2.02616,0.106694,1.64146,-2.21252,0.136855,1.54978,-2.25508,0.30559,1.47269,-2.1947,0.356928,1.43244,-2.20773,0.258311,1.35042,-1.8209,0.059585,1.41908,-1.85801,0.054992,1.45364,-1.91126,0.047076,1.43379,-1.96842,0.231844,1.40471,-2.08178,0.334097,1.08004,-1.75919,0.215312,1.01679,-1.78452,0.25455,0.943345,-1.8065,0.34845,0.879138,-1.78868,0.202868,0.829124,-1.77008,0.127651,0.818982,-1.77624,0.18884,0.937103,-1.8018,0.118264,0.929102,-1.79836,-0.102311,0.851498,-1.78435,-0.180118,0.937865,-1.8636,-0.140017,0.68673,-1.8149,-0.19034,0.712771,-1.74471,0.26591,1.1099,-2.14487,0.300782,1.03306,-2.12985,0.144566,1.06014,-2.08103,0.180476,0.987108,-2.06785,0.288131,0.876402,-2.0836,0.279259,0.684727,-2.05508,0.171439,0.718967,-2.06561,0.152949,0.652382,-2.04645,0.114152,0.43143,-1.98931,0.016762,0.362835,-1.92475,0.297927,0.377105,-1.97628,0.243717,0.340617,-2.03784,0.181153,1.2661,-1.84686,0.152519,1.3074,-2.05615},
/*1439*/{0.289195,1.84685,-1.72754,0.353124,1.78398,-1.88422,0.166293,1.72415,-1.63873,0.070364,1.63708,-1.58471,0.198983,1.54568,-1.63948,0.267527,1.49029,-1.65418,0.270746,1.85814,-2.12715,0.355461,1.78797,-1.96205,0.139387,1.83442,-2.02717,0.114557,1.64051,-2.21264,0.145861,1.54802,-2.25523,0.317377,1.47444,-2.19311,0.368703,1.4353,-2.20542,0.25647,1.35092,-1.82123,0.058895,1.42029,-1.85877,0.055063,1.45359,-1.91173,0.046032,1.4343,-1.97022,0.231806,1.40512,-2.08264,0.340657,1.08698,-1.75946,0.225257,1.02075,-1.78335,0.264626,0.946778,-1.80548,0.361285,0.886048,-1.78873,0.215682,0.831662,-1.77231,0.14127,0.82039,-1.7782,0.199466,0.940202,-1.80035,0.128183,0.92979,-1.79822,-0.087677,0.846115,-1.78747,-0.17233,0.929251,-1.86393,-0.118333,0.680463,-1.81491,-0.168198,0.704089,-1.7437,0.260766,1.10811,-2.14587,0.293068,1.03006,-2.13107,0.13682,1.06068,-2.08323,0.172417,0.986529,-2.06957,0.276819,0.872358,-2.08388,0.264876,0.680092,-2.05454,0.158444,0.716531,-2.0671,0.138456,0.652484,-2.0495,0.094291,0.431988,-1.99055,-0.004519,0.363532,-1.9263,0.277405,0.376718,-1.9773,0.222086,0.340365,-2.03895,0.179952,1.26661,-1.84741,0.15206,1.30777,-2.05683},
/*1440*/{0.287118,1.84771,-1.72729,0.353014,1.78414,-1.8829,0.161833,1.728,-1.63999,0.063465,1.6425,-1.58724,0.190532,1.54795,-1.63883,0.25817,1.49107,-1.65369,0.273401,1.8589,-2.12692,0.355201,1.78831,-1.96119,0.14049,1.83595,-2.02948,0.120182,1.63958,-2.21262,0.155375,1.54777,-2.25538,0.328641,1.47845,-2.19125,0.379521,1.43993,-2.20247,0.255471,1.35232,-1.82055,0.058104,1.42088,-1.86053,0.053855,1.45437,-1.91256,0.04572,1.43549,-1.97163,0.231009,1.40549,-2.08354,0.347307,1.0928,-1.75981,0.233783,1.02362,-1.78227,0.275432,0.95141,-1.80519,0.374399,0.892197,-1.78834,0.229685,0.834518,-1.77291,0.156475,0.820752,-1.77823,0.209938,0.942076,-1.79951,0.139172,0.929966,-1.79745,-0.072733,0.837475,-1.78788,-0.164286,0.918835,-1.86382,-0.096221,0.673819,-1.81532,-0.145226,0.695547,-1.74227,0.25551,1.10613,-2.14649,0.285627,1.02741,-2.13199,0.131043,1.06101,-2.08458,0.163115,0.986084,-2.0717,0.26496,0.868557,-2.08363,0.25042,0.676597,-2.05426,0.14404,0.714858,-2.06896,0.123171,0.650519,-2.05052,0.073407,0.433287,-1.99203,-0.025366,0.364378,-1.92742,0.255231,0.376935,-1.97835,0.200472,0.340224,-2.04013,0.178959,1.26779,-1.84758,0.151781,1.30822,-2.05723},
/*1441*/{0.285092,1.84924,-1.72706,0.350913,1.78515,-1.88177,0.156867,1.73204,-1.6408,0.057171,1.64802,-1.58867,0.183941,1.55209,-1.63907,0.250226,1.49341,-1.65307,0.275881,1.86044,-2.12639,0.35433,1.78871,-1.96,0.140855,1.83622,-2.0299,0.127024,1.63935,-2.21246,0.163787,1.54781,-2.25548,0.337931,1.48196,-2.18881,0.391125,1.44557,-2.19921,0.253708,1.35457,-1.821,0.056797,1.42232,-1.8611,0.052865,1.45513,-1.91417,0.0459,1.43634,-1.97293,0.231303,1.40531,-2.08463,0.354065,1.10074,-1.76018,0.240776,1.02602,-1.78245,0.286592,0.957223,-1.80426,0.38587,0.898937,-1.7885,0.242789,0.83759,-1.77373,0.168749,0.821178,-1.77961,0.219515,0.944852,-1.79762,0.148564,0.929957,-1.79616,-0.059115,0.832662,-1.79051,-0.155931,0.906826,-1.86482,-0.072953,0.666848,-1.81565,-0.120913,0.687197,-1.7414,0.249397,1.10386,-2.14716,0.278196,1.02454,-2.1326,0.123711,1.06172,-2.08673,0.153864,0.986293,-2.07418,0.251882,0.864992,-2.08457,0.234176,0.674291,-2.05414,0.128574,0.71309,-2.06922,0.106769,0.649506,-2.05137,0.052401,0.434301,-1.99269,-0.045957,0.364457,-1.92688,0.234327,0.375536,-1.97841,0.179527,0.340529,-2.04089,0.177998,1.26946,-1.84732,0.151652,1.30833,-2.05737},
/*1442*/{0.281841,1.85112,-1.72694,0.350753,1.78592,-1.88055,0.151668,1.73643,-1.64146,0.051336,1.65433,-1.59022,0.175372,1.55526,-1.6386,0.2412,1.49674,-1.65236,0.278832,1.86232,-2.12508,0.354613,1.79032,-1.9585,0.142182,1.83762,-2.03177,0.132391,1.63932,-2.21229,0.171817,1.54855,-2.25514,0.346881,1.48649,-2.18627,0.401242,1.45258,-2.19591,0.252406,1.35657,-1.82022,0.056047,1.42347,-1.86248,0.052235,1.45598,-1.91638,0.045055,1.43724,-1.97432,0.231207,1.40532,-2.08499,0.359823,1.10886,-1.76081,0.248825,1.03236,-1.78242,0.295518,0.963046,-1.80369,0.397836,0.905599,-1.78928,0.256111,0.83962,-1.77587,0.183319,0.821095,-1.7811,0.228283,0.94695,-1.79715,0.158037,0.929712,-1.79647,-0.045908,0.82592,-1.79178,-0.147835,0.894896,-1.86642,-0.049803,0.659688,-1.81539,-0.097231,0.677715,-1.74089,0.243333,1.10302,-2.14761,0.270054,1.02189,-2.13285,0.116307,1.06336,-2.08865,0.145097,0.98677,-2.07568,0.237843,0.861006,-2.08499,0.217786,0.672733,-2.05498,0.113579,0.712926,-2.07035,0.090286,0.649516,-2.05245,0.031845,0.435779,-1.99356,-0.067594,0.36821,-1.92913,0.213371,0.375845,-1.9801,0.158023,0.34053,-2.04148,0.176983,1.27115,-1.84684,0.151799,1.30838,-2.05733},
/*1443*/{0.279776,1.85331,-1.72617,0.349321,1.78787,-1.87865,0.146634,1.74167,-1.64218,0.043669,1.65943,-1.59195,0.168354,1.56001,-1.63788,0.233582,1.50079,-1.65172,0.281889,1.86469,-2.1245,0.355125,1.79185,-1.95751,0.142956,1.83877,-2.03338,0.136501,1.63905,-2.21172,0.179749,1.55012,-2.25454,0.3555,1.49314,-2.18347,0.410619,1.46012,-2.19182,0.251283,1.35936,-1.81987,0.054834,1.4247,-1.86391,0.052717,1.45792,-1.91699,0.044514,1.43853,-1.97585,0.230904,1.40602,-2.08591,0.364748,1.11702,-1.76045,0.259613,1.03798,-1.7804,0.30429,0.969454,-1.80358,0.409375,0.913394,-1.78958,0.268346,0.842142,-1.77776,0.195649,0.82166,-1.78251,0.236419,0.948984,-1.7958,0.166714,0.928591,-1.79519,-0.030678,0.817757,-1.79271,-0.138625,0.880763,-1.86829,-0.02615,0.652735,-1.81567,-0.073953,0.668941,-1.73997,0.236241,1.10177,-2.14746,0.261555,1.02026,-2.13263,0.107917,1.06447,-2.08938,0.133934,0.987139,-2.07681,0.223103,0.858633,-2.08525,0.201529,0.671705,-2.05522,0.097276,0.713523,-2.07054,0.073482,0.650513,-2.0527,0.0104,0.436904,-1.99465,-0.089215,0.368122,-1.92921,0.191589,0.375555,-1.97981,0.137338,0.340376,-2.0422,0.176354,1.27334,-1.84659,0.151781,1.30921,-2.05739},
/*1444*/{0.276828,1.85616,-1.72593,0.348572,1.79033,-1.87722,0.141512,1.74671,-1.64249,0.037003,1.66584,-1.59332,0.160511,1.56575,-1.64001,0.225115,1.50567,-1.65237,0.282492,1.86761,-2.12336,0.354807,1.79391,-1.95558,0.143367,1.84043,-2.03444,0.142406,1.64003,-2.21152,0.18655,1.55184,-2.25416,0.364154,1.5013,-2.18077,0.419603,1.46924,-2.18724,0.250173,1.36149,-1.81914,0.055433,1.42587,-1.86541,0.052624,1.45938,-1.91874,0.045301,1.43966,-1.97757,0.231328,1.40629,-2.08666,0.369875,1.12567,-1.76126,0.267465,1.04367,-1.78013,0.312338,0.975172,-1.80477,0.419297,0.920638,-1.7899,0.281031,0.846127,-1.77665,0.209538,0.821683,-1.78263,0.24429,0.950717,-1.79461,0.174952,0.926968,-1.79507,-0.014356,0.812063,-1.79426,-0.128164,0.865707,-1.86939,-0.002894,0.646301,-1.81526,-0.051147,0.66023,-1.73973,0.230074,1.10115,-2.14761,0.252943,1.01871,-2.13232,0.099383,1.06703,-2.09052,0.124284,0.989029,-2.07881,0.207638,0.857351,-2.0856,0.18453,0.670127,-2.05614,0.080581,0.716093,-2.07108,0.054952,0.65233,-2.05363,-0.004255,0.43871,-1.99492,-0.109249,0.370083,-1.92973,0.170384,0.375663,-1.98101,0.115083,0.339653,-2.0425,0.175931,1.27513,-1.84635,0.15256,1.30959,-2.05752},
/*1445*/{0.27369,1.8594,-1.72546,0.347737,1.79369,-1.87634,0.136284,1.75194,-1.64342,0.030643,1.67228,-1.59454,0.153895,1.57227,-1.64079,0.21821,1.51155,-1.65247,0.285183,1.87094,-2.12193,0.354877,1.79671,-1.95376,0.144582,1.84213,-2.03609,0.146873,1.64081,-2.21083,0.194589,1.55447,-2.25405,0.370653,1.50768,-2.17768,0.427328,1.4787,-2.18315,0.248441,1.36425,-1.81793,0.05472,1.42831,-1.86774,0.053085,1.46141,-1.92045,0.045722,1.44187,-1.97977,0.232474,1.40702,-2.08697,0.374277,1.13413,-1.76171,0.269586,1.04598,-1.7813,0.320769,0.982506,-1.80335,0.428824,0.928915,-1.79072,0.293093,0.848516,-1.77782,0.223174,0.820913,-1.78389,0.252171,0.95155,-1.79301,0.183745,0.925084,-1.79433,-0.003939,0.800733,-1.79649,-0.118121,0.850437,-1.87266,0.019487,0.638666,-1.81502,-0.028259,0.651181,-1.73988,0.223614,1.10005,-2.14619,0.244207,1.01763,-2.13137,0.091047,1.07051,-2.09216,0.113691,0.991208,-2.07963,0.191719,0.857261,-2.08572,0.166034,0.670852,-2.05619,0.064059,0.717484,-2.07023,0.037361,0.655551,-2.0535,-0.029113,0.441933,-1.99968,-0.130264,0.373224,-1.93001,0.148666,0.374639,-1.98134,0.094002,0.339808,-2.04349,0.174573,1.27767,-1.84589,0.153517,1.31069,-2.05753},
/*1446*/{0.27115,1.86267,-1.72503,0.346802,1.79693,-1.87391,0.132572,1.75717,-1.64386,0.023616,1.67819,-1.59641,0.14784,1.57794,-1.64117,0.210655,1.51729,-1.65273,0.287351,1.8747,-2.12142,0.355,1.80011,-1.95223,0.144738,1.8438,-2.0372,0.150834,1.64182,-2.21068,0.201245,1.5572,-2.25378,0.378829,1.51639,-2.17408,0.435325,1.48898,-2.1781,0.251011,1.3682,-1.81814,0.054218,1.43027,-1.86961,0.053029,1.46394,-1.92217,0.045914,1.44449,-1.98166,0.232996,1.4076,-2.08723,0.37988,1.14242,-1.75902,0.27844,1.05479,-1.78176,0.328419,0.989788,-1.80439,0.438732,0.938745,-1.7911,0.304165,0.851611,-1.77831,0.236271,0.821262,-1.78546,0.258478,0.952639,-1.79243,0.191891,0.922876,-1.79443,0.010321,0.792047,-1.79778,-0.106126,0.834065,-1.87528,0.044474,0.631742,-1.81455,-0.005267,0.641607,-1.73914,0.216882,1.09963,-2.14507,0.234271,1.01645,-2.13029,0.084502,1.07355,-2.09316,0.103092,0.993424,-2.08006,0.175686,0.858097,-2.08583,0.149193,0.67165,-2.05648,0.046749,0.719892,-2.06952,0.018591,0.658221,-2.05336,-0.049879,0.444517,-2.00058,-0.151083,0.377175,-1.93378,0.127268,0.374795,-1.98071,0.071421,0.339954,-2.0445,0.175638,1.28118,-1.84549,0.154603,1.31179,-2.0575},
/*1447*/{0.267052,1.86619,-1.7247,0.34559,1.80049,-1.87256,0.127121,1.76303,-1.64457,0.017668,1.68585,-1.59776,0.140751,1.58561,-1.6427,0.204803,1.52415,-1.65302,0.288766,1.87841,-2.12,0.354806,1.80353,-1.95042,0.146292,1.84706,-2.03795,0.157263,1.64483,-2.20984,0.207299,1.56037,-2.25378,0.384169,1.52425,-2.16999,0.443575,1.49855,-2.172,0.249967,1.37181,-1.81811,0.053904,1.43314,-1.87239,0.054251,1.4667,-1.92444,0.047043,1.44745,-1.98429,0.234376,1.40861,-2.08695,0.382159,1.14986,-1.76049,0.282831,1.06027,-1.7824,0.334765,0.996567,-1.8066,0.447628,0.948748,-1.79132,0.315479,0.853645,-1.77829,0.248744,0.82018,-1.78591,0.26466,0.95281,-1.79268,0.200041,0.919909,-1.79466,0.024468,0.784194,-1.80065,-0.093256,0.817532,-1.87755,0.067072,0.623733,-1.81383,0.016871,0.63203,-1.739,0.209981,1.09949,-2.14475,0.225101,1.01608,-2.12895,0.075428,1.07734,-2.0933,0.092713,0.997388,-2.08012,0.160536,0.860183,-2.08584,0.13013,0.673843,-2.05656,0.029166,0.723801,-2.06955,0.000502,0.661648,-2.05319,-0.07095,0.448399,-2.00141,-0.17226,0.382643,-1.93329,0.106184,0.374294,-1.98045,0.050374,0.339927,-2.04253,0.17478,1.28441,-1.84535,0.155989,1.31339,-2.0578},
/*1448*/{0.264026,1.87039,-1.72498,0.344934,1.80435,-1.8709,0.123179,1.76863,-1.64548,0.012218,1.69314,-1.60012,0.134387,1.59192,-1.64382,0.197758,1.52995,-1.65426,0.289525,1.88287,-2.11945,0.355431,1.80751,-1.94878,0.147065,1.84947,-2.03871,0.160509,1.64605,-2.20963,0.21407,1.5638,-2.2538,0.39049,1.53363,-2.16608,0.450509,1.50951,-2.16791,0.248929,1.37548,-1.81825,0.05501,1.43568,-1.87454,0.054704,1.46869,-1.92649,0.048144,1.44978,-1.9862,0.236389,1.40958,-2.08727,0.386748,1.1584,-1.76117,0.287791,1.06619,-1.78333,0.343581,1.00438,-1.8059,0.455958,0.959123,-1.79177,0.327544,0.856442,-1.77928,0.26048,0.819436,-1.7868,0.270885,0.953232,-1.79227,0.208406,0.917192,-1.79519,0.037172,0.772979,-1.80203,-0.080858,0.799773,-1.88071,0.090395,0.616556,-1.81356,0.038459,0.62267,-1.74024,0.203231,1.09931,-2.14307,0.216327,1.01618,-2.1276,0.067157,1.08134,-2.09496,0.082985,1.00049,-2.08053,0.144566,0.861683,-2.08451,0.113191,0.676138,-2.05691,0.01172,0.726679,-2.06861,-0.017288,0.665657,-2.05277,-0.095448,0.448783,-1.99844,-0.193115,0.387011,-1.93482,0.085096,0.373911,-1.98046,0.028436,0.33974,-2.04261,0.174797,1.28747,-1.84515,0.157708,1.31472,-2.05797},
/*1449*/{0.26034,1.87419,-1.72514,0.344351,1.80845,-1.86962,0.118593,1.77409,-1.64634,0.006534,1.70001,-1.60214,0.128616,1.59933,-1.64547,0.191662,1.5375,-1.65466,0.291198,1.88731,-2.11845,0.355286,1.81141,-1.94743,0.148126,1.85203,-2.03999,0.163483,1.65002,-2.21106,0.220263,1.56813,-2.25381,0.39544,1.54226,-2.16222,0.456747,1.52076,-2.16275,0.249568,1.37943,-1.81869,0.056113,1.43914,-1.87681,0.055701,1.4721,-1.92807,0.049052,1.4527,-1.98871,0.238168,1.40982,-2.08741,0.388846,1.1662,-1.76165,0.293112,1.07145,-1.78376,0.349403,1.01115,-1.80625,0.46297,0.969921,-1.79235,0.338146,0.859702,-1.77923,0.27422,0.818831,-1.78712,0.276407,0.952803,-1.79249,0.21642,0.913674,-1.79515,0.054765,0.760466,-1.80247,-0.06616,0.782584,-1.88367,0.113376,0.609377,-1.81295,0.060504,0.613162,-1.74003,0.197424,1.10024,-2.14166,0.206999,1.01654,-2.12557,0.060775,1.08657,-2.09466,0.072792,1.00486,-2.08069,0.130125,0.864134,-2.08382,0.095232,0.678321,-2.05599,-0.004861,0.73064,-2.06836,-0.033994,0.669441,-2.05261,-0.109878,0.454686,-2.00093,-0.213436,0.392253,-1.93597,0.062377,0.375093,-1.9808,0.007087,0.339271,-2.0421,0.174925,1.29127,-1.8446,0.158864,1.31593,-2.05781},
/*1450*/{0.257774,1.87901,-1.72488,0.344189,1.81351,-1.86852,0.11456,1.78001,-1.64687,0.000628,1.70729,-1.60376,0.122733,1.60698,-1.64707,0.185666,1.54443,-1.65471,0.292472,1.89193,-2.11696,0.356969,1.81486,-1.9453,0.148496,1.85519,-2.04123,0.16753,1.65365,-2.21211,0.22654,1.57264,-2.25375,0.401241,1.55265,-2.15798,0.462006,1.53242,-2.1573,0.2505,1.38443,-1.81958,0.056138,1.44331,-1.87891,0.057044,1.47537,-1.93029,0.052002,1.45653,-1.99052,0.238544,1.41086,-2.08805,0.391184,1.17378,-1.7614,0.29661,1.07716,-1.78496,0.355566,1.01849,-1.80742,0.469735,0.981113,-1.79279,0.348546,0.862105,-1.77914,0.286192,0.81856,-1.78767,0.282778,0.952635,-1.7931,0.224654,0.911396,-1.79564,0.069093,0.75095,-1.80463,-0.051353,0.764482,-1.88565,0.137983,0.602274,-1.81279,0.083045,0.603018,-1.74009,0.190613,1.10112,-2.14073,0.198106,1.01659,-2.12356,0.052975,1.09141,-2.09523,0.063019,1.00985,-2.08066,0.117024,0.866944,-2.08165,0.078271,0.681909,-2.05595,-0.021377,0.73473,-2.06797,-0.051404,0.671702,-2.05099,-0.129145,0.458564,-2.00164,-0.232534,0.40024,-1.93588,0.041324,0.374408,-1.97957,-0.014059,0.339418,-2.04162,0.1754,1.29582,-1.84426,0.159854,1.31779,-2.0578},
/*1451*/{0.254782,1.88317,-1.72499,0.343906,1.81764,-1.86673,0.110966,1.78583,-1.64804,-0.004205,1.71445,-1.60656,0.118507,1.61446,-1.64853,0.179592,1.55173,-1.65575,0.292994,1.89693,-2.11645,0.356519,1.81927,-1.94366,0.148919,1.85861,-2.04152,0.172426,1.65715,-2.21359,0.233069,1.57708,-2.25404,0.405598,1.56239,-2.15409,0.467285,1.54387,-2.15264,0.25164,1.38929,-1.82086,0.056607,1.44748,-1.88182,0.058462,1.47899,-1.93232,0.053383,1.4601,-1.99247,0.240375,1.41159,-2.08859,0.392217,1.1815,-1.76208,0.301402,1.08355,-1.78557,0.36018,1.0264,-1.80802,0.475888,0.991551,-1.79242,0.358467,0.864791,-1.77937,0.298689,0.818561,-1.78805,0.287626,0.951732,-1.79396,0.231681,0.906856,-1.79802,0.084843,0.7405,-1.8058,-0.036371,0.746741,-1.889,0.16194,0.59617,-1.81243,0.106823,0.593426,-1.74052,0.185358,1.10266,-2.13858,0.190239,1.01862,-2.12138,0.045806,1.09644,-2.09519,0.053683,1.01487,-2.08114,0.102944,0.870719,-2.08025,0.062223,0.686161,-2.05557,-0.036891,0.740143,-2.06727,-0.067238,0.678291,-2.05103,-0.14556,0.464717,-2.00204,-0.250546,0.408395,-1.93612,0.019769,0.375066,-1.97957,-0.035352,0.339019,-2.04165,0.175932,1.30038,-1.84403,0.161106,1.31955,-2.0579},
/*1452*/{0.25182,1.88734,-1.72544,0.342682,1.82317,-1.86553,0.107084,1.79121,-1.64957,-0.009679,1.72165,-1.60903,0.112682,1.62149,-1.65057,0.174187,1.55914,-1.65685,0.294662,1.90188,-2.11595,0.356411,1.82411,-1.94239,0.150372,1.86229,-2.04213,0.177728,1.66195,-2.21498,0.239287,1.58228,-2.25416,0.409456,1.57132,-2.14978,0.4719,1.55576,-2.14759,0.252966,1.39314,-1.8216,0.057987,1.45158,-1.88245,0.05997,1.48264,-1.93476,0.056252,1.46333,-1.99413,0.242271,1.41255,-2.08853,0.396299,1.18919,-1.7619,0.303696,1.08959,-1.7861,0.364821,1.03367,-1.8089,0.480351,1.00059,-1.79362,0.367815,0.867096,-1.77878,0.311262,0.817427,-1.78785,0.29324,0.95092,-1.79513,0.241108,0.903124,-1.79957,0.099993,0.729092,-1.80718,-0.019192,0.727436,-1.89058,0.186283,0.589664,-1.81247,0.129316,0.584169,-1.74104,0.179632,1.10415,-2.1369,0.182034,1.01999,-2.11908,0.040453,1.10212,-2.09578,0.044957,1.02051,-2.0813,0.090074,0.87529,-2.07887,0.046187,0.690806,-2.05558,-0.05262,0.74645,-2.06715,-0.084112,0.683248,-2.05074,-0.162491,0.469962,-2.00263,-0.26932,0.416155,-1.93731,-0.002086,0.374939,-1.97869,-0.057405,0.340295,-2.04106,0.176673,1.30437,-1.84352,0.162629,1.32134,-2.05762},
/*1453*/{0.25006,1.8917,-1.72553,0.34256,1.82625,-1.86368,0.104034,1.79735,-1.65051,-0.012106,1.72943,-1.61136,0.107882,1.62855,-1.65244,0.169248,1.56548,-1.65793,0.295151,1.9074,-2.11462,0.356607,1.82866,-1.94105,0.150774,1.86595,-2.04335,0.181796,1.6668,-2.21652,0.245075,1.58747,-2.2542,0.412497,1.58101,-2.1456,0.475504,1.56698,-2.14297,0.255256,1.3982,-1.82281,0.059542,1.45587,-1.8847,0.062041,1.48564,-1.93599,0.058448,1.46682,-1.9959,0.243881,1.41367,-2.08916,0.398259,1.19577,-1.76201,0.310348,1.09593,-1.78587,0.369181,1.04072,-1.80921,0.484419,1.00969,-1.79352,0.376996,0.869379,-1.77926,0.322109,0.816798,-1.78879,0.299005,0.94867,-1.79626,0.247759,0.898822,-1.80109,0.116066,0.718221,-1.80954,-0.002205,0.708826,-1.89315,0.210781,0.58406,-1.8129,0.154344,0.575584,-1.74233,0.174717,1.10651,-2.13464,0.174172,1.02191,-2.11701,0.034658,1.10823,-2.09552,0.036485,1.02681,-2.08125,0.077445,0.879867,-2.0775,0.030829,0.696548,-2.0562,-0.068502,0.751478,-2.06655,-0.099397,0.690541,-2.0516,-0.180556,0.475568,-2.00442,-0.28829,0.425427,-1.93833,-0.022881,0.375426,-1.9779,-0.079822,0.340028,-2.04047,0.178537,1.30906,-1.84317,0.164351,1.32321,-2.05747},
/*1454*/{0.247772,1.89656,-1.72562,0.342492,1.83232,-1.863,0.100314,1.80311,-1.65235,-0.01752,1.73678,-1.61469,0.102663,1.63545,-1.654,0.163691,1.5719,-1.65781,0.29637,1.91246,-2.11302,0.356341,1.83337,-1.9397,0.151843,1.86877,-2.04418,0.186628,1.67244,-2.2178,0.251596,1.59322,-2.25465,0.415932,1.59102,-2.14153,0.478225,1.57802,-2.13807,0.255796,1.40246,-1.82373,0.060846,1.46089,-1.88554,0.06284,1.4902,-1.93847,0.06151,1.47084,-1.99753,0.246279,1.41447,-2.08927,0.399674,1.20289,-1.76217,0.310575,1.09946,-1.78656,0.371626,1.04631,-1.80996,0.487441,1.01773,-1.79418,0.38571,0.871117,-1.77943,0.333535,0.816016,-1.78899,0.303541,0.946598,-1.7984,0.255604,0.894363,-1.80269,0.132898,0.70594,-1.80987,0.014924,0.691018,-1.89478,0.234875,0.578457,-1.81375,0.17888,0.566493,-1.74347,0.169882,1.10813,-2.13245,0.166273,1.02447,-2.11465,0.030147,1.11497,-2.09591,0.028674,1.03242,-2.08107,0.064407,0.886025,-2.07707,0.014381,0.701502,-2.0558,-0.083166,0.758792,-2.06646,-0.115238,0.696371,-2.05141,-0.197643,0.48157,-2.00548,-0.304826,0.435014,-1.93871,-0.044711,0.375588,-1.97723,-0.098987,0.341146,-2.04,0.178481,1.31365,-1.84257,0.165453,1.32538,-2.05709},
/*1455*/{0.24629,1.90054,-1.72591,0.342097,1.83653,-1.86198,0.097043,1.80901,-1.65384,-0.022808,1.7434,-1.61755,0.099222,1.64251,-1.65649,0.160355,1.57956,-1.65939,0.297933,1.91793,-2.1123,0.356521,1.83833,-1.93849,0.152625,1.87333,-2.04508,0.190556,1.67694,-2.2188,0.257294,1.59907,-2.25464,0.417941,1.59942,-2.13776,0.48104,1.58816,-2.13326,0.256815,1.40667,-1.82492,0.062473,1.46573,-1.88671,0.065613,1.49411,-1.94022,0.063549,1.47494,-1.99872,0.248052,1.41554,-2.08969,0.402214,1.20976,-1.76287,0.313327,1.10898,-1.78714,0.373729,1.05253,-1.81072,0.489477,1.02466,-1.79566,0.393955,0.872056,-1.77971,0.344507,0.815617,-1.78938,0.309115,0.944275,-1.79942,0.263549,0.888793,-1.80456,0.150382,0.694023,-1.81084,0.033469,0.671904,-1.89576,0.259219,0.572769,-1.8151,0.204258,0.557352,-1.74482,0.16485,1.11046,-2.1308,0.159258,1.02655,-2.11209,0.024784,1.12112,-2.09576,0.021004,1.03994,-2.08128,0.051096,0.891451,-2.07679,-0.000255,0.708351,-2.05681,-0.097803,0.766102,-2.06641,-0.130233,0.704452,-2.05204,-0.215539,0.487696,-2.0078,-0.319939,0.445682,-1.93983,-0.066338,0.376223,-1.97731,-0.122202,0.342256,-2.04106,0.179108,1.31805,-1.84227,0.16634,1.32762,-2.05691},
/*1456*/{0.244845,1.90489,-1.7263,0.340537,1.84088,-1.86113,0.094405,1.81514,-1.65577,-0.02666,1.75114,-1.62075,0.094246,1.64956,-1.65811,0.154655,1.58537,-1.66067,0.298506,1.92323,-2.11136,0.356083,1.84268,-1.93754,0.153171,1.87682,-2.04534,0.195713,1.68294,-2.22093,0.262553,1.60479,-2.25566,0.420208,1.60941,-2.13427,0.483355,1.59865,-2.12832,0.258741,1.41135,-1.82592,0.064695,1.47041,-1.88778,0.068015,1.49786,-1.9425,0.066251,1.47909,-1.99948,0.249921,1.41717,-2.0897,0.403419,1.21592,-1.76273,0.31843,1.11424,-1.78526,0.375808,1.05913,-1.81015,0.490678,1.03023,-1.79567,0.402009,0.871881,-1.78033,0.355938,0.812941,-1.79015,0.314156,0.940443,-1.80166,0.270279,0.883151,-1.80648,0.169183,0.683264,-1.81261,0.052345,0.653551,-1.896,0.283948,0.567636,-1.81683,0.230145,0.548596,-1.74686,0.160591,1.11275,-2.12915,0.152006,1.02945,-2.11006,0.019734,1.12807,-2.09601,0.014043,1.04691,-2.08171,0.038698,0.89716,-2.07634,-0.014446,0.715594,-2.05759,-0.111274,0.772742,-2.06608,-0.144274,0.71148,-2.05222,-0.233878,0.493564,-2.01052,-0.336034,0.458128,-1.94017,-0.088885,0.376132,-1.97751,-0.144609,0.341459,-2.03954,0.180628,1.32279,-1.84183,0.16799,1.33008,-2.05657},
/*1457*/{0.243095,1.90911,-1.72651,0.339808,1.84667,-1.86076,0.091747,1.82053,-1.65744,-0.029601,1.75811,-1.6244,0.089984,1.65497,-1.65912,0.150787,1.59099,-1.66147,0.299891,1.9278,-2.11028,0.356431,1.84783,-1.93643,0.15484,1.87997,-2.04624,0.200015,1.68797,-2.22265,0.267519,1.61064,-2.25601,0.421618,1.61775,-2.13103,0.484488,1.60846,-2.12459,0.259384,1.41622,-1.8264,0.065958,1.47489,-1.88865,0.068623,1.50191,-1.9442,0.068982,1.48294,-2.00052,0.251976,1.41816,-2.08961,0.403579,1.22179,-1.76381,0.317642,1.11907,-1.78584,0.378747,1.0651,-1.80983,0.49128,1.03597,-1.79561,0.410914,0.872269,-1.78046,0.366117,0.810283,-1.79021,0.319146,0.936369,-1.80317,0.277626,0.876633,-1.80763,0.186295,0.669361,-1.81292,0.072047,0.635521,-1.89652,0.308635,0.562899,-1.81982,0.25594,0.53989,-1.74904,0.156366,1.11521,-2.12801,0.144754,1.03257,-2.1079,0.016463,1.13549,-2.09641,0.006528,1.05434,-2.08132,0.027296,0.903964,-2.07661,-0.027695,0.72201,-2.05871,-0.124965,0.780531,-2.06642,-0.157724,0.719576,-2.05252,-0.245758,0.501317,-2.01312,-0.351241,0.469812,-1.94218,-0.110192,0.376726,-1.97797,-0.166478,0.342004,-2.03937,0.181078,1.3276,-1.84085,0.169237,1.33228,-2.05571},
/*1458*/{0.24168,1.91321,-1.72737,0.340146,1.85115,-1.86047,0.088606,1.82657,-1.65946,-0.034365,1.76533,-1.62819,0.086657,1.66147,-1.6615,0.147258,1.59757,-1.66149,0.300955,1.93282,-2.10953,0.355944,1.85203,-1.93537,0.155351,1.88326,-2.04659,0.203525,1.69305,-2.2243,0.272829,1.61665,-2.25706,0.422582,1.62574,-2.12772,0.486585,1.61803,-2.12077,0.261046,1.42042,-1.82734,0.068367,1.48057,-1.88882,0.071538,1.50585,-1.94575,0.07184,1.48618,-2.00192,0.254024,1.41993,-2.08999,0.404893,1.2269,-1.76431,0.318307,1.1256,-1.78642,0.37803,1.06816,-1.81056,0.490134,1.03972,-1.79672,0.417985,0.871692,-1.78095,0.377619,0.80776,-1.79032,0.323005,0.931133,-1.80418,0.287301,0.869901,-1.80796,0.206806,0.659406,-1.81316,0.091344,0.618105,-1.89544,0.332994,0.557536,-1.8233,0.283233,0.531006,-1.75106,0.152438,1.11745,-2.12677,0.13756,1.03569,-2.10641,0.012021,1.1426,-2.09644,0.001016,1.0619,-2.08086,0.016679,0.910595,-2.07637,-0.03997,0.729738,-2.06019,-0.136958,0.78868,-2.06729,-0.169757,0.728177,-2.05435,-0.258421,0.508312,-2.01403,-0.365372,0.482569,-1.94366,-0.131288,0.377472,-1.9779,-0.185729,0.34323,-2.03855,0.182565,1.33228,-1.84034,0.170709,1.33474,-2.05524},
/*1459*/{0.240515,1.91695,-1.72759,0.33881,1.85495,-1.85966,0.087211,1.83211,-1.66131,-0.035672,1.77201,-1.63208,0.083041,1.66672,-1.66251,0.142474,1.60287,-1.6624,0.301728,1.9375,-2.10809,0.355451,1.85599,-1.93532,0.155971,1.8863,-2.04725,0.207245,1.69824,-2.22534,0.277601,1.62202,-2.25742,0.424059,1.63411,-2.12493,0.487686,1.62741,-2.11776,0.263127,1.42494,-1.82779,0.070593,1.48532,-1.89001,0.074237,1.51027,-1.94693,0.074545,1.49043,-2.00248,0.25547,1.42084,-2.08978,0.407552,1.23156,-1.76504,0.31843,1.12549,-1.78559,0.378832,1.07419,-1.80879,0.489876,1.0447,-1.7971,0.425226,0.870903,-1.7816,0.387914,0.80513,-1.79084,0.329367,0.925056,-1.80539,0.294526,0.862278,-1.8095,0.224143,0.645436,-1.81433,0.111551,0.600437,-1.8946,0.35731,0.552867,-1.82569,0.310225,0.523096,-1.75449,0.148664,1.12038,-2.12566,0.131174,1.03925,-2.10532,0.009541,1.15046,-2.09695,-0.003797,1.06941,-2.08098,0.006225,0.918093,-2.07703,-0.052794,0.73745,-2.06113,-0.147915,0.797826,-2.06871,-0.180679,0.735109,-2.05499,-0.279066,0.511999,-2.01706,-0.376482,0.496958,-1.94551,-0.151706,0.378006,-1.97905,-0.209096,0.344576,-2.03928,0.183746,1.33714,-1.83936,0.171713,1.33697,-2.05426},
/*1460*/{0.239461,1.92052,-1.72812,0.338958,1.85836,-1.85915,0.084314,1.83756,-1.66362,-0.039281,1.77791,-1.63588,0.079387,1.67189,-1.66399,0.139833,1.60792,-1.66269,0.302616,1.94126,-2.10707,0.356204,1.85994,-1.93389,0.156864,1.88942,-2.04909,0.211553,1.7031,-2.22698,0.281639,1.62734,-2.25859,0.424283,1.64031,-2.12207,0.488411,1.63569,-2.11367,0.263827,1.42938,-1.82832,0.072576,1.49109,-1.89043,0.076213,1.51439,-1.94837,0.076215,1.49353,-2.00291,0.257996,1.42209,-2.08971,0.407158,1.23516,-1.76633,0.317425,1.13045,-1.78537,0.377817,1.07751,-1.80765,0.487075,1.047,-1.79888,0.433226,0.869245,-1.78219,0.398452,0.801589,-1.79126,0.334051,0.919238,-1.80647,0.301581,0.85486,-1.81059,0.243082,0.634819,-1.81508,0.133087,0.584032,-1.89421,0.380982,0.548458,-1.82907,0.337552,0.515203,-1.75746,0.144232,1.12311,-2.12516,0.125952,1.04232,-2.10474,0.00678,1.15667,-2.09715,-0.009762,1.07733,-2.08082,-0.003441,0.925495,-2.07731,-0.06178,0.74585,-2.06344,-0.159641,0.804046,-2.06941,-0.191483,0.742323,-2.05581,-0.282285,0.522294,-2.0196,-0.386169,0.510975,-1.94478,-0.171093,0.378116,-1.9803,-0.230308,0.346562,-2.04099,0.184476,1.34208,-1.8382,0.172783,1.33924,-2.0531},
/*1461*/{0.238315,1.92413,-1.72854,0.338841,1.86167,-1.85801,0.082572,1.84264,-1.66587,-0.042939,1.78415,-1.64003,0.076435,1.67746,-1.66577,0.136103,1.61232,-1.66341,0.30384,1.94575,-2.10643,0.355921,1.86388,-1.93392,0.158014,1.89242,-2.04951,0.212351,1.70718,-2.2283,0.285743,1.63234,-2.25937,0.424637,1.64677,-2.12048,0.489219,1.64396,-2.11066,0.264833,1.43298,-1.82963,0.07522,1.49541,-1.89052,0.077039,1.51779,-1.95026,0.079007,1.49732,-2.0035,0.25905,1.42342,-2.08964,0.408738,1.23905,-1.76659,0.317604,1.13511,-1.78339,0.376566,1.08098,-1.80692,0.485944,1.04796,-1.79975,0.440017,0.867234,-1.78296,0.409898,0.799764,-1.79193,0.339,0.912957,-1.80759,0.307387,0.846869,-1.81351,0.260262,0.622494,-1.81566,0.15343,0.567199,-1.89392,0.40458,0.544681,-1.83206,0.362749,0.506907,-1.76097,0.141334,1.12601,-2.12463,0.120148,1.04555,-2.10448,0.004135,1.16284,-2.09685,-0.01539,1.08399,-2.08086,-0.012362,0.932682,-2.07818,-0.071577,0.752726,-2.06514,-0.16791,0.811534,-2.06995,-0.201058,0.749856,-2.05715,-0.29243,0.528997,-2.02343,-0.395589,0.525814,-1.94913,-0.188449,0.378207,-1.98203,-0.250286,0.349489,-2.03991,0.185311,1.34606,-1.83795,0.173408,1.34154,-2.05281},
/*1462*/{0.237772,1.92731,-1.72906,0.339027,1.86524,-1.85804,0.080388,1.84807,-1.66794,-0.045643,1.78943,-1.64419,0.07369,1.6817,-1.66692,0.133076,1.61605,-1.66279,0.303626,1.94924,-2.10566,0.356645,1.86697,-1.93259,0.159029,1.89576,-2.0503,0.215799,1.71201,-2.23024,0.28866,1.63746,-2.26027,0.425757,1.65392,-2.11834,0.489224,1.6512,-2.10788,0.266622,1.43644,-1.82993,0.077497,1.49977,-1.89052,0.079456,1.52172,-1.95057,0.081421,1.50119,-2.00421,0.261065,1.42445,-2.08906,0.408558,1.24155,-1.76818,0.3164,1.13902,-1.78315,0.375119,1.08324,-1.80496,0.48328,1.04693,-1.80065,0.445824,0.864799,-1.78346,0.418024,0.794919,-1.7933,0.343981,0.905754,-1.80832,0.315132,0.838283,-1.81372,0.280597,0.610688,-1.81598,0.173789,0.551255,-1.89327,0.426994,0.540782,-1.83623,0.388898,0.499342,-1.76405,0.137903,1.12862,-2.12468,0.114717,1.04835,-2.10444,0.001883,1.16877,-2.09618,-0.018638,1.09043,-2.08039,-0.020856,0.939224,-2.07884,-0.081028,0.759715,-2.06686,-0.17694,0.818909,-2.07098,-0.209837,0.756934,-2.0592,-0.301776,0.537461,-2.02541,-0.404321,0.541032,-1.95177,-0.206883,0.378998,-1.98436,-0.27179,0.353577,-2.04046,0.186357,1.35004,-1.83705,0.17445,1.34386,-2.05186},
/*1463*/{0.236564,1.9305,-1.72945,0.337739,1.86802,-1.85779,0.078642,1.85262,-1.67058,-0.048952,1.79402,-1.64747,0.070835,1.68599,-1.66807,0.13041,1.62066,-1.66291,0.304797,1.95251,-2.10477,0.356201,1.87039,-1.93244,0.160098,1.89804,-2.05069,0.219644,1.71617,-2.23217,0.291154,1.64142,-2.26095,0.425927,1.65898,-2.11656,0.489824,1.65799,-2.10462,0.267463,1.4403,-1.831,0.079621,1.50406,-1.8901,0.081889,1.52566,-1.95079,0.084523,1.50415,-2.00435,0.261773,1.42576,-2.0885,0.40873,1.24301,-1.76941,0.315064,1.14336,-1.78141,0.372947,1.08532,-1.8046,0.479091,1.04522,-1.80194,0.452151,0.862037,-1.78415,0.426923,0.789268,-1.79237,0.348278,0.898449,-1.81016,0.321266,0.82926,-1.81606,0.298678,0.599237,-1.81631,0.195176,0.535872,-1.89272,0.449995,0.536029,-1.83762,0.414101,0.493086,-1.76731,0.134013,1.13149,-2.12493,0.10931,1.053,-2.10597,7.6e-005,1.17445,-2.09608,-0.022386,1.09577,-2.07986,-0.028194,0.945469,-2.07921,-0.087381,0.765858,-2.06832,-0.183258,0.825903,-2.07259,-0.217031,0.764438,-2.06123,-0.311506,0.544788,-2.02919,-0.411381,0.555346,-1.95281,-0.224209,0.379031,-1.98636,-0.290231,0.357901,-2.03967,0.187453,1.3541,-1.83607,0.175012,1.34609,-2.0508},
/*1464*/{0.236251,1.93343,-1.73022,0.332166,1.8746,-1.85882,0.076564,1.85709,-1.67297,-0.05055,1.79852,-1.65122,0.068517,1.69039,-1.66969,0.127948,1.62409,-1.66354,0.305634,1.95579,-2.10351,0.35606,1.87356,-1.93246,0.161169,1.90069,-2.05172,0.22243,1.72081,-2.23413,0.294123,1.64566,-2.26185,0.425511,1.66544,-2.11537,0.489375,1.66345,-2.10196,0.268851,1.44287,-1.83092,0.081449,1.5083,-1.89023,0.083969,1.52881,-1.95154,0.085775,1.50802,-2.00471,0.263224,1.42702,-2.08809,0.409181,1.24499,-1.77101,0.313835,1.14467,-1.78077,0.372019,1.0862,-1.80329,0.478678,1.04538,-1.80238,0.458255,0.858996,-1.78451,0.435988,0.786413,-1.79224,0.352502,0.890496,-1.811,0.332165,0.821705,-1.81372,0.317785,0.589416,-1.81715,0.215985,0.521438,-1.89303,0.469961,0.532547,-1.84046,0.438058,0.4861,-1.77084,0.132099,1.13482,-2.12546,0.105498,1.056,-2.1063,-0.002127,1.17973,-2.0954,-0.025212,1.10084,-2.07941,-0.032301,0.951325,-2.07908,-0.094752,0.771878,-2.06992,-0.189507,0.833276,-2.07389,-0.224746,0.771785,-2.06373,-0.321175,0.553615,-2.03261,-0.419967,0.572331,-1.95789,-0.240687,0.378733,-1.98804,-0.311986,0.364331,-2.04042,0.187853,1.35745,-1.83554,0.175462,1.34841,-2.05022},
/*1465*/{0.236013,1.93622,-1.73064,0.332918,1.87759,-1.85872,0.075681,1.86086,-1.67504,-0.054614,1.80258,-1.6549,0.06657,1.69398,-1.67065,0.126181,1.62664,-1.66351,0.306072,1.9587,-2.1029,0.356407,1.87659,-1.93215,0.161989,1.90342,-2.05309,0.224924,1.72441,-2.23587,0.296545,1.64983,-2.26259,0.425757,1.67006,-2.11426,0.489173,1.66823,-2.09977,0.269035,1.4472,-1.83266,0.082096,1.51192,-1.89021,0.084431,1.53215,-1.95186,0.087659,1.51085,-2.00488,0.265378,1.42762,-2.08743,0.409279,1.24522,-1.77186,0.31351,1.14661,-1.78074,0.368753,1.08671,-1.80395,0.474928,1.04255,-1.80202,0.46218,0.855378,-1.78419,0.446051,0.781363,-1.79341,0.356867,0.88175,-1.81244,0.338648,0.812089,-1.81524,0.335923,0.578631,-1.81781,0.236776,0.507443,-1.89327,0.492106,0.529872,-1.84426,0.462679,0.479984,-1.77366,0.12966,1.13741,-2.12568,0.102622,1.05907,-2.10739,-0.003241,1.18341,-2.09349,-0.027424,1.10549,-2.07839,-0.035211,0.95599,-2.07927,-0.100179,0.777206,-2.0709,-0.195177,0.83977,-2.07506,-0.230228,0.778598,-2.06568,-0.329532,0.562633,-2.03491,-0.426046,0.58745,-1.96092,-0.258589,0.38003,-1.99043,-0.332077,0.370673,-2.04047,0.188569,1.36157,-1.83452,0.176306,1.35031,-2.04911},
/*1466*/{0.23521,1.93883,-1.73141,0.338303,1.87657,-1.85679,0.074534,1.865,-1.67679,-0.057064,1.8059,-1.65894,0.06492,1.69749,-1.67215,0.12431,1.63067,-1.66332,0.306617,1.96094,-2.1024,0.356717,1.87837,-1.93145,0.162857,1.90555,-2.05341,0.229162,1.72921,-2.23813,0.298751,1.65346,-2.26344,0.425889,1.67306,-2.11389,0.48885,1.67276,-2.09822,0.268243,1.44927,-1.83313,0.084062,1.51487,-1.88974,0.086608,1.53554,-1.95182,0.089276,1.51419,-2.00526,0.265697,1.43015,-2.08719,0.407338,1.24529,-1.77382,0.314285,1.1488,-1.78018,0.362569,1.08578,-1.80812,0.473071,1.04013,-1.80271,0.467073,0.852071,-1.78369,0.452987,0.777436,-1.79413,0.359176,0.872742,-1.81347,0.345572,0.802251,-1.81501,0.354124,0.566861,-1.81786,0.257723,0.494615,-1.89449,0.511217,0.525334,-1.84692,0.483495,0.473539,-1.77648,0.128033,1.14027,-2.12628,0.101121,1.0626,-2.10766,-0.004443,1.1868,-2.09265,-0.028227,1.10869,-2.07819,-0.036675,0.959567,-2.07901,-0.10527,0.781768,-2.07241,-0.197733,0.847785,-2.07758,-0.235856,0.786617,-2.06852,-0.338178,0.572589,-2.03859,-0.431606,0.603597,-1.96596,-0.275349,0.37889,-1.98945,-0.350876,0.378682,-2.03992,0.188293,1.36382,-1.83483,0.176341,1.35327,-2.04948},
/*1467*/{0.235276,1.94156,-1.73138,0.332776,1.88189,-1.85831,0.073726,1.86836,-1.678,-0.057147,1.80909,-1.66199,0.062382,1.69999,-1.67316,0.121288,1.6333,-1.66348,0.307186,1.96343,-2.10233,0.356435,1.88162,-1.93149,0.1636,1.90829,-2.0543,0.232346,1.73262,-2.23965,0.301178,1.65652,-2.26524,0.425794,1.67658,-2.11295,0.488593,1.67629,-2.09641,0.267524,1.4519,-1.83518,0.085021,1.51789,-1.8895,0.086274,1.53871,-1.95172,0.090602,1.51685,-2.00518,0.266359,1.43151,-2.08689,0.406665,1.24261,-1.77452,0.312931,1.14834,-1.77996,0.363428,1.08521,-1.80345,0.470089,1.03745,-1.80254,0.471,0.847655,-1.78451,0.460004,0.773725,-1.79433,0.361856,0.863943,-1.81297,0.35223,0.792118,-1.81549,0.372247,0.559213,-1.81964,0.277037,0.482122,-1.89556,0.530014,0.52187,-1.84822,0.505279,0.468558,-1.77931,0.128135,1.14299,-2.12666,0.100175,1.06445,-2.10842,-0.004755,1.18988,-2.09186,-0.029191,1.11241,-2.07764,-0.036867,0.961938,-2.07891,-0.110068,0.785922,-2.07303,-0.200527,0.852661,-2.0788,-0.238648,0.794086,-2.07165,-0.346278,0.581726,-2.04124,-0.437584,0.619252,-1.9704,-0.293458,0.37789,-1.98897,-0.368602,0.387313,-2.03866,0.188161,1.36652,-1.83483,0.175985,1.35553,-2.04944},
/*1468*/{0.235204,1.94389,-1.73217,0.338106,1.88224,-1.85695,0.072436,1.8707,-1.68151,-0.06083,1.81147,-1.66634,0.061107,1.70336,-1.67534,0.120221,1.63537,-1.6635,0.307081,1.96549,-2.10193,0.356225,1.88389,-1.93126,0.164783,1.91005,-2.05404,0.234532,1.7354,-2.24068,0.302431,1.65887,-2.26587,0.426205,1.67942,-2.11296,0.487872,1.67915,-2.09536,0.271584,1.45497,-1.83414,0.085931,1.52116,-1.88943,0.087733,1.54158,-1.95128,0.09116,1.52059,-2.00472,0.266774,1.4341,-2.08691,0.406185,1.24105,-1.77516,0.309967,1.14786,-1.78019,0.360833,1.08357,-1.8034,0.467357,1.03411,-1.80258,0.473458,0.843217,-1.78456,0.467008,0.76885,-1.79385,0.364318,0.853425,-1.81322,0.357765,0.781734,-1.81603,0.388351,0.550462,-1.82151,0.297024,0.469953,-1.89689,0.548385,0.520488,-1.85098,0.526065,0.465339,-1.78207,0.128196,1.14547,-2.12676,0.100855,1.06784,-2.10966,-0.003636,1.19263,-2.09189,-0.028052,1.11465,-2.0776,-0.03543,0.96467,-2.07888,-0.113186,0.788913,-2.07373,-0.202355,0.858187,-2.08032,-0.242935,0.800228,-2.07362,-0.3535,0.590224,-2.04405,-0.444317,0.634032,-1.97666,-0.313959,0.384205,-1.98703,-0.386187,0.39695,-2.03741,0.190444,1.37005,-1.83419,0.176899,1.35831,-2.04867},
/*1469*/{0.23495,1.94608,-1.73281,0.339368,1.88264,-1.85646,0.071991,1.87335,-1.68327,-0.060292,1.81364,-1.66953,0.059325,1.70484,-1.67615,0.118448,1.63691,-1.66369,0.307682,1.96727,-2.10185,0.357222,1.88446,-1.93085,0.165035,1.91274,-2.0542,0.236818,1.73831,-2.24264,0.303043,1.6609,-2.2666,0.425406,1.68079,-2.11226,0.487378,1.68069,-2.09415,0.271362,1.45641,-1.83517,0.087053,1.52326,-1.88945,0.088369,1.54404,-1.95092,0.091746,1.52248,-2.00409,0.26755,1.43621,-2.08662,0.405611,1.23735,-1.77611,0.305858,1.14643,-1.78083,0.355643,1.08124,-1.80418,0.463666,1.02928,-1.80206,0.476455,0.838969,-1.78528,0.473475,0.764832,-1.79562,0.365963,0.844095,-1.81157,0.362579,0.772802,-1.81566,0.404283,0.541965,-1.82255,0.315984,0.45872,-1.89817,0.56364,0.519243,-1.85254,0.544594,0.461785,-1.78383,0.129501,1.14708,-2.12723,0.101742,1.0681,-2.10959,-0.002832,1.19376,-2.09142,-0.027018,1.11601,-2.07745,-0.034303,0.965032,-2.07948,-0.115634,0.791504,-2.07388,-0.202095,0.863724,-2.08242,-0.245025,0.806115,-2.07472,-0.363995,0.598792,-2.04749,-0.449307,0.649191,-1.98178,-0.331395,0.394916,-1.98391,-0.403526,0.408684,-2.03753,0.190692,1.37164,-1.83449,0.177105,1.36053,-2.04901},
/*1470*/{0.235207,1.94814,-1.73343,0.33913,1.88348,-1.85621,0.07083,1.8751,-1.68577,-0.06119,1.81631,-1.6731,0.05831,1.70707,-1.67757,0.117125,1.6378,-1.66379,0.307479,1.96836,-2.10143,0.357891,1.88604,-1.93102,0.165479,1.91409,-2.05455,0.238646,1.74095,-2.2428,0.304949,1.6629,-2.26788,0.425613,1.68273,-2.11225,0.486577,1.68118,-2.09293,0.271981,1.45858,-1.83573,0.088218,1.52491,-1.88873,0.088911,1.54605,-1.95078,0.093187,1.52466,-2.00343,0.268052,1.43852,-2.0866,0.403134,1.23419,-1.77681,0.303804,1.14409,-1.78069,0.35169,1.07802,-1.80341,0.459827,1.02414,-1.80219,0.478594,0.8332,-1.78626,0.47895,0.760724,-1.79774,0.368178,0.834378,-1.81003,0.367288,0.762334,-1.8137,0.418063,0.532944,-1.82353,0.333964,0.447528,-1.9,0.579965,0.519002,-1.85469,0.564372,0.461445,-1.78638,0.131124,1.14821,-2.12631,0.103683,1.07047,-2.10993,-0.000742,1.19465,-2.09136,-0.025034,1.11705,-2.07737,-0.031823,0.966196,-2.08038,-0.117176,0.793179,-2.07438,-0.201736,0.8683,-2.08364,-0.245987,0.811497,-2.07605,-0.370968,0.609122,-2.04955,-0.45628,0.664111,-1.98659,-0.349614,0.405415,-1.98085,-0.41775,0.420805,-2.0358,0.19184,1.37352,-1.83457,0.177856,1.36277,-2.04908},
/*1471*/{0.23482,1.94958,-1.73377,0.333491,1.88835,-1.85816,0.070639,1.87667,-1.68714,-0.063172,1.81753,-1.67648,0.058073,1.70777,-1.67917,0.115609,1.63785,-1.66408,0.307955,1.96946,-2.10142,0.357211,1.88828,-1.93142,0.165195,1.91632,-2.05476,0.240436,1.74273,-2.24415,0.30538,1.66365,-2.26899,0.425429,1.68504,-2.11232,0.48613,1.68176,-2.09232,0.272241,1.46005,-1.83627,0.088042,1.5266,-1.88774,0.089467,1.54788,-1.95023,0.093197,1.52611,-2.00331,0.266906,1.44105,-2.08673,0.401378,1.22886,-1.77755,0.299732,1.1412,-1.78048,0.344972,1.07455,-1.80515,0.455364,1.01827,-1.80208,0.481405,0.828424,-1.78618,0.484025,0.75567,-1.80006,0.370691,0.824431,-1.80777,0.374091,0.751689,-1.81191,0.432604,0.52677,-1.82599,0.351128,0.436926,-1.90192,0.594109,0.518805,-1.85633,0.579741,0.459534,-1.78806,0.133578,1.14951,-2.12691,0.107061,1.07067,-2.11021,0.000852,1.19512,-2.09089,-0.022821,1.11695,-2.0776,-0.028964,0.965848,-2.08095,-0.11867,0.794642,-2.07433,-0.201293,0.871761,-2.08557,-0.246933,0.817481,-2.07808,-0.378673,0.620473,-2.05106,-0.463834,0.678331,-1.99259,-0.365122,0.417442,-1.97804,-0.432457,0.432866,-2.03563,0.192233,1.37496,-1.83486,0.177384,1.36486,-2.04934},
/*1472*/{0.235442,1.95107,-1.73465,0.333471,1.8892,-1.85848,0.07097,1.87803,-1.68955,-0.062599,1.81807,-1.679,0.057135,1.70843,-1.67999,0.114301,1.63776,-1.66319,0.308013,1.97014,-2.10131,0.357768,1.88922,-1.93199,0.165949,1.91747,-2.05464,0.241923,1.74434,-2.24471,0.304994,1.66448,-2.2696,0.424648,1.68486,-2.11237,0.484844,1.68138,-2.09248,0.272231,1.46132,-1.83634,0.088699,1.52705,-1.88738,0.089706,1.54979,-1.94933,0.092324,1.52773,-2.0025,0.267628,1.44291,-2.08683,0.399227,1.22379,-1.77834,0.292456,1.13698,-1.78147,0.340572,1.07098,-1.80488,0.451095,1.01242,-1.802,0.484487,0.823201,-1.78744,0.489519,0.750431,-1.80097,0.373063,0.815988,-1.80569,0.377416,0.744068,-1.81112,0.444548,0.519677,-1.82586,0.367404,0.427669,-1.90375,0.606804,0.518138,-1.85667,0.595955,0.459438,-1.78985,0.136174,1.14989,-2.1268,0.110034,1.07136,-2.10935,0.002946,1.19493,-2.09124,-0.019163,1.11597,-2.07714,-0.025575,0.965253,-2.0811,-0.119685,0.79534,-2.0746,-0.198742,0.875814,-2.08702,-0.24768,0.823074,-2.07948,-0.386268,0.63125,-2.05273,-0.470682,0.693173,-1.99816,-0.379485,0.429668,-1.97496,-0.443699,0.44612,-2.03395,0.192693,1.37593,-1.83505,0.177621,1.36672,-2.04956},
/*1473*/{0.235205,1.952,-1.73515,0.340097,1.88765,-1.85738,0.070611,1.87888,-1.69083,-0.062937,1.81918,-1.68129,0.057465,1.70841,-1.68115,0.114243,1.6374,-1.66287,0.307973,1.97016,-2.10131,0.357671,1.88936,-1.93135,0.166383,1.91873,-2.05487,0.240524,1.74503,-2.24436,0.304491,1.66485,-2.27063,0.423024,1.68309,-2.11278,0.484735,1.68006,-2.09303,0.272985,1.46299,-1.83726,0.089269,1.52811,-1.88724,0.089261,1.55111,-1.94886,0.09297,1.52896,-2.00161,0.268033,1.44494,-2.08666,0.396209,1.21798,-1.77896,0.291214,1.13484,-1.78131,0.334109,1.06651,-1.80541,0.445471,1.00663,-1.80281,0.487616,0.819014,-1.78901,0.49312,0.744537,-1.80309,0.375964,0.807458,-1.80366,0.384152,0.735887,-1.80967,0.458202,0.51446,-1.82761,0.382238,0.419199,-1.90544,0.618285,0.518185,-1.8594,0.610333,0.459231,-1.79183,0.13952,1.15045,-2.12638,0.114605,1.07039,-2.10966,0.006106,1.19297,-2.09141,-0.016266,1.11467,-2.07722,-0.021322,0.963758,-2.08209,-0.120537,0.796498,-2.07365,-0.195688,0.879945,-2.08942,-0.246558,0.829066,-2.08168,-0.392616,0.642697,-2.05426,-0.478212,0.707625,-2.00378,-0.391121,0.441944,-1.97098,-0.453976,0.45891,-2.03292,0.193904,1.37731,-1.83521,0.178271,1.36841,-2.04969},
/*1474*/{0.236002,1.95249,-1.73536,0.339782,1.88857,-1.85774,0.070563,1.87896,-1.69266,-0.06218,1.81894,-1.6838,0.056745,1.70731,-1.68186,0.113996,1.63704,-1.66257,0.307737,1.9703,-2.10137,0.357524,1.88998,-1.93165,0.166042,1.91945,-2.05463,0.23945,1.74533,-2.24433,0.302908,1.66418,-2.27097,0.423241,1.68223,-2.11344,0.483803,1.67815,-2.09333,0.27227,1.46338,-1.83782,0.089195,1.52816,-1.88678,0.089128,1.55197,-1.9488,0.093059,1.53004,-2.00131,0.268148,1.44626,-2.08683,0.392637,1.2127,-1.78023,0.286823,1.13109,-1.78116,0.328521,1.062,-1.80591,0.43966,0.999837,-1.80266,0.489571,0.814546,-1.79081,0.498415,0.740246,-1.80444,0.378001,0.798927,-1.80264,0.387094,0.728443,-1.80939,0.46941,0.509594,-1.82865,0.393986,0.412547,-1.9059,0.628212,0.518078,-1.86074,0.61965,0.456932,-1.7947,0.143769,1.1502,-2.12616,0.1193,1.07022,-2.10951,0.009484,1.19139,-2.09211,-0.012456,1.11214,-2.0782,-0.016261,0.962019,-2.08226,-0.121183,0.796945,-2.07321,-0.193027,0.883493,-2.09103,-0.244049,0.835728,-2.08342,-0.399287,0.654396,-2.05537,-0.482936,0.722662,-2.00888,-0.403629,0.455639,-1.968,-0.467242,0.473537,-2.0335,0.193665,1.37742,-1.83584,0.178215,1.36968,-2.05038},
/*1475*/{0.236215,1.95264,-1.7354,0.339634,1.88902,-1.85806,0.071049,1.87863,-1.69347,-0.061947,1.81741,-1.68577,0.056803,1.70601,-1.68257,0.113593,1.63526,-1.66228,0.307739,1.97007,-2.10139,0.357463,1.8901,-1.93162,0.165573,1.9196,-2.05478,0.237609,1.74595,-2.24426,0.300477,1.66358,-2.27129,0.422091,1.67977,-2.11398,0.482807,1.6751,-2.0939,0.274224,1.46426,-1.83881,0.089797,1.52777,-1.88549,0.088927,1.55225,-1.94827,0.092721,1.53054,-2.00004,0.268686,1.44737,-2.08708,0.390024,1.20588,-1.7805,0.27667,1.12528,-1.78335,0.321475,1.05676,-1.80564,0.433275,0.993607,-1.80357,0.491478,0.811131,-1.79435,0.502556,0.736169,-1.80642,0.379608,0.792169,-1.8019,0.391668,0.722014,-1.80801,0.474615,0.503267,-1.82853,0.40468,0.406863,-1.90695,0.636439,0.516427,-1.8626,0.631396,0.457478,-1.79601,0.147508,1.14913,-2.12547,0.123935,1.06907,-2.10914,0.012187,1.18828,-2.09211,-0.007583,1.10908,-2.07866,-0.010526,0.959771,-2.08225,-0.121165,0.797761,-2.07257,-0.188892,0.886516,-2.09251,-0.2426,0.841075,-2.08459,-0.404389,0.666767,-2.05597,-0.489697,0.7374,-2.01243,-0.416106,0.47009,-1.96609,-0.474003,0.486927,-2.03116,0.195864,1.37787,-1.83597,0.178905,1.37046,-2.05041},
/*1476*/{0.236881,1.95248,-1.73549,0.340111,1.88895,-1.85825,0.071303,1.87792,-1.69478,-0.060962,1.81584,-1.68836,0.057173,1.70397,-1.6828,0.11327,1.63301,-1.66194,0.307234,1.96948,-2.1018,0.357428,1.89007,-1.93166,0.165469,1.91953,-2.05456,0.236168,1.74555,-2.24397,0.298587,1.66268,-2.27197,0.420974,1.67691,-2.11508,0.481366,1.67147,-2.09503,0.275326,1.46429,-1.83886,0.090188,1.52713,-1.88507,0.088665,1.55196,-1.94753,0.093442,1.52981,-1.99958,0.268668,1.44863,-2.08727,0.387195,1.19931,-1.7806,0.273229,1.12373,-1.78373,0.314572,1.05157,-1.80708,0.427361,0.98828,-1.80357,0.491291,0.808397,-1.79561,0.504593,0.733234,-1.80803,0.38058,0.786177,-1.80229,0.393768,0.715402,-1.80749,0.482659,0.499886,-1.82989,0.413194,0.401757,-1.90717,0.643548,0.514708,-1.86473,0.639006,0.453894,-1.79882,0.15192,1.14792,-2.12487,0.130426,1.06722,-2.10859,0.016638,1.18548,-2.09373,-0.002666,1.10534,-2.07864,-0.004491,0.956637,-2.08204,-0.120835,0.799364,-2.07189,-0.186261,0.888031,-2.09203,-0.240515,0.847458,-2.08561,-0.408089,0.679934,-2.05613,-0.493152,0.753225,-2.01625,-0.426944,0.485313,-1.96462,-0.484568,0.5022,-2.03264,0.197343,1.37756,-1.83626,0.179828,1.37085,-2.05068},
/*1477*/{0.238024,1.95202,-1.73556,0.339493,1.88846,-1.85862,0.071384,1.87676,-1.69634,-0.060995,1.81289,-1.69042,0.058412,1.70166,-1.68302,0.113773,1.63029,-1.66002,0.30751,1.96839,-2.10219,0.35757,1.88921,-1.93253,0.165273,1.91947,-2.05432,0.232431,1.74437,-2.24336,0.294664,1.66132,-2.27166,0.420102,1.67338,-2.11626,0.479943,1.66769,-2.09587,0.275446,1.464,-1.83931,0.089891,1.52558,-1.88448,0.088982,1.55037,-1.94695,0.092909,1.52868,-1.99924,0.26961,1.44905,-2.08775,0.382236,1.19303,-1.78133,0.267483,1.11708,-1.78445,0.307961,1.04718,-1.80808,0.420213,0.981754,-1.80376,0.49041,0.804973,-1.79731,0.505268,0.731182,-1.80982,0.37992,0.780776,-1.80227,0.396545,0.709581,-1.80754,0.489912,0.497042,-1.83082,0.419923,0.397196,-1.90795,0.649417,0.51341,-1.86593,0.646563,0.451952,-1.79947,0.157159,1.14645,-2.12447,0.135888,1.06555,-2.10774,0.019855,1.18155,-2.09394,0.002419,1.10177,-2.0795,0.002631,0.953396,-2.08194,-0.12043,0.800865,-2.07178,-0.180083,0.894419,-2.09485,-0.237229,0.85364,-2.08613,-0.413803,0.693266,-2.05812,-0.495888,0.769401,-2.01861,-0.437075,0.499912,-1.96429,-0.493076,0.518117,-2.03277,0.198517,1.3765,-1.83673,0.180899,1.37059,-2.05116},
/*1478*/{0.238632,1.95114,-1.73541,0.340247,1.88746,-1.85911,0.072381,1.87531,-1.69703,-0.059345,1.81074,-1.69157,0.059072,1.69931,-1.68288,0.114511,1.62766,-1.65974,0.307073,1.96684,-2.10223,0.356992,1.88917,-1.93277,0.16492,1.91946,-2.05399,0.227834,1.74325,-2.24192,0.290682,1.65953,-2.27132,0.41743,1.67065,-2.11755,0.478186,1.66262,-2.09735,0.275376,1.46383,-1.84018,0.090156,1.52392,-1.88328,0.088941,1.54997,-1.94733,0.092501,1.52729,-1.9988,0.271202,1.44886,-2.08744,0.37921,1.18604,-1.78119,0.261201,1.1143,-1.78531,0.300125,1.04255,-1.80937,0.414746,0.974983,-1.80357,0.48786,0.802394,-1.79892,0.503044,0.728042,-1.80976,0.377743,0.776223,-1.80305,0.395128,0.704861,-1.80873,0.492488,0.493239,-1.83158,0.425719,0.392713,-1.9087,0.652949,0.51208,-1.86797,0.650736,0.449634,-1.80204,0.161856,1.14475,-2.12367,0.141775,1.06378,-2.10775,0.024187,1.17697,-2.0949,0.008001,1.09716,-2.07961,0.009808,0.949394,-2.08186,-0.118592,0.802255,-2.07145,-0.175704,0.897719,-2.0955,-0.234251,0.859734,-2.08702,-0.417374,0.708164,-2.05888,-0.49718,0.786339,-2.02058,-0.445803,0.515551,-1.96449,-0.500932,0.534744,-2.03415,0.19949,1.37578,-1.83676,0.182008,1.37009,-2.05121},
/*1479*/{0.239439,1.9493,-1.73529,0.339791,1.88667,-1.85932,0.073201,1.87287,-1.69726,-0.058265,1.80808,-1.69291,0.060103,1.69581,-1.68235,0.115774,1.62461,-1.65809,0.306,1.96521,-2.10233,0.356648,1.88776,-1.93297,0.164114,1.91809,-2.05356,0.223954,1.74208,-2.24127,0.287106,1.65814,-2.27105,0.415871,1.66517,-2.11873,0.476038,1.65731,-2.09915,0.275076,1.46238,-1.84037,0.089848,1.52188,-1.88359,0.089454,1.548,-1.94675,0.09215,1.52537,-1.99804,0.27149,1.44854,-2.0877,0.37661,1.17994,-1.78059,0.256639,1.11184,-1.78545,0.294807,1.03838,-1.80963,0.406988,0.968756,-1.80384,0.484397,0.79916,-1.79926,0.50107,0.725593,-1.81135,0.375092,0.770462,-1.80466,0.391884,0.700701,-1.81142,0.494944,0.488896,-1.83338,0.428599,0.388544,-1.90982,0.655043,0.509871,-1.87025,0.65529,0.448456,-1.80439,0.167147,1.14254,-2.12289,0.148842,1.06046,-2.10696,0.029271,1.17222,-2.09491,0.013896,1.09236,-2.0798,0.018033,0.945048,-2.08184,-0.116835,0.803436,-2.07212,-0.16934,0.902019,-2.09648,-0.229754,0.865234,-2.08727,-0.419005,0.722501,-2.06076,-0.495505,0.803227,-2.0211,-0.45328,0.531509,-1.96625,-0.508178,0.552355,-2.03481,0.200013,1.37386,-1.83723,0.182584,1.3691,-2.05171},
/*1480*/{0.239802,1.94739,-1.73492,0.340165,1.88507,-1.85978,0.073805,1.87002,-1.69705,-0.055933,1.80367,-1.6928,0.060832,1.69212,-1.68141,0.117169,1.62132,-1.65738,0.305764,1.96357,-2.10307,0.355767,1.88674,-1.93334,0.164018,1.91679,-2.05267,0.218628,1.74042,-2.23965,0.282359,1.65593,-2.27099,0.414423,1.66077,-2.12078,0.473726,1.65101,-2.10117,0.275185,1.46098,-1.84089,0.088951,1.51984,-1.88384,0.088905,1.54547,-1.94654,0.092635,1.52326,-1.99823,0.271873,1.44782,-2.08777,0.371962,1.17447,-1.7804,0.252155,1.10554,-1.78562,0.28928,1.03421,-1.81035,0.400069,0.963064,-1.80453,0.479414,0.795233,-1.79938,0.497188,0.721357,-1.81095,0.370618,0.764996,-1.80688,0.389325,0.695755,-1.81242,0.494745,0.48566,-1.83494,0.429914,0.384412,-1.91096,0.655328,0.50925,-1.87317,0.657061,0.446811,-1.80707,0.172597,1.1401,-2.12282,0.1563,1.0574,-2.1064,0.032869,1.16798,-2.0957,0.019997,1.08671,-2.07932,0.025553,0.940419,-2.08154,-0.115368,0.805774,-2.07163,-0.162962,0.904658,-2.09635,-0.224926,0.872157,-2.0875,-0.421568,0.738393,-2.06053,-0.494912,0.82068,-2.02204,-0.460421,0.54666,-1.96861,-0.514612,0.570052,-2.03688,0.200588,1.37202,-1.83771,0.183459,1.36775,-2.05222},
/*1481*/{0.24081,1.94487,-1.73468,0.340831,1.8825,-1.85964,0.074331,1.866,-1.69699,-0.055006,1.79928,-1.69322,0.062567,1.68802,-1.6806,0.119344,1.61724,-1.65625,0.304118,1.96111,-2.10351,0.356004,1.88436,-1.93359,0.163121,1.91559,-2.0517,0.21448,1.73815,-2.23911,0.277418,1.65409,-2.2704,0.411051,1.6554,-2.1221,0.471529,1.6444,-2.10354,0.274873,1.45819,-1.84057,0.089755,1.51644,-1.88311,0.088569,1.54316,-1.94669,0.092226,1.52124,-1.99775,0.271958,1.44679,-2.08753,0.369344,1.16797,-1.77943,0.248406,1.10211,-1.78551,0.283409,1.03035,-1.812,0.394124,0.95728,-1.8042,0.473882,0.790482,-1.79951,0.493581,0.718127,-1.81126,0.366485,0.76016,-1.80858,0.38564,0.690578,-1.8138,0.493736,0.481198,-1.83767,0.429192,0.380255,-1.91243,0.654753,0.506287,-1.87498,0.655083,0.442064,-1.80914,0.177846,1.13654,-2.12311,0.162474,1.05422,-2.10602,0.03795,1.16189,-2.09534,0.025797,1.08182,-2.08002,0.033572,0.93618,-2.08174,-0.111062,0.806792,-2.07205,-0.155248,0.908561,-2.09684,-0.218773,0.878717,-2.08821,-0.419224,0.752358,-2.06156,-0.49001,0.838334,-2.02048,-0.466647,0.562314,-1.97107,-0.520016,0.588247,-2.03906,0.200715,1.36898,-1.83825,0.183804,1.3662,-2.0528},
/*1482*/{0.241165,1.94194,-1.7344,0.340122,1.88091,-1.86074,0.074929,1.86178,-1.69681,-0.054144,1.79399,-1.69284,0.063811,1.68332,-1.67951,0.120698,1.61294,-1.65502,0.30324,1.95839,-2.10424,0.355646,1.88325,-1.93375,0.162394,1.9134,-2.05076,0.208882,1.737,-2.23743,0.271829,1.65103,-2.27002,0.408501,1.64939,-2.12376,0.468604,1.63733,-2.10583,0.274839,1.45595,-1.84078,0.090208,1.51359,-1.88305,0.08802,1.54048,-1.94628,0.092083,1.51811,-1.99802,0.272312,1.4454,-2.0878,0.366288,1.16359,-1.77774,0.243597,1.10094,-1.78657,0.278969,1.02725,-1.81282,0.390462,0.953022,-1.80449,0.469279,0.78653,-1.79945,0.488097,0.714788,-1.81226,0.361251,0.755284,-1.81001,0.381386,0.685261,-1.81616,0.492373,0.47729,-1.83904,0.426309,0.376069,-1.91612,0.651936,0.501491,-1.87768,0.653038,0.438955,-1.8126,0.182976,1.13319,-2.12371,0.168867,1.05049,-2.10661,0.042607,1.15645,-2.09553,0.032449,1.07584,-2.07929,0.041373,0.931293,-2.08158,-0.107244,0.808122,-2.0722,-0.146814,0.91193,-2.0966,-0.21185,0.883674,-2.08798,-0.411978,0.76382,-2.05934,-0.483737,0.855444,-2.01792,-0.47121,0.577238,-1.97401,-0.524288,0.607454,-2.04195,0.201435,1.36641,-1.83868,0.184505,1.36414,-2.05323},
/*1483*/{0.24115,1.93858,-1.73461,0.339986,1.87859,-1.86089,0.075311,1.85766,-1.69648,-0.052582,1.78797,-1.69168,0.066099,1.6781,-1.67809,0.123517,1.60814,-1.65402,0.302909,1.95523,-2.10528,0.355338,1.8803,-1.93405,0.161836,1.91169,-2.05088,0.210422,1.73405,-2.23603,0.266906,1.6485,-2.26944,0.405217,1.64269,-2.12554,0.46569,1.63017,-2.10943,0.27424,1.45297,-1.83982,0.089499,1.51062,-1.88281,0.088991,1.53705,-1.94587,0.091487,1.5154,-1.99856,0.272177,1.44339,-2.08731,0.362634,1.15988,-1.77683,0.24023,1.09866,-1.78751,0.274788,1.02429,-1.81401,0.38857,0.950677,-1.80429,0.463994,0.781385,-1.79918,0.48408,0.708873,-1.81219,0.35667,0.750139,-1.81232,0.375559,0.680867,-1.81959,0.488449,0.473589,-1.84154,0.422251,0.372417,-1.91929,0.648138,0.496885,-1.87978,0.649716,0.433899,-1.81672,0.188542,1.13029,-2.12402,0.176144,1.04676,-2.10702,0.047919,1.15053,-2.09558,0.039011,1.0699,-2.07923,0.04979,0.926658,-2.08148,-0.102647,0.809161,-2.07245,-0.139681,0.915146,-2.09735,-0.204607,0.889618,-2.0884,-0.416028,0.781872,-2.06106,-0.476889,0.871558,-2.0167,-0.475072,0.592593,-1.97843,-0.526125,0.626744,-2.0451,0.200983,1.36326,-1.83866,0.184782,1.36168,-2.05328},
/*1484*/{0.241082,1.93487,-1.73451,0.340175,1.87446,-1.86145,0.075946,1.85186,-1.69569,-0.050674,1.78154,-1.68971,0.068201,1.67287,-1.67646,0.126674,1.60318,-1.65268,0.302254,1.95204,-2.10591,0.354579,1.87743,-1.93431,0.161911,1.90912,-2.05012,0.198977,1.73121,-2.23511,0.2612,1.64512,-2.26941,0.40184,1.63667,-2.12742,0.462076,1.62186,-2.1118,0.274034,1.44968,-1.83987,0.088358,1.50849,-1.88291,0.087933,1.53347,-1.9468,0.092423,1.51135,-1.99882,0.273333,1.44163,-2.08733,0.36003,1.15652,-1.77467,0.237594,1.09532,-1.7877,0.273101,1.02107,-1.814,0.387787,0.949604,-1.80509,0.458719,0.776696,-1.7995,0.478553,0.703938,-1.81333,0.350935,0.745573,-1.81426,0.370537,0.675772,-1.82175,0.483096,0.46913,-1.84419,0.416176,0.368725,-1.92333,0.642674,0.491763,-1.88273,0.645148,0.427475,-1.81913,0.193227,1.12671,-2.12432,0.182869,1.04356,-2.1074,0.052384,1.14464,-2.0952,0.045313,1.06401,-2.07902,0.057954,0.922127,-2.08195,-0.097111,0.810731,-2.07356,-0.130003,0.917785,-2.09796,-0.19621,0.893716,-2.0885,-0.412364,0.796493,-2.06134,-0.469457,0.888312,-2.01395,-0.479894,0.608459,-1.98384,-0.528466,0.645945,-2.04878,0.200948,1.36017,-1.83909,0.185923,1.35912,-2.0538},
/*1485*/{0.241854,1.93064,-1.73384,0.340302,1.8722,-1.862,0.077356,1.84596,-1.694,-0.04881,1.77511,-1.68767,0.071358,1.66762,-1.67519,0.129625,1.59828,-1.65123,0.301851,1.94799,-2.10631,0.355087,1.87429,-1.93434,0.160779,1.90615,-2.04958,0.192118,1.72758,-2.23376,0.2557,1.64138,-2.26908,0.397694,1.62872,-2.12918,0.458469,1.61284,-2.11547,0.273486,1.44644,-1.8393,0.089218,1.50469,-1.88256,0.087514,1.53045,-1.94741,0.091662,1.50793,-1.99905,0.273101,1.43928,-2.08638,0.356231,1.15395,-1.77363,0.234517,1.09238,-1.78851,0.26932,1.01991,-1.81524,0.385665,0.947178,-1.80599,0.454202,0.771315,-1.80015,0.47315,0.698667,-1.81484,0.345532,0.741486,-1.81512,0.365496,0.672812,-1.824,0.474403,0.462162,-1.84702,0.408427,0.365208,-1.9266,0.636698,0.485307,-1.884,0.636934,0.418665,-1.82165,0.197984,1.12314,-2.12509,0.189038,1.03986,-2.10803,0.057048,1.1385,-2.09505,0.051977,1.0575,-2.07906,0.06607,0.916734,-2.08246,-0.091903,0.811451,-2.07402,-0.120315,0.92002,-2.09749,-0.187223,0.898479,-2.08874,-0.399425,0.806768,-2.06021,-0.459375,0.90356,-2.01066,-0.479833,0.62342,-1.98878,-0.529197,0.664487,-2.05137,0.200751,1.35687,-1.83905,0.186203,1.3562,-2.05379},
/*1486*/{0.242087,1.92585,-1.7334,0.339371,1.86716,-1.86205,0.077474,1.84008,-1.6936,-0.047276,1.76834,-1.68564,0.073819,1.66136,-1.67267,0.133384,1.59263,-1.64964,0.30049,1.94412,-2.10741,0.354094,1.87086,-1.93533,0.160323,1.90195,-2.04879,0.187284,1.72471,-2.23258,0.249046,1.63729,-2.26869,0.393547,1.62101,-2.13161,0.454328,1.60447,-2.11849,0.2734,1.44345,-1.83862,0.090365,1.50197,-1.88205,0.087567,1.52627,-1.9467,0.091441,1.50341,-1.99909,0.273856,1.43652,-2.08602,0.35326,1.15158,-1.77325,0.231676,1.09024,-1.78968,0.267388,1.01642,-1.81418,0.384471,0.944694,-1.80653,0.448491,0.765518,-1.80184,0.466689,0.692273,-1.81611,0.340309,0.737622,-1.81679,0.358985,0.667098,-1.8248,0.465897,0.456058,-1.84979,0.399208,0.361672,-1.93069,0.627564,0.477169,-1.88745,0.628364,0.410439,-1.82562,0.2032,1.11959,-2.12519,0.195599,1.03647,-2.10886,0.062138,1.13255,-2.09494,0.058011,1.0508,-2.07905,0.074821,0.911857,-2.08255,-0.085342,0.81262,-2.07425,-0.109934,0.921591,-2.09738,-0.178078,0.903073,-2.08947,-0.39706,0.823232,-2.06307,-0.448698,0.916721,-2.00848,-0.478799,0.638111,-1.99317,-0.52826,0.682235,-2.05413,0.201629,1.35378,-1.8384,0.187169,1.35272,-2.05315},
/*1487*/{0.242045,1.92082,-1.73356,0.339976,1.86417,-1.86335,0.078556,1.83338,-1.69149,-0.045633,1.76064,-1.68341,0.076569,1.65528,-1.67091,0.13734,1.58779,-1.64785,0.299517,1.93931,-2.10875,0.354243,1.86647,-1.93532,0.159659,1.89873,-2.04789,0.182046,1.721,-2.23098,0.242928,1.63315,-2.26845,0.388438,1.61219,-2.13324,0.450234,1.59466,-2.12198,0.273089,1.44004,-1.83786,0.087391,1.49724,-1.88328,0.086385,1.52276,-1.94732,0.089539,1.49905,-2.00029,0.273836,1.4334,-2.08502,0.352091,1.14813,-1.77163,0.229078,1.08844,-1.79067,0.264928,1.01387,-1.81548,0.380451,0.941084,-1.80759,0.44363,0.760473,-1.80294,0.461093,0.686939,-1.8181,0.334566,0.732777,-1.81791,0.352609,0.663336,-1.82704,0.456485,0.450408,-1.85222,0.388585,0.357641,-1.93517,0.618632,0.468805,-1.88873,0.618173,0.401429,-1.82889,0.207507,1.11628,-2.12578,0.201618,1.03199,-2.10922,0.067392,1.12561,-2.0942,0.064629,1.0439,-2.07832,0.083872,0.907244,-2.0831,-0.078815,0.813601,-2.0766,-0.099458,0.923554,-2.09735,-0.168046,0.907034,-2.09139,-0.389873,0.837023,-2.06429,-0.436984,0.929939,-2.00531,-0.476671,0.651,-1.99755,-0.526375,0.700873,-2.05931,0.200511,1.35021,-1.83841,0.187487,1.34907,-2.05325},
/*1488*/{0.242134,1.91532,-1.73284,0.33979,1.85917,-1.86363,0.079674,1.82538,-1.69022,-0.044156,1.75278,-1.68107,0.079881,1.64783,-1.6689,0.140641,1.58149,-1.64699,0.299516,1.93468,-2.10967,0.354334,1.86333,-1.93573,0.158758,1.89416,-2.04712,0.176002,1.7176,-2.22982,0.235997,1.6289,-2.26787,0.383838,1.60377,-2.13586,0.445959,1.58428,-2.12491,0.272637,1.43652,-1.83715,0.085989,1.49251,-1.88376,0.086669,1.51799,-1.94777,0.090232,1.49483,-2.00018,0.274014,1.43034,-2.08441,0.349222,1.14494,-1.77104,0.227204,1.08602,-1.7918,0.261892,1.01113,-1.8159,0.375993,0.935562,-1.80738,0.437728,0.754313,-1.80485,0.453732,0.680425,-1.81946,0.328144,0.729353,-1.82011,0.344206,0.659074,-1.83071,0.444383,0.443824,-1.8541,0.376239,0.353361,-1.93881,0.610056,0.462504,-1.8919,0.605865,0.391975,-1.83193,0.212833,1.11242,-2.12724,0.209113,1.02855,-2.11017,0.071291,1.11923,-2.09413,0.071723,1.03759,-2.07841,0.092917,0.901957,-2.0835,-0.071169,0.814115,-2.07587,-0.088682,0.924578,-2.09697,-0.15723,0.910601,-2.09174,-0.380999,0.848827,-2.06461,-0.425944,0.942043,-2.00445,-0.473512,0.663533,-2.00262,-0.520415,0.715522,-2.06101,0.200486,1.34614,-1.83837,0.18862,1.34537,-2.05327},
/*1489*/{0.242649,1.9097,-1.7325,0.339698,1.85479,-1.8643,0.081146,1.81776,-1.68802,-0.042024,1.74405,-1.67816,0.083787,1.64074,-1.66613,0.146008,1.57513,-1.64492,0.298626,1.93017,-2.11102,0.353751,1.85873,-1.9364,0.159318,1.89013,-2.04695,0.170435,1.71269,-2.22905,0.230836,1.62386,-2.26807,0.380646,1.59597,-2.13857,0.441584,1.57384,-2.12892,0.270963,1.43288,-1.83601,0.084617,1.48851,-1.88427,0.085253,1.51383,-1.94788,0.088321,1.49015,-2.00129,0.274302,1.42718,-2.08395,0.346642,1.14105,-1.77023,0.225369,1.08313,-1.79292,0.259538,1.0078,-1.81646,0.371489,0.929935,-1.80726,0.430471,0.747864,-1.80548,0.444836,0.674528,-1.82225,0.320845,0.72505,-1.82182,0.33662,0.655092,-1.83052,0.434531,0.441069,-1.85744,0.363023,0.350089,-1.94218,0.597269,0.453696,-1.89475,0.593311,0.382889,-1.83533,0.217546,1.10909,-2.12767,0.216261,1.02448,-2.11126,0.077043,1.11267,-2.09367,0.078209,1.03101,-2.078,0.10228,0.89644,-2.08484,-0.063202,0.815505,-2.07817,-0.077272,0.926663,-2.09696,-0.146697,0.913288,-2.09095,-0.367628,0.857762,-2.06253,-0.414173,0.952602,-2.00237,-0.466642,0.675525,-2.00633,-0.513352,0.729397,-2.06418,0.19919,1.34237,-1.83818,0.188777,1.34163,-2.05317},
/*1490*/{0.242966,1.90339,-1.73204,0.339496,1.84954,-1.86414,0.082513,1.80925,-1.68657,-0.039964,1.73486,-1.67444,0.08669,1.6338,-1.66382,0.150629,1.56888,-1.64305,0.297122,1.92422,-2.11213,0.354662,1.85355,-1.93698,0.158325,1.88553,-2.04662,0.16491,1.70866,-2.22795,0.223757,1.61903,-2.26789,0.374911,1.58603,-2.14057,0.436558,1.56325,-2.13232,0.269423,1.42997,-1.83491,0.084008,1.48362,-1.88512,0.085095,1.50949,-1.94789,0.088364,1.48442,-2.00199,0.273843,1.42363,-2.08311,0.344188,1.13748,-1.76935,0.222794,1.07983,-1.79455,0.256541,1.00489,-1.81794,0.36712,0.924891,-1.80801,0.423706,0.741238,-1.80735,0.437242,0.667793,-1.82273,0.31297,0.720293,-1.82344,0.327862,0.650263,-1.83215,0.42121,0.438449,-1.86073,0.345163,0.354179,-1.94291,0.586132,0.44285,-1.89746,0.577988,0.374499,-1.83926,0.223019,1.10509,-2.12831,0.223403,1.02031,-2.11244,0.082961,1.10601,-2.09254,0.085949,1.02391,-2.07766,0.112465,0.89179,-2.08518,-0.055132,0.815021,-2.07856,-0.065836,0.927545,-2.09683,-0.135111,0.916816,-2.08916,-0.361351,0.870092,-2.06579,-0.402973,0.96274,-2.00078,-0.458719,0.686638,-2.01033,-0.504418,0.741306,-2.06685,0.198934,1.33876,-1.83744,0.1897,1.33718,-2.05247},
/*1491*/{0.243433,1.89744,-1.73134,0.340618,1.84312,-1.86442,0.08436,1.8014,-1.68406,-0.037849,1.72579,-1.67082,0.091449,1.62601,-1.66145,0.155878,1.56223,-1.64099,0.296166,1.91823,-2.11377,0.354171,1.8487,-1.93795,0.158391,1.88046,-2.04634,0.160146,1.70445,-2.22736,0.217557,1.61354,-2.26748,0.370059,1.57574,-2.14352,0.430765,1.55129,-2.13638,0.268807,1.4269,-1.83365,0.082639,1.47857,-1.88516,0.083989,1.50502,-1.9488,0.086822,1.47907,-2.0021,0.273799,1.42012,-2.08249,0.34148,1.1321,-1.76877,0.220264,1.07581,-1.79588,0.254074,1.00079,-1.81874,0.362774,0.919401,-1.8086,0.415812,0.735115,-1.8085,0.428656,0.661025,-1.82509,0.305535,0.716165,-1.82496,0.319445,0.645362,-1.83494,0.406322,0.435329,-1.8633,0.326536,0.35468,-1.94484,0.570416,0.431045,-1.90234,0.55835,0.363158,-1.84152,0.228685,1.1003,-2.12929,0.230452,1.01639,-2.1138,0.089171,1.09813,-2.09188,0.093335,1.0168,-2.07785,0.12248,0.886585,-2.08634,-0.045366,0.815324,-2.08,-0.053813,0.928374,-2.0965,-0.123448,0.919602,-2.08886,-0.349597,0.879962,-2.06561,-0.39173,0.972153,-2.00038,-0.449113,0.696192,-2.01423,-0.494797,0.752325,-2.06972,0.198774,1.3352,-1.83673,0.190381,1.33286,-2.05179},
/*1492*/{0.243562,1.89095,-1.73073,0.339813,1.83744,-1.86446,0.086635,1.79258,-1.68004,-0.036107,1.7153,-1.66673,0.095499,1.61764,-1.65848,0.160849,1.5559,-1.63876,0.296121,1.91245,-2.11496,0.354573,1.84289,-1.9382,0.156992,1.87468,-2.04599,0.158146,1.69778,-2.22579,0.210483,1.60828,-2.2672,0.364704,1.56527,-2.14662,0.424023,1.53969,-2.14097,0.267847,1.42268,-1.83183,0.080513,1.47359,-1.88636,0.082426,1.49996,-1.94879,0.085991,1.47398,-2.00212,0.273144,1.41622,-2.08146,0.339489,1.12718,-1.76795,0.21673,1.07247,-1.79722,0.25163,0.996418,-1.82008,0.357628,0.913931,-1.80891,0.408249,0.729053,-1.80993,0.419461,0.654841,-1.8261,0.29696,0.711478,-1.8264,0.309962,0.640027,-1.83702,0.391645,0.432582,-1.86615,0.30792,0.356161,-1.94636,0.555894,0.418431,-1.90653,0.541722,0.353417,-1.8439,0.234027,1.0968,-2.12999,0.23743,1.01281,-2.11493,0.095205,1.09157,-2.09115,0.10104,1.01009,-2.07764,0.133361,0.881628,-2.08779,-0.036029,0.815273,-2.08112,-0.04083,0.928625,-2.09593,-0.110536,0.920573,-2.08822,-0.338303,0.887595,-2.06577,-0.380713,0.980123,-2.00134,-0.438208,0.704992,-2.01691,-0.483821,0.760905,-2.07186,0.197544,1.33081,-1.83611,0.190537,1.32837,-2.05122},
/*1493*/{0.24473,1.88437,-1.72984,0.341199,1.83185,-1.86533,0.08873,1.78323,-1.6783,-0.032539,1.70538,-1.6625,0.099946,1.6098,-1.65577,0.166594,1.54959,-1.63782,0.295077,1.90599,-2.11655,0.354255,1.83755,-1.93947,0.156979,1.86969,-2.04633,0.153731,1.69233,-2.22546,0.204215,1.6027,-2.26749,0.359062,1.55418,-2.14901,0.418656,1.52775,-2.14513,0.266907,1.4192,-1.82995,0.079593,1.46712,-1.88698,0.0821,1.49425,-1.94855,0.084754,1.46804,-2.00394,0.272207,1.41213,-2.08091,0.336408,1.12104,-1.76728,0.212958,1.06684,-1.79816,0.24756,0.990891,-1.8215,0.352975,0.908618,-1.80949,0.399439,0.722072,-1.81157,0.409865,0.648579,-1.82778,0.288046,0.707221,-1.82864,0.299411,0.636363,-1.83901,0.375073,0.42992,-1.86814,0.287701,0.357797,-1.94767,0.542139,0.405916,-1.90897,0.521549,0.341784,-1.84464,0.239158,1.09333,-2.1315,0.245496,1.00923,-2.11587,0.100765,1.08465,-2.09115,0.107978,1.00312,-2.07764,0.144078,0.87615,-2.08895,-0.024975,0.815833,-2.08293,-0.028045,0.929465,-2.09504,-0.097746,0.923717,-2.08899,-0.325348,0.895281,-2.06579,-0.368926,0.986808,-2.00069,-0.425714,0.71315,-2.01918,-0.471195,0.769205,-2.07448,0.197454,1.32638,-1.83556,0.191464,1.32331,-2.05069},
/*1494*/{0.245267,1.87792,-1.72898,0.342276,1.82731,-1.86645,0.091348,1.77366,-1.67588,-0.028626,1.69536,-1.65749,0.105572,1.60096,-1.65302,0.173495,1.54174,-1.63488,0.294171,1.89944,-2.11834,0.355115,1.8321,-1.94083,0.156523,1.86335,-2.04584,0.148965,1.68723,-2.22493,0.196786,1.59678,-2.26704,0.35372,1.54359,-2.1519,0.412191,1.51502,-2.14965,0.265836,1.41522,-1.82785,0.077578,1.46193,-1.88847,0.081161,1.48962,-1.94848,0.083176,1.46247,-2.00503,0.271272,1.40805,-2.08081,0.332621,1.11437,-1.76549,0.210554,1.06181,-1.7982,0.244624,0.986018,-1.82194,0.346729,0.902558,-1.80913,0.391919,0.716049,-1.81339,0.40031,0.642059,-1.82996,0.279974,0.703417,-1.82874,0.289108,0.632364,-1.84071,0.358395,0.426858,-1.86944,0.266043,0.357606,-1.94655,0.524795,0.396351,-1.9138,0.502426,0.338588,-1.84617,0.244889,1.08909,-2.13187,0.252339,1.00531,-2.11726,0.106944,1.07727,-2.09145,0.116391,0.995851,-2.07756,0.155933,0.871075,-2.09072,-0.014476,0.815389,-2.08405,-0.013677,0.928658,-2.09514,-0.083175,0.923743,-2.08793,-0.307919,0.898603,-2.06396,-0.355697,0.992791,-2.00085,-0.412815,0.718352,-2.02141,-0.457265,0.775102,-2.07679,0.196233,1.32215,-1.83515,0.191442,1.31862,-2.0503},
/*1495*/{0.246411,1.87148,-1.72859,0.342278,1.82035,-1.86618,0.094462,1.76402,-1.67344,-0.024067,1.68493,-1.65252,0.111205,1.5934,-1.64968,0.180313,1.53564,-1.63322,0.294556,1.89332,-2.11949,0.355164,1.82554,-1.94206,0.155754,1.85817,-2.0462,0.144463,1.68178,-2.22467,0.190492,1.5909,-2.26747,0.347851,1.53227,-2.15504,0.406111,1.50206,-2.15404,0.264371,1.41166,-1.8261,0.075207,1.45757,-1.88866,0.079289,1.48361,-1.94847,0.080706,1.45687,-2.00553,0.270704,1.40367,-2.07996,0.327866,1.10804,-1.76409,0.20407,1.05519,-1.79895,0.239016,0.981623,-1.82452,0.34036,0.896643,-1.8096,0.382342,0.708792,-1.81619,0.389645,0.636724,-1.83225,0.271857,0.701183,-1.8309,0.277559,0.629671,-1.84024,0.341268,0.42403,-1.87057,0.244285,0.357974,-1.94533,0.502758,0.391999,-1.91772,0.480899,0.340189,-1.84679,0.250464,1.08552,-2.13268,0.260423,1.00172,-2.11784,0.111872,1.07032,-2.09174,0.12428,0.989064,-2.07808,0.166765,0.865344,-2.09318,-0.002234,0.814973,-2.08642,0.000777,0.927408,-2.09587,-0.069628,0.924957,-2.08838,-0.298766,0.906223,-2.06675,-0.342337,0.997202,-2.00058,-0.398243,0.723551,-2.02325,-0.442695,0.7798,-2.07977,0.194985,1.3183,-1.83393,0.191222,1.31363,-2.04908},
/*1496*/{0.247534,1.86554,-1.72746,0.343629,1.8144,-1.8669,0.098099,1.7538,-1.66998,-0.019846,1.6739,-1.64765,0.118923,1.58535,-1.64637,0.187708,1.52874,-1.63079,0.293852,1.88754,-2.12167,0.355477,1.82005,-1.94288,0.155718,1.85249,-2.04613,0.139144,1.67645,-2.22454,0.18302,1.58462,-2.26724,0.341969,1.52115,-2.15839,0.3993,1.48922,-2.1578,0.261566,1.40639,-1.82477,0.072935,1.45273,-1.88992,0.07572,1.47844,-1.94996,0.07854,1.45104,-2.00648,0.269209,1.39871,-2.07901,0.321606,1.10261,-1.76183,0.199046,1.05198,-1.80067,0.232924,0.977843,-1.82611,0.332889,0.889208,-1.81005,0.37558,0.706553,-1.81655,0.378751,0.631909,-1.83417,0.264299,0.702328,-1.82975,0.267986,0.630144,-1.84097,0.322697,0.420149,-1.87337,0.221702,0.35774,-1.9469,0.479028,0.391684,-1.91947,0.459004,0.340145,-1.84764,0.255434,1.08264,-2.13427,0.268147,0.99891,-2.11908,0.118029,1.06248,-2.09249,0.134064,0.982692,-2.07864,0.179521,0.857854,-2.09247,0.01043,0.813518,-2.08707,0.015229,0.925458,-2.09597,-0.054849,0.924741,-2.08826,-0.279835,0.908003,-2.06581,-0.329298,1.00195,-2.00226,-0.383836,0.72655,-2.02529,-0.426467,0.782794,-2.08147,0.191778,1.31336,-1.83366,0.189827,1.30831,-2.04883},
/*1497*/{0.249216,1.86048,-1.72727,0.343536,1.80929,-1.86736,0.10282,1.74386,-1.66676,-0.013191,1.66304,-1.64169,0.126247,1.57757,-1.64285,0.196063,1.52313,-1.62925,0.293738,1.88231,-2.1231,0.35669,1.81391,-1.9445,0.154537,1.84801,-2.04536,0.135588,1.67083,-2.224,0.176266,1.57872,-2.26733,0.336599,1.51065,-2.16128,0.392088,1.4767,-2.16166,0.25975,1.40265,-1.82313,0.068395,1.44786,-1.89165,0.072697,1.47258,-1.95118,0.076301,1.44635,-2.00774,0.269202,1.39416,-2.07751,0.31539,1.10008,-1.75711,0.191854,1.05088,-1.80306,0.227637,0.976872,-1.82885,0.324783,0.882615,-1.81123,0.369435,0.705703,-1.81696,0.365134,0.630817,-1.83698,0.256616,0.706086,-1.82918,0.258694,0.63432,-1.84211,0.300331,0.418299,-1.8741,0.198939,0.359017,-1.94729,0.457402,0.390248,-1.91964,0.435008,0.339412,-1.84723,0.261871,1.07848,-2.13399,0.27632,0.99604,-2.11977,0.124477,1.05609,-2.09281,0.141452,0.976195,-2.07929,0.191709,0.854364,-2.09373,0.023873,0.811932,-2.08767,0.030551,0.92439,-2.09701,-0.038795,0.923876,-2.08886,-0.265315,0.911553,-2.06687,-0.316924,1.00411,-2.00394,-0.367604,0.729009,-2.02727,-0.410346,0.784194,-2.08391,0.189075,1.30935,-1.83297,0.18972,1.30355,-2.04813},
/*1498*/{0.250281,1.85576,-1.72674,0.344971,1.8026,-1.86889,0.107562,1.73373,-1.66339,-0.006028,1.65168,-1.63518,0.132671,1.5692,-1.63911,0.20484,1.51705,-1.62647,0.292874,1.87766,-2.12559,0.357454,1.80841,-1.94637,0.153841,1.84536,-2.04413,0.13008,1.66754,-2.22389,0.169528,1.57292,-2.26665,0.330069,1.4988,-2.16454,0.384504,1.46381,-2.16597,0.256333,1.39858,-1.82243,0.063417,1.44392,-1.89314,0.069853,1.46817,-1.95337,0.073239,1.44016,-2.00845,0.26826,1.39004,-2.07645,0.311416,1.09799,-1.75577,0.18999,1.05235,-1.80538,0.223065,0.976916,-1.83023,0.320053,0.880978,-1.8105,0.362438,0.704086,-1.81894,0.358373,0.630561,-1.83623,0.249417,0.710494,-1.82815,0.246011,0.638813,-1.8404,0.280876,0.422086,-1.87431,0.177225,0.359716,-1.94896,0.435,0.388898,-1.91962,0.413572,0.337731,-1.84778,0.2673,1.07722,-2.13461,0.283765,0.994618,-2.12079,0.130231,1.04936,-2.0932,0.150972,0.969949,-2.07935,0.203687,0.852455,-2.09498,0.037727,0.810175,-2.08789,0.045821,0.922049,-2.09732,-0.023627,0.923241,-2.08994,-0.24877,0.911069,-2.06683,-0.302222,1.00562,-2.00503,-0.351491,0.728247,-2.0301,-0.392261,0.78449,-2.08727,0.185395,1.30549,-1.83257,0.188401,1.29882,-2.04768},
/*1499*/{0.251886,1.85161,-1.72618,0.34481,1.79844,-1.87048,0.113053,1.72452,-1.6606,0.002948,1.64144,-1.6293,0.143058,1.56259,-1.63551,0.214694,1.51248,-1.625,0.291746,1.87438,-2.12719,0.357883,1.80305,-1.94886,0.152845,1.84378,-2.042,0.129287,1.66231,-2.22366,0.163137,1.56773,-2.26493,0.323538,1.48931,-2.16834,0.376887,1.45182,-2.17026,0.252969,1.39466,-1.82047,0.060113,1.44079,-1.89568,0.066552,1.46359,-1.95398,0.070148,1.43511,-2.01034,0.266525,1.38576,-2.07577,0.308562,1.09645,-1.75347,0.186942,1.05325,-1.80728,0.221042,0.976724,-1.82919,0.319923,0.884076,-1.80844,0.352905,0.70376,-1.81932,0.346546,0.630202,-1.83641,0.241202,0.713853,-1.82549,0.234322,0.643592,-1.83949,0.260525,0.423135,-1.87484,0.155154,0.360997,-1.9482,0.414553,0.388694,-1.91971,0.391347,0.336876,-1.84645,0.272811,1.07692,-2.13466,0.292389,0.995148,-2.12167,0.136203,1.0442,-2.0938,0.15935,0.965393,-2.08024,0.215878,0.847906,-2.09762,0.051711,0.809056,-2.08945,0.061222,0.920173,-2.09821,-0.008455,0.922004,-2.09043,-0.23721,0.912857,-2.07021,-0.289355,1.00482,-2.00648,-0.333878,0.727928,-2.03147,-0.37477,0.783706,-2.08834,0.181452,1.30192,-1.83209,0.186605,1.29424,-2.04713},
/*1500*/{0.253624,1.848,-1.72612,0.345677,1.79452,-1.87246,0.11928,1.71601,-1.65817,0.01094,1.63107,-1.62337,0.152134,1.55579,-1.63157,0.225127,1.50766,-1.62244,0.290736,1.87118,-2.12891,0.358652,1.79888,-1.94977,0.15193,1.84246,-2.0407,0.126086,1.65917,-2.22338,0.157198,1.56364,-2.26271,0.316569,1.47812,-2.17164,0.369342,1.44007,-2.17479,0.250026,1.39243,-1.81863,0.056159,1.43741,-1.89803,0.064792,1.46039,-1.95519,0.066986,1.42942,-2.01178,0.264065,1.38169,-2.07498,0.302979,1.09704,-1.75246,0.185735,1.05026,-1.80487,0.219454,0.974382,-1.82957,0.322816,0.888235,-1.80678,0.344128,0.70309,-1.81872,0.33384,0.629414,-1.83541,0.231516,0.715669,-1.82434,0.223864,0.645678,-1.83728,0.241296,0.423528,-1.87543,0.133918,0.362079,-1.94832,0.393065,0.387257,-1.91917,0.369761,0.337191,-1.84653,0.278225,1.07804,-2.1347,0.300427,0.996436,-2.12199,0.142548,1.04044,-2.09504,0.167527,0.962613,-2.08195,0.229308,0.84555,-2.09774,0.067464,0.806732,-2.08928,0.077405,0.919106,-2.09974,0.008151,0.920723,-2.09252,-0.222094,0.912393,-2.07057,-0.275534,1.0033,-2.00868,-0.316038,0.725477,-2.03334,-0.357075,0.780632,-2.09143,0.178146,1.29963,-1.83098,0.184967,1.28968,-2.04588},
/*1501*/{0.254891,1.8449,-1.72664,0.346516,1.78946,-1.87368,0.125053,1.71045,-1.65649,0.02008,1.62199,-1.61796,0.162192,1.55088,-1.62995,0.236227,1.50444,-1.62047,0.290369,1.86858,-2.1293,0.358969,1.79546,-1.9528,0.151865,1.84164,-2.03986,0.123257,1.65707,-2.22116,0.154105,1.56295,-2.25933,0.309728,1.46917,-2.17445,0.360443,1.429,-2.17982,0.24669,1.39141,-1.8172,0.053921,1.43501,-1.90038,0.061903,1.45972,-1.95702,0.063918,1.42537,-2.01436,0.262377,1.37849,-2.0746,0.299401,1.09793,-1.75348,0.182141,1.04866,-1.80317,0.217206,0.973274,-1.82842,0.326653,0.891586,-1.80704,0.33291,0.701351,-1.81739,0.3214,0.628086,-1.83448,0.221528,0.717914,-1.82307,0.211978,0.646918,-1.8356,0.222152,0.423775,-1.87539,0.112309,0.362483,-1.94808,0.372656,0.386689,-1.91876,0.34808,0.336897,-1.84544,0.283325,1.07906,-2.1352,0.308919,0.998631,-2.12213,0.150124,1.03676,-2.09543,0.177389,0.959691,-2.08256,0.245117,0.845382,-2.09778,0.082795,0.806263,-2.08885,0.093552,0.917197,-2.10051,0.02458,0.919412,-2.09298,-0.20378,0.908667,-2.07065,-0.263247,1.00132,-2.00916,-0.296602,0.721574,-2.03464,-0.337625,0.776306,-2.09382,0.174539,1.29866,-1.83039,0.183261,1.28649,-2.04511},
/*1502*/{0.256188,1.84241,-1.72765,0.34578,1.78729,-1.87627,0.13048,1.70582,-1.65454,0.030672,1.61495,-1.61284,0.17379,1.54669,-1.62709,0.24724,1.50168,-1.61839,0.290563,1.86633,-2.12948,0.359087,1.79246,-1.95451,0.151815,1.84042,-2.03992,0.118913,1.65658,-2.21862,0.148393,1.56325,-2.25611,0.303222,1.46339,-2.17645,0.351396,1.42018,-2.18476,0.243229,1.38985,-1.81544,0.051504,1.43424,-1.90168,0.06066,1.45911,-1.95807,0.061479,1.42277,-2.01606,0.26046,1.37644,-2.07502,0.29516,1.09663,-1.75303,0.175897,1.0478,-1.80319,0.212099,0.973132,-1.82604,0.327134,0.892786,-1.80779,0.321385,0.698564,-1.81548,0.309252,0.62575,-1.833,0.209294,0.717826,-1.82266,0.197656,0.647529,-1.83542,0.20228,0.424347,-1.87487,0.091231,0.362938,-1.94812,0.351616,0.385996,-1.91915,0.326442,0.336313,-1.84592,0.289976,1.08124,-2.13539,0.318011,1.00222,-2.1221,0.157496,1.03467,-2.09737,0.186928,0.958638,-2.08455,0.261314,0.845659,-2.09657,0.098738,0.805438,-2.08811,0.109652,0.915966,-2.10162,0.039139,0.917477,-2.09408,-0.186768,0.904871,-2.06994,-0.25147,0.996925,-2.01109,-0.276818,0.716338,-2.03682,-0.318708,0.769178,-2.09541,0.170918,1.29749,-1.8302,0.18112,1.28442,-2.04479},
/*1503*/{0.257863,1.84011,-1.72879,0.346012,1.78402,-1.87764,0.136116,1.70221,-1.65336,0.038934,1.60964,-1.60901,0.185625,1.54476,-1.62601,0.260367,1.50049,-1.61692,0.291011,1.86418,-2.12993,0.358121,1.79003,-1.95542,0.150986,1.84023,-2.04075,0.114928,1.65724,-2.21522,0.143005,1.56456,-2.25348,0.295077,1.45781,-2.17878,0.342193,1.41273,-2.18894,0.239981,1.38871,-1.81283,0.049401,1.43304,-1.90382,0.059245,1.45856,-1.9593,0.059364,1.42185,-2.01797,0.258706,1.37375,-2.07524,0.289357,1.0948,-1.75275,0.170492,1.04635,-1.80208,0.205114,0.970333,-1.82427,0.323171,0.889764,-1.80707,0.307214,0.696073,-1.81401,0.293102,0.623289,-1.83216,0.196267,0.717649,-1.82085,0.182811,0.648072,-1.83436,0.182601,0.425562,-1.87466,0.069953,0.363728,-1.94668,0.329611,0.384804,-1.91851,0.305662,0.335028,-1.84365,0.297729,1.08435,-2.13564,0.328504,1.00593,-2.12223,0.166106,1.03277,-2.09916,0.198874,0.957734,-2.08579,0.277979,0.848553,-2.09654,0.115497,0.802189,-2.08583,0.12519,0.91452,-2.10289,0.055689,0.916265,-2.09497,-0.177131,0.904508,-2.07466,-0.239079,0.990402,-2.01354,-0.256651,0.709333,-2.0384,-0.298225,0.761422,-2.09715,0.166889,1.29657,-1.82988,0.179023,1.2824,-2.04431},
/*1504*/{0.259702,1.83874,-1.7296,0.345615,1.78399,-1.87952,0.141305,1.70037,-1.65226,0.049518,1.60589,-1.60422,0.197312,1.54272,-1.62388,0.27222,1.50096,-1.61528,0.290097,1.8626,-2.13063,0.357763,1.78895,-1.95614,0.151026,1.84002,-2.04117,0.110699,1.659,-2.21158,0.134657,1.56587,-2.25159,0.286739,1.45426,-2.18194,0.33299,1.40701,-2.19273,0.23701,1.38811,-1.81089,0.047805,1.43354,-1.90469,0.057066,1.45867,-1.95986,0.058494,1.42111,-2.01853,0.255841,1.37203,-2.07575,0.282557,1.0927,-1.75266,0.161798,1.04527,-1.80211,0.197447,0.968693,-1.82434,0.312954,0.884155,-1.8069,0.292562,0.692038,-1.81346,0.277152,0.620597,-1.83159,0.183151,0.716724,-1.81912,0.168606,0.647861,-1.83293,0.161956,0.425633,-1.87362,0.048198,0.364337,-1.94608,0.308791,0.384575,-1.91736,0.285024,0.334936,-1.84352,0.305034,1.08755,-2.13542,0.338907,1.01048,-2.12205,0.175574,1.03106,-2.10021,0.210561,0.957362,-2.0871,0.29478,0.850664,-2.0957,0.132309,0.802526,-2.08575,0.140258,0.913737,-2.10416,0.07075,0.914213,-2.09694,-0.157977,0.895585,-2.07243,-0.229138,0.983476,-2.01518,-0.233462,0.70235,-2.03987,-0.277625,0.752216,-2.09961,0.163461,1.29645,-1.82929,0.176287,1.28114,-2.04359},
/*1505*/{0.262205,1.83791,-1.7301,0.344688,1.78118,-1.87984,0.146309,1.69805,-1.65098,0.058558,1.60205,-1.6005,0.208254,1.54198,-1.62223,0.285927,1.50287,-1.61451,0.289909,1.86165,-2.13126,0.357797,1.78754,-1.95669,0.150958,1.8396,-2.04221,0.106021,1.6613,-2.20791,0.12807,1.56807,-2.24997,0.27834,1.45084,-2.18434,0.323043,1.40296,-2.19587,0.23408,1.3878,-1.80982,0.04653,1.43301,-1.90609,0.055931,1.45757,-1.96068,0.057047,1.42128,-2.01952,0.254553,1.3713,-2.07617,0.278769,1.08872,-1.75063,0.155752,1.04284,-1.80089,0.189262,0.967579,-1.8221,0.300659,0.879895,-1.80514,0.277799,0.688282,-1.81321,0.258645,0.617214,-1.83079,0.168839,0.716824,-1.81926,0.152817,0.646983,-1.83336,0.141331,0.425539,-1.87281,0.027018,0.364473,-1.94545,0.286247,0.384465,-1.91651,0.262375,0.335702,-1.84399,0.314208,1.09117,-2.13496,0.349227,1.01672,-2.12254,0.184681,1.0333,-2.10308,0.222895,0.958429,-2.08877,0.312116,0.855331,-2.09434,0.148903,0.801207,-2.084,0.155666,0.913569,-2.10482,0.085782,0.914121,-2.09858,-0.147704,0.89222,-2.07638,-0.221494,0.975518,-2.0163,-0.210761,0.694651,-2.04054,-0.255663,0.741315,-2.10104,0.160927,1.29595,-1.82957,0.175042,1.28055,-2.04379},
/*1506*/{0.263823,1.83741,-1.7309,0.344802,1.78078,-1.88118,0.151623,1.69729,-1.64893,0.069291,1.59898,-1.59581,0.220271,1.5431,-1.62007,0.298406,1.50611,-1.61447,0.289261,1.86126,-2.13216,0.354647,1.78671,-1.95834,0.150932,1.83935,-2.0441,0.100566,1.66526,-2.20482,0.119747,1.56998,-2.24918,0.269792,1.45082,-2.18725,0.313147,1.40085,-2.19857,0.23164,1.38789,-1.80871,0.045262,1.43351,-1.90625,0.055293,1.45731,-1.96112,0.055638,1.4221,-2.01984,0.253763,1.37131,-2.07641,0.271253,1.08566,-1.75132,0.147888,1.04202,-1.79961,0.178824,0.96544,-1.82294,0.286652,0.875262,-1.80376,0.262732,0.684902,-1.81219,0.242006,0.613712,-1.8307,0.154108,0.714432,-1.81933,0.136155,0.645781,-1.83371,0.119132,0.42634,-1.87211,0.005688,0.364856,-1.94507,0.265487,0.383953,-1.91722,0.241351,0.33513,-1.84214,0.32057,1.09822,-2.13614,0.36009,1.02276,-2.12196,0.194495,1.03374,-2.10505,0.23385,0.962772,-2.09093,0.328717,0.861245,-2.09496,0.165648,0.801567,-2.08372,0.169564,0.913674,-2.10534,0.100107,0.911742,-2.09865,-0.129484,0.882827,-2.07468,-0.211245,0.965635,-2.01953,-0.18798,0.685186,-2.03993,-0.233623,0.730162,-2.10327,0.158804,1.29603,-1.82952,0.173847,1.28074,-2.04368},
/*1507*/{0.265875,1.83766,-1.73165,0.344945,1.78029,-1.88175,0.156912,1.69717,-1.64741,0.079876,1.59657,-1.59154,0.231095,1.54515,-1.6192,0.311695,1.51039,-1.61453,0.288084,1.86099,-2.13282,0.353608,1.78642,-1.95912,0.150174,1.83915,-2.04448,0.095867,1.67044,-2.20164,0.111479,1.57305,-2.24835,0.261773,1.4502,-2.18966,0.302692,1.39986,-2.20143,0.229937,1.38755,-1.80852,0.04441,1.43317,-1.90629,0.05318,1.45661,-1.96129,0.05527,1.42238,-2.01879,0.252589,1.37247,-2.07646,0.263745,1.08237,-1.7513,0.139448,1.0411,-1.79985,0.168028,0.964379,-1.82034,0.272871,0.870645,-1.80349,0.245912,0.680866,-1.81176,0.225862,0.610107,-1.83037,0.138295,0.713458,-1.82039,0.118602,0.644664,-1.83422,0.099467,0.426583,-1.87224,-0.015078,0.365564,-1.94453,0.244883,0.383552,-1.91419,0.219396,0.334567,-1.84288,0.327927,1.10431,-2.13641,0.369955,1.02993,-2.12126,0.204808,1.0353,-2.10593,0.246887,0.965905,-2.09237,0.343859,0.86659,-2.0951,0.182785,0.8026,-2.08387,0.183388,0.914679,-2.10576,0.113455,0.912214,-2.09912,-0.113691,0.874262,-2.07472,-0.201866,0.954301,-2.02052,-0.161424,0.675365,-2.04147,-0.212388,0.718142,-2.10471,0.157822,1.29551,-1.82989,0.173226,1.28139,-2.04411},
/*1508*/{0.267712,1.83841,-1.73251,0.342965,1.78123,-1.88351,0.162061,1.69776,-1.6462,0.088681,1.59436,-1.58724,0.242386,1.54842,-1.61787,0.324873,1.51613,-1.61502,0.286821,1.8614,-2.13395,0.353134,1.78643,-1.96034,0.14895,1.84037,-2.045,0.08985,1.67557,-2.19917,0.102849,1.57722,-2.24777,0.2526,1.45176,-2.1914,0.292784,1.40139,-2.20327,0.227745,1.38766,-1.80729,0.042433,1.433,-1.90739,0.052055,1.45762,-1.96177,0.054457,1.42364,-2.01864,0.251508,1.37386,-2.07635,0.257079,1.08148,-1.75227,0.130586,1.04385,-1.79961,0.158707,0.964737,-1.82191,0.257296,0.866481,-1.8037,0.229311,0.677754,-1.81252,0.207122,0.606794,-1.83094,0.122244,0.710356,-1.8209,0.101632,0.643813,-1.83378,0.078672,0.426204,-1.87137,-0.035687,0.365828,-1.94432,0.223899,0.384064,-1.91447,0.198644,0.334793,-1.84281,0.336087,1.11118,-2.13638,0.380509,1.03821,-2.12136,0.215125,1.03749,-2.10696,0.259113,0.968951,-2.09328,0.359556,0.8728,-2.09552,0.199166,0.803972,-2.08411,0.196797,0.916576,-2.10678,0.126998,0.911551,-2.1002,-0.103918,0.868766,-2.07888,-0.192177,0.941353,-2.02206,-0.137078,0.665279,-2.04207,-0.187602,0.705047,-2.10705,0.155634,1.29556,-1.83037,0.172413,1.28262,-2.04456},
/*1509*/{0.269437,1.84088,-1.73381,0.344362,1.78228,-1.88479,0.167072,1.69887,-1.64544,0.098278,1.59412,-1.5837,0.253491,1.55205,-1.61701,0.336936,1.52273,-1.61677,0.284797,1.86207,-2.1343,0.352913,1.78709,-1.96164,0.147608,1.84148,-2.04516,0.083844,1.67986,-2.19635,0.095211,1.58203,-2.24727,0.243845,1.45388,-2.19205,0.282251,1.40319,-2.20404,0.227116,1.38847,-1.80731,0.042275,1.43361,-1.90813,0.051871,1.45804,-1.9615,0.053744,1.42389,-2.01852,0.25124,1.37564,-2.07639,0.248836,1.08009,-1.75283,0.122554,1.04449,-1.79935,0.14573,0.964653,-1.82294,0.242726,0.861317,-1.80341,0.212572,0.674929,-1.81297,0.191636,0.605925,-1.83169,0.10479,0.709238,-1.82104,0.084785,0.641407,-1.83465,0.057457,0.426524,-1.87161,-0.056419,0.366577,-1.94462,0.202889,0.3832,-1.91522,0.177808,0.335258,-1.8419,0.342957,1.11808,-2.13545,0.389823,1.04798,-2.12097,0.224638,1.04078,-2.10771,0.270904,0.974709,-2.09359,0.373272,0.879406,-2.09553,0.216263,0.806182,-2.08442,0.210123,0.919037,-2.10729,0.139873,0.91101,-2.10087,-0.085567,0.857661,-2.07647,-0.182574,0.928278,-2.02422,-0.111685,0.655113,-2.04369,-0.163,0.69181,-2.1092,0.155644,1.2962,-1.83068,0.17264,1.28378,-2.04489},
/*1510*/{0.271532,1.84266,-1.73516,0.343187,1.7836,-1.88624,0.17222,1.70066,-1.64405,0.108377,1.59432,-1.58114,0.263651,1.55722,-1.61701,0.348254,1.53023,-1.61826,0.282592,1.86369,-2.13596,0.35183,1.78857,-1.96338,0.147257,1.8424,-2.04489,0.077149,1.68636,-2.19497,0.087142,1.58804,-2.24649,0.235485,1.45819,-2.19328,0.272664,1.40618,-2.20434,0.224844,1.38862,-1.80581,0.042003,1.43571,-1.90837,0.051376,1.45947,-1.9617,0.052987,1.42556,-2.01973,0.250826,1.37813,-2.07589,0.239621,1.07728,-1.75351,0.113005,1.04631,-1.79997,0.135375,0.96457,-1.82235,0.22642,0.857492,-1.80403,0.194903,0.67242,-1.81347,0.172115,0.602374,-1.83334,0.088755,0.707554,-1.82229,0.066286,0.640159,-1.83566,0.03882,0.426415,-1.87198,-0.076818,0.367208,-1.9449,0.182289,0.383398,-1.91472,0.156576,0.335488,-1.842,0.349629,1.12683,-2.13559,0.39866,1.05777,-2.12033,0.233507,1.0452,-2.10911,0.281819,0.980164,-2.09463,0.387285,0.8871,-2.09562,0.232831,0.808633,-2.08447,0.221813,0.921787,-2.10802,0.153505,0.908823,-2.10196,-0.075587,0.850278,-2.08212,-0.171565,0.91248,-2.02455,-0.085407,0.644238,-2.04597,-0.137924,0.679099,-2.11108,0.15357,1.2969,-1.83116,0.172183,1.28582,-2.0453},
/*1511*/{0.274066,1.84574,-1.73649,0.343635,1.78551,-1.8874,0.177943,1.70289,-1.64342,0.117261,1.59466,-1.57755,0.273435,1.5628,-1.61678,0.359071,1.53896,-1.61995,0.280328,1.86542,-2.13637,0.350699,1.79045,-1.96507,0.145998,1.84493,-2.04494,0.070815,1.69226,-2.19449,0.07899,1.59405,-2.24588,0.226746,1.46327,-2.19314,0.262565,1.41112,-2.2049,0.224076,1.38943,-1.8058,0.041112,1.43656,-1.90862,0.050767,1.46128,-1.96175,0.052152,1.42705,-2.01937,0.250552,1.38046,-2.07585,0.231982,1.07586,-1.75518,0.102469,1.0467,-1.80011,0.124493,0.96644,-1.82279,0.207119,0.855377,-1.80498,0.17884,0.671131,-1.8154,0.155026,0.601932,-1.83378,0.071831,0.707769,-1.8233,0.050339,0.64071,-1.83636,0.018129,0.427713,-1.87259,-0.097719,0.367814,-1.94456,0.161008,0.382521,-1.91463,0.137302,0.33634,-1.84068,0.355813,1.13489,-2.13526,0.406698,1.06761,-2.12012,0.242314,1.05001,-2.10898,0.293109,0.986553,-2.09439,0.401785,0.896901,-2.09595,0.248433,0.811925,-2.08506,0.233358,0.923736,-2.10643,0.165012,0.910298,-2.10226,-0.0572,0.837854,-2.07888,-0.161749,0.896484,-2.02637,-0.058883,0.633776,-2.04745,-0.112301,0.66551,-2.11362,0.152921,1.29776,-1.83173,0.171888,1.28785,-2.0459},
/*1512*/{0.276185,1.84891,-1.73767,0.343068,1.78773,-1.88873,0.183428,1.70508,-1.6427,0.126143,1.59662,-1.57597,0.282471,1.56864,-1.61746,0.368738,1.54829,-1.62264,0.277192,1.8679,-2.13747,0.350483,1.79234,-1.96656,0.144589,1.84633,-2.04463,0.064462,1.69834,-2.19403,0.071087,1.60005,-2.2455,0.217591,1.46911,-2.19268,0.253334,1.41598,-2.20428,0.224194,1.38993,-1.80617,0.040929,1.4381,-1.90837,0.050963,1.46245,-1.96213,0.052361,1.42906,-2.02026,0.250487,1.38216,-2.07513,0.221314,1.07444,-1.75659,0.095127,1.05047,-1.80023,0.112166,0.968446,-1.82316,0.18849,0.854265,-1.80628,0.162486,0.670716,-1.81669,0.136058,0.601053,-1.83513,0.055907,0.708647,-1.82426,0.034175,0.642518,-1.83719,-0.001664,0.42809,-1.87203,-0.118062,0.368593,-1.94475,0.140367,0.382784,-1.91512,0.115155,0.336468,-1.84218,0.361584,1.14437,-2.13415,0.413911,1.07811,-2.11952,0.250106,1.05527,-2.10893,0.302498,0.993508,-2.09451,0.414962,0.906909,-2.09582,0.26471,0.815499,-2.08561,0.244657,0.926017,-2.10752,0.176029,0.910332,-2.10377,-0.045422,0.828492,-2.08127,-0.150224,0.879138,-2.02541,-0.031601,0.62381,-2.05056,-0.087246,0.652693,-2.11591,0.152486,1.2986,-1.83229,0.171888,1.28951,-2.04646},
/*1513*/{0.277638,1.85291,-1.73947,0.343738,1.79078,-1.89076,0.190035,1.70803,-1.64206,0.13622,1.5987,-1.57383,0.291193,1.57623,-1.61884,0.378012,1.55816,-1.62531,0.274958,1.87119,-2.13846,0.349684,1.79519,-1.96822,0.143585,1.8488,-2.04362,0.057868,1.70383,-2.19323,0.06347,1.60611,-2.24514,0.209504,1.47496,-2.19244,0.243679,1.42234,-2.20369,0.223964,1.39082,-1.80507,0.04122,1.43947,-1.90883,0.051419,1.46458,-1.96119,0.052353,1.43095,-2.02073,0.250499,1.38479,-2.07458,0.21381,1.07434,-1.75974,0.084974,1.05073,-1.80036,0.100541,0.969935,-1.82315,0.17095,0.854372,-1.80876,0.144839,0.670942,-1.81826,0.119657,0.602439,-1.83688,0.039143,0.709926,-1.82551,0.016034,0.64502,-1.83759,-0.021929,0.42904,-1.87261,-0.138322,0.370078,-1.94474,0.119866,0.383058,-1.91638,0.094414,0.335678,-1.84242,0.366307,1.15254,-2.13343,0.420625,1.08916,-2.11942,0.257626,1.06104,-2.10923,0.312113,1.00045,-2.09505,0.426371,0.917687,-2.09626,0.280488,0.818958,-2.08639,0.255756,0.926873,-2.10655,0.186653,0.908261,-2.10385,-0.029469,0.816698,-2.08231,-0.138706,0.861389,-2.02603,-0.004249,0.613433,-2.05253,-0.061795,0.639684,-2.11847,0.152184,1.29969,-1.83256,0.172275,1.29181,-2.04671},
/*1514*/{0.280198,1.85679,-1.74081,0.344319,1.79421,-1.89268,0.196437,1.71072,-1.64164,0.143564,1.60156,-1.57164,0.299195,1.58395,-1.62028,0.385829,1.56892,-1.62838,0.271593,1.87453,-2.13946,0.348709,1.79834,-1.97031,0.14145,1.85102,-2.04249,0.052179,1.71042,-2.19338,0.055665,1.61235,-2.24469,0.200141,1.48144,-2.19166,0.235208,1.42906,-2.2029,0.22458,1.39178,-1.80516,0.04174,1.44238,-1.90848,0.051882,1.46684,-1.96032,0.053329,1.43337,-2.02083,0.251428,1.38788,-2.0743,0.206596,1.0741,-1.76062,0.075313,1.05401,-1.80123,0.088376,0.972933,-1.8237,0.152965,0.85567,-1.81071,0.127374,0.672006,-1.81997,0.100429,0.602995,-1.83848,0.02307,0.712776,-1.82624,-0.003815,0.646309,-1.84041,-0.044195,0.433244,-1.87558,-0.159018,0.372352,-1.94396,0.100372,0.382873,-1.91636,0.074654,0.336857,-1.84246,0.371187,1.16146,-2.13367,0.426888,1.09901,-2.11853,0.264428,1.06642,-2.10921,0.320485,1.00761,-2.09455,0.438326,0.929546,-2.09559,0.29533,0.822807,-2.08744,0.263702,0.931502,-2.10821,0.197728,0.90728,-2.10406,-0.011892,0.804263,-2.08131,-0.125644,0.841239,-2.02708,0.022997,0.603285,-2.05559,-0.03477,0.626833,-2.12111,0.152589,1.30118,-1.83307,0.172889,1.29468,-2.04725},
/*1515*/{0.282185,1.86164,-1.74261,0.344894,1.79802,-1.89494,0.202213,1.71395,-1.64171,0.151268,1.60457,-1.57091,0.30629,1.59173,-1.62241,0.393718,1.57892,-1.63225,0.268295,1.87787,-2.1411,0.348534,1.80165,-1.97243,0.140172,1.85322,-2.04157,0.046351,1.71707,-2.19345,0.048543,1.61914,-2.24435,0.191857,1.48841,-2.19077,0.227128,1.43693,-2.20209,0.225507,1.39245,-1.80394,0.042673,1.44473,-1.9088,0.052852,1.46887,-1.95882,0.054369,1.43586,-2.02037,0.252376,1.3909,-2.07317,0.19918,1.0729,-1.76195,0.066748,1.05726,-1.8005,0.077471,0.976618,-1.82448,0.137326,0.858264,-1.81328,0.110809,0.673405,-1.82215,0.082499,0.604695,-1.84014,0.00561,0.714968,-1.82778,-0.020253,0.649192,-1.84019,-0.060434,0.431406,-1.87223,-0.178969,0.374742,-1.94402,0.080312,0.382611,-1.91639,0.054113,0.336957,-1.84205,0.374984,1.1702,-2.13345,0.432223,1.10945,-2.11759,0.270933,1.0722,-2.10864,0.328123,1.01516,-2.09472,0.448985,0.941482,-2.09467,0.310127,0.826891,-2.08819,0.27231,0.933519,-2.10787,0.207316,0.906114,-2.10392,0.006576,0.789508,-2.07974,-0.111974,0.821818,-2.02651,0.051383,0.594764,-2.05951,-0.008718,0.613799,-2.12384,0.153047,1.30238,-1.83309,0.173969,1.29741,-2.04725},
/*1516*/{0.283874,1.86623,-1.74439,0.345278,1.80187,-1.89683,0.209191,1.71775,-1.64162,0.15994,1.6083,-1.56941,0.312952,1.59997,-1.62502,0.400432,1.58925,-1.63722,0.265272,1.88194,-2.14149,0.34828,1.80571,-1.97486,0.137927,1.8557,-2.04109,0.040208,1.72373,-2.19327,0.041139,1.62547,-2.24369,0.184405,1.4968,-2.18972,0.219766,1.44473,-2.2009,0.225961,1.39326,-1.80349,0.044084,1.44682,-1.90849,0.053746,1.47205,-1.95851,0.054375,1.43965,-2.01972,0.253061,1.39441,-2.07237,0.19181,1.07209,-1.76533,0.059982,1.064,-1.80113,0.06582,0.980742,-1.8264,0.125113,0.861417,-1.81614,0.093239,0.675776,-1.8239,0.064287,0.606848,-1.84188,-0.011948,0.716931,-1.82922,-0.038041,0.651423,-1.84107,-0.080397,0.434217,-1.87295,-0.198475,0.378708,-1.94381,0.060003,0.382563,-1.91734,0.03364,0.337338,-1.84278,0.378427,1.17865,-2.13266,0.438142,1.118,-2.11681,0.2765,1.0784,-2.10798,0.335465,1.02313,-2.09421,0.458234,0.954009,-2.09428,0.324765,0.830041,-2.08954,0.280503,0.934554,-2.10725,0.217445,0.903341,-2.1028,0.021123,0.777424,-2.082,-0.097867,0.801396,-2.02597,0.078434,0.584574,-2.06218,0.018102,0.601181,-2.12728,0.153125,1.30376,-1.83381,0.174398,1.30089,-2.04797},
/*1517*/{0.285878,1.87083,-1.74603,0.345309,1.80607,-1.89902,0.216027,1.72204,-1.64186,0.166857,1.61268,-1.56897,0.318332,1.60808,-1.62703,0.406508,1.59966,-1.64189,0.261531,1.88619,-2.14257,0.347726,1.80976,-1.97719,0.137009,1.85849,-2.03925,0.036835,1.73086,-2.19336,0.034875,1.63236,-2.24241,0.177339,1.50515,-2.18836,0.21275,1.45253,-2.19991,0.226853,1.39401,-1.80258,0.044762,1.45004,-1.90761,0.055032,1.47431,-1.95678,0.05595,1.44281,-2.01886,0.253252,1.39785,-2.07125,0.183925,1.07328,-1.76867,0.051414,1.06783,-1.80155,0.056057,0.985719,-1.82604,0.113601,0.863869,-1.818,0.075728,0.678423,-1.82627,0.04592,0.609296,-1.84383,-0.029246,0.71997,-1.83057,-0.055243,0.65491,-1.84295,-0.098473,0.438269,-1.87375,-0.218161,0.384002,-1.94342,0.040039,0.382419,-1.91774,0.012575,0.337412,-1.84284,0.381898,1.18731,-2.13203,0.441961,1.12946,-2.11664,0.282192,1.08522,-2.10788,0.341818,1.03007,-2.093,0.466849,0.965856,-2.09378,0.337734,0.834303,-2.09025,0.287786,0.936136,-2.10699,0.226537,0.901206,-2.10197,0.038186,0.764602,-2.08123,-0.082393,0.78015,-2.026,0.10793,0.575108,-2.06574,0.046249,0.589966,-2.13025,0.153512,1.30523,-1.83376,0.174915,1.3041,-2.04793},
/*1518*/{0.287506,1.87662,-1.74848,0.346482,1.80961,-1.9009,0.221779,1.72652,-1.64221,0.174568,1.61762,-1.56813,0.323522,1.61618,-1.62951,0.411572,1.60956,-1.64447,0.258917,1.89025,-2.14285,0.347182,1.81404,-1.97926,0.135165,1.86165,-2.03864,0.032747,1.7366,-2.19285,0.02798,1.63908,-2.24156,0.169892,1.51331,-2.18648,0.205735,1.46091,-2.19899,0.229004,1.39437,-1.80161,0.046774,1.45378,-1.90551,0.055872,1.47741,-1.95463,0.056828,1.4469,-2.01849,0.254259,1.40194,-2.07005,0.180024,1.07467,-1.77073,0.043588,1.07226,-1.80371,0.045992,0.991283,-1.82597,0.101277,0.866512,-1.82112,0.058561,0.681712,-1.82823,0.029195,0.613583,-1.84483,-0.045097,0.725159,-1.83157,-0.071429,0.659168,-1.84384,-0.118669,0.443436,-1.87329,-0.237261,0.390544,-1.94392,0.020838,0.381677,-1.9181,-0.007249,0.338041,-1.84321,0.385087,1.19582,-2.13137,0.445785,1.1392,-2.11606,0.287147,1.09172,-2.10753,0.347795,1.03848,-2.09464,0.473512,0.97723,-2.09343,0.35073,0.83839,-2.09112,0.295036,0.937043,-2.10633,0.236378,0.898527,-2.10188,0.054342,0.75225,-2.08124,-0.065137,0.759019,-2.02583,0.137681,0.567163,-2.06961,0.074704,0.578924,-2.13349,0.154538,1.30679,-1.83397,0.175494,1.30811,-2.04818},
/*1519*/{0.289631,1.8821,-1.75036,0.346651,1.81423,-1.90335,0.227555,1.73092,-1.64321,0.180096,1.62175,-1.56765,0.328494,1.62484,-1.63288,0.415906,1.62053,-1.65027,0.25606,1.89437,-2.14314,0.347354,1.81785,-1.9817,0.134351,1.86479,-2.03674,0.028569,1.74428,-2.19273,0.021822,1.64646,-2.24036,0.163091,1.52187,-2.18474,0.199261,1.46908,-2.198,0.229992,1.39515,-1.80184,0.048978,1.45635,-1.90487,0.05769,1.48081,-1.95314,0.058155,1.4518,-2.01777,0.254882,1.40572,-2.06929,0.172952,1.0756,-1.77374,0.037841,1.07809,-1.80431,0.034554,0.997467,-1.82845,0.090534,0.870449,-1.82329,0.041975,0.686634,-1.82934,0.011831,0.617651,-1.84573,-0.061787,0.730381,-1.83279,-0.090257,0.66455,-1.84525,-0.136411,0.4474,-1.874,-0.25502,0.397288,-1.94325,0.001036,0.381048,-1.91862,-0.027766,0.339177,-1.84406,0.387317,1.20417,-2.13093,0.449815,1.14869,-2.11469,0.291515,1.09862,-2.10748,0.352825,1.0459,-2.0937,0.479915,0.988054,-2.09282,0.363806,0.842338,-2.0915,0.302462,0.937229,-2.10568,0.24524,0.895554,-2.1007,0.064795,0.737545,-2.08056,-0.048725,0.737583,-2.02536,0.166308,0.559506,-2.07357,0.102358,0.569624,-2.13684,0.155162,1.30822,-1.83498,0.176012,1.31217,-2.04917},
/*1520*/{0.291406,1.88803,-1.75218,0.348282,1.8199,-1.90595,0.232085,1.73618,-1.64369,0.187779,1.62741,-1.56644,0.332108,1.63295,-1.6348,0.42022,1.63006,-1.65399,0.252905,1.89827,-2.14366,0.346331,1.82291,-1.98396,0.133519,1.8682,-2.03568,0.023207,1.7521,-2.19362,0.015853,1.65329,-2.23852,0.156858,1.53003,-2.18281,0.193838,1.47738,-2.19717,0.232868,1.3953,-1.80131,0.051414,1.46006,-1.90356,0.058932,1.48458,-1.95107,0.059778,1.45644,-2.01794,0.255438,1.41057,-2.06851,0.168192,1.07787,-1.7764,0.031749,1.08474,-1.80474,0.026939,1.00419,-1.82993,0.075433,0.875529,-1.82506,0.02593,0.692285,-1.82999,-0.004424,0.623905,-1.84642,-0.078518,0.73649,-1.83352,-0.105237,0.671696,-1.84447,-0.153259,0.452324,-1.87325,-0.272877,0.405245,-1.94375,-0.018111,0.379873,-1.91942,-0.048168,0.339325,-1.84461,0.39032,1.21237,-2.13002,0.452871,1.15817,-2.11365,0.295465,1.10557,-2.10758,0.358015,1.0533,-2.09239,0.485206,0.998643,-2.09105,0.375298,0.845793,-2.09177,0.308683,0.936175,-2.10432,0.253895,0.89203,-2.10035,0.09129,0.726247,-2.08069,-0.029898,0.716576,-2.02406,0.195652,0.552665,-2.07736,0.131058,0.559536,-2.14014,0.156542,1.30981,-1.83612,0.176796,1.31688,-2.05028},
/*1521*/{0.292636,1.89368,-1.7546,0.348305,1.82441,-1.90852,0.236326,1.74191,-1.64407,0.19249,1.63257,-1.56616,0.335775,1.64135,-1.63833,0.423076,1.63944,-1.6588,0.250487,1.90263,-2.14364,0.345503,1.82707,-1.98609,0.132147,1.87187,-2.03538,0.019682,1.7589,-2.19282,0.011055,1.66067,-2.23755,0.150491,1.53835,-2.18154,0.188783,1.48587,-2.19573,0.234314,1.39595,-1.80236,0.053027,1.46416,-1.90222,0.060129,1.48836,-1.94917,0.06203,1.4613,-2.01783,0.256074,1.41508,-2.06814,0.161414,1.07967,-1.77849,0.026094,1.09121,-1.80422,0.018456,1.01088,-1.83121,0.059803,0.881291,-1.82447,0.009669,0.698185,-1.83115,-0.021692,0.629847,-1.84719,-0.093374,0.743347,-1.83502,-0.122649,0.6785,-1.84616,-0.170341,0.458493,-1.87406,-0.290857,0.414693,-1.9435,-0.037601,0.379014,-1.92025,-0.069651,0.339773,-1.84616,0.393077,1.22038,-2.12935,0.45675,1.16667,-2.11132,0.298491,1.11295,-2.10748,0.361683,1.06181,-2.09164,0.487967,1.00779,-2.09139,0.386518,0.848762,-2.09287,0.314337,0.935164,-2.10381,0.263647,0.887617,-2.09942,0.106476,0.712765,-2.08132,-0.010665,0.694711,-2.02362,0.224861,0.546643,-2.08116,0.159696,0.551089,-2.14348,0.157253,1.31159,-1.83756,0.17709,1.32162,-2.05165},
/*1522*/{0.294077,1.89857,-1.75618,0.348307,1.82927,-1.91102,0.240888,1.74723,-1.64434,0.196895,1.63815,-1.5657,0.338947,1.64903,-1.64006,0.425751,1.6491,-1.66262,0.248083,1.90652,-2.14446,0.345033,1.83198,-1.9878,0.131334,1.87547,-2.03455,0.014895,1.76483,-2.19182,0.005436,1.66806,-2.23585,0.145201,1.54488,-2.17882,0.182946,1.49353,-2.19502,0.23677,1.39656,-1.80338,0.055117,1.4674,-1.90149,0.061169,1.49214,-1.94783,0.063403,1.46671,-2.01625,0.257205,1.41996,-2.0673,0.157301,1.08101,-1.78307,0.022425,1.09841,-1.80399,0.011202,1.01754,-1.8292,0.045208,0.887836,-1.82515,-0.005704,0.70459,-1.83002,-0.038142,0.636174,-1.84695,-0.107866,0.751051,-1.83539,-0.1371,0.686603,-1.84636,-0.186791,0.462844,-1.87302,-0.307409,0.424477,-1.94376,-0.055089,0.37854,-1.9203,-0.089346,0.340639,-1.84569,0.395314,1.2281,-2.12874,0.458778,1.17457,-2.11056,0.301724,1.12025,-2.10747,0.364967,1.06886,-2.09047,0.490015,1.01681,-2.09094,0.397185,0.851823,-2.09355,0.320646,0.935405,-2.103,0.271633,0.88248,-2.09812,0.124923,0.699404,-2.08094,0.011856,0.672989,-2.02141,0.254532,0.542296,-2.08438,0.188719,0.543227,-2.14668,0.158626,1.31326,-1.83916,0.177875,1.32675,-2.05311},
/*1523*/{0.296007,1.90469,-1.75832,0.34895,1.83398,-1.91329,0.244296,1.75295,-1.64529,0.201523,1.64418,-1.56561,0.341394,1.6579,-1.64326,0.4279,1.65819,-1.66702,0.246167,1.91035,-2.14474,0.344568,1.83653,-1.98963,0.12995,1.87903,-2.0338,0.012522,1.77012,-2.19011,0.001085,1.67443,-2.23439,0.14036,1.55301,-2.17723,0.178752,1.5014,-2.19435,0.238798,1.39732,-1.80425,0.057736,1.4723,-1.89974,0.063325,1.49909,-1.94681,0.064376,1.47223,-2.01562,0.25898,1.42578,-2.06709,0.1515,1.08414,-1.78351,0.017763,1.10513,-1.8044,0.004028,1.02608,-1.83047,0.031876,0.895565,-1.82504,-0.020295,0.712215,-1.8297,-0.051926,0.644044,-1.84615,-0.121664,0.759242,-1.83574,-0.15027,0.69441,-1.8465,-0.202665,0.468791,-1.87239,-0.322844,0.435916,-1.9448,-0.07423,0.377103,-1.9205,-0.110108,0.341274,-1.84706,0.39675,1.23521,-2.12758,0.46097,1.18259,-2.10921,0.304289,1.12739,-2.10766,0.367499,1.07596,-2.08967,0.491111,1.02557,-2.09011,0.407218,0.853709,-2.09403,0.325875,0.931498,-2.10156,0.280069,0.877225,-2.09698,0.148728,0.686139,-2.08006,0.031194,0.651644,-2.02279,0.283931,0.538108,-2.08773,0.217779,0.536014,-2.14927,0.159423,1.31598,-1.84102,0.178233,1.33294,-2.05476},
/*1524*/{0.296888,1.90968,-1.76045,0.348676,1.83799,-1.91501,0.247961,1.75874,-1.64584,0.205817,1.64952,-1.56529,0.343678,1.6643,-1.64496,0.429464,1.66632,-1.6707,0.244225,1.91402,-2.14495,0.344064,1.84094,-1.99142,0.129348,1.8828,-2.03332,0.009612,1.77605,-2.18865,-0.003613,1.68116,-2.23253,0.135546,1.56015,-2.17568,0.174636,1.50855,-2.19349,0.240438,1.39859,-1.80528,0.059117,1.47581,-1.89861,0.065259,1.50076,-1.94527,0.066195,1.47791,-2.01446,0.25965,1.43034,-2.06708,0.146627,1.0876,-1.78354,0.016081,1.11454,-1.80481,-0.002319,1.0338,-1.83033,0.019572,0.902565,-1.82385,-0.032433,0.719758,-1.82797,-0.064505,0.652656,-1.8434,-0.135094,0.76716,-1.83668,-0.163574,0.703107,-1.84667,-0.217776,0.475721,-1.87141,-0.338437,0.447891,-1.94502,-0.093481,0.377024,-1.92125,-0.131117,0.342395,-1.84761,0.398123,1.2421,-2.12707,0.46245,1.18938,-2.10714,0.305946,1.13297,-2.10739,0.369001,1.08277,-2.08925,0.489714,1.03186,-2.0907,0.417413,0.85566,-2.09481,0.330749,0.928779,-2.10057,0.288895,0.871669,-2.09666,0.164821,0.671981,-2.07893,0.05424,0.627383,-2.02016,0.312288,0.534909,-2.09022,0.246626,0.529063,-2.15113,0.160813,1.31773,-1.84253,0.178973,1.33772,-2.05606},
/*1525*/{0.298094,1.91471,-1.76207,0.348918,1.84333,-1.91707,0.250505,1.76433,-1.64679,0.209481,1.65473,-1.56515,0.345743,1.67099,-1.64702,0.431049,1.67452,-1.67462,0.242499,1.9174,-2.14641,0.343698,1.84556,-1.99339,0.128738,1.88608,-2.03327,0.007921,1.78101,-2.18664,-0.007281,1.68695,-2.23126,0.131909,1.56689,-2.17395,0.170907,1.51505,-2.19267,0.243388,1.40062,-1.80712,0.062045,1.47949,-1.89711,0.066943,1.50538,-1.9436,0.068755,1.48358,-2.01376,0.259498,1.4363,-2.06736,0.144661,1.09135,-1.7857,0.011756,1.12218,-1.80586,-0.008611,1.04223,-1.83048,0.010364,0.910284,-1.82429,-0.045235,0.727588,-1.82719,-0.078609,0.659738,-1.84259,-0.146752,0.775734,-1.83717,-0.17593,0.711441,-1.84713,-0.232964,0.483309,-1.87184,-0.352318,0.460721,-1.94605,-0.112653,0.376792,-1.92202,-0.152439,0.343283,-1.84846,0.399396,1.24865,-2.12603,0.463173,1.19536,-2.1062,0.307209,1.13964,-2.10874,0.368941,1.08808,-2.09005,0.488338,1.03745,-2.09009,0.427243,0.857022,-2.0962,0.336263,0.925209,-2.09937,0.297946,0.866177,-2.09638,0.184195,0.658335,-2.08066,0.07781,0.607159,-2.01975,0.341984,0.531618,-2.09206,0.274592,0.522014,-2.15299,0.163203,1.32048,-1.84451,0.179621,1.34367,-2.05786},
/*1526*/{0.300209,1.91993,-1.76389,0.34999,1.8482,-1.91904,0.25268,1.76973,-1.64733,0.212848,1.66004,-1.56503,0.347155,1.67826,-1.6501,0.432759,1.68271,-1.67772,0.241504,1.92121,-2.14634,0.342931,1.84971,-1.99481,0.127904,1.89036,-2.03311,0.004937,1.78641,-2.18567,-0.010693,1.69293,-2.22942,0.128955,1.57268,-2.1725,0.167642,1.52145,-2.19231,0.244587,1.40225,-1.80887,0.064389,1.48423,-1.89528,0.068724,1.50972,-1.94193,0.069744,1.48943,-2.01273,0.259825,1.44099,-2.06791,0.142136,1.09439,-1.78743,0.011311,1.12908,-1.80421,-0.012804,1.04966,-1.82903,0.00145,0.917625,-1.82356,-0.056198,0.735535,-1.82582,-0.090157,0.666549,-1.84063,-0.157255,0.784203,-1.83794,-0.187134,0.720421,-1.8474,-0.246311,0.490347,-1.87006,-0.364624,0.475756,-1.94658,-0.131257,0.376605,-1.92199,-0.173191,0.344549,-1.84872,0.400961,1.25401,-2.12512,0.463706,1.20119,-2.10458,0.307789,1.14399,-2.1088,0.369537,1.09364,-2.09008,0.487193,1.04177,-2.09109,0.435571,0.857365,-2.09598,0.34156,0.921035,-2.0986,0.30586,0.860141,-2.09564,0.205563,0.646179,-2.08096,0.102625,0.586232,-2.01961,0.370059,0.529386,-2.09309,0.303997,0.516236,-2.15401,0.163909,1.32321,-1.84606,0.178951,1.34901,-2.05922},
/*1527*/{0.301023,1.92418,-1.76534,0.350132,1.85229,-1.92047,0.253308,1.77518,-1.64803,0.215986,1.66546,-1.56503,0.348695,1.68443,-1.65188,0.433629,1.6899,-1.68191,0.239994,1.92408,-2.147,0.342351,1.85443,-1.99649,0.127486,1.89403,-2.03307,0.003276,1.79171,-2.18324,-0.01438,1.69848,-2.22759,0.126007,1.5788,-2.17147,0.165054,1.52661,-2.1918,0.246884,1.4046,-1.81002,0.065927,1.48822,-1.89415,0.0689,1.51408,-1.9403,0.070889,1.49486,-2.01167,0.260161,1.44631,-2.06802,0.138867,1.09804,-1.78657,0.007245,1.13468,-1.80504,-0.016903,1.05767,-1.83018,-0.004646,0.924758,-1.82338,-0.065809,0.742929,-1.82409,-0.099385,0.676269,-1.83788,-0.166224,0.792018,-1.83869,-0.196859,0.728907,-1.84739,-0.25988,0.497859,-1.86869,-0.376019,0.490941,-1.94784,-0.150167,0.377523,-1.92144,-0.194912,0.345273,-1.84996,0.401687,1.25903,-2.12331,0.463881,1.20498,-2.10282,0.307053,1.14954,-2.10993,0.369517,1.09768,-2.0915,0.485312,1.04409,-2.09135,0.443818,0.857508,-2.09731,0.347294,0.915549,-2.09807,0.314846,0.852483,-2.09416,0.226898,0.633179,-2.08101,0.126303,0.567498,-2.02081,0.39741,0.527209,-2.09357,0.332576,0.510273,-2.15412,0.165349,1.32629,-1.84738,0.179107,1.35458,-2.06031},
/*1528*/{0.302387,1.92834,-1.76655,0.35047,1.85626,-1.92201,0.255818,1.78038,-1.64864,0.217763,1.67011,-1.56447,0.350438,1.69023,-1.65405,0.433994,1.69761,-1.6871,0.238452,1.92726,-2.14719,0.342261,1.85808,-1.99655,0.127146,1.89685,-2.03326,0.001611,1.79576,-2.18123,-0.017118,1.70352,-2.22627,0.124792,1.58305,-2.17084,0.163242,1.53183,-2.19135,0.247969,1.40686,-1.81168,0.067159,1.49262,-1.89323,0.069256,1.51847,-1.93898,0.072743,1.50063,-2.01136,0.260723,1.45111,-2.06853,0.135461,1.10132,-1.78612,0.005158,1.14154,-1.80445,-0.020822,1.06423,-1.83037,-0.010685,0.931169,-1.82283,-0.074819,0.751255,-1.8224,-0.108648,0.684404,-1.83527,-0.174743,0.801991,-1.83875,-0.204779,0.737935,-1.84767,-0.270879,0.506022,-1.86693,-0.385838,0.506928,-1.94835,-0.168131,0.378427,-1.92067,-0.216256,0.347405,-1.8504,0.40122,1.26285,-2.12212,0.463447,1.2086,-2.10096,0.306514,1.15373,-2.11072,0.369948,1.10095,-2.09345,0.483664,1.04614,-2.09182,0.452017,0.857135,-2.09853,0.351417,0.909714,-2.09774,0.322837,0.845156,-2.09394,0.246437,0.620823,-2.08398,0.152308,0.54769,-2.02021,0.424183,0.52499,-2.09303,0.361754,0.504135,-2.15415,0.165824,1.32934,-1.84908,0.17898,1.36004,-2.06171},
/*1529*/{0.30387,1.93285,-1.76731,0.35161,1.86115,-1.92318,0.257315,1.78526,-1.64919,0.220384,1.67517,-1.56474,0.350417,1.69607,-1.6568,0.434641,1.70341,-1.68876,0.23741,1.93006,-2.14734,0.341993,1.86255,-1.99852,0.12647,1.90037,-2.0334,4.8e-005,1.79984,-2.18001,-0.01916,1.70824,-2.2241,0.122449,1.58822,-2.17028,0.161514,1.53633,-2.1908,0.25043,1.40967,-1.81205,0.06845,1.49719,-1.89197,0.071575,1.52275,-1.93889,0.073821,1.50586,-2.00994,0.260811,1.45543,-2.0686,0.133042,1.10572,-1.78485,0.003802,1.14905,-1.80443,-0.022667,1.07036,-1.83001,-0.014911,0.937752,-1.82176,-0.081721,0.758275,-1.82014,-0.115641,0.691518,-1.83228,-0.181325,0.809362,-1.83879,-0.21299,0.745296,-1.84827,-0.282217,0.514013,-1.86569,-0.393543,0.522668,-1.94738,-0.185797,0.380079,-1.91978,-0.237306,0.350676,-1.8509,0.401118,1.26592,-2.12068,0.4626,1.21062,-2.10028,0.305445,1.15794,-2.1119,0.366467,1.10611,-2.09659,0.481805,1.0472,-2.09277,0.458664,0.855941,-2.09937,0.355437,0.903785,-2.09834,0.331016,0.837348,-2.09384,0.268407,0.608721,-2.08266,0.176154,0.531801,-2.02284,0.450891,0.523246,-2.0918,0.388956,0.497612,-2.15335,0.167086,1.33301,-1.84945,0.179035,1.36466,-2.06201},
/*1530*/{0.304611,1.93573,-1.76917,0.351313,1.86511,-1.92499,0.257995,1.79061,-1.6501,0.221978,1.67889,-1.56424,0.351366,1.70038,-1.65838,0.435348,1.70876,-1.69236,0.236606,1.93289,-2.148,0.342485,1.86611,-1.99917,0.125958,1.90302,-2.03318,-0.000468,1.80457,-2.17715,-0.020711,1.71214,-2.22275,0.121312,1.59211,-2.16988,0.160902,1.54038,-2.19082,0.250601,1.41296,-1.81365,0.070063,1.50105,-1.89099,0.072939,1.52635,-1.93759,0.074146,1.51074,-2.00847,0.26194,1.4603,-2.06848,0.131157,1.10964,-1.78247,0.002601,1.15386,-1.80564,-0.025242,1.07608,-1.82936,-0.017645,0.94323,-1.82176,-0.087641,0.764756,-1.81904,-0.122931,0.698443,-1.83154,-0.186239,0.817083,-1.83905,-0.218189,0.754047,-1.84706,-0.293424,0.523184,-1.86431,-0.401271,0.542014,-1.94813,-0.203314,0.381932,-1.91858,-0.258834,0.355242,-1.85155,0.400946,1.26879,-2.11916,0.461491,1.21184,-2.09933,0.304245,1.16156,-2.11318,0.363976,1.10818,-2.09834,0.479943,1.04744,-2.09354,0.46536,0.854762,-2.1003,0.360768,0.896214,-2.09857,0.338632,0.828406,-2.09439,0.289536,0.596387,-2.08322,0.200648,0.515028,-2.02495,0.476521,0.521296,-2.09005,0.417231,0.492118,-2.1523,0.168046,1.3362,-1.8504,0.179431,1.36979,-2.0627},
/*1531*/{0.305216,1.93919,-1.77049,0.351689,1.86932,-1.92574,0.25875,1.79447,-1.65048,0.224231,1.68337,-1.56416,0.35154,1.70423,-1.66016,0.434744,1.71323,-1.69708,0.236354,1.93596,-2.14848,0.342203,1.87001,-2.0003,0.128795,1.90395,-2.0325,-0.000278,1.80791,-2.17547,-0.022168,1.71603,-2.22136,0.120982,1.59525,-2.16976,0.160915,1.54293,-2.19015,0.252101,1.41625,-1.81405,0.071628,1.50488,-1.89089,0.072632,1.53106,-1.93788,0.075025,1.51494,-2.00831,0.262358,1.46445,-2.06828,0.129185,1.11442,-1.7804,0.0022,1.15765,-1.80461,-0.026437,1.07964,-1.8302,-0.019875,0.947676,-1.82123,-0.092137,0.770722,-1.8172,-0.129425,0.704721,-1.82903,-0.188977,0.82448,-1.83767,-0.223766,0.760741,-1.84766,-0.300305,0.533172,-1.86267,-0.406673,0.560017,-1.94584,-0.221849,0.384502,-1.91829,-0.279128,0.36165,-1.85319,0.399781,1.27047,-2.11833,0.460407,1.21311,-2.0995,0.301278,1.16422,-2.11404,0.361462,1.10986,-2.09914,0.477968,1.04642,-2.09542,0.471913,0.852244,-2.1017,0.364967,0.887926,-2.09897,0.346224,0.820434,-2.0952,0.309541,0.58443,-2.0844,0.224693,0.499665,-2.02702,0.501254,0.519737,-2.08832,0.444271,0.486462,-2.15069,0.168877,1.33999,-1.85084,0.179893,1.37407,-2.06307},
/*1532*/{0.305929,1.94274,-1.77116,0.352033,1.87363,-1.92671,0.259726,1.7987,-1.65078,0.225438,1.68669,-1.56399,0.351485,1.70878,-1.662,0.434906,1.71796,-1.69971,0.23583,1.93825,-2.14875,0.343285,1.87367,-2.0009,0.129248,1.90687,-2.03294,-0.000981,1.81106,-2.17345,-0.024,1.71916,-2.21988,0.120292,1.59831,-2.16979,0.15968,1.54709,-2.19032,0.25273,1.41927,-1.81436,0.072473,1.50914,-1.89048,0.074217,1.53466,-1.93728,0.07823,1.51809,-2.00582,0.262898,1.46818,-2.06788,0.127103,1.11844,-1.77792,-0.000855,1.16018,-1.80588,-0.026142,1.08315,-1.82977,-0.020368,0.951571,-1.82064,-0.095595,0.77564,-1.81591,-0.132437,0.711991,-1.82726,-0.191152,0.831645,-1.83646,-0.225207,0.76875,-1.84417,-0.312106,0.543017,-1.86094,-0.411634,0.57908,-1.94272,-0.238934,0.389361,-1.91925,-0.299083,0.368807,-1.85498,0.399144,1.27077,-2.11752,0.458135,1.2122,-2.09882,0.299535,1.16659,-2.11446,0.357496,1.11111,-2.10095,0.475741,1.04466,-2.09643,0.477671,0.850056,-2.10329,0.368381,0.88048,-2.1016,0.353413,0.811378,-2.09642,0.330781,0.574353,-2.08534,0.250059,0.48421,-2.02631,0.524808,0.518406,-2.08622,0.471007,0.481238,-2.14758,0.169739,1.34318,-1.85057,0.180652,1.37784,-2.06272},
/*1533*/{0.306327,1.94509,-1.77191,0.352228,1.87627,-1.92684,0.260741,1.8019,-1.65104,0.22652,1.69005,-1.56308,0.351507,1.71188,-1.66314,0.434559,1.72083,-1.70301,0.236314,1.94099,-2.14961,0.343152,1.87647,-2.00209,0.129483,1.90802,-2.03308,0.000187,1.81369,-2.17101,-0.024324,1.72151,-2.2191,0.120229,1.60019,-2.16954,0.159831,1.54958,-2.19062,0.253439,1.42335,-1.81493,0.073261,1.51268,-1.88999,0.07429,1.53805,-1.9371,0.079313,1.5217,-2.00591,0.262782,1.47181,-2.06821,0.125912,1.12259,-1.77629,-0.001566,1.1626,-1.80602,-0.025877,1.08532,-1.83006,-0.018887,0.954649,-1.82087,-0.097426,0.779783,-1.81471,-0.136624,0.716018,-1.82661,-0.191954,0.838037,-1.83492,-0.228969,0.776837,-1.84285,-0.315642,0.553526,-1.85761,-0.416514,0.597788,-1.93859,-0.255429,0.396258,-1.92154,-0.318473,0.376849,-1.85773,0.398303,1.27025,-2.11693,0.456891,1.21,-2.09938,0.296056,1.16768,-2.11459,0.35388,1.11129,-2.10131,0.472803,1.04182,-2.09808,0.482665,0.84686,-2.10469,0.372002,0.871746,-2.10214,0.360034,0.802224,-2.09808,0.347681,0.56306,-2.08574,0.272789,0.471452,-2.02726,0.54722,0.517082,-2.08391,0.496505,0.475612,-2.14609,0.170675,1.34694,-1.85057,0.180913,1.38141,-2.06278},
/*1534*/{0.306465,1.94789,-1.77241,0.352479,1.88112,-1.92856,0.261052,1.80558,-1.65156,0.228693,1.69359,-1.56273,0.351979,1.71398,-1.66514,0.433905,1.72195,-1.70574,0.235799,1.94299,-2.15033,0.343928,1.87928,-2.00238,0.129742,1.91064,-2.03311,-0.000566,1.81555,-2.1695,-0.024122,1.72357,-2.21817,0.121609,1.60302,-2.16905,0.160146,1.55122,-2.19071,0.2536,1.42728,-1.81435,0.073529,1.51605,-1.88955,0.074893,1.54192,-1.93681,0.079358,1.52478,-2.00492,0.263986,1.47459,-2.06772,0.126345,1.12614,-1.77442,-0.001427,1.16511,-1.80666,-0.023382,1.08657,-1.8313,-0.015535,0.956395,-1.81922,-0.099156,0.783491,-1.81385,-0.14141,0.719706,-1.82603,-0.191557,0.845212,-1.83253,-0.229847,0.784084,-1.83948,-0.324568,0.563872,-1.85556,-0.421481,0.615777,-1.93372,-0.272564,0.404866,-1.92402,-0.334781,0.385856,-1.86157,0.396281,1.26842,-2.11664,0.453841,1.20727,-2.09945,0.292791,1.16754,-2.115,0.349189,1.10999,-2.10151,0.468672,1.03863,-2.10017,0.48679,0.844333,-2.10645,0.37529,0.862069,-2.10442,0.367938,0.792549,-2.09935,0.369639,0.555028,-2.08736,0.295936,0.460328,-2.02771,0.569071,0.515954,-2.08177,0.520427,0.471251,-2.14379,0.171027,1.35064,-1.84951,0.181432,1.38442,-2.06183},
/*1535*/{0.306826,1.95053,-1.77348,0.35279,1.88342,-1.92922,0.261673,1.80845,-1.65151,0.227528,1.69648,-1.5625,0.351236,1.71628,-1.667,0.432755,1.72259,-1.70764,0.237057,1.94529,-2.15101,0.344555,1.88163,-2.00387,0.130804,1.91264,-2.03332,-0.000356,1.8173,-2.16899,-0.023841,1.7256,-2.21756,0.121926,1.6037,-2.16869,0.161307,1.5531,-2.19086,0.253638,1.43161,-1.81303,0.074147,1.51911,-1.88889,0.075488,1.54558,-1.93676,0.080456,1.52777,-2.0042,0.264302,1.47702,-2.06699,0.127599,1.12955,-1.77276,0.002805,1.16756,-1.80609,-0.022535,1.08805,-1.8303,-0.012425,0.958157,-1.81902,-0.099226,0.786774,-1.81331,-0.142281,0.725202,-1.82423,-0.19002,0.850962,-1.83,-0.230867,0.791806,-1.83819,-0.333185,0.574317,-1.85503,-0.425825,0.633373,-1.92571,-0.289236,0.415101,-1.92818,-0.352125,0.396874,-1.86466,0.393628,1.2663,-2.11838,0.449825,1.20392,-2.10005,0.288632,1.16673,-2.11494,0.344036,1.10834,-2.10254,0.463831,1.03458,-2.10123,0.489858,0.840724,-2.10744,0.376912,0.853471,-2.10946,0.374334,0.785426,-2.10282,0.388548,0.546246,-2.08853,0.317728,0.448962,-2.02792,0.589374,0.515127,-2.08021,0.54337,0.46638,-2.14063,0.171395,1.35453,-1.84786,0.182004,1.38693,-2.06038},
/*1536*/{0.306716,1.95284,-1.7737,0.352232,1.88599,-1.92979,0.261529,1.81082,-1.6523,0.22902,1.69992,-1.56148,0.351,1.7174,-1.66774,0.431888,1.72292,-1.70962,0.23725,1.9469,-2.1519,0.345767,1.8833,-2.00419,0.13126,1.91537,-2.03403,0.001501,1.81851,-2.16653,-0.022813,1.72624,-2.21697,0.122709,1.60537,-2.16917,0.16249,1.55402,-2.19168,0.254192,1.43576,-1.81336,0.073571,1.52237,-1.88889,0.074912,1.54809,-1.93618,0.080143,1.53014,-2.00437,0.264859,1.47935,-2.06666,0.129506,1.1318,-1.77229,0.001814,1.16761,-1.80697,-0.019439,1.08888,-1.83078,-0.007993,0.958392,-1.81982,-0.098615,0.789347,-1.81329,-0.14409,0.729906,-1.82453,-0.18727,0.857048,-1.8282,-0.22979,0.799536,-1.83429,-0.335807,0.585826,-1.85265,-0.431683,0.651187,-1.91886,-0.305798,0.427201,-1.93227,-0.365538,0.409227,-1.86754,0.392275,1.26246,-2.11728,0.445961,1.19911,-2.10064,0.284392,1.16558,-2.11561,0.338359,1.1054,-2.10343,0.458518,1.02937,-2.10247,0.49408,0.837419,-2.10775,0.380534,0.8443,-2.11255,0.38003,0.773724,-2.1073,0.405509,0.538305,-2.0895,0.338811,0.43935,-2.02865,0.60822,0.515479,-2.07745,0.565374,0.463299,-2.13856,0.172009,1.35808,-1.84697,0.182278,1.38931,-2.05968},
/*1537*/{0.307391,1.95389,-1.77432,0.352603,1.88838,-1.93068,0.261623,1.81314,-1.65225,0.227511,1.70195,-1.56116,0.350187,1.71816,-1.66864,0.430862,1.72322,-1.71204,0.23912,1.94858,-2.1528,0.345309,1.88465,-2.00505,0.132732,1.91691,-2.03421,0.002361,1.81927,-2.16654,-0.021779,1.72726,-2.21694,0.125054,1.60635,-2.16967,0.163597,1.55448,-2.19214,0.254483,1.43923,-1.8118,0.074024,1.52491,-1.88914,0.075215,1.55116,-1.93681,0.081429,1.53252,-2.00446,0.2643,1.4811,-2.06601,0.132182,1.13318,-1.77126,0.005437,1.17061,-1.80743,-0.015491,1.08887,-1.83043,-0.003372,0.958405,-1.8202,-0.09723,0.790986,-1.81341,-0.146022,0.734648,-1.82552,-0.183962,0.862157,-1.82604,-0.22862,0.807525,-1.83186,-0.343448,0.597359,-1.84969,-0.439102,0.667757,-1.91172,-0.318684,0.441059,-1.93606,-0.378382,0.422883,-1.87009,0.389103,1.25837,-2.11796,0.442083,1.19403,-2.10104,0.279151,1.16386,-2.11634,0.332361,1.10254,-2.10394,0.452899,1.02455,-2.10393,0.497149,0.835299,-2.10776,0.382934,0.836701,-2.11644,0.386824,0.765734,-2.11037,0.422803,0.531927,-2.09073,0.35769,0.431405,-2.02906,0.625178,0.514815,-2.07664,0.585572,0.460494,-2.13543,0.172045,1.36143,-1.84558,0.182659,1.39102,-2.05851},
/*1538*/{0.306338,1.95547,-1.77535,0.352183,1.89092,-1.93184,0.260621,1.81525,-1.65339,0.227415,1.70421,-1.56077,0.348347,1.71851,-1.66962,0.429416,1.72202,-1.71425,0.239454,1.94987,-2.15444,0.34582,1.88593,-2.00572,0.133621,1.91823,-2.03736,0.005237,1.81972,-2.16548,-0.019816,1.72751,-2.2172,0.126737,1.60603,-2.17024,0.166149,1.55429,-2.19287,0.254749,1.44246,-1.81135,0.074443,1.52674,-1.8892,0.075109,1.55354,-1.93693,0.081193,1.53421,-2.00316,0.265976,1.48253,-2.065,0.136089,1.13383,-1.77173,0.008757,1.16941,-1.80672,-0.011618,1.08769,-1.83034,0.003355,0.957759,-1.82072,-0.095947,0.793647,-1.8141,-0.146896,0.738107,-1.82667,-0.179862,0.868113,-1.82365,-0.226291,0.81539,-1.82949,-0.349633,0.608875,-1.84966,-0.445731,0.683571,-1.9044,-0.332635,0.455605,-1.94007,-0.389196,0.436358,-1.87204,0.386203,1.2537,-2.11828,0.437506,1.18806,-2.10195,0.274027,1.16131,-2.11661,0.325822,1.09915,-2.10537,0.447087,1.01875,-2.10453,0.499823,0.832093,-2.10633,0.387063,0.828804,-2.12104,0.393322,0.758819,-2.11371,0.437273,0.525959,-2.09101,0.375481,0.423925,-2.03077,0.640086,0.515938,-2.07539,0.603594,0.459259,-2.13403,0.172687,1.36409,-1.8443,0.183668,1.39265,-2.05735},
/*1539*/{0.306601,1.95651,-1.77621,0.350967,1.89206,-1.93224,0.26068,1.81709,-1.65384,0.227144,1.7068,-1.56132,0.346839,1.71805,-1.67049,0.427102,1.72041,-1.71541,0.241279,1.95111,-2.15517,0.346015,1.88723,-2.00598,0.134161,1.92128,-2.03727,0.004959,1.81981,-2.16496,-0.018115,1.72731,-2.21801,0.129877,1.60555,-2.17055,0.1688,1.55391,-2.19387,0.254724,1.44485,-1.81035,0.074019,1.52857,-1.89019,0.075969,1.55584,-1.93611,0.082303,1.53494,-2.00379,0.267095,1.48315,-2.06405,0.141072,1.13561,-1.77245,0.013422,1.16758,-1.80548,-0.006907,1.0867,-1.82942,0.010488,0.956821,-1.82076,-0.094142,0.795301,-1.81417,-0.14749,0.743041,-1.82662,-0.17427,0.873932,-1.82139,-0.223719,0.823172,-1.82767,-0.355151,0.623554,-1.84989,-0.452257,0.700277,-1.89744,-0.344728,0.470333,-1.94304,-0.398188,0.450832,-1.87358,0.382503,1.24823,-2.11952,0.432732,1.18188,-2.10287,0.26852,1.15886,-2.11719,0.319596,1.09543,-2.10535,0.441456,1.0134,-2.10552,0.502082,0.829797,-2.10463,0.390988,0.821906,-2.12462,0.400469,0.751944,-2.11708,0.449536,0.520243,-2.09244,0.390788,0.418267,-2.03161,0.653683,0.517752,-2.07336,0.61997,0.459057,-2.13164,0.172602,1.36626,-1.84306,0.184672,1.39346,-2.05622},
/*1540*/{0.306366,1.95782,-1.77722,0.351999,1.89394,-1.93336,0.259891,1.81876,-1.65461,0.224332,1.70772,-1.56136,0.34599,1.7172,-1.67178,0.425758,1.71842,-1.71728,0.242927,1.95173,-2.15615,0.346061,1.88781,-2.00607,0.1344,1.92283,-2.03885,0.00854,1.81913,-2.16486,-0.015221,1.72712,-2.21876,0.131564,1.60469,-2.17118,0.171654,1.55279,-2.19457,0.25555,1.44742,-1.80877,0.074125,1.52929,-1.88998,0.07565,1.55695,-1.93689,0.082121,1.53647,-2.00457,0.268442,1.48375,-2.06291,0.149164,1.13566,-1.77384,0.017928,1.16572,-1.8055,-0.001133,1.08394,-1.82962,0.017705,0.955038,-1.82145,-0.091881,0.797773,-1.81505,-0.14839,0.747187,-1.8276,-0.168947,0.879971,-1.81946,-0.220642,0.83143,-1.8264,-0.360169,0.637075,-1.84844,-0.456256,0.717957,-1.89164,-0.355735,0.48602,-1.94452,-0.407584,0.466386,-1.87374,0.378794,1.24303,-2.11996,0.427339,1.17538,-2.10394,0.263307,1.15573,-2.11736,0.312275,1.09146,-2.10586,0.436187,1.00794,-2.10661,0.50464,0.827509,-2.10265,0.394803,0.816129,-2.12709,0.405523,0.746602,-2.12008,0.461604,0.516293,-2.09341,0.405971,0.411709,-2.03162,0.666302,0.518614,-2.07175,0.633933,0.458912,-2.13031,0.173192,1.36835,-1.84169,0.186072,1.39413,-2.05499},
/*1541*/{0.305124,1.95831,-1.77824,0.35054,1.89481,-1.93422,0.258364,1.81974,-1.65518,0.222638,1.70933,-1.56211,0.343806,1.71663,-1.67253,0.423551,1.71558,-1.71789,0.243571,1.95206,-2.15695,0.346195,1.88834,-2.00612,0.136428,1.92403,-2.04102,0.009654,1.81883,-2.16441,-0.012091,1.72618,-2.21967,0.13485,1.60303,-2.17178,0.174391,1.55155,-2.19573,0.254316,1.44915,-1.80763,0.074887,1.53024,-1.89029,0.075303,1.55861,-1.93729,0.082218,1.53641,-2.00473,0.269724,1.48427,-2.06161,0.153314,1.1327,-1.77513,0.021601,1.16225,-1.80405,0.004827,1.08175,-1.82815,0.025989,0.952551,-1.82263,-0.090112,0.800475,-1.81509,-0.148246,0.752581,-1.82787,-0.162683,0.885249,-1.81778,-0.216897,0.839724,-1.82401,-0.364563,0.652305,-1.84761,-0.459418,0.735417,-1.88754,-0.366759,0.501613,-1.94505,-0.416678,0.483166,-1.8726,0.374531,1.23705,-2.12019,0.42279,1.1687,-2.1052,0.257625,1.15292,-2.11814,0.305828,1.08698,-2.10588,0.429781,1.00221,-2.10707,0.505787,0.825449,-2.10042,0.396981,0.810992,-2.12854,0.409526,0.74174,-2.12182,0.470796,0.511603,-2.09524,0.417186,0.407702,-2.03467,0.67595,0.520414,-2.07095,0.64713,0.459061,-2.12907,0.172757,1.36984,-1.84049,0.187069,1.39454,-2.05383},
/*1542*/{0.304843,1.95836,-1.77925,0.349626,1.89509,-1.93427,0.257058,1.82059,-1.65569,0.220458,1.71026,-1.56201,0.342317,1.71463,-1.67347,0.421191,1.71236,-1.71933,0.244741,1.95197,-2.15795,0.346096,1.88878,-2.00602,0.136569,1.92498,-2.04254,0.01249,1.81824,-2.16417,-0.009115,1.7245,-2.22164,0.137676,1.60159,-2.17364,0.17712,1.54954,-2.19706,0.254472,1.45089,-1.80607,0.075019,1.53018,-1.89063,0.075381,1.55875,-1.93727,0.082722,1.53582,-2.00468,0.270962,1.48377,-2.06055,0.159108,1.13132,-1.77688,0.027416,1.1583,-1.80334,0.011288,1.07831,-1.82795,0.035237,0.950549,-1.82231,-0.086724,0.802667,-1.81587,-0.147615,0.758229,-1.82789,-0.156383,0.891514,-1.81705,-0.212854,0.848888,-1.82278,-0.368021,0.667088,-1.84533,-0.459295,0.754225,-1.88482,-0.377592,0.517124,-1.94379,-0.426298,0.500274,-1.87042,0.370735,1.23121,-2.12211,0.417345,1.16176,-2.10661,0.252705,1.14899,-2.11674,0.300006,1.08118,-2.10535,0.423716,0.997067,-2.10755,0.505631,0.823917,-2.09962,0.397122,0.806215,-2.1292,0.412366,0.737905,-2.12257,0.480201,0.509154,-2.09655,0.428037,0.402824,-2.03484,0.684002,0.521242,-2.07073,0.656961,0.458295,-2.12813,0.173333,1.37091,-1.83876,0.188482,1.3939,-2.05223},
/*1543*/{0.304106,1.95893,-1.78042,0.348928,1.89547,-1.93457,0.255147,1.82107,-1.65619,0.217828,1.71098,-1.5627,0.338896,1.71255,-1.67447,0.417756,1.70825,-1.72023,0.246845,1.95195,-2.15914,0.346015,1.88959,-2.00639,0.13687,1.92564,-2.04461,0.014833,1.81654,-2.16611,-0.00553,1.72248,-2.22304,0.141441,1.59958,-2.17461,0.180625,1.54758,-2.19867,0.254543,1.45147,-1.80551,0.075485,1.52997,-1.89182,0.075516,1.55859,-1.93777,0.082985,1.53526,-2.00515,0.272601,1.48377,-2.05933,0.166652,1.13011,-1.77768,0.032552,1.15478,-1.80253,0.018171,1.07497,-1.82762,0.043537,0.94713,-1.82334,-0.08426,0.805563,-1.81544,-0.146545,0.763599,-1.82724,-0.148928,0.89722,-1.81613,-0.20772,0.855984,-1.82281,-0.369879,0.682575,-1.84324,-0.457276,0.774398,-1.8836,-0.385043,0.532853,-1.94061,-0.436824,0.519271,-1.86689,0.367749,1.22541,-2.12252,0.412698,1.15556,-2.10767,0.247312,1.14637,-2.11662,0.292658,1.07841,-2.10476,0.417826,0.992184,-2.10734,0.504082,0.822239,-2.09925,0.395805,0.802657,-2.12861,0.412411,0.734447,-2.12222,0.486225,0.505835,-2.09703,0.435307,0.399881,-2.03646,0.690912,0.522376,-2.06956,0.665898,0.457952,-2.1275,0.173732,1.37119,-1.83833,0.190202,1.39368,-2.05175},
/*1544*/{0.30233,1.9587,-1.78089,0.34716,1.89515,-1.93422,0.252964,1.8219,-1.65727,0.214572,1.71151,-1.56326,0.335595,1.71048,-1.67427,0.415001,1.70428,-1.72093,0.247604,1.95095,-2.15932,0.344836,1.88996,-2.00642,0.137781,1.92569,-2.04664,0.018607,1.8145,-2.16647,-0.001879,1.72012,-2.22548,0.144768,1.59743,-2.17682,0.184359,1.54514,-2.20036,0.254459,1.45177,-1.80455,0.075505,1.5298,-1.89215,0.076404,1.55772,-1.93841,0.084522,1.53335,-2.00549,0.275048,1.48267,-2.0582,0.172807,1.12864,-1.77964,0.040191,1.15181,-1.80067,0.025648,1.07043,-1.82688,0.052342,0.94323,-1.82398,-0.081336,0.809392,-1.81507,-0.144483,0.770062,-1.8267,-0.141884,0.904243,-1.81452,-0.201907,0.864112,-1.82185,-0.370507,0.698585,-1.84121,-0.453364,0.793641,-1.88334,-0.392355,0.548745,-1.93649,-0.445526,0.538037,-1.86421,0.364381,1.21976,-2.12303,0.407955,1.14837,-2.10926,0.242567,1.14219,-2.11609,0.287089,1.07408,-2.10463,0.411291,0.98734,-2.10778,0.500652,0.820371,-2.10009,0.392667,0.798713,-2.1268,0.410047,0.731084,-2.12134,0.490239,0.504003,-2.09747,0.441479,0.396791,-2.03678,0.695205,0.522076,-2.06943,0.669877,0.45791,-2.12721,0.174258,1.37114,-1.83712,0.192395,1.39235,-2.05054},
/*1545*/{0.300869,1.95817,-1.7824,0.346922,1.89507,-1.93429,0.250535,1.82214,-1.65743,0.210874,1.71225,-1.56438,0.332508,1.7073,-1.67496,0.411694,1.69975,-1.72099,0.248338,1.94995,-2.15984,0.343785,1.8891,-2.00618,0.137743,1.92458,-2.04827,0.021014,1.81183,-2.16869,0.00178,1.71704,-2.22845,0.14818,1.5945,-2.17867,0.188584,1.54262,-2.20168,0.25501,1.45181,-1.80396,0.075155,1.52844,-1.8929,0.076827,1.55666,-1.93819,0.085206,1.53189,-2.00645,0.275692,1.48092,-2.05714,0.180525,1.12746,-1.78013,0.045723,1.14571,-1.80018,0.033022,1.06499,-1.82557,0.061575,0.939711,-1.82404,-0.076202,0.813682,-1.81464,-0.14212,0.776347,-1.82596,-0.134955,0.909261,-1.81588,-0.195332,0.873029,-1.82402,-0.371483,0.713334,-1.8379,-0.448314,0.813163,-1.88455,-0.399412,0.564426,-1.93161,-0.453948,0.558546,-1.85926,0.361679,1.21403,-2.12434,0.404894,1.1422,-2.11066,0.238692,1.13882,-2.11578,0.282339,1.06956,-2.10415,0.404962,0.982486,-2.10823,0.496526,0.81792,-2.10109,0.388157,0.794259,-2.12558,0.407262,0.72698,-2.11946,0.493514,0.501726,-2.09753,0.446337,0.394243,-2.03636,0.697358,0.521273,-2.06979,0.674667,0.457489,-2.12681,0.174625,1.3707,-1.83616,0.193444,1.39064,-2.04964},
/*1546*/{0.298826,1.9572,-1.78272,0.346388,1.89486,-1.93446,0.247194,1.82172,-1.65769,0.207099,1.71179,-1.56476,0.329113,1.7041,-1.67511,0.408215,1.69399,-1.72039,0.248636,1.94855,-2.16019,0.343255,1.88839,-2.00634,0.137936,1.9241,-2.05086,0.023197,1.8095,-2.17068,0.005705,1.71326,-2.23112,0.151442,1.59103,-2.18154,0.192595,1.53913,-2.20392,0.256298,1.45105,-1.80355,0.075341,1.52757,-1.89394,0.076913,1.55506,-1.93855,0.084897,1.52999,-2.00779,0.276176,1.47959,-2.05682,0.187653,1.12619,-1.78202,0.051482,1.14136,-1.7994,0.039962,1.06109,-1.82653,0.072104,0.936524,-1.8246,-0.07174,0.817951,-1.81373,-0.139083,0.781925,-1.82467,-0.126524,0.915401,-1.8149,-0.189032,0.879686,-1.82204,-0.371449,0.729536,-1.83658,-0.442697,0.831832,-1.88615,-0.404729,0.579803,-1.92542,-0.460417,0.57829,-1.85499,0.35908,1.20909,-2.12558,0.401673,1.13634,-2.11225,0.235682,1.13565,-2.1154,0.277907,1.06626,-2.10392,0.399661,0.978159,-2.10835,0.491244,0.815619,-2.10283,0.38303,0.789533,-2.12443,0.403252,0.722186,-2.1184,0.493439,0.498204,-2.09631,0.447414,0.390339,-2.03559,0.698509,0.520121,-2.06967,0.675229,0.455762,-2.12674,0.17536,1.36998,-1.83587,0.19432,1.38896,-2.04943},
/*1547*/{0.296824,1.95628,-1.78285,0.345492,1.89371,-1.93518,0.244012,1.82152,-1.6583,0.203315,1.71099,-1.56543,0.325015,1.7004,-1.67512,0.404681,1.68851,-1.72009,0.249906,1.94687,-2.16116,0.34309,1.88772,-2.00663,0.137106,1.92429,-2.05264,0.025213,1.80593,-2.17305,0.008944,1.70936,-2.23501,0.156272,1.58734,-2.18433,0.196898,1.53593,-2.2053,0.257427,1.45027,-1.80379,0.075185,1.52595,-1.89403,0.078233,1.5525,-1.93923,0.085743,1.5283,-2.00824,0.276444,1.47729,-2.05676,0.194343,1.12294,-1.78231,0.056929,1.13688,-1.79902,0.047847,1.05667,-1.82545,0.081066,0.932943,-1.82446,-0.067201,0.821337,-1.81345,-0.135018,0.788342,-1.82314,-0.118347,0.920919,-1.81513,-0.180587,0.888626,-1.8219,-0.368767,0.746394,-1.83514,-0.435284,0.848983,-1.88765,-0.407428,0.594674,-1.91989,-0.465944,0.597844,-1.85004,0.357887,1.2046,-2.12683,0.398323,1.13126,-2.1137,0.232589,1.13277,-2.11549,0.273754,1.06322,-2.1041,0.395187,0.97385,-2.10841,0.486291,0.811999,-2.10494,0.37736,0.78458,-2.12289,0.399143,0.717671,-2.11694,0.49267,0.495038,-2.09559,0.447072,0.386587,-2.03447,0.698548,0.517997,-2.06851,0.674099,0.453405,-2.12571,0.176313,1.36879,-1.83543,0.195087,1.38665,-2.0491},
/*1548*/{0.294526,1.95528,-1.78354,0.344373,1.89258,-1.93452,0.240122,1.82125,-1.65878,0.199638,1.7099,-1.56653,0.320354,1.69686,-1.67508,0.400709,1.68276,-1.71945,0.250054,1.94454,-2.16155,0.342308,1.88653,-2.00629,0.136769,1.92223,-2.05499,0.027638,1.8019,-2.17665,0.012816,1.70478,-2.23898,0.159072,1.58333,-2.18745,0.201142,1.53217,-2.20788,0.257225,1.44901,-1.80322,0.076794,1.52343,-1.89521,0.078459,1.55085,-1.94004,0.086602,1.52594,-2.00978,0.277501,1.47439,-2.05716,0.199948,1.12067,-1.78366,0.064282,1.13404,-1.79843,0.056567,1.05224,-1.82586,0.089984,0.930388,-1.82489,-0.062042,0.824996,-1.81236,-0.130173,0.794807,-1.82198,-0.109687,0.926647,-1.81557,-0.174038,0.896024,-1.82103,-0.366094,0.761929,-1.83235,-0.427702,0.866014,-1.8893,-0.410302,0.610225,-1.91444,-0.468247,0.617662,-1.84512,0.356066,1.20054,-2.12834,0.396327,1.12555,-2.11445,0.230201,1.13013,-2.11519,0.270553,1.0601,-2.10373,0.39123,0.969589,-2.10894,0.481331,0.808249,-2.10563,0.37275,0.780651,-2.12225,0.39415,0.713617,-2.11556,0.490437,0.491334,-2.094,0.445415,0.383283,-2.03209,0.695086,0.513789,-2.06854,0.672853,0.449503,-2.12454,0.17657,1.36723,-1.83525,0.196149,1.38389,-2.04895},
/*1549*/{0.291976,1.95374,-1.78353,0.344356,1.89145,-1.93456,0.235489,1.82034,-1.65862,0.194268,1.70881,-1.56731,0.315606,1.69244,-1.67439,0.396657,1.67606,-1.71822,0.249578,1.94194,-2.16188,0.341573,1.88509,-2.00626,0.136422,1.92008,-2.05683,0.029595,1.79652,-2.17983,0.016346,1.69979,-2.24289,0.163731,1.58014,-2.19132,0.205838,1.52817,-2.20965,0.258067,1.44755,-1.80317,0.076962,1.52141,-1.89505,0.0796,1.5477,-1.93971,0.087816,1.52259,-2.00936,0.277561,1.47111,-2.05774,0.207472,1.11975,-1.78378,0.071013,1.1273,-1.79778,0.063927,1.04702,-1.82462,0.098189,0.927527,-1.82474,-0.056244,0.828606,-1.8113,-0.126681,0.800144,-1.82036,-0.100698,0.931877,-1.81784,-0.165489,0.903174,-1.82165,-0.362945,0.776754,-1.83126,-0.420084,0.881248,-1.88997,-0.410123,0.624964,-1.90846,-0.469548,0.636115,-1.83952,0.353712,1.19635,-2.12979,0.39276,1.12169,-2.11661,0.227861,1.12869,-2.1158,0.266991,1.05747,-2.10376,0.3871,0.965873,-2.10914,0.476738,0.804517,-2.10561,0.367862,0.776129,-2.12112,0.389713,0.709381,-2.11478,0.486187,0.487539,-2.09338,0.440415,0.380676,-2.02955,0.690962,0.508876,-2.06804,0.667213,0.444108,-2.12338,0.177691,1.36534,-1.83428,0.196525,1.38049,-2.04815},
/*1550*/{0.289611,1.95239,-1.78335,0.342908,1.88952,-1.93416,0.231842,1.81898,-1.65828,0.189769,1.70809,-1.5691,0.31113,1.68766,-1.67423,0.392274,1.6692,-1.71681,0.250118,1.93959,-2.1624,0.341661,1.88314,-2.00611,0.135661,1.91776,-2.05907,0.031858,1.79189,-2.18367,0.019685,1.69449,-2.24694,0.168095,1.57586,-2.19494,0.210559,1.52434,-2.21143,0.258245,1.44535,-1.80299,0.077243,1.51848,-1.89498,0.080065,1.54526,-1.93987,0.087678,1.51957,-2.01105,0.278311,1.4687,-2.05813,0.214069,1.1163,-1.78363,0.076944,1.12226,-1.79682,0.072237,1.04206,-1.82486,0.106794,0.924811,-1.8243,-0.049741,0.83254,-1.81046,-0.120877,0.806358,-1.81952,-0.090569,0.936642,-1.81877,-0.157269,0.910321,-1.82084,-0.358315,0.793341,-1.83007,-0.41152,0.896388,-1.89229,-0.410025,0.638649,-1.90306,-0.468327,0.653141,-1.83453,0.35197,1.1927,-2.13161,0.390422,1.11796,-2.11736,0.22521,1.12665,-2.11531,0.264592,1.05464,-2.10357,0.385401,0.962542,-2.10923,0.472366,0.800235,-2.10635,0.363244,0.772211,-2.12091,0.384682,0.705485,-2.11376,0.48136,0.483407,-2.0915,0.435288,0.378187,-2.02508,0.686641,0.502679,-2.06681,0.661546,0.436982,-2.12101,0.178188,1.36293,-1.83447,0.197309,1.37787,-2.04833},
/*1551*/{0.287707,1.95017,-1.78289,0.342225,1.88768,-1.93421,0.227968,1.81741,-1.65847,0.184758,1.70642,-1.57047,0.306919,1.68338,-1.6742,0.387915,1.66249,-1.71556,0.250351,1.93625,-2.16258,0.340816,1.88167,-2.00614,0.135549,1.91456,-2.06161,0.033922,1.78589,-2.1875,0.023787,1.68914,-2.2518,0.17257,1.57159,-2.19841,0.215484,1.52,-2.21422,0.259144,1.4431,-1.80345,0.077393,1.51549,-1.89473,0.079805,1.54186,-1.94062,0.087224,1.5164,-2.01088,0.278129,1.46576,-2.05952,0.222281,1.11655,-1.78309,0.084342,1.11954,-1.79643,0.079167,1.03749,-1.82469,0.115297,0.922325,-1.82386,-0.042474,0.83581,-1.80884,-0.114232,0.812829,-1.81683,-0.080908,0.941023,-1.81928,-0.147886,0.91685,-1.82189,-0.351605,0.805071,-1.82802,-0.403502,0.909993,-1.89284,-0.406712,0.652136,-1.89839,-0.464734,0.669442,-1.83069,0.35058,1.19001,-2.13245,0.387888,1.11501,-2.11928,0.222763,1.12449,-2.11366,0.261531,1.05316,-2.10372,0.383515,0.959619,-2.10862,0.468189,0.795572,-2.10581,0.358642,0.768716,-2.12011,0.380113,0.701967,-2.11278,0.474415,0.477873,-2.08939,0.427674,0.373828,-2.02398,0.68005,0.495703,-2.06427,0.655505,0.427864,-2.11797,0.179208,1.36038,-1.8346,0.197214,1.37473,-2.0486},
/*1552*/{0.284426,1.94812,-1.78289,0.342276,1.88586,-1.93382,0.22345,1.81549,-1.65891,0.178523,1.70422,-1.57206,0.30214,1.67822,-1.6738,0.382746,1.65512,-1.7138,0.250201,1.93299,-2.16319,0.339653,1.87896,-2.00551,0.134326,1.91124,-2.06319,0.034711,1.77967,-2.19277,0.027728,1.68307,-2.25677,0.177218,1.56657,-2.20195,0.221016,1.51549,-2.2157,0.260088,1.44088,-1.80433,0.077659,1.51266,-1.89557,0.079634,1.53825,-1.94116,0.087696,1.51267,-2.01084,0.277078,1.46358,-2.06075,0.222867,1.11186,-1.78646,0.089218,1.11568,-1.79797,0.087526,1.03308,-1.82416,0.12316,0.91951,-1.82285,-0.035615,0.839181,-1.80767,-0.107853,0.816695,-1.81638,-0.069693,0.945666,-1.82003,-0.137685,0.922958,-1.82286,-0.344115,0.818072,-1.82614,-0.39497,0.922717,-1.89257,-0.402919,0.665009,-1.89372,-0.459745,0.684421,-1.8259,0.348636,1.18699,-2.1343,0.385616,1.11207,-2.1206,0.220313,1.1221,-2.11379,0.258982,1.05018,-2.10311,0.381694,0.957114,-2.1077,0.463906,0.790456,-2.10501,0.354675,0.76465,-2.11943,0.374997,0.697897,-2.11235,0.466365,0.472848,-2.08791,0.416295,0.372116,-2.02132,0.67276,0.487165,-2.06262,0.64739,0.41974,-2.11465,0.180507,1.35779,-1.83514,0.197431,1.37182,-2.04925},
/*1553*/{0.281762,1.94543,-1.7824,0.341822,1.88245,-1.93269,0.219631,1.81325,-1.65839,0.173091,1.70278,-1.57303,0.296485,1.67267,-1.67281,0.377318,1.64768,-1.71181,0.250102,1.92984,-2.16348,0.339352,1.87616,-2.00531,0.134032,1.90703,-2.06502,0.036717,1.77313,-2.19669,0.031479,1.67648,-2.26098,0.182011,1.56106,-2.20511,0.226295,1.51105,-2.21784,0.260713,1.4381,-1.8053,0.078263,1.50871,-1.89591,0.080078,1.53482,-1.94174,0.087075,1.50886,-2.01069,0.275943,1.46112,-2.06248,0.232063,1.10841,-1.78337,0.095401,1.11159,-1.79758,0.093255,1.02857,-1.82575,0.131415,0.917097,-1.82188,-0.027692,0.842174,-1.8065,-0.099992,0.821159,-1.81442,-0.058574,0.949022,-1.82055,-0.128214,0.929747,-1.82334,-0.335894,0.828582,-1.8239,-0.386677,0.934449,-1.89311,-0.397053,0.67684,-1.88987,-0.45299,0.697547,-1.82154,0.346697,1.18404,-2.13536,0.383677,1.10863,-2.12251,0.218701,1.12022,-2.11389,0.257002,1.04796,-2.10248,0.379185,0.954036,-2.10776,0.459829,0.7852,-2.10435,0.350009,0.760928,-2.11883,0.369017,0.693646,-2.11141,0.455667,0.466945,-2.08619,0.405626,0.366712,-2.0199,0.663761,0.478808,-2.06053,0.63723,0.409941,-2.11065,0.181761,1.35458,-1.83603,0.19726,1.36874,-2.05024},
/*1554*/{0.278944,1.94266,-1.78164,0.341335,1.87996,-1.93277,0.214841,1.81049,-1.65833,0.16692,1.70095,-1.57379,0.290791,1.66657,-1.672,0.372167,1.63964,-1.71,0.249887,1.92558,-2.16355,0.339016,1.87325,-2.00488,0.132896,1.90279,-2.06617,0.037548,1.76588,-2.20261,0.036006,1.67031,-2.2664,0.187428,1.55536,-2.20809,0.232163,1.5061,-2.21936,0.26233,1.43567,-1.80701,0.078652,1.50399,-1.89546,0.079523,1.53073,-1.94231,0.085792,1.50598,-2.01101,0.275913,1.45864,-2.06432,0.236912,1.10688,-1.78375,0.101202,1.10681,-1.79786,0.100041,1.02415,-1.82505,0.139794,0.914091,-1.82021,-0.018957,0.844617,-1.80531,-0.092402,0.826568,-1.81162,-0.048087,0.951796,-1.82239,-0.11696,0.934348,-1.82315,-0.327238,0.838921,-1.82324,-0.378056,0.94521,-1.89221,-0.39125,0.68757,-1.88647,-0.446397,0.710621,-1.81823,0.344451,1.18071,-2.1366,0.382284,1.10455,-2.12207,0.217138,1.11764,-2.11293,0.254994,1.04465,-2.10171,0.376285,0.950489,-2.10745,0.455241,0.779394,-2.10295,0.344771,0.757074,-2.11797,0.363116,0.68979,-2.11057,0.446717,0.462214,-2.08432,0.393173,0.363026,-2.01555,0.653336,0.468593,-2.05714,0.626088,0.400853,-2.10811,0.183811,1.3513,-1.83729,0.197536,1.36599,-2.05158},
/*1555*/{0.275926,1.93922,-1.78126,0.340318,1.87602,-1.93196,0.209919,1.80782,-1.65828,0.160656,1.69814,-1.57427,0.285091,1.661,-1.67113,0.365926,1.63171,-1.70785,0.250438,1.9221,-2.16416,0.3388,1.86971,-2.00466,0.131993,1.89784,-2.06873,0.038427,1.75812,-2.20749,0.04023,1.66258,-2.27104,0.19253,1.55045,-2.2106,0.23769,1.50127,-2.22122,0.262239,1.43311,-1.80878,0.078387,1.50004,-1.89502,0.079174,1.5273,-1.94275,0.084935,1.5013,-2.01061,0.275399,1.45604,-2.06639,0.241473,1.10446,-1.78317,0.107023,1.10225,-1.79806,0.107705,1.01939,-1.82407,0.148563,0.911339,-1.81867,-0.010911,0.847299,-1.80329,-0.08495,0.831101,-1.81087,-0.035555,0.954979,-1.82304,-0.105384,0.938809,-1.82323,-0.320015,0.851005,-1.82221,-0.368418,0.955325,-1.89177,-0.382706,0.697467,-1.88319,-0.438431,0.721314,-1.8149,0.343696,1.1776,-2.1382,0.380411,1.10202,-2.12367,0.215622,1.11473,-2.11255,0.253782,1.04214,-2.10154,0.373274,0.946497,-2.10704,0.450821,0.77361,-2.10218,0.339386,0.753486,-2.1172,0.355978,0.684979,-2.10954,0.434525,0.455364,-2.08201,0.378603,0.359468,-2.01298,0.641785,0.458413,-2.05475,0.613318,0.390809,-2.10462,0.184969,1.34806,-1.83812,0.197205,1.36277,-2.0525},
/*1556*/{0.273326,1.93545,-1.78053,0.34026,1.87232,-1.93122,0.205656,1.80446,-1.65817,0.155078,1.69603,-1.57531,0.279848,1.65513,-1.6699,0.359792,1.62384,-1.70542,0.249989,1.91775,-2.16474,0.33826,1.86588,-2.00468,0.131117,1.89327,-2.06998,0.040401,1.75062,-2.21327,0.04531,1.65557,-2.27599,0.198573,1.54493,-2.21268,0.243744,1.49644,-2.22253,0.263591,1.4301,-1.8108,0.078065,1.49539,-1.89426,0.079169,1.52234,-1.94229,0.084317,1.49719,-2.01065,0.274806,1.45309,-2.06876,0.244742,1.1027,-1.7824,0.110584,1.09577,-1.79901,0.11427,1.01479,-1.82464,0.157921,0.90898,-1.81748,-0.001535,0.848798,-1.80095,-0.074806,0.835648,-1.80794,-0.023154,0.95742,-1.82289,-0.094319,0.942976,-1.8237,-0.31054,0.859337,-1.82055,-0.358801,0.964047,-1.89094,-0.375163,0.705787,-1.8804,-0.428261,0.73113,-1.81106,0.341931,1.17393,-2.13958,0.379462,1.09899,-2.12501,0.214624,1.11169,-2.11249,0.25297,1.03894,-2.10106,0.371675,0.942258,-2.1066,0.445473,0.767054,-2.10095,0.333341,0.749281,-2.11651,0.34827,0.681048,-2.10862,0.422635,0.449984,-2.08043,0.36499,0.354251,-2.01171,0.629635,0.447561,-2.05038,0.600228,0.380962,-2.10114,0.187091,1.3442,-1.83929,0.197093,1.35936,-2.05376},
/*1557*/{0.271209,1.93079,-1.77966,0.3407,1.86769,-1.93013,0.20146,1.80074,-1.65837,0.147264,1.69317,-1.57602,0.274,1.64878,-1.66905,0.353647,1.61517,-1.70249,0.25016,1.9136,-2.16484,0.338678,1.86184,-2.0038,0.130316,1.88821,-2.07175,0.041996,1.74262,-2.21852,0.04978,1.64772,-2.28065,0.204065,1.53921,-2.21496,0.250712,1.49113,-2.22368,0.26462,1.42716,-1.81367,0.077294,1.49047,-1.89427,0.078405,1.51814,-1.94262,0.082353,1.4918,-2.01043,0.27372,1.44988,-2.07049,0.249358,1.10052,-1.78236,0.115462,1.09078,-1.8005,0.120358,1.00954,-1.82475,0.167285,0.905871,-1.81566,0.008083,0.850837,-1.79925,-0.066272,0.838112,-1.80591,-0.011161,0.958418,-1.82351,-0.082198,0.94611,-1.82379,-0.299906,0.867175,-1.8186,-0.348487,0.971869,-1.8903,-0.365574,0.71431,-1.87793,-0.42086,0.740162,-1.80936,0.340403,1.17043,-2.14082,0.378216,1.09558,-2.1264,0.213335,1.10738,-2.11221,0.25225,1.03502,-2.10077,0.368819,0.936968,-2.10651,0.438705,0.760275,-2.10002,0.327104,0.745336,-2.1158,0.340937,0.676306,-2.10722,0.40995,0.445146,-2.07899,0.349106,0.35111,-2.00952,0.617119,0.436552,-2.04636,0.585096,0.369995,-2.09714,0.188732,1.34048,-1.84042,0.196439,1.35551,-2.05499},
/*1558*/{0.269277,1.92672,-1.77893,0.34016,1.8627,-1.92914,0.19775,1.79678,-1.65821,0.140176,1.6898,-1.577,0.268001,1.64207,-1.66804,0.347251,1.60712,-1.70019,0.250306,1.90897,-2.16509,0.338141,1.8572,-2.00326,0.128863,1.88217,-2.07287,0.044923,1.73386,-2.22389,0.055021,1.63984,-2.28508,0.210136,1.53303,-2.21626,0.257189,1.48565,-2.22529,0.265739,1.42391,-1.81614,0.077903,1.4852,-1.89417,0.077861,1.51372,-1.9428,0.081688,1.48694,-2.00994,0.272743,1.44677,-2.07309,0.253055,1.09767,-1.7808,0.120176,1.08816,-1.80157,0.126064,1.00494,-1.82662,0.176723,0.902852,-1.81415,0.017629,0.85092,-1.79795,-0.056363,0.840352,-1.80333,0.001137,0.959616,-1.82342,-0.06974,0.948797,-1.82337,-0.288542,0.873074,-1.81735,-0.337385,0.978902,-1.88925,-0.355762,0.720428,-1.87488,-0.410186,0.747975,-1.80681,0.339754,1.16616,-2.14221,0.377628,1.09167,-2.12768,0.212341,1.1036,-2.11213,0.25125,1.03084,-2.10005,0.36618,0.932015,-2.10626,0.432788,0.753969,-2.09931,0.320254,0.740752,-2.11501,0.332183,0.671482,-2.10642,0.396213,0.438701,-2.07702,0.33089,0.351607,-2.0092,0.60247,0.424194,-2.04408,0.568,0.358594,-2.09524,0.190894,1.33642,-1.84193,0.196142,1.35183,-2.05655},
/*1559*/{0.267879,1.92167,-1.77859,0.340672,1.85817,-1.92861,0.193943,1.79262,-1.6584,0.133258,1.68669,-1.57715,0.261476,1.63551,-1.6672,0.340413,1.59839,-1.69744,0.250795,1.90437,-2.16543,0.338862,1.85257,-2.00296,0.128459,1.87604,-2.07406,0.047536,1.72533,-2.22992,0.060992,1.63182,-2.28922,0.215842,1.52691,-2.2175,0.264327,1.48031,-2.22658,0.265704,1.42028,-1.81895,0.077721,1.47992,-1.89399,0.077695,1.50775,-1.9431,0.080853,1.48116,-2.00854,0.272649,1.44362,-2.07624,0.2563,1.09562,-1.77989,0.12586,1.08212,-1.80169,0.133102,0.9998,-1.82626,0.186066,0.900391,-1.81186,0.028763,0.851828,-1.79592,-0.045245,0.842547,-1.80093,0.014406,0.960037,-1.82337,-0.056773,0.950006,-1.82224,-0.277153,0.879968,-1.81597,-0.32656,0.9848,-1.88864,-0.34438,0.727439,-1.87174,-0.398424,0.753868,-1.80535,0.337882,1.16173,-2.14289,0.375982,1.0873,-2.12828,0.210855,1.09833,-2.11211,0.250559,1.02648,-2.09983,0.363813,0.925932,-2.10464,0.425452,0.747013,-2.09828,0.313043,0.735731,-2.11403,0.324092,0.666737,-2.10546,0.382921,0.43495,-2.07589,0.311735,0.357391,-2.0092,0.58818,0.411269,-2.03997,0.548532,0.348045,-2.09206,0.19302,1.33175,-1.84358,0.196163,1.34782,-2.0582},
/*1560*/{0.266707,1.91648,-1.77734,0.340025,1.85272,-1.92776,0.189571,1.78755,-1.65862,0.127783,1.68369,-1.57817,0.254351,1.62885,-1.66567,0.333208,1.59081,-1.69533,0.251553,1.89989,-2.16598,0.338681,1.84768,-2.00224,0.127211,1.87028,-2.07531,0.051099,1.71626,-2.235,0.067629,1.62376,-2.29316,0.223014,1.52095,-2.21873,0.271497,1.4751,-2.22785,0.266642,1.41588,-1.82139,0.077948,1.47505,-1.89311,0.075878,1.503,-1.94472,0.078745,1.47628,-2.00779,0.271362,1.44016,-2.07868,0.264545,1.09172,-1.776,0.129511,1.07524,-1.80271,0.14026,0.993441,-1.82694,0.195426,0.896748,-1.81085,0.040249,0.85104,-1.79461,-0.034983,0.842802,-1.80093,0.027734,0.959328,-1.82259,-0.043594,0.9519,-1.82143,-0.265431,0.884941,-1.81513,-0.3142,0.989358,-1.8875,-0.333543,0.731424,-1.8685,-0.387597,0.759328,-1.80231,0.335321,1.15683,-2.14429,0.37466,1.08198,-2.129,0.209402,1.09338,-2.11212,0.247475,1.02173,-2.09885,0.360818,0.919955,-2.10332,0.41782,0.73981,-2.09641,0.305791,0.730753,-2.11348,0.315328,0.661374,-2.10447,0.369243,0.430023,-2.07355,0.291581,0.355433,-2.0072,0.573271,0.396522,-2.03709,0.530777,0.338426,-2.08974,0.194167,1.32727,-1.84531,0.194846,1.34386,-2.0599},
/*1561*/{0.26563,1.91044,-1.77678,0.340017,1.84723,-1.92646,0.185995,1.78301,-1.65887,0.121198,1.68012,-1.57934,0.248564,1.62234,-1.66443,0.325964,1.58235,-1.69272,0.252677,1.89537,-2.16633,0.338628,1.84257,-2.0015,0.126954,1.86413,-2.07613,0.055607,1.70728,-2.24157,0.074444,1.61569,-2.29716,0.230256,1.5149,-2.22016,0.279554,1.46949,-2.22881,0.266238,1.41182,-1.82374,0.077834,1.46935,-1.89293,0.075082,1.49632,-1.94568,0.078384,1.4703,-2.00751,0.270742,1.43644,-2.08209,0.268904,1.08829,-1.773,0.135234,1.07115,-1.80326,0.14723,0.988631,-1.82656,0.206472,0.894385,-1.8086,0.052302,0.85042,-1.79304,-0.023299,0.843895,-1.79892,0.04162,0.958787,-1.82199,-0.030675,0.952229,-1.82025,-0.252138,0.888793,-1.81272,-0.302131,0.993128,-1.88715,-0.320607,0.73614,-1.8658,-0.375515,0.76399,-1.80004,0.333252,1.15057,-2.14575,0.371292,1.07617,-2.12985,0.206496,1.08847,-2.11247,0.244942,1.01628,-2.09954,0.356671,0.914387,-2.10309,0.410373,0.732507,-2.09476,0.298628,0.725692,-2.11245,0.306156,0.656958,-2.10418,0.353817,0.424816,-2.06879,0.272007,0.356234,-2.00484,0.556112,0.387597,-2.02433,0.509318,0.341139,-2.08908,0.195843,1.32226,-1.84712,0.194784,1.33926,-2.06168},
/*1562*/{0.265593,1.905,-1.77603,0.340207,1.84199,-1.92504,0.182428,1.778,-1.65935,0.114078,1.67696,-1.58053,0.242289,1.61614,-1.66255,0.318362,1.57423,-1.6896,0.252333,1.89045,-2.1668,0.339024,1.83745,-2.00102,0.126745,1.85858,-2.07634,0.060054,1.69895,-2.24806,0.082053,1.60714,-2.30042,0.237518,1.50934,-2.22132,0.287166,1.46448,-2.22958,0.267033,1.40678,-1.82506,0.076083,1.46429,-1.89227,0.072951,1.49053,-1.94674,0.076302,1.46532,-2.0072,0.26942,1.43235,-2.08458,0.273946,1.08592,-1.77137,0.140574,1.06403,-1.80371,0.154536,0.981678,-1.82694,0.216659,0.891519,-1.80619,0.064379,0.849177,-1.79111,-0.01054,0.842869,-1.79891,0.055442,0.957101,-1.82042,-0.016963,0.952073,-1.81889,-0.240931,0.891719,-1.81164,-0.289317,0.996081,-1.88599,-0.307746,0.738071,-1.86358,-0.361886,0.767411,-1.7978,0.329038,1.14457,-2.14738,0.366571,1.0696,-2.13147,0.2024,1.08393,-2.11124,0.239884,1.01171,-2.09951,0.351933,0.908916,-2.1035,0.403118,0.724987,-2.09142,0.292032,0.721107,-2.11163,0.296442,0.651788,-2.10229,0.335274,0.424664,-2.06231,0.248045,0.353689,-2.008,0.530713,0.385745,-2.02606,0.487261,0.34081,-2.08933,0.196137,1.31726,-1.84857,0.193292,1.33478,-2.06307},
/*1563*/{0.26507,1.89897,-1.775,0.340694,1.83567,-1.92482,0.17937,1.77291,-1.65984,0.108017,1.67392,-1.58254,0.235811,1.61044,-1.662,0.311235,1.56724,-1.68775,0.254003,1.88637,-2.16772,0.340229,1.83202,-2.00003,0.126377,1.85433,-2.07552,0.064944,1.6917,-2.25434,0.09025,1.59891,-2.30372,0.244926,1.5032,-2.22267,0.295668,1.45907,-2.23072,0.266738,1.40201,-1.82786,0.07429,1.4587,-1.89206,0.072715,1.4845,-1.94668,0.07391,1.46028,-2.00614,0.268367,1.42761,-2.08706,0.277847,1.08191,-1.7709,0.146251,1.05794,-1.80422,0.163674,0.976468,-1.82709,0.227744,0.889374,-1.80461,0.076779,0.847061,-1.78994,0.001125,0.842416,-1.79732,0.069018,0.955726,-1.81873,-0.002758,0.951218,-1.81702,-0.226313,0.894776,-1.81155,-0.276723,0.997427,-1.88553,-0.294344,0.739951,-1.86124,-0.347881,0.769772,-1.79517,0.323997,1.13895,-2.15052,0.360837,1.06356,-2.13425,0.197511,1.08071,-2.11145,0.234512,1.00866,-2.09847,0.346052,0.902254,-2.10405,0.396656,0.717268,-2.08698,0.284735,0.716483,-2.10972,0.287813,0.647175,-2.09885,0.312372,0.425215,-2.05808,0.223517,0.355,-2.00257,0.506072,0.385428,-2.02344,0.462338,0.341285,-2.08937,0.196469,1.31194,-1.85013,0.191541,1.33,-2.06455},
/*1564*/{0.265048,1.89314,-1.77399,0.339583,1.82996,-1.92292,0.1761,1.76763,-1.66015,0.101184,1.67151,-1.58446,0.229559,1.60471,-1.66128,0.303463,1.56023,-1.6849,0.255274,1.88114,-2.16842,0.34081,1.82633,-1.99993,0.127327,1.85061,-2.07446,0.072656,1.68403,-2.26026,0.098329,1.59093,-2.30671,0.253461,1.49767,-2.22358,0.304541,1.45403,-2.23115,0.266617,1.39676,-1.82981,0.073308,1.45306,-1.8919,0.070357,1.47766,-1.94676,0.070866,1.45602,-2.00633,0.265493,1.42387,-2.08815,0.283616,1.07918,-1.76961,0.152711,1.05107,-1.80402,0.170723,0.969685,-1.82826,0.239518,0.886307,-1.8022,0.089812,0.844959,-1.7882,0.01427,0.840692,-1.79474,0.083191,0.953268,-1.81648,0.01186,0.950024,-1.81398,-0.214663,0.895386,-1.80997,-0.264293,0.99801,-1.8843,-0.27939,0.740595,-1.85905,-0.334465,0.770111,-1.79248,0.318451,1.13508,-2.15481,0.354979,1.05876,-2.13868,0.192154,1.07952,-2.10952,0.229294,1.00701,-2.09664,0.339905,0.896026,-2.10466,0.389271,0.711645,-2.08256,0.278319,0.715632,-2.10675,0.277139,0.645853,-2.09376,0.286416,0.425059,-2.05364,0.200788,0.355197,-2.00249,0.483918,0.381675,-2.02274,0.439651,0.341014,-2.08919,0.196273,1.30644,-1.85199,0.189434,1.32581,-2.06624},
/*1565*/{0.264426,1.88761,-1.77319,0.340867,1.82322,-1.9214,0.173223,1.76292,-1.66112,0.094967,1.6693,-1.58572,0.223022,1.59939,-1.65989,0.296191,1.55391,-1.68252,0.257279,1.87724,-2.16955,0.342167,1.82109,-1.99947,0.128391,1.84776,-2.07444,0.080676,1.67672,-2.2656,0.10742,1.58339,-2.30913,0.26173,1.49141,-2.22454,0.313304,1.4495,-2.23205,0.265336,1.39197,-1.8318,0.070775,1.44794,-1.89171,0.067112,1.47214,-1.94621,0.067633,1.45199,-2.00694,0.262029,1.42118,-2.08946,0.287741,1.07621,-1.76887,0.158993,1.04534,-1.80448,0.180393,0.963941,-1.82764,0.252593,0.882538,-1.80125,0.104089,0.842121,-1.78724,0.028333,0.83907,-1.79435,0.097386,0.951252,-1.81482,0.026279,0.948291,-1.8127,-0.200549,0.89423,-1.80983,-0.251441,0.997362,-1.88315,-0.26381,0.739826,-1.85658,-0.318807,0.769174,-1.7908,0.314633,1.13106,-2.1587,0.349922,1.05414,-2.14132,0.188555,1.07989,-2.10902,0.223904,1.00649,-2.09542,0.333613,0.893323,-2.1049,0.380207,0.710438,-2.07948,0.269645,0.719502,-2.10381,0.265154,0.650579,-2.09166,0.271618,0.428849,-2.05203,0.178106,0.356658,-1.99952,0.461361,0.381581,-2.02224,0.416365,0.341322,-2.08792,0.195041,1.30145,-1.85411,0.186601,1.3226,-2.06813},
/*1566*/{0.265058,1.88258,-1.77183,0.340785,1.81797,-1.9212,0.169978,1.75833,-1.66195,0.08842,1.66735,-1.58841,0.216285,1.59528,-1.65883,0.288929,1.54851,-1.6801,0.259163,1.87321,-2.1707,0.343039,1.81579,-1.99878,0.129698,1.84541,-2.07448,0.09076,1.66895,-2.27041,0.117251,1.57576,-2.31101,0.271319,1.48765,-2.22542,0.323034,1.44549,-2.23232,0.264305,1.38741,-1.83477,0.068236,1.44341,-1.89152,0.064463,1.46745,-1.94611,0.064207,1.44753,-2.00767,0.259582,1.4183,-2.09107,0.293588,1.07432,-1.76877,0.165238,1.03905,-1.80509,0.191283,0.958471,-1.82796,0.266887,0.879677,-1.79886,0.118324,0.839252,-1.78606,0.042015,0.836673,-1.79353,0.112092,0.949107,-1.81202,0.040432,0.947271,-1.81027,-0.185382,0.893892,-1.80634,-0.239206,0.995962,-1.88202,-0.246898,0.738494,-1.85562,-0.302163,0.766951,-1.78892,0.312019,1.12912,-2.15889,0.347004,1.05274,-2.14055,0.185787,1.0793,-2.10891,0.221176,1.00543,-2.09415,0.3294,0.893344,-2.10466,0.368912,0.709612,-2.0777,0.26031,0.725109,-2.10192,0.251309,0.655106,-2.09102,0.25111,0.430034,-2.04971,0.155669,0.357595,-1.99865,0.439077,0.38023,-2.02089,0.394046,0.341868,-2.08743,0.194003,1.29682,-1.85636,0.183893,1.31933,-2.07018},
/*1567*/{0.265131,1.87787,-1.77088,0.341912,1.81232,-1.92049,0.165534,1.75406,-1.66285,0.081268,1.6658,-1.59044,0.209827,1.5907,-1.65837,0.281731,1.54324,-1.67771,0.261224,1.86945,-2.1711,0.344302,1.81118,-1.99863,0.130489,1.84298,-2.07434,0.099935,1.66323,-2.27481,0.126965,1.56869,-2.31192,0.280375,1.48278,-2.22618,0.332693,1.44229,-2.2325,0.263224,1.38312,-1.8373,0.064215,1.43886,-1.89146,0.062811,1.4639,-1.94586,0.060895,1.44433,-2.00795,0.256035,1.41582,-2.09281,0.299722,1.07314,-1.76797,0.171857,1.03264,-1.80586,0.200944,0.952789,-1.82799,0.281187,0.876637,-1.79787,0.131418,0.836664,-1.78601,0.055997,0.833003,-1.79312,0.126238,0.947235,-1.80945,0.054693,0.944052,-1.80793,-0.170955,0.890953,-1.80546,-0.227538,0.993001,-1.88022,-0.229647,0.734738,-1.85322,-0.285896,0.76254,-1.78705,0.30833,1.12949,-2.15718,0.345244,1.05347,-2.13887,0.182609,1.07647,-2.10871,0.220105,1.00173,-2.09264,0.32806,0.894101,-2.10378,0.358352,0.708646,-2.07809,0.248836,0.730233,-2.10148,0.237827,0.660046,-2.09024,0.231588,0.430688,-2.04825,0.133554,0.358331,-1.99726,0.418004,0.379011,-2.021,0.370855,0.341363,-2.08819,0.192255,1.29248,-1.85874,0.180434,1.31675,-2.07227},
/*1568*/{0.264278,1.87404,-1.76972,0.342149,1.80859,-1.91952,0.161385,1.75158,-1.66393,0.073562,1.66581,-1.59334,0.202831,1.58811,-1.65839,0.27436,1.54051,-1.67692,0.262944,1.86617,-2.17037,0.345283,1.80753,-1.99726,0.131263,1.84192,-2.07466,0.112256,1.65779,-2.27819,0.137789,1.56267,-2.3137,0.290529,1.47955,-2.22707,0.343222,1.43998,-2.23279,0.261436,1.37904,-1.83923,0.061754,1.43471,-1.89266,0.061666,1.46282,-1.9458,0.057615,1.44098,-2.00723,0.253248,1.41323,-2.09421,0.304849,1.07489,-1.76859,0.179327,1.02879,-1.80479,0.210013,0.951017,-1.82721,0.294876,0.873764,-1.79718,0.145215,0.834452,-1.78587,0.07135,0.831769,-1.79283,0.140967,0.945908,-1.80681,0.069411,0.942873,-1.80672,-0.156583,0.889098,-1.804,-0.217324,0.988721,-1.87882,-0.211025,0.730293,-1.85268,-0.267804,0.755832,-1.78573,0.304919,1.13093,-2.15553,0.342878,1.05403,-2.13898,0.179985,1.07546,-2.10977,0.217693,0.999991,-2.09385,0.327781,0.894849,-2.10143,0.346597,0.707918,-2.08034,0.237398,0.731126,-2.10191,0.225825,0.662043,-2.08927,0.209164,0.42999,-2.04874,0.111028,0.359056,-2.00039,0.395997,0.378589,-2.01949,0.348897,0.341312,-2.08682,0.190034,1.28865,-1.86064,0.177109,1.31431,-2.07395},
/*1569*/{0.264168,1.87074,-1.76769,0.341737,1.80558,-1.91841,0.157151,1.75017,-1.66504,0.066955,1.6659,-1.5968,0.195871,1.58577,-1.65756,0.267642,1.5368,-1.67501,0.265754,1.86396,-2.16925,0.3453,1.80443,-1.99696,0.13188,1.83997,-2.07478,0.119115,1.65115,-2.28084,0.148663,1.55794,-2.31391,0.3011,1.47734,-2.22724,0.353906,1.43812,-2.23172,0.259264,1.37526,-1.84066,0.058633,1.43176,-1.89202,0.0581,1.4628,-1.94525,0.054649,1.43904,-2.00568,0.251586,1.41174,-2.09576,0.311894,1.07951,-1.76935,0.187646,1.02824,-1.8034,0.221051,0.950567,-1.82444,0.308765,0.873862,-1.7985,0.161042,0.833063,-1.78521,0.085725,0.830049,-1.79325,0.154643,0.945072,-1.80418,0.083279,0.941485,-1.80435,-0.143387,0.88447,-1.80297,-0.208036,0.982899,-1.87689,-0.191433,0.725399,-1.85077,-0.249075,0.74855,-1.78408,0.302103,1.13072,-2.15548,0.338256,1.05341,-2.13909,0.176051,1.07383,-2.10999,0.214086,0.998534,-2.09371,0.328507,0.895933,-2.09942,0.334671,0.706269,-2.08225,0.225329,0.731034,-2.10326,0.212463,0.663043,-2.08986,0.190397,0.430858,-2.04773,0.088685,0.360763,-1.99947,0.373905,0.377619,-2.02144,0.32751,0.341344,-2.08648,0.187113,1.28547,-1.86224,0.17343,1.31327,-2.07524},
/*1570*/{0.26425,1.86845,-1.76621,0.341794,1.80314,-1.91672,0.153074,1.74933,-1.66616,0.058956,1.66649,-1.60018,0.19018,1.5844,-1.65775,0.260582,1.53419,-1.6732,0.26744,1.86222,-2.16757,0.345748,1.80282,-1.99499,0.132126,1.83943,-2.07526,0.128035,1.64735,-2.28179,0.159221,1.554,-2.31299,0.311312,1.47526,-2.22742,0.365014,1.43634,-2.23096,0.25711,1.37209,-1.84108,0.056967,1.43023,-1.89072,0.057408,1.46253,-1.94555,0.05392,1.4382,-2.00401,0.249292,1.41083,-2.09764,0.317211,1.08376,-1.76973,0.196159,1.02832,-1.80173,0.233102,0.952823,-1.82243,0.322585,0.875507,-1.79934,0.174842,0.832534,-1.78632,0.100933,0.831167,-1.79311,0.167386,0.945079,-1.8018,0.096757,0.939995,-1.8026,-0.129405,0.879145,-1.80309,-0.199095,0.975637,-1.87508,-0.172519,0.718083,-1.8507,-0.22903,0.739826,-1.78287,0.298369,1.12758,-2.15512,0.333142,1.05113,-2.13875,0.171366,1.07339,-2.11111,0.208513,0.998264,-2.09523,0.32464,0.895562,-2.09782,0.322157,0.703977,-2.08372,0.213266,0.729624,-2.10355,0.198038,0.66242,-2.09072,0.168929,0.431278,-2.04808,0.067728,0.360498,-1.9982,0.353336,0.378024,-2.02008,0.305875,0.340739,-2.08673,0.184882,1.28298,-1.8635,0.170463,1.31257,-2.0762},
/*1571*/{0.264299,1.86655,-1.76492,0.340916,1.80184,-1.91583,0.149003,1.75003,-1.66747,0.0524,1.66822,-1.60378,0.183029,1.58481,-1.65894,0.254498,1.53257,-1.67137,0.270186,1.86113,-2.16658,0.346254,1.80154,-1.99391,0.133658,1.83858,-2.07639,0.136738,1.64592,-2.28241,0.168987,1.55173,-2.31203,0.322166,1.47386,-2.22569,0.37558,1.4369,-2.22969,0.25546,1.36984,-1.84126,0.055592,1.42957,-1.88972,0.055378,1.46215,-1.94589,0.05228,1.43857,-2.00255,0.245612,1.41001,-2.10018,0.323981,1.08958,-1.77078,0.205784,1.02934,-1.80015,0.243999,0.954007,-1.82096,0.338019,0.879768,-1.79978,0.189973,0.833122,-1.78618,0.114639,0.828224,-1.79409,0.179654,0.945358,-1.79925,0.108928,0.939179,-1.80082,-0.116144,0.871735,-1.80273,-0.191219,0.966642,-1.87361,-0.151082,0.711053,-1.85025,-0.208173,0.728518,-1.78167,0.293066,1.12491,-2.1559,0.327742,1.04779,-2.13911,0.16613,1.06949,-2.11003,0.201963,0.996298,-2.09578,0.31632,0.892487,-2.09862,0.308223,0.699599,-2.0843,0.200677,0.72933,-2.10543,0.184385,0.661835,-2.09199,0.149974,0.432368,-2.04937,0.045371,0.36151,-1.99913,0.331174,0.37676,-2.02113,0.28272,0.340338,-2.08745,0.182532,1.28145,-1.86466,0.166515,1.31209,-2.0771},
/*1572*/{0.263964,1.86562,-1.76403,0.340279,1.8008,-1.91425,0.143641,1.75144,-1.66882,0.046604,1.67144,-1.60799,0.176089,1.58443,-1.65917,0.247602,1.53141,-1.67072,0.272377,1.86006,-2.16513,0.346346,1.80082,-1.99247,0.134588,1.83806,-2.07712,0.141879,1.64177,-2.28191,0.178689,1.55017,-2.31138,0.333248,1.47409,-2.22392,0.386855,1.43819,-2.22775,0.252777,1.36848,-1.84058,0.054371,1.42971,-1.89014,0.054606,1.46116,-1.94618,0.05116,1.43954,-2.0025,0.24675,1.4099,-2.10036,0.327803,1.09793,-1.77316,0.213153,1.03103,-1.79969,0.254205,0.957688,-1.8193,0.352126,0.886041,-1.79993,0.203861,0.834389,-1.78679,0.130068,0.828274,-1.79489,0.191574,0.946093,-1.79693,0.120444,0.938625,-1.79871,-0.101944,0.864566,-1.8023,-0.183349,0.956463,-1.87173,-0.129898,0.703848,-1.84962,-0.1862,0.718471,-1.78059,0.288004,1.12153,-2.15771,0.321537,1.04407,-2.14041,0.161111,1.06884,-2.11044,0.194633,0.994416,-2.09688,0.305991,0.887637,-2.09987,0.294111,0.695233,-2.08528,0.187172,0.727685,-2.10695,0.169333,0.661717,-2.09329,0.127824,0.432729,-2.05038,0.024066,0.362185,-1.99947,0.308938,0.376366,-2.02167,0.26109,0.34033,-2.08802,0.180219,1.28041,-1.86514,0.16601,1.31237,-2.07751},
/*1573*/{0.262961,1.86573,-1.76312,0.34005,1.80034,-1.91337,0.138582,1.75284,-1.67075,0.040111,1.67402,-1.61215,0.170763,1.58576,-1.66002,0.240931,1.53222,-1.67045,0.275228,1.85987,-2.16357,0.346684,1.80026,-1.99101,0.135165,1.83785,-2.07783,0.151503,1.6411,-2.28035,0.187074,1.54958,-2.30999,0.344203,1.47641,-2.22181,0.397599,1.44016,-2.22551,0.250205,1.3685,-1.83895,0.052933,1.43048,-1.8906,0.053796,1.46135,-1.94629,0.051239,1.44023,-2.00198,0.245983,1.40999,-2.10068,0.335133,1.10397,-1.77329,0.220721,1.03452,-1.7991,0.265117,0.962623,-1.81907,0.366214,0.892997,-1.80022,0.217218,0.836143,-1.78745,0.143391,0.82731,-1.79496,0.20148,0.947284,-1.7968,0.131991,0.937761,-1.79742,-0.088048,0.856237,-1.80101,-0.174497,0.944521,-1.87005,-0.108199,0.695088,-1.85009,-0.16413,0.70614,-1.77996,0.282208,1.11812,-2.15887,0.314725,1.04012,-2.14133,0.154082,1.06776,-2.11113,0.186966,0.993245,-2.09822,0.295184,0.883318,-2.10099,0.279651,0.690361,-2.08472,0.174366,0.726127,-2.10721,0.153927,0.660096,-2.09404,0.108027,0.433119,-2.05021,0.003515,0.361633,-1.99967,0.287829,0.37626,-2.02326,0.238718,0.340181,-2.08924,0.178096,1.28058,-1.86463,0.165107,1.31258,-2.07707},
/*1574*/{0.261148,1.86588,-1.76317,0.339723,1.80033,-1.91168,0.134748,1.75564,-1.6721,0.034669,1.67731,-1.61622,0.164357,1.58649,-1.66053,0.233699,1.53205,-1.67025,0.277206,1.86032,-2.16296,0.345941,1.80016,-1.98895,0.136588,1.83779,-2.07797,0.15478,1.63903,-2.27869,0.194895,1.54943,-2.30882,0.352997,1.47748,-2.21957,0.407129,1.44344,-2.22223,0.247391,1.36872,-1.83732,0.051799,1.43149,-1.89139,0.052364,1.46188,-1.94692,0.050604,1.44121,-2.00273,0.244809,1.40979,-2.1011,0.342995,1.11087,-1.77383,0.232467,1.0382,-1.79615,0.276448,0.967194,-1.81702,0.380053,0.90139,-1.80055,0.23182,0.838381,-1.78797,0.157327,0.826851,-1.79565,0.211942,0.949245,-1.79543,0.140964,0.936282,-1.79603,-0.07466,0.849164,-1.80121,-0.167218,0.931368,-1.86921,-0.085886,0.686253,-1.85051,-0.141184,0.694204,-1.77885,0.276534,1.11508,-2.1592,0.307082,1.03628,-2.14156,0.146666,1.06835,-2.1126,0.178584,0.992025,-2.09903,0.282563,0.878903,-2.10124,0.26475,0.685719,-2.08431,0.160288,0.72417,-2.10705,0.137492,0.658628,-2.09417,0.08562,0.433586,-2.05164,-0.018271,0.362959,-1.99967,0.266362,0.375952,-2.02336,0.217282,0.339314,-2.08982,0.17545,1.28108,-1.86422,0.163816,1.31263,-2.07681},
/*1575*/{0.260082,1.86717,-1.76229,0.338927,1.7999,-1.90993,0.129568,1.75839,-1.67311,0.029442,1.68118,-1.6196,0.158452,1.58846,-1.66195,0.22744,1.53333,-1.67012,0.280384,1.86131,-2.16112,0.346333,1.80104,-1.9878,0.138,1.83891,-2.07844,0.159399,1.63826,-2.27666,0.202605,1.54943,-2.30707,0.362225,1.48116,-2.2162,0.416607,1.44831,-2.21866,0.245688,1.37004,-1.83474,0.050597,1.43185,-1.89319,0.051618,1.46279,-1.94759,0.050148,1.44206,-2.00472,0.245284,1.4093,-2.10082,0.34916,1.11835,-1.77325,0.239599,1.04063,-1.79535,0.285624,0.974065,-1.81785,0.392677,0.910727,-1.80087,0.245167,0.840783,-1.78855,0.171849,0.826972,-1.7961,0.221732,0.950912,-1.79235,0.151387,0.93584,-1.79473,-0.06205,0.838696,-1.802,-0.158349,0.916854,-1.86921,-0.062785,0.6771,-1.85013,-0.117294,0.682164,-1.7777,0.269937,1.11255,-2.15905,0.297815,1.03278,-2.14197,0.138446,1.06818,-2.11344,0.167272,0.991181,-2.10036,0.268777,0.874447,-2.10124,0.248243,0.682013,-2.08346,0.144323,0.72148,-2.10728,0.121292,0.656165,-2.09391,0.064178,0.434223,-2.05238,-0.041337,0.365142,-2.00244,0.244828,0.37517,-2.02369,0.195118,0.340143,-2.0907,0.17366,1.28224,-1.86315,0.164315,1.31244,-2.07605},
/*1576*/{0.258372,1.86915,-1.76131,0.338727,1.80176,-1.9086,0.125204,1.76155,-1.67451,0.022024,1.68462,-1.62337,0.153642,1.59175,-1.66261,0.22183,1.53567,-1.66973,0.28265,1.86291,-2.16012,0.345839,1.80176,-1.98608,0.138724,1.83951,-2.07881,0.165179,1.63961,-2.27483,0.20979,1.5505,-2.30584,0.370695,1.4851,-2.21293,0.425599,1.45347,-2.21506,0.243227,1.3716,-1.83269,0.050689,1.43307,-1.89435,0.051127,1.46376,-1.94977,0.050302,1.4429,-2.00617,0.245846,1.40912,-2.10039,0.355684,1.12687,-1.77357,0.247466,1.04774,-1.79511,0.294627,0.97897,-1.81587,0.404853,0.919813,-1.80106,0.258746,0.843552,-1.78941,0.185377,0.826638,-1.79654,0.230242,0.952753,-1.79228,0.159465,0.934798,-1.79525,-0.0467,0.828715,-1.80311,-0.149306,0.901539,-1.8697,-0.039125,0.667389,-1.84952,-0.093475,0.670313,-1.77748,0.263261,1.1099,-2.15835,0.28845,1.02861,-2.14184,0.130016,1.06874,-2.1147,0.157575,0.991255,-2.10133,0.253051,0.869759,-2.10156,0.230943,0.677265,-2.08301,0.128419,0.719458,-2.10747,0.104692,0.654533,-2.09402,0.044379,0.43502,-2.05318,-0.062495,0.365581,-2.00203,0.222788,0.375245,-2.02485,0.173778,0.339747,-2.091,0.171921,1.28372,-1.86209,0.16496,1.31236,-2.0753},
/*1577*/{0.255806,1.87112,-1.76049,0.337949,1.802,-1.90647,0.120985,1.76504,-1.67608,0.01638,1.68904,-1.62656,0.147204,1.59444,-1.66312,0.216073,1.53848,-1.66959,0.285644,1.86505,-2.15855,0.345986,1.80278,-1.98359,0.140338,1.84049,-2.08008,0.170936,1.64016,-2.27155,0.216508,1.55173,-2.30497,0.378298,1.49091,-2.20963,0.434214,1.45906,-2.21018,0.241716,1.37341,-1.83136,0.049665,1.43425,-1.8969,0.050567,1.46451,-1.95043,0.050262,1.44418,-2.00798,0.246314,1.40908,-2.09993,0.36266,1.13534,-1.77302,0.257048,1.05329,-1.79472,0.304772,0.984437,-1.81571,0.415674,0.929652,-1.80082,0.27192,0.847133,-1.78987,0.198758,0.826304,-1.79758,0.237695,0.954179,-1.79178,0.168766,0.933267,-1.79489,-0.032245,0.818345,-1.80375,-0.140171,0.884625,-1.87118,-0.015673,0.658456,-1.84957,-0.069122,0.658152,-1.77682,0.256147,1.1068,-2.15794,0.279085,1.02503,-2.14152,0.121436,1.07021,-2.11583,0.146436,0.991731,-2.10199,0.237932,0.86533,-2.10174,0.213775,0.674805,-2.08228,0.11052,0.717501,-2.10718,0.085825,0.653407,-2.09418,0.025902,0.437423,-2.05245,-0.082472,0.364986,-2.00109,0.201185,0.37537,-2.02621,0.151834,0.339971,-2.0915,0.170425,1.28526,-1.8615,0.165515,1.31265,-2.07493},
/*1578*/{0.252467,1.87424,-1.76031,0.336819,1.80528,-1.90434,0.1162,1.76867,-1.67697,0.010826,1.69239,-1.62959,0.140501,1.59811,-1.66465,0.209528,1.54204,-1.66978,0.286988,1.86736,-2.15701,0.346468,1.80523,-1.9826,0.141972,1.84205,-2.08097,0.173441,1.6407,-2.26868,0.222465,1.5538,-2.30423,0.384949,1.4962,-2.2055,0.44202,1.46647,-2.20601,0.239844,1.37585,-1.82898,0.049083,1.43581,-1.89781,0.050831,1.46625,-1.95224,0.050559,1.44586,-2.01014,0.246597,1.40892,-2.09987,0.367654,1.14309,-1.77178,0.26441,1.05907,-1.79412,0.312622,0.991984,-1.81611,0.425571,0.939095,-1.80085,0.284893,0.850005,-1.79042,0.21359,0.825634,-1.79738,0.245634,0.955747,-1.79165,0.178085,0.930996,-1.7938,-0.017275,0.807845,-1.80392,-0.129655,0.867693,-1.87206,0.008651,0.649299,-1.848,-0.045174,0.646341,-1.77508,0.249259,1.10441,-2.15711,0.2692,1.02203,-2.1414,0.112716,1.07233,-2.11624,0.135841,0.992955,-2.10171,0.220863,0.861643,-2.10151,0.19584,0.673859,-2.08152,0.093988,0.717838,-2.10636,0.067619,0.653159,-2.09411,0.00576,0.438486,-2.05279,-0.104197,0.368439,-2.00233,0.179396,0.375288,-2.02608,0.130081,0.340037,-2.09232,0.16874,1.28751,-1.86024,0.165979,1.31286,-2.07396},
/*1579*/{0.249808,1.87751,-1.75917,0.336456,1.80817,-1.90274,0.111212,1.77251,-1.67893,0.00476,1.69633,-1.63286,0.136027,1.60244,-1.66612,0.203812,1.54547,-1.67009,0.289548,1.87067,-2.15535,0.346786,1.80812,-1.97997,0.142202,1.84355,-2.08146,0.175288,1.64275,-2.26565,0.228399,1.55678,-2.30332,0.39026,1.50289,-2.2018,0.448833,1.47447,-2.20093,0.237913,1.37824,-1.82651,0.049405,1.43739,-1.90004,0.050679,1.46745,-1.95423,0.051317,1.44742,-2.01262,0.247603,1.40876,-2.09923,0.37221,1.15091,-1.77249,0.270317,1.06481,-1.79487,0.320895,0.999852,-1.81657,0.434699,0.950168,-1.80055,0.297816,0.853843,-1.79046,0.227706,0.825137,-1.7979,0.252828,0.956522,-1.79183,0.186349,0.92902,-1.79438,-0.002156,0.796693,-1.80378,-0.11852,0.850211,-1.87406,0.03299,0.64022,-1.84727,-0.0206,0.634689,-1.77456,0.241435,1.10185,-2.15651,0.2587,1.02004,-2.14041,0.103978,1.07462,-2.11659,0.124306,0.995074,-2.10209,0.203921,0.859877,-2.10129,0.178561,0.673849,-2.08066,0.076808,0.718576,-2.10575,0.04969,0.655061,-2.09413,-0.018363,0.441027,-2.05624,-0.126852,0.37074,-2.00493,0.158102,0.375446,-2.02611,0.108937,0.339963,-2.09181,0.167186,1.28969,-1.85911,0.167295,1.31301,-2.07307},
/*1580*/{0.246346,1.88029,-1.75922,0.336668,1.81031,-1.90048,0.107118,1.77635,-1.67986,-0.001095,1.70062,-1.63575,0.130628,1.60672,-1.66742,0.198755,1.54981,-1.67115,0.291924,1.87419,-2.15372,0.34863,1.81052,-1.97676,0.144141,1.84574,-2.08183,0.178649,1.64432,-2.26155,0.233589,1.56016,-2.30205,0.396183,1.51045,-2.19737,0.454383,1.48238,-2.1957,0.237058,1.38136,-1.82571,0.049043,1.43942,-1.90207,0.052148,1.47008,-1.95593,0.052768,1.44916,-2.01441,0.249387,1.40852,-2.09905,0.374983,1.15897,-1.77289,0.274596,1.06926,-1.79565,0.327642,1.00596,-1.81698,0.4433,0.960021,-1.80028,0.309079,0.85714,-1.78993,0.241651,0.825601,-1.79757,0.259046,0.957712,-1.79184,0.195191,0.926128,-1.79408,0.012934,0.785733,-1.80436,-0.106073,0.831237,-1.87591,0.056942,0.631259,-1.84519,0.003254,0.624,-1.77306,0.234222,1.10109,-2.15515,0.248333,1.01794,-2.13834,0.095938,1.07843,-2.11681,0.113154,0.99717,-2.10135,0.186888,0.861115,-2.10135,0.159855,0.674115,-2.0797,0.060134,0.720549,-2.10526,0.032421,0.656464,-2.09305,-0.039139,0.442163,-2.05407,-0.146389,0.374189,-2.00329,0.136268,0.375293,-2.02606,0.087333,0.340493,-2.09245,0.166378,1.29244,-1.8582,0.168618,1.31351,-2.07239},
/*1581*/{0.243524,1.8842,-1.7583,0.334944,1.81523,-1.89814,0.10273,1.78055,-1.68101,-0.007229,1.70478,-1.63877,0.125607,1.61193,-1.66894,0.19236,1.55465,-1.67295,0.293676,1.8782,-2.15221,0.348133,1.81411,-1.97512,0.144999,1.84798,-2.08231,0.180731,1.6472,-2.25822,0.238571,1.56474,-2.30104,0.400515,1.51756,-2.1929,0.460137,1.49208,-2.19016,0.23608,1.38396,-1.82428,0.048826,1.44157,-1.90463,0.053576,1.47242,-1.95747,0.053403,1.45181,-2.01753,0.251051,1.40883,-2.09859,0.379323,1.16694,-1.77244,0.281403,1.07521,-1.79572,0.33497,1.01295,-1.81705,0.451078,0.969818,-1.80032,0.320604,0.860445,-1.78945,0.254463,0.824826,-1.79708,0.265457,0.958428,-1.79234,0.20266,0.923538,-1.7953,0.028148,0.775083,-1.80524,-0.092188,0.812784,-1.87778,0.081808,0.622543,-1.84354,0.027791,0.612324,-1.77121,0.225767,1.10116,-2.1536,0.238374,1.01686,-2.13608,0.088019,1.08258,-2.1169,0.102573,1.00122,-2.10137,0.168328,0.862266,-2.10097,0.141557,0.675862,-2.07843,0.041853,0.722977,-2.10439,0.013568,0.659456,-2.09237,-0.059403,0.444652,-2.05551,-0.168326,0.377858,-2.00479,0.114929,0.375286,-2.02619,0.065466,0.340528,-2.09253,0.164999,1.29499,-1.85785,0.169918,1.31453,-2.07214},
/*1582*/{0.2393,1.88758,-1.7585,0.334665,1.81922,-1.89646,0.098462,1.78443,-1.68274,-0.011486,1.70931,-1.6415,0.119792,1.61653,-1.67076,0.187316,1.55949,-1.67335,0.295565,1.88189,-2.15062,0.348723,1.81791,-1.97296,0.146451,1.85085,-2.08272,0.182645,1.65054,-2.25513,0.243896,1.56919,-2.29929,0.405943,1.5254,-2.18883,0.465257,1.50068,-2.1844,0.236264,1.3877,-1.82367,0.049506,1.44446,-1.90513,0.053838,1.47461,-1.95898,0.054836,1.45413,-2.01918,0.253705,1.40897,-2.09758,0.381781,1.17476,-1.77264,0.286342,1.07978,-1.79553,0.342436,1.02015,-1.81805,0.456276,0.978949,-1.80002,0.332139,0.863754,-1.78844,0.266217,0.823784,-1.79618,0.270903,0.958252,-1.79399,0.209911,0.919199,-1.7959,0.042438,0.76279,-1.80664,-0.078176,0.792759,-1.87996,0.105592,0.613902,-1.84217,0.051144,0.60106,-1.77121,0.219644,1.10034,-2.1516,0.228263,1.01678,-2.13406,0.079389,1.08612,-2.11695,0.091129,1.00428,-2.10221,0.151745,0.864999,-2.10015,0.124084,0.678745,-2.078,0.023657,0.726746,-2.10418,-0.004581,0.662821,-2.09152,-0.07989,0.447248,-2.05693,-0.189497,0.382203,-2.00507,0.093429,0.375391,-2.02694,0.042954,0.340457,-2.09222,0.165048,1.29839,-1.85641,0.171657,1.31546,-2.07087},
/*1583*/{0.236523,1.89156,-1.75797,0.335229,1.82157,-1.89412,0.09378,1.78897,-1.68406,-0.015927,1.71354,-1.64444,0.115718,1.62212,-1.67296,0.182612,1.56517,-1.67577,0.296686,1.88649,-2.1488,0.348283,1.82143,-1.9711,0.147651,1.85315,-2.08326,0.183792,1.65415,-2.25178,0.248362,1.57388,-2.29891,0.409553,1.53413,-2.18523,0.469702,1.51053,-2.179,0.236942,1.39053,-1.8241,0.050506,1.44786,-1.90801,0.055786,1.47741,-1.96107,0.056312,1.45675,-2.02079,0.254784,1.40952,-2.09731,0.382947,1.18208,-1.7725,0.28909,1.08582,-1.79606,0.347595,1.02745,-1.81723,0.46182,0.988569,-1.80169,0.341676,0.866341,-1.78799,0.279841,0.823287,-1.79564,0.27704,0.957749,-1.79479,0.217716,0.916551,-1.79799,0.057598,0.751088,-1.80801,-0.063053,0.773657,-1.88253,0.129763,0.605194,-1.84015,0.075304,0.590989,-1.76954,0.211844,1.10073,-2.15008,0.218112,1.01668,-2.13173,0.072332,1.09122,-2.11633,0.078936,1.00995,-2.10278,0.136328,0.867422,-2.09874,0.10516,0.681342,-2.07649,0.005881,0.730205,-2.10377,-0.02321,0.666844,-2.09139,-0.099338,0.451235,-2.05459,-0.208027,0.387583,-2.00438,0.071923,0.374396,-2.02446,0.021299,0.340582,-2.09189,0.164843,1.30148,-1.85644,0.172647,1.3167,-2.071},
/*1584*/{0.232752,1.89506,-1.75809,0.333713,1.82716,-1.89179,0.09057,1.79267,-1.68534,-0.021664,1.71787,-1.64643,0.109994,1.6276,-1.67506,0.179094,1.57053,-1.6761,0.298542,1.89157,-2.14795,0.348483,1.82532,-1.96856,0.149123,1.85636,-2.08348,0.184009,1.65807,-2.24965,0.252292,1.57879,-2.29766,0.413754,1.54221,-2.17995,0.473508,1.5198,-2.17316,0.237762,1.39492,-1.82484,0.052316,1.45071,-1.90922,0.057012,1.47992,-1.96283,0.059091,1.45925,-2.02176,0.25752,1.41008,-2.09603,0.385343,1.18892,-1.77261,0.292131,1.09044,-1.79663,0.351481,1.0324,-1.81889,0.466871,0.997043,-1.80127,0.351438,0.868565,-1.78678,0.291713,0.822406,-1.79482,0.281784,0.956094,-1.79719,0.225909,0.911438,-1.80025,0.073824,0.738478,-1.80886,-0.047122,0.75402,-1.8849,0.154082,0.596781,-1.83777,0.099391,0.580519,-1.76733,0.206091,1.10136,-2.14778,0.208316,1.01738,-2.12915,0.063629,1.09701,-2.11773,0.06875,1.01487,-2.10313,0.121998,0.870479,-2.09663,0.086837,0.6852,-2.07545,-0.011505,0.734574,-2.10355,-0.041348,0.671171,-2.0913,-0.121226,0.455759,-2.05381,-0.230245,0.394211,-2.00556,0.050139,0.374919,-2.02529,-0.00016,0.340982,-2.0911,0.165945,1.30523,-1.85538,0.175082,1.31798,-2.07004},
/*1585*/{0.230452,1.89915,-1.75741,0.332798,1.83146,-1.8905,0.086112,1.79788,-1.68637,-0.026053,1.72268,-1.64924,0.105805,1.63299,-1.67752,0.174266,1.57621,-1.67713,0.300132,1.896,-2.1459,0.349956,1.83001,-1.96702,0.150296,1.85967,-2.084,0.185848,1.66232,-2.24751,0.25737,1.58399,-2.29684,0.416728,1.55082,-2.17602,0.477431,1.53004,-2.16782,0.239294,1.39946,-1.82619,0.052301,1.45483,-1.91133,0.058345,1.4832,-1.96474,0.061365,1.4622,-2.02355,0.258646,1.41025,-2.09643,0.386857,1.1963,-1.77262,0.297052,1.09672,-1.79687,0.356121,1.03962,-1.81902,0.470236,1.00587,-1.80004,0.360482,0.87107,-1.78588,0.303125,0.821369,-1.79374,0.286648,0.954913,-1.79764,0.233213,0.906388,-1.80261,0.090284,0.726747,-1.80968,-0.030667,0.734952,-1.88652,0.178701,0.589716,-1.83562,0.123904,0.570695,-1.76598,0.199209,1.10251,-2.14526,0.198747,1.01837,-2.12597,0.056693,1.1027,-2.11756,0.059038,1.02027,-2.10293,0.107104,0.873419,-2.09425,0.068586,0.689382,-2.07486,-0.029317,0.739771,-2.10283,-0.059702,0.676305,-2.09069,-0.139659,0.461166,-2.05424,-0.247627,0.40137,-2.00488,0.028738,0.375513,-2.02526,-0.022446,0.340352,-2.0905,0.16635,1.30963,-1.85493,0.175834,1.31925,-2.06974},
/*1586*/{0.227436,1.90275,-1.75748,0.332575,1.83597,-1.88846,0.082626,1.80205,-1.68711,-0.02989,1.72816,-1.65239,0.102035,1.63868,-1.67928,0.169715,1.58218,-1.67867,0.301024,1.90089,-2.1449,0.348843,1.83451,-1.96505,0.152164,1.8628,-2.08488,0.189041,1.66655,-2.24652,0.261686,1.58895,-2.2955,0.418682,1.5587,-2.17056,0.480005,1.54001,-2.16209,0.241434,1.40374,-1.82653,0.053832,1.45867,-1.91184,0.060135,1.48633,-1.96642,0.06287,1.46532,-2.02506,0.258653,1.41135,-2.09804,0.389245,1.20319,-1.77253,0.29862,1.10244,-1.79691,0.359029,1.04513,-1.8184,0.47426,1.01453,-1.79978,0.369276,0.872867,-1.78453,0.314217,0.820278,-1.79282,0.291297,0.952938,-1.79934,0.239667,0.902151,-1.80313,0.10771,0.715051,-1.81035,-0.012541,0.713364,-1.88873,0.202782,0.582043,-1.83315,0.148444,0.560595,-1.76369,0.19289,1.1039,-2.14301,0.189893,1.02002,-2.12347,0.050865,1.10753,-2.11804,0.04938,1.02633,-2.10352,0.0936,0.878339,-2.09268,0.050822,0.694693,-2.07488,-0.046821,0.745491,-2.10202,-0.077256,0.683115,-2.09041,-0.158815,0.466554,-2.05339,-0.267655,0.410056,-2.0052,0.007402,0.376112,-2.02411,-0.044502,0.341427,-2.09028,0.167714,1.31388,-1.85468,0.17622,1.32095,-2.06963},
/*1587*/{0.224758,1.9065,-1.75739,0.332023,1.84124,-1.88697,0.079145,1.80669,-1.68852,-0.034381,1.73327,-1.655,0.098777,1.64469,-1.68151,0.166682,1.5875,-1.67998,0.302493,1.90592,-2.14288,0.349371,1.83939,-1.96261,0.153034,1.86631,-2.08471,0.192312,1.67133,-2.24632,0.266214,1.59443,-2.29462,0.421635,1.56835,-2.16726,0.482233,1.54969,-2.15723,0.24268,1.40804,-1.82847,0.05616,1.46261,-1.91276,0.062915,1.48935,-1.96778,0.065793,1.46934,-2.02579,0.261034,1.41102,-2.0976,0.390315,1.20951,-1.77231,0.300183,1.10831,-1.79673,0.361713,1.05205,-1.81722,0.476757,1.02171,-1.79914,0.376369,0.873606,-1.78378,0.325379,0.818307,-1.79194,0.295795,0.949433,-1.8026,0.245512,0.89798,-1.80713,0.125562,0.703095,-1.81021,0.00533,0.693829,-1.89009,0.227728,0.575684,-1.83111,0.173979,0.552086,-1.76212,0.1866,1.10564,-2.14054,0.181685,1.02255,-2.12058,0.04357,1.11437,-2.11792,0.040544,1.03346,-2.10324,0.078617,0.884653,-2.0923,0.034128,0.700752,-2.0751,-0.064085,0.752385,-2.10187,-0.094726,0.689478,-2.09032,-0.177992,0.472375,-2.05281,-0.285929,0.417813,-2.00217,-0.014188,0.375925,-2.02345,-0.065929,0.341872,-2.08967,0.16868,1.31793,-1.85395,0.177429,1.32228,-2.06896},
/*1588*/{0.222371,1.91035,-1.75717,0.33171,1.84412,-1.88473,0.076335,1.81138,-1.68964,-0.038225,1.73716,-1.65759,0.095195,1.64969,-1.68347,0.163128,1.59321,-1.68111,0.303691,1.91136,-2.14139,0.350299,1.84424,-1.96104,0.154354,1.86943,-2.08499,0.195828,1.67641,-2.24693,0.271165,1.59983,-2.29412,0.423637,1.57638,-2.16274,0.484243,1.55921,-2.15219,0.24448,1.41239,-1.8299,0.056981,1.46689,-1.91359,0.064492,1.49327,-1.97006,0.068929,1.47223,-2.02629,0.261672,1.41215,-2.09803,0.391462,1.21537,-1.77213,0.304782,1.11388,-1.79522,0.363297,1.05742,-1.81843,0.479429,1.0287,-1.79953,0.384988,0.87407,-1.78289,0.334419,0.817806,-1.79275,0.300474,0.946486,-1.80454,0.254079,0.89089,-1.80776,0.143493,0.689958,-1.81065,0.024006,0.674188,-1.89132,0.253259,0.568408,-1.82938,0.199143,0.54275,-1.7603,0.181073,1.10837,-2.13786,0.172108,1.02482,-2.11907,0.038147,1.12115,-2.11855,0.031727,1.03976,-2.10335,0.063031,0.89102,-2.09279,0.016959,0.706982,-2.07583,-0.080951,0.760028,-2.1014,-0.111587,0.697336,-2.09039,-0.193219,0.479915,-2.05297,-0.303487,0.427049,-2.00106,-0.036634,0.376262,-2.02298,-0.087738,0.342002,-2.08871,0.169702,1.3224,-1.85357,0.178173,1.32419,-2.06864},
/*1589*/{0.220163,1.91385,-1.75713,0.324838,1.85168,-1.88483,0.073457,1.81603,-1.6913,-0.042802,1.74198,-1.65996,0.091568,1.65523,-1.68522,0.159957,1.59876,-1.68201,0.305674,1.9163,-2.13985,0.349917,1.84929,-1.95929,0.155414,1.87383,-2.08507,0.199432,1.68203,-2.24838,0.276096,1.60545,-2.29328,0.42372,1.5831,-2.15904,0.486011,1.56826,-2.14725,0.247114,1.41566,-1.83084,0.059333,1.4712,-1.91455,0.065729,1.49688,-1.97147,0.071651,1.47647,-2.02703,0.264654,1.41281,-2.09807,0.393146,1.22171,-1.77198,0.303102,1.11785,-1.7963,0.36523,1.06272,-1.81707,0.48079,1.03438,-1.79934,0.392262,0.874235,-1.78211,0.34708,0.814806,-1.79061,0.304609,0.941635,-1.80647,0.262173,0.884212,-1.80897,0.162247,0.677346,-1.81059,0.043992,0.654142,-1.89183,0.2772,0.562566,-1.8282,0.225964,0.533899,-1.75916,0.175638,1.10987,-2.13645,0.163629,1.02766,-2.11663,0.033286,1.12906,-2.11939,0.023192,1.04732,-2.10356,0.047756,0.897189,-2.09376,0.001978,0.714755,-2.07691,-0.096735,0.768525,-2.10096,-0.127839,0.705377,-2.08991,-0.211218,0.486142,-2.05372,-0.320873,0.439889,-1.99946,-0.058567,0.376486,-2.02248,-0.109497,0.342943,-2.08821,0.170906,1.32622,-1.8534,0.179575,1.32633,-2.06846},
/*1590*/{0.218528,1.91745,-1.75721,0.325501,1.85575,-1.8828,0.070845,1.81988,-1.69247,-0.046654,1.74621,-1.66369,0.088335,1.66029,-1.68717,0.156925,1.60427,-1.68361,0.306729,1.92156,-2.13846,0.349557,1.85413,-1.95761,0.155971,1.8773,-2.0852,0.203521,1.68807,-2.25057,0.280446,1.61071,-2.29229,0.426574,1.59249,-2.15484,0.48765,1.57736,-2.14253,0.249476,1.4199,-1.8323,0.0614,1.47673,-1.91506,0.068632,1.50121,-1.97261,0.073667,1.4804,-2.0281,0.265841,1.4131,-2.09803,0.395052,1.22669,-1.77164,0.308053,1.12537,-1.79419,0.366719,1.06755,-1.81662,0.479297,1.03921,-1.80068,0.399573,0.873811,-1.78157,0.357303,0.812024,-1.79007,0.309187,0.936427,-1.80739,0.269201,0.876659,-1.81027,0.178924,0.664912,-1.81,0.06376,0.634333,-1.89151,0.302492,0.557055,-1.82683,0.251704,0.525758,-1.75724,0.169927,1.11259,-2.1349,0.155164,1.03097,-2.11502,0.027679,1.13558,-2.11882,0.015587,1.05548,-2.10379,0.032708,0.904238,-2.09483,-0.013452,0.722633,-2.07848,-0.112033,0.776724,-2.10079,-0.143388,0.714113,-2.08947,-0.228403,0.493503,-2.05365,-0.335682,0.451426,-1.99923,-0.081363,0.376492,-2.02194,-0.132303,0.343177,-2.08814,0.171859,1.33112,-1.85257,0.179713,1.32817,-2.06765},
/*1591*/{0.216791,1.92147,-1.75655,0.325431,1.86076,-1.88175,0.067808,1.8247,-1.69388,-0.048466,1.75092,-1.66605,0.085248,1.66527,-1.68893,0.15395,1.60928,-1.68458,0.307803,1.92664,-2.1368,0.349719,1.85828,-1.9559,0.158187,1.88149,-2.08534,0.205448,1.69389,-2.25147,0.284677,1.61628,-2.29166,0.426638,1.59962,-2.1501,0.488455,1.58601,-2.13825,0.251095,1.42372,-1.83287,0.06288,1.48175,-1.91551,0.071432,1.50569,-1.97381,0.076795,1.48404,-2.02864,0.266031,1.41435,-2.09797,0.394946,1.23091,-1.77222,0.308377,1.12983,-1.79352,0.367798,1.0729,-1.8141,0.478263,1.04195,-1.80029,0.406809,0.873231,-1.78091,0.368705,0.808921,-1.7888,0.313631,0.930809,-1.80945,0.275976,0.8692,-1.81148,0.198604,0.652443,-1.80982,0.084426,0.615244,-1.89101,0.327238,0.551639,-1.82585,0.278788,0.518675,-1.75721,0.165312,1.11458,-2.13357,0.147211,1.03391,-2.11352,0.023911,1.14443,-2.11954,0.008496,1.06384,-2.10339,0.019475,0.912397,-2.09627,-0.028163,0.7307,-2.07978,-0.126247,0.785788,-2.10123,-0.157132,0.723265,-2.08989,-0.242113,0.501268,-2.05477,-0.350541,0.465214,-1.99807,-0.103363,0.377,-2.02189,-0.153011,0.344429,-2.0873,0.17239,1.33558,-1.85194,0.179902,1.33047,-2.06698},
/*1592*/{0.215124,1.92481,-1.75647,0.325808,1.86497,-1.8806,0.065543,1.82836,-1.69519,-0.052578,1.75494,-1.6687,0.082772,1.66988,-1.69047,0.151494,1.61383,-1.68528,0.308368,1.931,-2.13518,0.349728,1.86276,-1.95427,0.158712,1.88486,-2.08548,0.210906,1.69824,-2.25477,0.288826,1.6212,-2.29134,0.427365,1.60749,-2.14721,0.48919,1.59413,-2.13411,0.253058,1.42709,-1.83424,0.065977,1.48675,-1.91561,0.074229,1.50993,-1.97448,0.078815,1.48818,-2.02883,0.268686,1.41535,-2.09815,0.396254,1.23484,-1.77201,0.306533,1.13215,-1.79292,0.366941,1.0773,-1.81386,0.477692,1.04492,-1.79984,0.413353,0.872054,-1.77985,0.377561,0.806046,-1.78823,0.317962,0.924473,-1.8091,0.283121,0.861753,-1.81182,0.217005,0.638154,-1.80947,0.105653,0.595703,-1.89014,0.352764,0.547166,-1.82673,0.306059,0.511941,-1.75692,0.160541,1.11759,-2.13315,0.13963,1.03728,-2.1125,0.020875,1.15159,-2.11873,0.001832,1.0728,-2.10305,0.007365,0.921584,-2.09746,-0.040176,0.738934,-2.08131,-0.139109,0.794336,-2.1005,-0.170336,0.731786,-2.08936,-0.25498,0.508276,-2.05438,-0.36409,0.479933,-1.99571,-0.124825,0.37662,-2.02208,-0.17585,0.345444,-2.08682,0.173704,1.33965,-1.85162,0.180712,1.33297,-2.06664},
/*1593*/{0.21372,1.92802,-1.75669,0.325687,1.8693,-1.87879,0.063587,1.83227,-1.69683,-0.053788,1.7593,-1.67152,0.080429,1.67465,-1.69272,0.148417,1.61867,-1.68625,0.309699,1.93556,-2.13402,0.350268,1.86685,-1.95262,0.160203,1.88784,-2.08507,0.215371,1.70383,-2.25663,0.293376,1.62645,-2.29101,0.427691,1.61493,-2.14388,0.489917,1.60242,-2.1312,0.255115,1.43072,-1.83478,0.067951,1.49289,-1.91535,0.077029,1.51417,-1.97548,0.08138,1.4924,-2.02898,0.268787,1.41709,-2.09799,0.396611,1.23804,-1.77255,0.308313,1.13847,-1.79197,0.365721,1.08055,-1.81254,0.476264,1.04643,-1.79966,0.419926,0.87,-1.77979,0.387689,0.802007,-1.78748,0.321755,0.91792,-1.81143,0.291565,0.85307,-1.8123,0.237379,0.626197,-1.80959,0.127586,0.577107,-1.8892,0.377205,0.543228,-1.82551,0.3334,0.504933,-1.7562,0.155387,1.12041,-2.1328,0.132616,1.04078,-2.11235,0.016291,1.15879,-2.1184,-0.003665,1.0804,-2.10282,-0.003483,0.930127,-2.09846,-0.052339,0.747192,-2.08335,-0.15039,0.803024,-2.09996,-0.181532,0.740157,-2.08924,-0.268294,0.515893,-2.05528,-0.376506,0.495163,-1.99493,-0.14728,0.377622,-2.02213,-0.199138,0.34685,-2.08657,0.174433,1.34435,-1.85088,0.180536,1.33572,-2.06586},
/*1594*/{0.212645,1.93158,-1.75635,0.325422,1.87269,-1.87766,0.061518,1.836,-1.69838,-0.057099,1.7631,-1.67422,0.078452,1.67857,-1.69442,0.146975,1.6226,-1.68697,0.310948,1.93993,-2.13195,0.350745,1.87093,-1.95171,0.161202,1.89102,-2.08525,0.218582,1.70857,-2.2594,0.297548,1.63163,-2.29113,0.428055,1.62093,-2.14084,0.490262,1.60903,-2.12742,0.257958,1.43491,-1.835,0.06991,1.49859,-1.91578,0.079749,1.51879,-1.97601,0.083986,1.49688,-2.0292,0.269966,1.41817,-2.09779,0.397362,1.24097,-1.77306,0.307025,1.14273,-1.79063,0.3631,1.08328,-1.81128,0.472867,1.04796,-1.80036,0.426767,0.867711,-1.77922,0.396871,0.798094,-1.78739,0.326538,0.910432,-1.81104,0.29774,0.844525,-1.81098,0.257226,0.61414,-1.80934,0.150316,0.559116,-1.88895,0.401152,0.538526,-1.82557,0.36,0.499492,-1.75558,0.151236,1.12324,-2.1331,0.125755,1.04453,-2.11279,0.014074,1.16532,-2.11769,-0.008236,1.08802,-2.10195,-0.012403,0.937778,-2.09949,-0.062589,0.755989,-2.08503,-0.160687,0.811523,-2.09957,-0.192912,0.747574,-2.08904,-0.279335,0.524518,-2.056,-0.385764,0.511377,-1.99356,-0.167806,0.377573,-2.02352,-0.22252,0.349901,-2.08671,0.175621,1.34943,-1.8498,0.180907,1.33833,-2.06468},
/*1595*/{0.212119,1.93459,-1.7566,0.326062,1.87661,-1.8769,0.060638,1.83915,-1.69965,-0.058637,1.76655,-1.67728,0.077127,1.68276,-1.6957,0.144973,1.62634,-1.68774,0.311349,1.94384,-2.13111,0.350726,1.87535,-1.94998,0.162278,1.89402,-2.08534,0.222956,1.71341,-2.26157,0.301273,1.63614,-2.29047,0.428139,1.62776,-2.13848,0.490428,1.61671,-2.12383,0.258653,1.43825,-1.83654,0.07171,1.50327,-1.9157,0.081369,1.52268,-1.97748,0.085612,1.50017,-2.02935,0.27118,1.41902,-2.09723,0.397088,1.24233,-1.77325,0.305188,1.14545,-1.78937,0.36058,1.08564,-1.8099,0.468034,1.04703,-1.80056,0.432626,0.865223,-1.77937,0.407105,0.794118,-1.78677,0.330635,0.902676,-1.81062,0.305693,0.835017,-1.81305,0.276679,0.602961,-1.80884,0.172945,0.542279,-1.88824,0.425296,0.535826,-1.82622,0.386315,0.492375,-1.75659,0.14693,1.12656,-2.13404,0.119954,1.04771,-2.11394,0.010846,1.17169,-2.11687,-0.01381,1.09375,-2.10173,-0.019914,0.944301,-2.09974,-0.072696,0.762771,-2.08708,-0.170269,0.819707,-2.0989,-0.202665,0.75644,-2.08835,-0.288137,0.533654,-2.05582,-0.395283,0.525787,-1.99036,-0.186683,0.378041,-2.02523,-0.245767,0.352786,-2.08553,0.175854,1.35349,-1.84923,0.180876,1.34044,-2.06401},
/*1596*/{0.211156,1.93714,-1.7563,0.325742,1.87982,-1.87545,0.058366,1.84279,-1.70108,-0.061366,1.77005,-1.68049,0.074529,1.6858,-1.69644,0.143704,1.62976,-1.68805,0.311967,1.9472,-2.12889,0.3511,1.87863,-1.94887,0.16378,1.89719,-2.08555,0.226971,1.71756,-2.26393,0.304385,1.64057,-2.29054,0.427447,1.6331,-2.1358,0.48991,1.62261,-2.12052,0.259114,1.44103,-1.83669,0.074444,1.50766,-1.91527,0.082505,1.52762,-1.97771,0.087485,1.50405,-2.02896,0.272126,1.42106,-2.09697,0.397936,1.24412,-1.77424,0.305901,1.14902,-1.7881,0.357583,1.08719,-1.8092,0.464619,1.04683,-1.80036,0.4382,0.862263,-1.77862,0.416678,0.789594,-1.78625,0.33446,0.894812,-1.81138,0.313037,0.825173,-1.813,0.296711,0.592215,-1.81012,0.196447,0.525786,-1.88872,0.447819,0.532474,-1.82618,0.411035,0.486807,-1.75684,0.142984,1.12957,-2.13531,0.115586,1.05045,-2.11526,0.008037,1.17668,-2.11509,-0.017453,1.09929,-2.10049,-0.026219,0.95073,-2.10007,-0.080903,0.769573,-2.08823,-0.178606,0.826813,-2.09831,-0.210208,0.764154,-2.08802,-0.299462,0.542015,-2.05595,-0.403806,0.543196,-1.98867,-0.206638,0.378683,-2.02637,-0.268184,0.356912,-2.08416,0.175943,1.3571,-1.84885,0.180775,1.34356,-2.0636},
/*1597*/{0.211033,1.93984,-1.75632,0.327468,1.88326,-1.87452,0.057546,1.84569,-1.70245,-0.061952,1.77289,-1.68329,0.073846,1.68922,-1.69833,0.142189,1.63301,-1.68821,0.313117,1.95058,-2.12788,0.351922,1.88192,-1.94753,0.164643,1.90049,-2.08459,0.232799,1.72243,-2.2663,0.306992,1.64388,-2.28972,0.427762,1.63789,-2.13374,0.489413,1.62906,-2.11337,0.262841,1.44399,-1.83687,0.076464,1.51202,-1.91427,0.084285,1.53087,-1.9777,0.090351,1.50798,-2.02929,0.272945,1.42207,-2.09679,0.398293,1.24524,-1.77566,0.301276,1.15055,-1.78774,0.355906,1.0874,-1.80738,0.460541,1.04526,-1.80039,0.443991,0.858545,-1.77841,0.42801,0.78723,-1.78692,0.338243,0.884834,-1.81154,0.320392,0.815117,-1.81255,0.31617,0.581082,-1.80973,0.219144,0.510876,-1.88969,0.470167,0.528825,-1.82733,0.435992,0.481293,-1.758,0.1389,1.13293,-2.13653,0.110019,1.05612,-2.11778,0.005204,1.18114,-2.11359,-0.021731,1.10392,-2.09946,-0.030772,0.95556,-2.09973,-0.088308,0.775671,-2.08952,-0.185134,0.834648,-2.09763,-0.219074,0.771149,-2.08825,-0.307435,0.550718,-2.05636,-0.411594,0.559564,-1.98821,-0.224419,0.37898,-2.02644,-0.289912,0.363274,-2.0822,0.177912,1.3609,-1.84797,0.181309,1.34581,-2.06265},
/*1598*/{0.210954,1.94209,-1.75609,0.32712,1.88567,-1.87391,0.057019,1.84898,-1.70335,-0.065957,1.77482,-1.68561,0.072306,1.69211,-1.6989,0.141412,1.63544,-1.68863,0.314134,1.95402,-2.12653,0.352436,1.8852,-1.94639,0.16619,1.90296,-2.08402,0.237059,1.72626,-2.26779,0.309977,1.64801,-2.28968,0.428089,1.64374,-2.13163,0.488773,1.63452,-2.11074,0.262621,1.44652,-1.83762,0.078648,1.51642,-1.91376,0.085774,1.53547,-1.97784,0.091952,1.51202,-2.02928,0.273244,1.42434,-2.09628,0.397093,1.24495,-1.77592,0.29775,1.14907,-1.78701,0.352046,1.08718,-1.80727,0.456796,1.04303,-1.79972,0.44803,0.855002,-1.77798,0.435436,0.781598,-1.78624,0.341518,0.876137,-1.81144,0.327525,0.805051,-1.81337,0.334964,0.570579,-1.81043,0.242536,0.496496,-1.8907,0.492742,0.526637,-1.82743,0.460534,0.476178,-1.75938,0.136194,1.13631,-2.13807,0.106542,1.05844,-2.11916,0.001833,1.18493,-2.11187,-0.023402,1.10795,-2.09828,-0.034545,0.959531,-2.09948,-0.094792,0.780907,-2.09048,-0.190185,0.840772,-2.09713,-0.225048,0.777844,-2.08839,-0.318063,0.559836,-2.05739,-0.419,0.577132,-1.98669,-0.242689,0.378133,-2.0264,-0.311237,0.37107,-2.08054,0.17746,1.36427,-1.8479,0.180741,1.34907,-2.06257},
/*1599*/{0.21098,1.94425,-1.75565,0.328539,1.88901,-1.87232,0.056345,1.85164,-1.7043,-0.06569,1.778,-1.68869,0.071691,1.69423,-1.69967,0.139362,1.63773,-1.6885,0.314423,1.95696,-2.12492,0.352684,1.88705,-1.94553,0.167013,1.90581,-2.08365,0.241148,1.72993,-2.26983,0.312661,1.65152,-2.28983,0.427376,1.64798,-2.12965,0.488147,1.6386,-2.10752,0.263294,1.44806,-1.83845,0.080011,1.52037,-1.91342,0.085734,1.53862,-1.97811,0.092704,1.51586,-2.02825,0.273923,1.42628,-2.09649,0.395205,1.24516,-1.77764,0.297654,1.15308,-1.78626,0.348006,1.08681,-1.80626,0.452297,1.0399,-1.79869,0.452034,0.851171,-1.77686,0.441476,0.775598,-1.78523,0.344296,0.86531,-1.81039,0.334243,0.794624,-1.81229,0.353221,0.55954,-1.81073,0.264998,0.483027,-1.89226,0.513769,0.524261,-1.82849,0.483728,0.471757,-1.75974,0.134435,1.13879,-2.13871,0.104836,1.06162,-2.121,0.000797,1.18816,-2.11086,-0.024854,1.1102,-2.09659,-0.036318,0.962213,-2.09904,-0.100298,0.784739,-2.09094,-0.19508,0.846422,-2.09713,-0.230703,0.785145,-2.08841,-0.331873,0.568799,-2.05781,-0.424338,0.594101,-1.98662,-0.261664,0.378653,-2.02558,-0.332626,0.380034,-2.07828,0.177414,1.36676,-1.84816,0.180122,1.35195,-2.06287},
/*1600*/{0.211881,1.94621,-1.75479,0.328577,1.89094,-1.87156,0.055289,1.85441,-1.7064,-0.066449,1.78018,-1.69082,0.071417,1.69658,-1.70104,0.139597,1.63993,-1.68857,0.315417,1.95931,-2.12385,0.353601,1.8898,-1.94431,0.168677,1.90762,-2.08289,0.244963,1.7336,-2.26996,0.315392,1.65504,-2.29017,0.427635,1.65132,-2.12823,0.487672,1.64253,-2.10464,0.26361,1.4499,-1.83854,0.080453,1.52377,-1.91289,0.08721,1.54181,-1.97744,0.094015,1.51899,-2.02777,0.273802,1.42835,-2.09635,0.39513,1.24297,-1.77703,0.29242,1.15133,-1.78518,0.342958,1.086,-1.8052,0.446521,1.03589,-1.79717,0.455274,0.847208,-1.77663,0.450583,0.772414,-1.78559,0.346865,0.855303,-1.80883,0.341307,0.783787,-1.81128,0.371145,0.551383,-1.81189,0.286643,0.470555,-1.89459,0.533558,0.522008,-1.83003,0.505771,0.467721,-1.76195,0.132455,1.1421,-2.13953,0.103559,1.06381,-2.12248,-0.000707,1.19002,-2.11016,-0.025633,1.11248,-2.09556,-0.036429,0.964512,-2.09889,-0.104988,0.787591,-2.09098,-0.197819,0.852396,-2.09787,-0.234152,0.791791,-2.08867,-0.342976,0.578538,-2.05782,-0.430335,0.609805,-1.98604,-0.281248,0.378487,-2.02376,-0.351989,0.388693,-2.07592,0.177237,1.36917,-1.84801,0.179647,1.35465,-2.06274},
/*1601*/{0.212016,1.94768,-1.75446,0.329669,1.89337,-1.87127,0.055715,1.85615,-1.70776,-0.068,1.78188,-1.69372,0.071906,1.69862,-1.70219,0.138905,1.64084,-1.68865,0.316153,1.96194,-2.12216,0.354055,1.89238,-1.94328,0.169255,1.91065,-2.08284,0.24948,1.73696,-2.2711,0.317683,1.65811,-2.2907,0.427113,1.65436,-2.12641,0.487321,1.64582,-2.10247,0.266202,1.45106,-1.83889,0.081942,1.52633,-1.91135,0.087579,1.54491,-1.97784,0.094548,1.52183,-2.02723,0.274001,1.43043,-2.09664,0.391433,1.24121,-1.7773,0.288306,1.15046,-1.78502,0.339841,1.0856,-1.80334,0.442483,1.0328,-1.79569,0.458048,0.842047,-1.77652,0.456906,0.765847,-1.78507,0.349193,0.845102,-1.80751,0.346403,0.773163,-1.81153,0.3894,0.541413,-1.81223,0.308164,0.459577,-1.89656,0.552036,0.521186,-1.83109,0.528519,0.463888,-1.76467,0.132584,1.14368,-2.14069,0.104057,1.06565,-2.12342,-0.000505,1.19167,-2.10881,-0.025429,1.11377,-2.09463,-0.035793,0.965166,-2.09821,-0.108399,0.790169,-2.09071,-0.199489,0.857641,-2.09787,-0.238905,0.798389,-2.09027,-0.351165,0.589034,-2.05871,-0.437104,0.626156,-1.98801,-0.301011,0.379579,-2.02086,-0.372839,0.398116,-2.07384,0.178577,1.37121,-1.84816,0.179533,1.3571,-2.06293},
/*1602*/{0.213128,1.94919,-1.75405,0.330251,1.89457,-1.87024,0.055141,1.85792,-1.7091,-0.068532,1.78316,-1.6959,0.070847,1.70005,-1.70212,0.139166,1.64234,-1.68829,0.317054,1.96432,-2.12149,0.354454,1.89391,-1.94245,0.170654,1.91306,-2.0824,0.252853,1.73992,-2.27173,0.319378,1.66009,-2.29091,0.42733,1.65693,-2.12522,0.486502,1.64817,-2.09976,0.267035,1.45342,-1.83959,0.082013,1.52911,-1.91214,0.088908,1.54789,-1.97652,0.095628,1.52551,-2.02624,0.274176,1.43272,-2.09669,0.389148,1.23904,-1.77779,0.285495,1.15079,-1.78372,0.335474,1.08327,-1.80205,0.437971,1.0273,-1.79436,0.461441,0.837156,-1.77599,0.462759,0.761245,-1.78648,0.351375,0.836034,-1.80529,0.352915,0.763917,-1.80809,0.40572,0.533096,-1.81447,0.328998,0.448436,-1.89877,0.570131,0.520356,-1.83203,0.547895,0.46132,-1.76793,0.133112,1.1457,-2.14096,0.104609,1.0669,-2.12449,-0.000197,1.19247,-2.10829,-0.024167,1.11446,-2.0939,-0.034021,0.966066,-2.09675,-0.111705,0.792013,-2.09001,-0.200809,0.862665,-2.09807,-0.241237,0.804445,-2.09043,-0.357057,0.599063,-2.05897,-0.443166,0.642657,-1.99042,-0.323663,0.388933,-2.01691,-0.393674,0.409669,-2.07159,0.178973,1.37369,-1.8483,0.179439,1.36004,-2.0631},
/*1603*/{0.214042,1.95079,-1.75336,0.330235,1.89513,-1.8695,0.056241,1.85975,-1.70947,-0.067943,1.7843,-1.69756,0.070732,1.7006,-1.70292,0.139011,1.64332,-1.68777,0.317465,1.96595,-2.11982,0.355093,1.89551,-1.94173,0.171433,1.91538,-2.08214,0.255935,1.74267,-2.27162,0.321014,1.66283,-2.29016,0.425959,1.65862,-2.12421,0.486075,1.64995,-2.09883,0.267026,1.45527,-1.84071,0.083316,1.53149,-1.91045,0.088939,1.55035,-1.97654,0.09506,1.52765,-2.02607,0.274071,1.43532,-2.09659,0.385569,1.2353,-1.77734,0.282023,1.14944,-1.78249,0.32859,1.08088,-1.80075,0.43403,1.02304,-1.79339,0.463995,0.832139,-1.77585,0.469435,0.756222,-1.7867,0.354009,0.82563,-1.80237,0.359057,0.753595,-1.80673,0.42274,0.527554,-1.81539,0.348411,0.438933,-1.90012,0.586916,0.521554,-1.83405,0.567585,0.459143,-1.7692,0.133945,1.14705,-2.14158,0.106682,1.06854,-2.12502,0.001685,1.19191,-2.10694,-0.022643,1.11382,-2.09279,-0.03111,0.965825,-2.0963,-0.114952,0.793732,-2.08897,-0.201138,0.866232,-2.09779,-0.243015,0.810131,-2.09019,-0.363099,0.608282,-2.05949,-0.450584,0.659162,-1.99237,-0.34345,0.40063,-2.01325,-0.41163,0.421686,-2.06802,0.179452,1.37568,-1.84849,0.179062,1.36252,-2.06332},
/*1604*/{0.215599,1.95149,-1.75269,0.332309,1.89647,-1.86864,0.056783,1.86143,-1.71042,-0.068882,1.78498,-1.69981,0.070828,1.70176,-1.70358,0.138881,1.64356,-1.687,0.318367,1.96773,-2.11917,0.355936,1.89679,-1.94064,0.172659,1.91715,-2.08155,0.258374,1.74517,-2.27154,0.322134,1.66434,-2.29073,0.426015,1.65996,-2.12281,0.48542,1.65032,-2.0971,0.268851,1.45636,-1.84061,0.083806,1.53319,-1.91041,0.088303,1.553,-1.9762,0.095663,1.52912,-2.0255,0.274222,1.43731,-2.09671,0.382338,1.23138,-1.77695,0.276158,1.1471,-1.78202,0.323092,1.07751,-1.80036,0.429272,1.01686,-1.79261,0.46763,0.827661,-1.77598,0.474619,0.751668,-1.78704,0.35695,0.815819,-1.79994,0.364354,0.745202,-1.80433,0.438013,0.51765,-1.81643,0.366428,0.430019,-1.90121,0.602221,0.521644,-1.83609,0.585941,0.458114,-1.77222,0.136085,1.14806,-2.1414,0.109171,1.06855,-2.12534,0.002343,1.19134,-2.10622,-0.019934,1.11335,-2.09234,-0.028212,0.96494,-2.0956,-0.117604,0.793997,-2.08702,-0.199758,0.870917,-2.09817,-0.244928,0.815946,-2.0898,-0.372724,0.619979,-2.05943,-0.459652,0.6752,-1.99518,-0.36024,0.411425,-2.00886,-0.427174,0.435376,-2.06556,0.180383,1.37728,-1.84855,0.179297,1.36444,-2.0634},
/*1605*/{0.216762,1.95229,-1.75227,0.332389,1.89695,-1.86856,0.057166,1.86198,-1.71159,-0.068701,1.78508,-1.70118,0.071035,1.70192,-1.70412,0.139571,1.64333,-1.68676,0.318349,1.9686,-2.11778,0.356453,1.89748,-1.94033,0.172068,1.91943,-2.0788,0.2614,1.74775,-2.27182,0.323127,1.66568,-2.29031,0.425762,1.66045,-2.12221,0.484889,1.65077,-2.09578,0.269938,1.45804,-1.84078,0.083835,1.53415,-1.9104,0.088402,1.55483,-1.97544,0.09539,1.53139,-2.02437,0.274266,1.43934,-2.09717,0.379719,1.22575,-1.77607,0.270332,1.14179,-1.7811,0.315658,1.07421,-1.80123,0.424417,1.01011,-1.7917,0.470203,0.822802,-1.77642,0.480443,0.747929,-1.78796,0.359312,0.807947,-1.79886,0.369718,0.736441,-1.80412,0.451349,0.515022,-1.81772,0.383318,0.423218,-1.90336,0.614929,0.521993,-1.83862,0.603473,0.457416,-1.77516,0.137873,1.14835,-2.14135,0.111897,1.06838,-2.12518,0.004771,1.19129,-2.10585,-0.017737,1.11232,-2.09182,-0.023966,0.963922,-2.09476,-0.11759,0.794874,-2.0867,-0.197973,0.875167,-2.09814,-0.245901,0.822357,-2.09019,-0.382693,0.632239,-2.05914,-0.466665,0.69123,-1.99758,-0.377734,0.424657,-2.00503,-0.442377,0.449112,-2.06308,0.181299,1.37873,-1.84872,0.179402,1.3665,-2.0636},
/*1606*/{0.217852,1.95244,-1.75142,0.332623,1.89737,-1.86769,0.057636,1.8628,-1.71169,-0.067163,1.78565,-1.70268,0.071101,1.70148,-1.70409,0.140305,1.6426,-1.6856,0.31933,1.96946,-2.11684,0.356658,1.89769,-1.94,0.173102,1.92105,-2.07904,0.263037,1.74966,-2.27104,0.323011,1.66651,-2.2894,0.425679,1.66081,-2.12149,0.484473,1.65004,-2.09481,0.269548,1.45861,-1.84174,0.084452,1.53479,-1.90961,0.089015,1.5559,-1.97485,0.095194,1.53203,-2.02475,0.274488,1.44135,-2.09697,0.375053,1.2207,-1.77567,0.263348,1.13924,-1.78159,0.308822,1.0706,-1.80083,0.418777,1.00413,-1.79151,0.472082,0.818848,-1.77729,0.481052,0.743926,-1.78963,0.361705,0.799964,-1.79663,0.374096,0.729196,-1.80244,0.462881,0.510016,-1.81863,0.397958,0.417145,-1.90408,0.628326,0.522929,-1.84009,0.618688,0.456882,-1.77891,0.14083,1.14783,-2.14044,0.1164,1.06851,-2.12473,0.006956,1.18876,-2.1048,-0.014139,1.11039,-2.0906,-0.019444,0.961876,-2.09352,-0.119528,0.7957,-2.08457,-0.196314,0.878528,-2.0979,-0.244828,0.82865,-2.0903,-0.388972,0.644432,-2.05858,-0.4731,0.708121,-1.99946,-0.392639,0.438014,-2.00036,-0.45619,0.464627,-2.06096,0.181643,1.37911,-1.84933,0.179715,1.36799,-2.06427},
/*1607*/{0.219866,1.95265,-1.7512,0.332623,1.89737,-1.86769,0.058934,1.86308,-1.71243,-0.065747,1.78682,-1.70376,0.072899,1.70137,-1.70401,0.141154,1.64132,-1.68403,0.32072,1.96993,-2.11567,0.357274,1.89824,-1.93968,0.173537,1.92206,-2.07814,0.263589,1.75118,-2.2707,0.323017,1.66699,-2.28953,0.425649,1.66049,-2.12071,0.483969,1.64909,-2.09417,0.270415,1.45933,-1.84193,0.084472,1.53487,-1.90957,0.088825,1.55739,-1.97379,0.094979,1.53262,-2.02373,0.274299,1.44228,-2.09721,0.371438,1.21505,-1.77559,0.257488,1.13562,-1.7823,0.301178,1.06693,-1.80118,0.412694,0.997058,-1.79056,0.473286,0.816139,-1.77819,0.488085,0.74168,-1.79019,0.362876,0.792763,-1.79631,0.378118,0.722427,-1.80187,0.474709,0.505427,-1.81831,0.410421,0.412169,-1.90396,0.638111,0.521739,-1.84277,0.632943,0.455791,-1.78119,0.14432,1.14679,-2.13966,0.120759,1.06706,-2.12351,0.010471,1.1869,-2.10407,-0.010383,1.10787,-2.08951,-0.014583,0.959798,-2.09268,-0.120917,0.796271,-2.0824,-0.192552,0.88356,-2.09832,-0.244865,0.834778,-2.0902,-0.399904,0.659238,-2.05876,-0.480895,0.724236,-2.00206,-0.408293,0.452014,-1.99785,-0.468168,0.479136,-2.05905,0.182382,1.37971,-1.84927,0.179592,1.36893,-2.06422},
/*1608*/{0.221337,1.95283,-1.75032,0.332949,1.89688,-1.86725,0.060725,1.86236,-1.71197,-0.063342,1.78506,-1.70398,0.074154,1.70079,-1.70314,0.141928,1.64009,-1.6832,0.321241,1.97013,-2.11417,0.357222,1.89776,-1.93939,0.173812,1.92371,-2.07803,0.26368,1.75196,-2.26993,0.322568,1.66738,-2.28937,0.424908,1.65866,-2.12027,0.483301,1.64708,-2.09435,0.270079,1.45956,-1.84261,0.083553,1.53422,-1.90962,0.088131,1.55782,-1.97366,0.094632,1.53306,-2.02382,0.275268,1.44383,-2.09749,0.366153,1.20977,-1.77522,0.251624,1.13479,-1.78271,0.294224,1.06196,-1.80218,0.405736,0.991408,-1.79033,0.473036,0.812573,-1.77949,0.489666,0.739301,-1.7911,0.364075,0.786049,-1.79655,0.381199,0.717928,-1.80186,0.486509,0.502983,-1.81908,0.421078,0.408112,-1.90488,0.647145,0.521961,-1.84512,0.643603,0.455465,-1.78487,0.148237,1.14577,-2.13902,0.124814,1.06536,-2.12227,0.013107,1.18447,-2.10333,-0.006216,1.10483,-2.08942,-0.009233,0.957418,-2.09132,-0.121564,0.797664,-2.08084,-0.188744,0.887505,-2.09855,-0.243498,0.842087,-2.09033,-0.406572,0.672302,-2.0579,-0.486003,0.74123,-2.00366,-0.421139,0.467312,-1.99467,-0.47975,0.495666,-2.05826,0.182505,1.37943,-1.85025,0.180362,1.37007,-2.06527},
/*1609*/{0.222683,1.95226,-1.74949,0.337398,1.89381,-1.86599,0.061155,1.86187,-1.71197,-0.063031,1.78332,-1.70432,0.075169,1.6984,-1.70306,0.143738,1.63815,-1.68213,0.321474,1.96965,-2.1131,0.357322,1.89661,-1.93893,0.172432,1.92345,-2.07345,0.263758,1.75278,-2.26866,0.320609,1.66708,-2.28914,0.425335,1.65713,-2.12009,0.482198,1.64439,-2.09375,0.272591,1.46011,-1.84278,0.083264,1.53331,-1.90888,0.087737,1.55665,-1.97325,0.094625,1.53259,-2.02301,0.275408,1.44407,-2.09768,0.362937,1.20324,-1.77453,0.244935,1.13105,-1.78407,0.287315,1.05815,-1.80262,0.399164,0.986063,-1.79211,0.472336,0.810354,-1.78105,0.490338,0.736632,-1.79205,0.363606,0.780075,-1.79767,0.382326,0.711011,-1.80269,0.491905,0.49807,-1.8188,0.431065,0.404268,-1.90501,0.655509,0.521444,-1.84566,0.652851,0.453021,-1.78608,0.151615,1.14433,-2.13783,0.130338,1.06367,-2.12177,0.0167,1.18096,-2.10248,-0.001803,1.10142,-2.08838,-0.003397,0.954473,-2.09069,-0.119283,0.799937,-2.08053,-0.18481,0.89218,-2.09836,-0.241745,0.849104,-2.09007,-0.411485,0.687122,-2.05703,-0.490981,0.759171,-2.005,-0.432928,0.483176,-1.99224,-0.489987,0.512218,-2.0569,0.184789,1.37943,-1.84989,0.181321,1.36975,-2.06488},
/*1610*/{0.223956,1.9516,-1.74847,0.337065,1.89316,-1.86587,0.062974,1.86053,-1.71194,-0.060449,1.78307,-1.70435,0.077101,1.69682,-1.70216,0.144631,1.63562,-1.68038,0.321227,1.96862,-2.11188,0.357568,1.89571,-1.9381,0.173693,1.92436,-2.07566,0.260685,1.75256,-2.26697,0.318694,1.66651,-2.28821,0.424355,1.655,-2.12022,0.48144,1.64147,-2.09374,0.271292,1.45976,-1.8435,0.084165,1.53128,-1.90819,0.087483,1.55519,-1.97285,0.094411,1.53119,-2.02264,0.275446,1.44413,-2.09764,0.357957,1.19641,-1.77382,0.240448,1.12537,-1.78337,0.280192,1.05323,-1.80412,0.390773,0.980341,-1.79295,0.469035,0.80751,-1.78155,0.489442,0.735751,-1.79313,0.3616,0.774221,-1.79904,0.3828,0.706384,-1.80357,0.498533,0.496469,-1.8199,0.438483,0.400495,-1.90515,0.661262,0.522159,-1.84707,0.661676,0.454283,-1.7882,0.156111,1.14237,-2.13635,0.135855,1.06185,-2.12054,0.020896,1.17727,-2.10226,0.003285,1.09698,-2.08751,0.003592,0.95147,-2.08944,-0.120004,0.799522,-2.07883,-0.180509,0.895839,-2.09837,-0.23863,0.855443,-2.08925,-0.416159,0.703026,-2.05715,-0.493788,0.77618,-2.00539,-0.443814,0.499367,-1.99049,-0.498563,0.529698,-2.05628,0.185284,1.37812,-1.85015,0.181823,1.36912,-2.06516},
/*1611*/{0.225223,1.95006,-1.74775,0.338553,1.89251,-1.86616,0.064086,1.85859,-1.71085,-0.058156,1.77986,-1.70358,0.078616,1.69387,-1.70067,0.146779,1.63319,-1.67843,0.32088,1.96758,-2.11068,0.357648,1.89452,-1.93809,0.173505,1.92432,-2.07522,0.258627,1.75235,-2.26524,0.315227,1.66513,-2.28715,0.423115,1.65302,-2.12031,0.480399,1.63744,-2.0938,0.272101,1.4587,-1.84321,0.083302,1.52949,-1.90802,0.08704,1.55404,-1.97286,0.093748,1.52958,-2.02238,0.275408,1.44407,-2.09768,0.352611,1.19081,-1.77404,0.234167,1.12169,-1.78416,0.272368,1.04907,-1.80533,0.383916,0.973838,-1.79333,0.464658,0.803999,-1.78132,0.487581,0.732416,-1.79281,0.358666,0.77003,-1.80143,0.381116,0.701618,-1.80727,0.502789,0.493569,-1.81991,0.443661,0.396637,-1.90484,0.664842,0.521965,-1.84821,0.665842,0.453244,-1.78812,0.16139,1.13985,-2.13497,0.142202,1.05873,-2.1181,0.023955,1.17274,-2.10184,0.008572,1.09219,-2.08646,0.010303,0.947484,-2.08861,-0.118464,0.801781,-2.07697,-0.1758,0.9003,-2.09765,-0.235698,0.86303,-2.08815,-0.419381,0.717448,-2.05552,-0.495509,0.795048,-2.00607,-0.454135,0.515934,-1.98939,-0.50592,0.547998,-2.05469,0.185929,1.37685,-1.85034,0.182334,1.36834,-2.06537},
/*1612*/{0.227175,1.94855,-1.74675,0.337656,1.89051,-1.86554,0.065982,1.85602,-1.70978,-0.056069,1.77653,-1.70289,0.080735,1.6909,-1.69885,0.148457,1.6301,-1.6767,0.32074,1.96578,-2.10955,0.357452,1.8933,-1.9381,0.172583,1.92386,-2.07467,0.254904,1.75209,-2.26317,0.312806,1.66408,-2.28583,0.421847,1.64903,-2.12075,0.478761,1.63355,-2.09453,0.27223,1.45774,-1.84341,0.082653,1.52695,-1.90791,0.087185,1.55237,-1.97191,0.093587,1.5272,-2.02197,0.275284,1.44335,-2.09783,0.349492,1.1832,-1.77298,0.227877,1.1173,-1.78599,0.266237,1.04435,-1.80727,0.375128,0.968395,-1.79424,0.460754,0.800786,-1.78165,0.484838,0.728705,-1.79284,0.355666,0.764779,-1.80399,0.379896,0.695827,-1.80798,0.50396,0.490366,-1.82008,0.446905,0.392852,-1.90532,0.666449,0.520717,-1.849,0.667605,0.45267,-1.7886,0.165926,1.13738,-2.13377,0.148834,1.05452,-2.1165,0.028516,1.16783,-2.10131,0.013186,1.08694,-2.08555,0.016523,0.943326,-2.09065,-0.118718,0.806958,-2.0772,-0.170752,0.905096,-2.09771,-0.232383,0.8687,-2.08716,-0.425246,0.736273,-2.06328,-0.495016,0.812649,-2.00452,-0.462653,0.533103,-1.98956,-0.51533,0.567109,-2.05456,0.18679,1.37515,-1.85035,0.182893,1.36696,-2.0654},
/*1613*/{0.228638,1.94689,-1.74575,0.338269,1.88855,-1.86577,0.067481,1.85296,-1.70857,-0.053594,1.77289,-1.70088,0.082734,1.68726,-1.69685,0.151278,1.62618,-1.67447,0.320886,1.96402,-2.10871,0.35764,1.89147,-1.93801,0.172096,1.92242,-2.07229,0.249839,1.75029,-2.2613,0.309135,1.66237,-2.28474,0.420708,1.64518,-2.12146,0.477474,1.62834,-2.09562,0.273178,1.45688,-1.84358,0.083186,1.5246,-1.9067,0.086696,1.54952,-1.97137,0.093159,1.52548,-2.02245,0.27546,1.44222,-2.09738,0.34656,1.17699,-1.77158,0.224319,1.11457,-1.78753,0.261169,1.0402,-1.80867,0.367407,0.96209,-1.79562,0.455922,0.797047,-1.78237,0.481192,0.724966,-1.79297,0.351732,0.759577,-1.80657,0.377071,0.691487,-1.81118,0.504927,0.48601,-1.81932,0.449326,0.388782,-1.90641,0.667233,0.519353,-1.84957,0.66844,0.450812,-1.78865,0.171061,1.13409,-2.13291,0.154452,1.05157,-2.11526,0.03349,1.1628,-2.10108,0.018715,1.08162,-2.08474,0.024824,0.937214,-2.08728,-0.117387,0.807147,-2.0752,-0.164311,0.907993,-2.09545,-0.226807,0.87646,-2.08593,-0.423465,0.749643,-2.05714,-0.492037,0.831632,-2.0033,-0.470243,0.550032,-1.98869,-0.52176,0.586005,-2.05452,0.188216,1.37362,-1.85005,0.183733,1.36528,-2.06507},
/*1614*/{0.229277,1.94402,-1.74491,0.338433,1.88721,-1.86616,0.068558,1.84942,-1.70717,-0.051533,1.76857,-1.69884,0.085343,1.68395,-1.69455,0.153539,1.62232,-1.67222,0.319179,1.96135,-2.10798,0.356621,1.88954,-1.93804,0.1714,1.92127,-2.07127,0.244382,1.74859,-2.26003,0.305033,1.66046,-2.28387,0.41916,1.64062,-2.12191,0.476158,1.62398,-2.09719,0.274155,1.45499,-1.8433,0.082484,1.52173,-1.9069,0.085984,1.54623,-1.97118,0.09327,1.52244,-2.02183,0.275997,1.44054,-2.09712,0.341747,1.17148,-1.77086,0.219024,1.11098,-1.78986,0.256113,1.03602,-1.80994,0.360917,0.9562,-1.79634,0.451719,0.792369,-1.78241,0.478715,0.721231,-1.79391,0.348507,0.754328,-1.80826,0.373603,0.686094,-1.81331,0.503831,0.484651,-1.82259,0.449605,0.385108,-1.9074,0.666599,0.516514,-1.84915,0.667757,0.448562,-1.78885,0.175898,1.1306,-2.13153,0.160769,1.04827,-2.11371,0.036681,1.15668,-2.10071,0.024416,1.07625,-2.08378,0.031825,0.933719,-2.08666,-0.114859,0.809035,-2.07522,-0.157644,0.91255,-2.09483,-0.221635,0.883273,-2.08502,-0.422802,0.765122,-2.05568,-0.488482,0.84874,-2.00096,-0.4771,0.568068,-1.98948,-0.528032,0.605811,-2.05443,0.189303,1.37129,-1.84982,0.184859,1.36291,-2.06484},
/*1615*/{0.230521,1.94141,-1.74369,0.338663,1.88342,-1.86541,0.070265,1.84589,-1.70503,-0.047914,1.76372,-1.69631,0.088365,1.67887,-1.69203,0.156446,1.61832,-1.67015,0.317724,1.95913,-2.1077,0.356289,1.88673,-1.93777,0.170419,1.91907,-2.07052,0.239194,1.74721,-2.25842,0.300518,1.6581,-2.28308,0.417303,1.63662,-2.12247,0.474432,1.61812,-2.09858,0.272554,1.4521,-1.84343,0.083391,1.51832,-1.90659,0.086093,1.54246,-1.97076,0.09279,1.51856,-2.02191,0.275811,1.43942,-2.09684,0.338853,1.16508,-1.7693,0.21634,1.10613,-1.79086,0.251646,1.03098,-1.81246,0.356286,0.95111,-1.79668,0.447637,0.787915,-1.78293,0.47434,0.717889,-1.79462,0.344521,0.749498,-1.80989,0.369522,0.682091,-1.81506,0.501166,0.478739,-1.82245,0.447912,0.380684,-1.91026,0.664457,0.512771,-1.84894,0.664858,0.444547,-1.78915,0.180124,1.12697,-2.13095,0.167232,1.04479,-2.11263,0.04136,1.15114,-2.09942,0.030856,1.07011,-2.0823,0.040075,0.928285,-2.08453,-0.110966,0.811484,-2.07431,-0.150567,0.916091,-2.09347,-0.214698,0.888753,-2.08417,-0.417647,0.777465,-2.05356,-0.483252,0.865893,-1.99834,-0.483855,0.584849,-1.99129,-0.53463,0.624858,-2.05367,0.189491,1.3678,-1.85027,0.185514,1.36052,-2.06535},
/*1616*/{0.231625,1.93807,-1.74301,0.339122,1.88111,-1.86503,0.071888,1.841,-1.70291,-0.04597,1.75799,-1.69385,0.090527,1.67395,-1.68933,0.159323,1.61341,-1.6674,0.316178,1.95605,-2.10736,0.356491,1.88503,-1.93795,0.168417,1.91729,-2.06869,0.232942,1.74423,-2.25599,0.296256,1.65534,-2.28168,0.415344,1.63155,-2.12377,0.472235,1.61129,-2.10012,0.273198,1.44915,-1.84207,0.083128,1.51517,-1.90597,0.086328,1.53935,-1.9703,0.092363,1.51524,-2.0216,0.27635,1.43693,-2.09582,0.335548,1.1597,-1.76737,0.212536,1.10127,-1.79238,0.248843,1.02686,-1.81441,0.354544,0.947977,-1.79675,0.443907,0.782831,-1.78298,0.470672,0.712135,-1.79491,0.340859,0.744777,-1.81061,0.367838,0.677011,-1.81693,0.496074,0.474219,-1.82448,0.444073,0.37703,-1.91247,0.659979,0.507165,-1.84972,0.659661,0.439494,-1.79051,0.185656,1.12318,-2.13022,0.173908,1.04117,-2.11134,0.046618,1.14405,-2.09869,0.037121,1.06415,-2.08185,0.048247,0.923209,-2.08382,-0.107176,0.813104,-2.07411,-0.142521,0.920359,-2.09377,-0.208936,0.894996,-2.08307,-0.418743,0.794604,-2.05413,-0.476468,0.883164,-1.99757,-0.488877,0.602134,-1.99244,-0.538828,0.644672,-2.05353,0.189855,1.36486,-1.84949,0.186263,1.35762,-2.06458},
/*1617*/{0.232057,1.93436,-1.74224,0.337896,1.87964,-1.86494,0.073883,1.83534,-1.70067,-0.044162,1.75179,-1.69005,0.093398,1.66822,-1.68632,0.16351,1.60884,-1.66453,0.315312,1.9532,-2.10807,0.355922,1.8823,-1.93781,0.167523,1.91439,-2.06737,0.226796,1.74166,-2.25399,0.290689,1.65186,-2.28104,0.413171,1.62509,-2.12536,0.469963,1.60494,-2.10283,0.270646,1.44464,-1.84219,0.082079,1.51152,-1.90631,0.085546,1.53606,-1.9694,0.09179,1.51131,-2.02201,0.276476,1.43479,-2.09573,0.332717,1.15449,-1.76559,0.211387,1.0976,-1.79322,0.246388,1.02311,-1.81652,0.352892,0.9449,-1.79639,0.439506,0.777913,-1.78451,0.467344,0.707225,-1.79635,0.336908,0.740006,-1.81123,0.362916,0.67262,-1.8177,0.490999,0.468651,-1.82617,0.438586,0.372732,-1.91555,0.65539,0.501317,-1.85012,0.654869,0.434401,-1.79174,0.190953,1.12005,-2.12935,0.179851,1.0373,-2.11045,0.050069,1.13846,-2.09841,0.043713,1.05735,-2.08097,0.055112,0.917528,-2.08298,-0.10298,0.814392,-2.07299,-0.133774,0.923117,-2.09163,-0.200389,0.900218,-2.08195,-0.4144,0.809074,-2.0544,-0.468414,0.899207,-1.99415,-0.491125,0.618291,-1.99383,-0.538901,0.664391,-2.05503,0.188194,1.3603,-1.85045,0.185982,1.35501,-2.06561},
/*1618*/{0.232799,1.93026,-1.74134,0.338198,1.87497,-1.8649,0.075375,1.83003,-1.69746,-0.040648,1.74552,-1.68576,0.097168,1.66264,-1.68289,0.167375,1.60339,-1.66219,0.313464,1.95011,-2.10826,0.355039,1.87931,-1.93727,0.166233,1.91051,-2.06649,0.221756,1.73791,-2.25263,0.285448,1.64812,-2.28074,0.410079,1.61909,-2.12657,0.467868,1.59755,-2.10525,0.269927,1.44087,-1.84082,0.08196,1.50749,-1.90576,0.085444,1.53196,-1.96852,0.09192,1.50751,-2.02156,0.276807,1.43246,-2.09476,0.33012,1.14987,-1.76485,0.207178,1.09448,-1.79567,0.243447,1.01899,-1.81796,0.35272,0.942436,-1.79644,0.436286,0.77256,-1.78507,0.462209,0.701257,-1.79679,0.332436,0.735027,-1.81125,0.358216,0.667181,-1.8171,0.484229,0.464539,-1.82825,0.431806,0.368598,-1.91877,0.649132,0.494688,-1.85105,0.647047,0.425261,-1.79254,0.196029,1.11614,-2.12876,0.187251,1.03381,-2.10983,0.055214,1.13259,-2.09785,0.050178,1.05137,-2.08083,0.062957,0.9131,-2.08236,-0.0972,0.815854,-2.07282,-0.125481,0.925033,-2.09057,-0.192326,0.90422,-2.08097,-0.411215,0.822788,-2.05301,-0.458061,0.914076,-1.9937,-0.493054,0.634288,-1.9953,-0.540287,0.682679,-2.05475,0.188077,1.35624,-1.8501,0.186816,1.35198,-2.06529},
/*1619*/{0.233465,1.92583,-1.74016,0.338843,1.87211,-1.86514,0.077501,1.82354,-1.6946,-0.038476,1.7376,-1.68155,0.100044,1.65656,-1.67919,0.171002,1.59809,-1.65907,0.312297,1.94621,-2.10922,0.355304,1.87607,-1.93724,0.164733,1.90738,-2.06519,0.215967,1.73454,-2.25091,0.279877,1.64408,-2.28042,0.407309,1.61263,-2.12879,0.464518,1.59018,-2.10816,0.268942,1.43684,-1.84036,0.082536,1.50502,-1.90555,0.084895,1.52857,-1.96813,0.092502,1.50525,-2.02166,0.276767,1.42964,-2.09404,0.327387,1.14552,-1.76374,0.205573,1.09092,-1.79719,0.241529,1.01573,-1.81905,0.351594,0.939008,-1.79659,0.432325,0.766779,-1.78589,0.455892,0.696124,-1.79823,0.32849,0.73066,-1.81175,0.352345,0.663022,-1.81713,0.477153,0.457592,-1.82974,0.4227,0.363176,-1.9216,0.641103,0.486949,-1.85263,0.639093,0.415973,-1.79498,0.2011,1.11342,-2.12838,0.193988,1.03,-2.10947,0.060621,1.12591,-2.09712,0.056347,1.04494,-2.08045,0.071504,0.9087,-2.0817,-0.091925,0.816973,-2.07196,-0.115001,0.928009,-2.09001,-0.183533,0.90952,-2.08051,-0.402387,0.835798,-2.05339,-0.447558,0.927952,-1.9914,-0.49422,0.649319,-1.99694,-0.538543,0.700425,-2.05561,0.187011,1.35263,-1.85022,0.18653,1.3493,-2.06543},
/*1620*/{0.234279,1.92154,-1.73869,0.338232,1.86937,-1.86568,0.079588,1.81674,-1.69109,-0.034838,1.73066,-1.67647,0.103013,1.64946,-1.67534,0.176094,1.5923,-1.65679,0.309828,1.94188,-2.10949,0.354112,1.87286,-1.93789,0.163135,1.90313,-2.06385,0.210118,1.73005,-2.24991,0.27403,1.63948,-2.27989,0.40369,1.60634,-2.13067,0.461961,1.58167,-2.11161,0.266378,1.42953,-1.83913,0.080234,1.49828,-1.90516,0.084211,1.52453,-1.9685,0.091143,1.49803,-2.02178,0.277123,1.42667,-2.09357,0.32506,1.14182,-1.76325,0.203666,1.08865,-1.79901,0.238425,1.01299,-1.81993,0.350389,0.935696,-1.7971,0.426998,0.760874,-1.78603,0.450995,0.690546,-1.79935,0.322713,0.725729,-1.81257,0.346434,0.65792,-1.81885,0.468723,0.452091,-1.83176,0.412373,0.358265,-1.92376,0.633255,0.477896,-1.85353,0.630254,0.407964,-1.79776,0.206488,1.10969,-2.12886,0.20099,1.02607,-2.10969,0.066272,1.12037,-2.09718,0.063248,1.03891,-2.07967,0.078878,0.904581,-2.08198,-0.08625,0.818297,-2.07284,-0.105008,0.928696,-2.08824,-0.174491,0.912656,-2.07982,-0.395111,0.847687,-2.05295,-0.436924,0.940931,-1.99026,-0.49227,0.664524,-1.99778,-0.535503,0.717488,-2.05739,0.185005,1.34556,-1.85133,0.186801,1.34507,-2.06656},
/*1621*/{0.234479,1.91651,-1.73827,0.338354,1.86548,-1.8658,0.081331,1.80988,-1.68784,-0.033568,1.72172,-1.67157,0.107785,1.64291,-1.67137,0.18023,1.58626,-1.65419,0.308907,1.9375,-2.11075,0.354169,1.86949,-1.93749,0.1612,1.89835,-2.06278,0.205006,1.72525,-2.24823,0.268258,1.6351,-2.2799,0.400531,1.59874,-2.13327,0.458673,1.57386,-2.11466,0.268841,1.43009,-1.83842,0.08072,1.49404,-1.90471,0.084763,1.52006,-1.96782,0.089764,1.49266,-2.02208,0.276658,1.42363,-2.09255,0.322951,1.13936,-1.76376,0.202359,1.08609,-1.7999,0.236721,1.00931,-1.8201,0.348359,0.93124,-1.79703,0.421479,0.755213,-1.78645,0.443945,0.683882,-1.80007,0.316718,0.721659,-1.81316,0.338791,0.653348,-1.82008,0.458676,0.445361,-1.83282,0.400166,0.353346,-1.9246,0.62317,0.468476,-1.85574,0.620188,0.397339,-1.79963,0.211394,1.1058,-2.12933,0.207223,1.02174,-2.10997,0.069806,1.11409,-2.09716,0.069454,1.03284,-2.07941,0.086877,0.899781,-2.08163,-0.079707,0.818427,-2.07113,-0.095079,0.930362,-2.08769,-0.164279,0.917161,-2.08007,-0.386558,0.858927,-2.05218,-0.425784,0.952907,-1.98964,-0.48864,0.678291,-1.99893,-0.530698,0.733235,-2.05802,0.18849,1.34453,-1.84901,0.188635,1.34067,-2.06421},
/*1622*/{0.235183,1.91117,-1.73716,0.338564,1.86154,-1.86583,0.083901,1.8024,-1.68471,-0.02815,1.71418,-1.66629,0.112326,1.63527,-1.66749,0.185453,1.58054,-1.65121,0.306481,1.93298,-2.11237,0.354458,1.86571,-1.93792,0.159561,1.89377,-2.0615,0.198531,1.71997,-2.24674,0.262247,1.62982,-2.27907,0.396203,1.59094,-2.1355,0.454792,1.565,-2.11799,0.2679,1.42682,-1.83752,0.078962,1.48865,-1.90541,0.083005,1.51536,-1.96724,0.089659,1.48767,-2.02126,0.276673,1.42053,-2.09186,0.322329,1.13497,-1.76288,0.201064,1.08246,-1.80042,0.233399,1.00621,-1.82092,0.344645,0.92541,-1.79708,0.41564,0.74826,-1.78784,0.437838,0.676405,-1.80026,0.309595,0.717122,-1.81363,0.331636,0.647596,-1.81959,0.447869,0.437587,-1.83389,0.386973,0.347284,-1.92497,0.612241,0.458745,-1.85821,0.60824,0.387362,-1.80264,0.216653,1.10216,-2.12975,0.213898,1.01803,-2.11058,0.075348,1.10724,-2.09627,0.07587,1.02641,-2.0789,0.095171,0.895281,-2.08151,-0.072423,0.818788,-2.07118,-0.08448,0.931011,-2.08686,-0.154329,0.920747,-2.08026,-0.378119,0.870163,-2.05255,-0.414981,0.964297,-1.98925,-0.484549,0.690047,-2.0007,-0.525284,0.748524,-2.05926,0.188356,1.34039,-1.84857,0.189473,1.33679,-2.06377},
/*1623*/{0.235927,1.90553,-1.7362,0.338771,1.85651,-1.86586,0.086011,1.79411,-1.68091,-0.025796,1.70499,-1.6607,0.117132,1.62795,-1.66259,0.191691,1.57403,-1.64815,0.304139,1.92842,-2.11299,0.353601,1.86154,-1.93864,0.158297,1.88842,-2.06013,0.192069,1.71512,-2.24582,0.254981,1.62481,-2.27874,0.392424,1.5836,-2.13794,0.450682,1.55594,-2.12203,0.2671,1.42205,-1.83629,0.078807,1.48327,-1.90487,0.083631,1.51067,-1.96663,0.088513,1.48263,-2.02123,0.275751,1.41535,-2.09203,0.320996,1.13023,-1.76231,0.197957,1.07891,-1.80295,0.231608,1.00246,-1.82161,0.340903,0.920842,-1.79768,0.408522,0.741264,-1.7876,0.425145,0.668835,-1.80156,0.303048,0.712728,-1.81473,0.32214,0.642378,-1.82136,0.433628,0.431275,-1.83494,0.368293,0.351445,-1.92577,0.600479,0.447295,-1.8613,0.594125,0.376351,-1.80504,0.22118,1.09773,-2.13084,0.220758,1.01437,-2.11199,0.08128,1.10148,-2.09585,0.081409,1.02046,-2.07872,0.104259,0.890887,-2.08199,-0.065072,0.819152,-2.07175,-0.073649,0.931282,-2.08652,-0.143379,0.922889,-2.07979,-0.368315,0.877867,-2.05178,-0.402638,0.973905,-1.98838,-0.478538,0.702222,-2.00214,-0.517085,0.761256,-2.06027,0.187797,1.33547,-1.84801,0.188742,1.33163,-2.06321},
/*1624*/{0.236735,1.8999,-1.73513,0.338581,1.85063,-1.86567,0.088971,1.78648,-1.67705,-0.021395,1.69573,-1.65491,0.122085,1.62063,-1.6588,0.197512,1.56732,-1.64522,0.302668,1.9231,-2.11411,0.353845,1.85668,-1.93867,0.157706,1.88355,-2.06011,0.185774,1.70991,-2.2443,0.248046,1.61904,-2.27858,0.387923,1.57605,-2.14109,0.446857,1.54623,-2.12586,0.266346,1.41802,-1.83415,0.078382,1.47717,-1.90458,0.082527,1.50501,-1.96582,0.087759,1.47624,-2.02122,0.275124,1.41298,-2.09095,0.317833,1.12605,-1.76222,0.196541,1.07569,-1.80387,0.230371,0.998276,-1.82159,0.336733,0.915029,-1.7976,0.401423,0.734672,-1.78822,0.421321,0.662142,-1.80143,0.294882,0.707203,-1.81457,0.312464,0.638829,-1.82416,0.420339,0.427643,-1.83533,0.349107,0.352228,-1.92613,0.583629,0.43488,-1.86486,0.573883,0.36377,-1.80759,0.226586,1.09387,-2.13122,0.226341,1.01046,-2.11336,0.086256,1.09514,-2.09503,0.088123,1.01407,-2.0786,0.112757,0.885942,-2.08249,-0.057219,0.81886,-2.07227,-0.061452,0.931838,-2.08627,-0.132724,0.924199,-2.08029,-0.357903,0.888403,-2.05163,-0.391212,0.98205,-1.98687,-0.46975,0.712951,-2.00374,-0.508823,0.772149,-2.0617,0.188324,1.3306,-1.84742,0.190137,1.32744,-2.06262},
/*1625*/{0.236796,1.89414,-1.73397,0.33897,1.84686,-1.86616,0.092361,1.77784,-1.67318,-0.016412,1.68621,-1.64846,0.127509,1.61237,-1.65431,0.203316,1.56101,-1.64278,0.299468,1.918,-2.11548,0.353231,1.85196,-1.93971,0.155399,1.87846,-2.05969,0.178951,1.70411,-2.24258,0.241015,1.61324,-2.27829,0.383735,1.56715,-2.14403,0.441892,1.536,-2.13072,0.266219,1.414,-1.83389,0.077757,1.47165,-1.90437,0.082615,1.49906,-1.9647,0.087265,1.47042,-2.02076,0.274943,1.40895,-2.09053,0.316397,1.12216,-1.76139,0.195561,1.07145,-1.80293,0.227743,0.994189,-1.82205,0.332737,0.90966,-1.79749,0.394353,0.727823,-1.78987,0.412705,0.654787,-1.80186,0.287043,0.702724,-1.81512,0.30469,0.632284,-1.82213,0.404868,0.422068,-1.83724,0.331326,0.353276,-1.92895,0.572197,0.420828,-1.86691,0.557009,0.349771,-1.80978,0.230586,1.0904,-2.13259,0.232121,1.00635,-2.11396,0.090133,1.08855,-2.09491,0.094298,1.00797,-2.0785,0.12214,0.881098,-2.0841,-0.04818,0.818508,-2.07324,-0.049511,0.930428,-2.08623,-0.120854,0.926548,-2.07859,-0.342936,0.893615,-2.04956,-0.3785,0.990625,-1.9861,-0.46343,0.721343,-2.00608,-0.498755,0.781789,-2.06378,0.189191,1.32582,-1.84691,0.190859,1.32261,-2.06212},
/*1626*/{0.238007,1.88788,-1.73334,0.339383,1.84186,-1.86681,0.095964,1.76861,-1.66887,-0.011821,1.67623,-1.64237,0.134145,1.60436,-1.65005,0.209615,1.55473,-1.64048,0.297927,1.91319,-2.11659,0.353212,1.84762,-1.94042,0.153697,1.87216,-2.05833,0.177545,1.69729,-2.24284,0.235169,1.60781,-2.27843,0.378332,1.55724,-2.14687,0.436928,1.52626,-2.13506,0.265713,1.41064,-1.83241,0.076497,1.46541,-1.90458,0.080583,1.49341,-1.96377,0.086008,1.46451,-2.02044,0.273643,1.40512,-2.08951,0.316554,1.11669,-1.7614,0.193388,1.06565,-1.80228,0.226598,0.989346,-1.82132,0.328285,0.903881,-1.79794,0.387076,0.721325,-1.79029,0.403148,0.647438,-1.8037,0.278799,0.698437,-1.81544,0.294415,0.627836,-1.82153,0.389654,0.416484,-1.83959,0.311354,0.35399,-1.92915,0.558521,0.408153,-1.87063,0.538825,0.33886,-1.81319,0.234975,1.08643,-2.13294,0.238273,1.00246,-2.11489,0.095371,1.08229,-2.09446,0.100696,1.00115,-2.07864,0.131017,0.875801,-2.08459,-0.03961,0.817508,-2.07393,-0.038971,0.93148,-2.08493,-0.10947,0.927222,-2.07807,-0.331792,0.900112,-2.04942,-0.368973,0.997498,-1.98608,-0.45441,0.728676,-2.00728,-0.488828,0.790396,-2.06472,0.189383,1.3215,-1.84587,0.191228,1.31777,-2.06107},
/*1627*/{0.239169,1.8819,-1.73233,0.339997,1.83601,-1.86677,0.100192,1.75993,-1.66505,-0.006171,1.66676,-1.63595,0.139529,1.59596,-1.64538,0.217183,1.54801,-1.63727,0.295542,1.9081,-2.11803,0.353237,1.84242,-1.94178,0.152085,1.86656,-2.05708,0.17116,1.69144,-2.24141,0.226848,1.60183,-2.27805,0.373396,1.54833,-2.14964,0.43162,1.51553,-2.13994,0.264307,1.4059,-1.83029,0.074591,1.45997,-1.9048,0.078286,1.48694,-1.96298,0.084088,1.45834,-2.02046,0.273008,1.40031,-2.08867,0.31504,1.11083,-1.76153,0.19216,1.06338,-1.8015,0.223866,0.984662,-1.82074,0.323496,0.8979,-1.79685,0.380142,0.714635,-1.79172,0.395809,0.641896,-1.80572,0.271688,0.695515,-1.81443,0.285618,0.624354,-1.8201,0.375874,0.414663,-1.84302,0.290275,0.354284,-1.9281,0.543047,0.398982,-1.87686,0.520105,0.337533,-1.81451,0.238341,1.08283,-2.13427,0.243898,0.998537,-2.11672,0.100198,1.07496,-2.09446,0.107344,0.99447,-2.07827,0.140798,0.870393,-2.08583,-0.029321,0.816759,-2.07519,-0.027263,0.931074,-2.08519,-0.095449,0.927452,-2.07746,-0.323693,0.908454,-2.05113,-0.35599,1.00355,-1.98546,-0.443928,0.735259,-2.00963,-0.476845,0.79684,-2.06704,0.18822,1.31645,-1.84479,0.191,1.31233,-2.05996},
/*1628*/{0.240286,1.87634,-1.73082,0.34071,1.8319,-1.86776,0.104326,1.75031,-1.6608,-0.000279,1.6563,-1.62942,0.146599,1.58802,-1.64152,0.224267,1.5414,-1.63518,0.293941,1.90345,-2.11925,0.352978,1.83745,-1.94329,0.150422,1.86103,-2.05636,0.164702,1.68578,-2.24075,0.220629,1.5965,-2.27858,0.367953,1.5391,-2.15379,0.425141,1.50505,-2.14504,0.263569,1.40133,-1.82871,0.072096,1.45557,-1.90472,0.076599,1.48108,-1.96282,0.081623,1.45316,-2.02102,0.272811,1.39623,-2.08807,0.311784,1.10635,-1.7606,0.190286,1.05957,-1.80041,0.222083,0.981154,-1.82006,0.317998,0.892175,-1.79653,0.374356,0.71007,-1.79391,0.386766,0.636181,-1.80892,0.264724,0.694236,-1.81485,0.276688,0.624112,-1.82265,0.359086,0.415056,-1.84609,0.26951,0.355309,-1.92852,0.522326,0.394522,-1.88265,0.498656,0.337704,-1.81587,0.242669,1.07827,-2.13469,0.250279,0.99462,-2.11794,0.104039,1.06803,-2.09432,0.114352,0.98708,-2.07743,0.151117,0.864428,-2.08802,-0.018834,0.816074,-2.07678,-0.014034,0.930309,-2.08649,-0.083696,0.927744,-2.0767,-0.312023,0.912564,-2.05051,-0.343959,1.00846,-1.98522,-0.431064,0.740531,-2.0108,-0.465793,0.801772,-2.06548,0.187067,1.31189,-1.84425,0.190694,1.30772,-2.05941},
/*1629*/{0.241637,1.87078,-1.72977,0.34104,1.82534,-1.86774,0.109467,1.74091,-1.65666,0.006572,1.64585,-1.62285,0.15408,1.57991,-1.63744,0.232637,1.53626,-1.63302,0.291746,1.89859,-2.12051,0.353455,1.83197,-1.94376,0.148994,1.85611,-2.05503,0.158693,1.68006,-2.23957,0.21235,1.59075,-2.27865,0.362176,1.52975,-2.15717,0.419517,1.49448,-2.15069,0.259762,1.39634,-1.82833,0.068031,1.45049,-1.9055,0.074112,1.47541,-1.96349,0.078851,1.44726,-2.02177,0.272231,1.38996,-2.08711,0.307569,1.10636,-1.76001,0.186834,1.05789,-1.79816,0.21849,0.980534,-1.82027,0.312048,0.885504,-1.79752,0.369348,0.708946,-1.7958,0.378131,0.634384,-1.81207,0.258977,0.696827,-1.81396,0.267292,0.626444,-1.8246,0.338977,0.4159,-1.84954,0.247544,0.355487,-1.92996,0.501344,0.392,-1.88741,0.476565,0.339179,-1.81771,0.246745,1.07416,-2.13523,0.25618,0.991549,-2.11922,0.108979,1.06092,-2.09384,0.121255,0.980762,-2.07762,0.161641,0.857265,-2.08689,-0.007802,0.814828,-2.07727,-0.000385,0.929486,-2.08729,-0.070684,0.927508,-2.07687,-0.298011,0.917168,-2.05057,-0.331364,1.0122,-1.98468,-0.41871,0.743818,-2.01249,-0.451359,0.806494,-2.06951,0.183379,1.30682,-1.8436,0.188923,1.30176,-2.05871},
/*1630*/{0.2428,1.86554,-1.72857,0.341954,1.82014,-1.86827,0.115794,1.73155,-1.65244,0.014263,1.63529,-1.61617,0.163231,1.57313,-1.63379,0.241113,1.5305,-1.63123,0.290478,1.89512,-2.12221,0.354611,1.82731,-1.9449,0.14746,1.85382,-2.05281,0.154551,1.67575,-2.23908,0.205029,1.58548,-2.27909,0.357001,1.51989,-2.16141,0.412584,1.48337,-2.15612,0.258088,1.39495,-1.82884,0.064034,1.44643,-1.90546,0.070701,1.4698,-1.96484,0.075439,1.4421,-2.02121,0.269697,1.38598,-2.0862,0.305957,1.10684,-1.75452,0.182665,1.05672,-1.79702,0.21578,0.98145,-1.81949,0.307491,0.88513,-1.79787,0.365427,0.710875,-1.79762,0.371458,0.636204,-1.81375,0.254063,0.703798,-1.81396,0.259543,0.631489,-1.82471,0.31926,0.418538,-1.85158,0.225465,0.356804,-1.93183,0.479811,0.391806,-1.88916,0.455295,0.339327,-1.819,0.251156,1.07074,-2.13541,0.261994,0.987775,-2.1197,0.112778,1.05359,-2.09424,0.127438,0.973696,-2.07743,0.171384,0.852415,-2.08759,0.00455,0.813325,-2.07706,0.012781,0.926837,-2.08643,-0.057184,0.927354,-2.07723,-0.279395,0.916146,-2.04765,-0.317893,1.01521,-1.98468,-0.403213,0.746443,-2.01425,-0.43691,0.809777,-2.07132,0.182124,1.30453,-1.84232,0.187367,1.29711,-2.05737},
/*1631*/{0.244313,1.86071,-1.72714,0.342056,1.81628,-1.87053,0.121668,1.72227,-1.64901,0.022427,1.62504,-1.60949,0.171106,1.5667,-1.63122,0.250386,1.52578,-1.62889,0.288658,1.89174,-2.12416,0.354782,1.82229,-1.94716,0.145791,1.85157,-2.05011,0.148749,1.67215,-2.23822,0.197128,1.58068,-2.27941,0.350907,1.51046,-2.1661,0.405694,1.47243,-2.16153,0.253613,1.3928,-1.82916,0.059439,1.44403,-1.90825,0.066436,1.46562,-1.96583,0.071471,1.43677,-2.0225,0.269607,1.3815,-2.08414,0.303359,1.10734,-1.75155,0.181817,1.05839,-1.79675,0.215781,0.983077,-1.81847,0.308489,0.89126,-1.79729,0.361457,0.71137,-1.79862,0.363183,0.636574,-1.81465,0.249306,0.709447,-1.81447,0.252254,0.638103,-1.82456,0.298487,0.421585,-1.85308,0.202986,0.358303,-1.93204,0.458628,0.391064,-1.89,0.431842,0.338173,-1.81812,0.254114,1.06804,-2.13618,0.268456,0.98591,-2.12007,0.118213,1.04595,-2.0936,0.134822,0.966847,-2.07696,0.181444,0.847237,-2.08813,0.017123,0.811604,-2.07665,0.0267,0.925169,-2.0875,-0.043329,0.925766,-2.07745,-0.27068,0.920538,-2.05011,-0.305272,1.01571,-1.98415,-0.389673,0.747188,-2.01573,-0.420033,0.809746,-2.07349,0.177896,1.30234,-1.84123,0.185793,1.29259,-2.0561},
/*1632*/{0.246029,1.85689,-1.72532,0.343218,1.81268,-1.87169,0.129577,1.7132,-1.64556,0.033113,1.61589,-1.60339,0.180961,1.56115,-1.62935,0.259893,1.5212,-1.62713,0.287333,1.8888,-2.12606,0.355715,1.81869,-1.94838,0.145591,1.85124,-2.04852,0.144655,1.67184,-2.23704,0.189931,1.57669,-2.27821,0.344954,1.501,-2.17038,0.397751,1.46195,-2.16712,0.250455,1.39081,-1.82758,0.05582,1.44317,-1.91062,0.06361,1.4633,-1.96656,0.068275,1.43246,-2.02372,0.269442,1.37807,-2.08045,0.303025,1.10954,-1.74973,0.18165,1.05885,-1.79644,0.21561,0.982867,-1.81709,0.31382,0.898417,-1.79528,0.35606,0.711149,-1.79962,0.350384,0.635259,-1.81667,0.243102,0.71491,-1.81267,0.242234,0.643728,-1.82359,0.276985,0.422169,-1.85331,0.181363,0.359607,-1.93287,0.437115,0.389221,-1.88978,0.410037,0.336707,-1.818,0.258768,1.06805,-2.13571,0.275282,0.985857,-2.11994,0.121071,1.04076,-2.09385,0.142132,0.962532,-2.07725,0.193095,0.842803,-2.08742,0.030731,0.809556,-2.0754,0.040561,0.922027,-2.08678,-0.028443,0.922921,-2.07739,-0.25631,0.921703,-2.05186,-0.29275,1.01557,-1.98471,-0.374009,0.747031,-2.01718,-0.404385,0.809286,-2.07501,0.173677,1.30107,-1.83929,0.184594,1.28904,-2.05391},
/*1633*/{0.247528,1.85328,-1.72432,0.34386,1.80771,-1.87238,0.136499,1.70573,-1.64329,0.043019,1.60721,-1.5969,0.190612,1.5559,-1.62631,0.270247,1.5175,-1.62568,0.28634,1.88682,-2.12669,0.356178,1.81535,-1.95017,0.14532,1.8514,-2.04708,0.140161,1.67002,-2.23464,0.182268,1.57534,-2.2764,0.338889,1.49283,-2.17573,0.390056,1.45224,-2.1725,0.246346,1.39106,-1.82555,0.055612,1.44283,-1.9111,0.062386,1.46366,-1.96826,0.065612,1.42934,-2.02623,0.265198,1.37388,-2.08181,0.299637,1.11023,-1.74999,0.180694,1.05897,-1.79519,0.216147,0.982924,-1.81567,0.321491,0.903203,-1.79522,0.346215,0.71216,-1.79998,0.342207,0.636692,-1.81469,0.233845,0.718283,-1.81054,0.230059,0.647507,-1.82239,0.258782,0.422608,-1.8523,0.159564,0.360039,-1.93247,0.415892,0.387944,-1.88944,0.387869,0.336995,-1.81687,0.262783,1.06927,-2.135,0.282413,0.987556,-2.11937,0.126474,1.03798,-2.09498,0.149561,0.959975,-2.07762,0.205895,0.839909,-2.08587,0.044753,0.807393,-2.07448,0.055338,0.920466,-2.08914,-0.01457,0.922033,-2.07841,-0.242321,0.919848,-2.05175,-0.279912,1.01518,-1.98602,-0.357032,0.744474,-2.01781,-0.390526,0.807059,-2.07544,0.169935,1.30161,-1.8379,0.180804,1.28555,-2.05226},
/*1634*/{0.248544,1.85024,-1.72422,0.343261,1.80642,-1.87432,0.142948,1.70028,-1.64163,0.052806,1.60029,-1.59212,0.200448,1.55148,-1.62443,0.28077,1.51515,-1.625,0.287028,1.88552,-2.12631,0.355354,1.81264,-1.95086,0.145309,1.8516,-2.04704,0.135187,1.67185,-2.23161,0.175917,1.57643,-2.27299,0.330028,1.48412,-2.17911,0.381794,1.443,-2.17723,0.243694,1.39093,-1.82384,0.052456,1.44297,-1.91196,0.060262,1.46345,-1.96928,0.063446,1.42741,-2.0271,0.262696,1.37148,-2.08159,0.297539,1.11151,-1.74945,0.17979,1.05793,-1.79298,0.215918,0.982009,-1.81443,0.329112,0.904867,-1.79612,0.336002,0.711936,-1.79809,0.328538,0.636895,-1.81329,0.224225,0.721773,-1.81029,0.218157,0.650609,-1.81913,0.239401,0.423752,-1.85295,0.139487,0.360895,-1.93207,0.396504,0.387783,-1.88882,0.368907,0.336976,-1.81799,0.269253,1.07121,-2.1341,0.290384,0.990318,-2.11838,0.132257,1.03642,-2.09597,0.157398,0.958582,-2.07865,0.22018,0.838976,-2.08439,0.058943,0.805257,-2.07236,0.069696,0.918134,-2.08982,0.001303,0.920324,-2.07882,-0.223455,0.916874,-2.05006,-0.267764,1.01281,-1.98699,-0.340151,0.740934,-2.01918,-0.372049,0.801469,-2.07729,0.166449,1.30187,-1.83672,0.178139,1.28357,-2.05085},
/*1635*/{0.250071,1.84787,-1.72442,0.342997,1.8035,-1.87418,0.149822,1.69676,-1.64016,0.063971,1.5955,-1.5874,0.211458,1.54935,-1.62328,0.292692,1.51415,-1.62302,0.287784,1.88449,-2.12548,0.35545,1.81137,-1.95209,0.145781,1.852,-2.04718,0.131527,1.67109,-2.22792,0.169896,1.57825,-2.27042,0.322568,1.47915,-2.18086,0.372177,1.43493,-2.1826,0.240768,1.39057,-1.82215,0.050285,1.44317,-1.91219,0.057922,1.46398,-1.96919,0.06123,1.42703,-2.02788,0.260077,1.36949,-2.08119,0.295493,1.11094,-1.75043,0.175813,1.05685,-1.79369,0.211054,0.981007,-1.81322,0.329502,0.903236,-1.79716,0.324439,0.709921,-1.79583,0.315822,0.636497,-1.81154,0.213656,0.723499,-1.80879,0.205602,0.652034,-1.81791,0.220874,0.423826,-1.85145,0.118548,0.361845,-1.9315,0.375067,0.386803,-1.8883,0.346214,0.336698,-1.81743,0.276226,1.07403,-2.13342,0.299693,0.993379,-2.11693,0.140318,1.03484,-2.09675,0.166723,0.95802,-2.0803,0.236016,0.840024,-2.08213,0.074064,0.803783,-2.07071,0.084894,0.914938,-2.09074,0.015461,0.918314,-2.07927,-0.212901,0.914994,-2.05362,-0.258259,1.00998,-1.98927,-0.320754,0.734686,-2.01906,-0.355606,0.79467,-2.07746,0.162745,1.30196,-1.83575,0.174984,1.28239,-2.04974},
/*1636*/{0.251558,1.84613,-1.72492,0.342443,1.80169,-1.87451,0.154529,1.69429,-1.63895,0.07509,1.59208,-1.58377,0.222207,1.54783,-1.62246,0.303874,1.51423,-1.6229,0.288642,1.88301,-2.12534,0.355026,1.81013,-1.95209,0.145694,1.85155,-2.04723,0.126881,1.6733,-2.22447,0.163204,1.5812,-2.26798,0.312854,1.47438,-2.182,0.362205,1.42853,-2.18795,0.238718,1.39045,-1.82147,0.049303,1.44237,-1.9125,0.055752,1.46404,-1.96911,0.059537,1.42743,-2.02761,0.257173,1.36829,-2.08096,0.290179,1.1093,-1.74971,0.17105,1.05607,-1.79258,0.206419,0.979366,-1.81255,0.323208,0.899636,-1.79564,0.311421,0.707605,-1.79403,0.300309,0.633239,-1.80914,0.200245,0.723854,-1.80862,0.190951,0.654556,-1.81974,0.200258,0.424698,-1.851,0.096953,0.362284,-1.93086,0.353993,0.385724,-1.88726,0.32587,0.335851,-1.81546,0.283829,1.07755,-2.13277,0.309968,0.99776,-2.11594,0.148893,1.0338,-2.09799,0.177679,0.957424,-2.08186,0.252972,0.841902,-2.08047,0.089089,0.802558,-2.06826,0.099371,0.91316,-2.09095,0.029302,0.91781,-2.08078,-0.200028,0.911675,-2.05332,-0.24912,1.0043,-1.99022,-0.301228,0.727995,-2.019,-0.336478,0.785674,-2.07953,0.160408,1.3018,-1.83531,0.172416,1.2817,-2.04927},
/*1637*/{0.2531,1.84608,-1.72581,0.341844,1.80172,-1.87511,0.160852,1.69302,-1.63802,0.086288,1.58984,-1.57989,0.233478,1.54723,-1.62169,0.315729,1.51518,-1.62258,0.288948,1.88245,-2.12514,0.353695,1.80901,-1.95273,0.145526,1.85252,-2.04785,0.121181,1.6762,-2.22076,0.156238,1.58425,-2.2667,0.303753,1.47165,-2.18424,0.351464,1.42374,-2.19342,0.236012,1.39076,-1.81961,0.046884,1.44261,-1.9126,0.054719,1.46358,-1.9689,0.05753,1.42866,-2.0279,0.255103,1.36869,-2.08094,0.28489,1.10655,-1.75009,0.164333,1.05466,-1.7934,0.19947,0.978202,-1.81332,0.31247,0.894536,-1.7947,0.298351,0.704247,-1.79272,0.285147,0.630663,-1.80841,0.186757,0.722972,-1.8092,0.176278,0.652505,-1.81917,0.182258,0.425741,-1.85018,0.076003,0.363006,-1.93006,0.332484,0.386153,-1.8854,0.304881,0.335946,-1.81435,0.2918,1.08215,-2.13164,0.32096,1.00329,-2.11513,0.158466,1.03234,-2.09876,0.189378,0.95767,-2.08314,0.26885,0.847828,-2.08218,0.10482,0.801455,-2.06648,0.11346,0.911812,-2.09059,0.043484,0.915709,-2.08105,-0.187028,0.906261,-2.05278,-0.238864,0.99804,-1.99229,-0.281959,0.720068,-2.01949,-0.317153,0.775405,-2.07932,0.157722,1.30191,-1.83505,0.170602,1.28215,-2.04899},
/*1638*/{0.254656,1.84543,-1.72648,0.341266,1.80119,-1.87553,0.165814,1.69288,-1.63653,0.094732,1.58752,-1.57723,0.24474,1.54769,-1.62022,0.327544,1.51804,-1.6234,0.288786,1.88231,-2.12509,0.352722,1.80771,-1.95235,0.145107,1.85316,-2.04825,0.116998,1.6806,-2.21657,0.148404,1.588,-2.26552,0.295111,1.47129,-2.18741,0.340786,1.42046,-2.19765,0.234072,1.3917,-1.81911,0.045958,1.44207,-1.91244,0.051973,1.46365,-1.9682,0.05527,1.42969,-2.02744,0.253808,1.36931,-2.08126,0.279211,1.10304,-1.74905,0.157965,1.05356,-1.7943,0.193024,0.976473,-1.81367,0.301191,0.891486,-1.79338,0.283125,0.700553,-1.79207,0.269294,0.627131,-1.80824,0.173352,0.72245,-1.80819,0.160794,0.652235,-1.82035,0.162802,0.425404,-1.8483,0.055024,0.363809,-1.92846,0.312065,0.385158,-1.88257,0.283748,0.334915,-1.8142,0.301755,1.08655,-2.13039,0.331539,1.00933,-2.11339,0.167714,1.03622,-2.10245,0.202406,0.959145,-2.08489,0.285029,0.852495,-2.08071,0.120476,0.800018,-2.06437,0.126642,0.911045,-2.09066,0.057145,0.913899,-2.08111,-0.173954,0.90018,-2.05246,-0.231804,0.99042,-1.99385,-0.261729,0.710122,-2.01884,-0.297425,0.763545,-2.08043,0.156439,1.30226,-1.83494,0.169201,1.28285,-2.04891},
/*1639*/{0.256457,1.84581,-1.72683,0.34068,1.79939,-1.87605,0.169958,1.69276,-1.63569,0.105431,1.58627,-1.57402,0.255288,1.54909,-1.61988,0.339009,1.52117,-1.62454,0.288521,1.8823,-2.12487,0.351783,1.80762,-1.952,0.144528,1.85496,-2.04872,0.110841,1.68664,-2.21315,0.140073,1.59187,-2.26508,0.28589,1.47096,-2.19088,0.330271,1.41871,-2.20217,0.232399,1.39324,-1.81886,0.044118,1.44245,-1.91234,0.051125,1.46419,-1.96836,0.0541,1.4305,-2.02601,0.251381,1.37165,-2.08158,0.274047,1.09954,-1.74961,0.150973,1.0519,-1.79452,0.182815,0.975841,-1.81446,0.28925,0.88729,-1.79295,0.268916,0.697062,-1.79251,0.253273,0.623832,-1.80775,0.160145,0.721003,-1.80788,0.144994,0.651424,-1.81967,0.141179,0.42464,-1.84787,0.033838,0.364409,-1.92807,0.290943,0.384836,-1.88399,0.262747,0.335462,-1.8129,0.308487,1.09405,-2.13036,0.343217,1.01682,-2.11258,0.178307,1.03705,-2.10278,0.214005,0.961515,-2.08459,0.301417,0.85826,-2.08041,0.136131,0.800186,-2.06297,0.140421,0.911167,-2.09012,0.070015,0.912272,-2.08161,-0.160802,0.893676,-2.05274,-0.223086,0.981998,-1.99578,-0.239522,0.699928,-2.01791,-0.277412,0.750829,-2.08033,0.155642,1.30325,-1.83498,0.168171,1.28437,-2.04902},
/*1640*/{0.258031,1.84715,-1.72709,0.340317,1.79963,-1.87652,0.175586,1.69389,-1.6343,0.114874,1.58522,-1.57033,0.265963,1.55188,-1.61892,0.350959,1.52531,-1.62549,0.287152,1.88263,-2.12456,0.350331,1.80768,-1.95242,0.144054,1.85557,-2.04861,0.105791,1.69215,-2.21032,0.131967,1.59614,-2.26484,0.276299,1.47075,-2.19434,0.31939,1.41819,-2.20658,0.230613,1.3939,-1.81779,0.042275,1.44179,-1.91281,0.049325,1.46502,-1.96771,0.05195,1.43153,-2.02471,0.249174,1.37413,-2.08232,0.267197,1.09599,-1.75048,0.14273,1.05371,-1.79622,0.17322,0.97496,-1.81564,0.275877,0.883681,-1.79339,0.25463,0.693193,-1.79251,0.23697,0.62082,-1.8084,0.14518,0.719547,-1.80817,0.129436,0.649622,-1.81998,0.120521,0.425005,-1.84688,0.013536,0.364895,-1.92726,0.270583,0.384652,-1.8833,0.241781,0.335316,-1.81317,0.315921,1.10083,-2.12981,0.353305,1.02499,-2.11186,0.187787,1.039,-2.10395,0.225778,0.967743,-2.08809,0.315981,0.8635,-2.08006,0.151563,0.800931,-2.06229,0.153179,0.91205,-2.09034,0.082952,0.910987,-2.0819,-0.143328,0.883789,-2.05202,-0.214759,0.972183,-1.99842,-0.215389,0.689007,-2.0157,-0.256112,0.737815,-2.08078,0.15446,1.30337,-1.8355,0.166939,1.28613,-2.04968},
/*1641*/{0.25943,1.8486,-1.72696,0.339875,1.80041,-1.87712,0.17969,1.69588,-1.63332,0.124213,1.58518,-1.56783,0.275673,1.55511,-1.61863,0.362496,1.53153,-1.62788,0.286695,1.88365,-2.12457,0.349719,1.80866,-1.95336,0.143289,1.85742,-2.04778,0.10062,1.6984,-2.20711,0.122801,1.60184,-2.26492,0.267214,1.4726,-2.19832,0.308498,1.42004,-2.21105,0.229169,1.39465,-1.81729,0.04107,1.44203,-1.9124,0.048088,1.46543,-1.96657,0.050533,1.43259,-2.02419,0.246992,1.37671,-2.08325,0.261294,1.09318,-1.75144,0.135054,1.05213,-1.79586,0.16271,0.973672,-1.81634,0.261961,0.879148,-1.79403,0.239297,0.689173,-1.7933,0.221031,0.618485,-1.80919,0.130503,0.718102,-1.8097,0.11322,0.648395,-1.82057,0.101183,0.426262,-1.84684,-0.006624,0.365937,-1.92651,0.250482,0.3841,-1.88199,0.221629,0.334739,-1.81194,0.32327,1.10901,-2.12929,0.362987,1.03421,-2.11117,0.19726,1.04206,-2.10535,0.237346,0.972372,-2.08909,0.329326,0.86828,-2.07986,0.167296,0.802382,-2.06157,0.166364,0.912757,-2.08973,0.096807,0.90953,-2.08344,-0.129206,0.874587,-2.05149,-0.207374,0.960396,-1.9996,-0.192116,0.677866,-2.01422,-0.234399,0.723781,-2.081,0.153869,1.30366,-1.83606,0.165847,1.28795,-2.05038},
/*1642*/{0.260053,1.8512,-1.72782,0.339473,1.80151,-1.87724,0.183645,1.69848,-1.6318,0.133748,1.58546,-1.56485,0.285634,1.55999,-1.61903,0.373066,1.53793,-1.63016,0.285451,1.88462,-2.12491,0.350019,1.8107,-1.9536,0.142386,1.85913,-2.04751,0.094321,1.70424,-2.20464,0.114054,1.6076,-2.265,0.258435,1.47509,-2.20235,0.297248,1.42175,-2.21472,0.228424,1.39598,-1.81654,0.040363,1.44232,-1.91243,0.047624,1.46633,-1.96633,0.049175,1.43345,-2.02374,0.246423,1.37974,-2.08442,0.252131,1.09126,-1.75094,0.12721,1.05445,-1.79732,0.152515,0.974455,-1.81727,0.247554,0.87441,-1.79402,0.223715,0.68704,-1.79421,0.203421,0.614805,-1.81001,0.115735,0.717292,-1.80996,0.097482,0.64844,-1.82121,0.081093,0.427199,-1.84692,-0.02669,0.366216,-1.92644,0.230059,0.383885,-1.88363,0.200611,0.334384,-1.81275,0.329506,1.11703,-2.12982,0.37217,1.04406,-2.11092,0.205993,1.04661,-2.10559,0.248158,0.977285,-2.08974,0.34417,0.874638,-2.08017,0.182751,0.804433,-2.06147,0.17842,0.91474,-2.09004,0.108551,0.909747,-2.08291,-0.120044,0.86844,-2.05408,-0.198504,0.947291,-2.00061,-0.168269,0.666678,-2.01306,-0.211904,0.709406,-2.08118,0.154089,1.30447,-1.83672,0.166019,1.29007,-2.05114},
/*1643*/{0.261999,1.85435,-1.72791,0.339996,1.80304,-1.87882,0.187815,1.70171,-1.6312,0.143405,1.58743,-1.56285,0.294475,1.56546,-1.61949,0.382796,1.54518,-1.63263,0.283419,1.88626,-2.12583,0.35014,1.81241,-1.95407,0.141304,1.86182,-2.04644,0.088068,1.71065,-2.20364,0.105515,1.61452,-2.2654,0.249227,1.47891,-2.20635,0.286559,1.42497,-2.21735,0.226538,1.39744,-1.81616,0.038327,1.44426,-1.91271,0.046983,1.46813,-1.96595,0.048347,1.43496,-2.02345,0.245416,1.3828,-2.08503,0.242356,1.09009,-1.75261,0.118528,1.05604,-1.79757,0.141409,0.97551,-1.81823,0.232189,0.870864,-1.79455,0.207754,0.686102,-1.7955,0.187661,0.613394,-1.81116,0.099649,0.715718,-1.80993,0.081707,0.647265,-1.82161,0.062031,0.426673,-1.84644,-0.046937,0.367029,-1.92696,0.209491,0.383613,-1.88342,0.181443,0.335282,-1.81086,0.335057,1.12487,-2.12956,0.379794,1.05421,-2.11049,0.213949,1.04999,-2.10565,0.259363,0.983438,-2.09002,0.356714,0.881601,-2.08032,0.198312,0.806564,-2.06154,0.190044,0.918646,-2.08895,0.119866,0.909115,-2.08326,-0.106904,0.857546,-2.0536,-0.191272,0.93354,-2.00119,-0.14376,0.654485,-2.01292,-0.18955,0.695044,-2.08074,0.152809,1.30587,-1.83721,0.165247,1.29258,-2.05168},
/*1644*/{0.263713,1.85698,-1.72828,0.339825,1.80663,-1.87961,0.192125,1.70481,-1.63028,0.152333,1.58943,-1.56076,0.303912,1.57136,-1.62044,0.391719,1.55342,-1.63553,0.281703,1.88862,-2.12624,0.347245,1.81306,-1.95545,0.140253,1.86325,-2.04541,0.081788,1.71679,-2.20329,0.097095,1.62156,-2.26549,0.239502,1.484,-2.21009,0.27576,1.42915,-2.22016,0.226166,1.39834,-1.81653,0.039086,1.44618,-1.91225,0.046838,1.47002,-1.96563,0.047695,1.43676,-2.02312,0.243995,1.38549,-2.08514,0.234908,1.08869,-1.7534,0.109532,1.0584,-1.79854,0.130583,0.977013,-1.81934,0.214664,0.869073,-1.79631,0.19224,0.685077,-1.7966,0.171234,0.613393,-1.81232,0.084291,0.716229,-1.81091,0.06573,0.646857,-1.82153,0.042992,0.428393,-1.84722,-0.066735,0.36814,-1.92712,0.189661,0.383408,-1.88361,0.160027,0.335432,-1.81228,0.34034,1.13385,-2.12983,0.387627,1.06406,-2.11014,0.221551,1.05482,-2.10601,0.268233,0.989053,-2.08969,0.369627,0.890285,-2.08075,0.21385,0.809327,-2.06161,0.200863,0.920153,-2.08912,0.131542,0.908651,-2.08354,-0.093508,0.847333,-2.05497,-0.182253,0.918282,-2.00209,-0.119239,0.642403,-2.01276,-0.167296,0.679575,-2.08133,0.152666,1.30707,-1.83777,0.16441,1.29481,-2.05234},
/*1645*/{0.265594,1.86104,-1.72909,0.338327,1.8092,-1.88061,0.197432,1.70807,-1.62972,0.160346,1.59153,-1.55929,0.31087,1.57733,-1.62277,0.399503,1.56208,-1.6392,0.278869,1.8912,-2.12633,0.34689,1.81535,-1.95643,0.138751,1.86627,-2.04415,0.075756,1.7231,-2.2032,0.08861,1.62877,-2.26619,0.229905,1.48909,-2.21169,0.264972,1.43482,-2.22239,0.22641,1.39956,-1.81678,0.03863,1.44932,-1.91191,0.046055,1.47234,-1.96558,0.046491,1.4392,-2.02355,0.243394,1.38922,-2.08523,0.226962,1.08773,-1.75479,0.100203,1.06102,-1.79972,0.118296,0.979086,-1.81974,0.19714,0.868486,-1.79711,0.17596,0.68374,-1.79874,0.154683,0.612948,-1.81385,0.069356,0.71692,-1.81014,0.048597,0.648868,-1.82131,0.023825,0.429066,-1.84703,-0.087208,0.369624,-1.92674,0.169718,0.383406,-1.88369,0.139999,0.335575,-1.8122,0.345118,1.14274,-2.12878,0.393931,1.07411,-2.11053,0.228456,1.06032,-2.10601,0.277331,0.996193,-2.08958,0.383068,0.899575,-2.08159,0.22908,0.812467,-2.06308,0.211808,0.922357,-2.08994,0.14288,0.908278,-2.08408,-0.080399,0.836851,-2.05556,-0.173598,0.902153,-2.00193,-0.094414,0.630332,-2.01328,-0.14409,0.664865,-2.08151,0.15234,1.3089,-1.83864,0.163798,1.29797,-2.05329},
/*1646*/{0.268086,1.86527,-1.72955,0.339325,1.81276,-1.88156,0.20308,1.71181,-1.62888,0.168947,1.59474,-1.5577,0.319475,1.58476,-1.62401,0.406608,1.57138,-1.6426,0.276393,1.89419,-2.12691,0.34632,1.81794,-1.95761,0.137205,1.86935,-2.04316,0.069506,1.7301,-2.20333,0.080185,1.63574,-2.26659,0.220556,1.49579,-2.21349,0.255058,1.44069,-2.22397,0.226009,1.39995,-1.81662,0.038381,1.45204,-1.91145,0.047117,1.47486,-1.96469,0.046742,1.44134,-2.02337,0.243135,1.3928,-2.08559,0.219196,1.08707,-1.75597,0.090915,1.06451,-1.79948,0.1072,0.981774,-1.81952,0.180549,0.868911,-1.79838,0.160091,0.684233,-1.80016,0.136078,0.613509,-1.81578,0.054111,0.718727,-1.81145,0.031741,0.650493,-1.82279,0.002613,0.429903,-1.84735,-0.106745,0.370957,-1.92619,0.149375,0.382881,-1.88358,0.119748,0.335661,-1.81118,0.349165,1.15048,-2.12899,0.399856,1.08459,-2.11069,0.235097,1.0651,-2.1052,0.286037,1.00261,-2.08881,0.394438,0.910716,-2.08161,0.243736,0.816056,-2.06439,0.221549,0.924118,-2.0895,0.153449,0.907275,-2.08424,-0.066262,0.82434,-2.0556,-0.163972,0.884915,-2.00315,-0.067965,0.61842,-2.01431,-0.121396,0.649536,-2.08179,0.152011,1.30989,-1.83955,0.163562,1.30103,-2.05429},
/*1647*/{0.269789,1.86974,-1.73053,0.338665,1.81635,-1.88283,0.209118,1.71578,-1.62846,0.177603,1.59886,-1.55753,0.32625,1.59224,-1.62556,0.414174,1.581,-1.64635,0.273613,1.89781,-2.12784,0.345734,1.8212,-1.95935,0.135849,1.87122,-2.04139,0.062134,1.73827,-2.20444,0.072152,1.64373,-2.26715,0.210849,1.50265,-2.21462,0.244549,1.4473,-2.22527,0.226257,1.40121,-1.8167,0.039614,1.45453,-1.90983,0.046237,1.47696,-1.96388,0.046911,1.44392,-2.02339,0.243422,1.39694,-2.08509,0.211746,1.08735,-1.75824,0.080214,1.066,-1.79954,0.095316,0.984371,-1.82006,0.16508,0.870301,-1.80077,0.143501,0.685451,-1.80171,0.119661,0.614736,-1.81738,0.037359,0.721421,-1.81259,0.014628,0.652632,-1.82178,-0.017306,0.43044,-1.84675,-0.126585,0.372989,-1.92558,0.129445,0.38266,-1.88369,0.099631,0.335679,-1.81137,0.353151,1.15847,-2.12922,0.405879,1.09412,-2.11072,0.241327,1.06968,-2.10405,0.29383,1.00911,-2.08742,0.405157,0.921866,-2.08189,0.258476,0.819586,-2.06556,0.230157,0.928247,-2.09136,0.162978,0.905695,-2.08423,-0.048546,0.810994,-2.05409,-0.154161,0.866767,-2.00269,-0.040974,0.60733,-2.01622,-0.097602,0.634869,-2.0827,0.152648,1.31143,-1.84009,0.164037,1.3045,-2.05491},
/*1648*/{0.271789,1.87518,-1.73167,0.339233,1.81862,-1.88424,0.214533,1.72003,-1.62859,0.185213,1.6037,-1.55621,0.332715,1.60046,-1.62821,0.420682,1.59082,-1.65,0.270354,1.90196,-2.12803,0.344872,1.82394,-1.96069,0.134103,1.87437,-2.03962,0.05581,1.74578,-2.20397,0.06364,1.65119,-2.26701,0.201583,1.50989,-2.21567,0.235411,1.45484,-2.22627,0.226495,1.40224,-1.81623,0.039283,1.45783,-1.90979,0.046552,1.48069,-1.96312,0.046998,1.44827,-2.02298,0.242904,1.40047,-2.08442,0.204024,1.08743,-1.76051,0.072324,1.07144,-1.79939,0.083924,0.987377,-1.82045,0.150687,0.872363,-1.80297,0.126221,0.686492,-1.80337,0.101872,0.61623,-1.81835,0.019373,0.72327,-1.81447,-0.002733,0.656089,-1.82364,-0.036979,0.43163,-1.84669,-0.146371,0.375752,-1.92572,0.110044,0.382734,-1.88355,0.079904,0.336086,-1.81203,0.357145,1.16633,-2.1291,0.410758,1.10337,-2.11058,0.247474,1.07553,-2.10391,0.30094,1.01591,-2.08667,0.415736,0.933668,-2.08221,0.272976,0.823268,-2.06761,0.238655,0.930145,-2.09035,0.172698,0.9052,-2.08458,-0.038072,0.79961,-2.05667,-0.142206,0.847424,-2.0027,-0.015108,0.59544,-2.01731,-0.07377,0.619928,-2.08331,0.151628,1.31334,-1.84069,0.163207,1.30824,-2.05555},
/*1649*/{0.273754,1.87986,-1.73259,0.340892,1.82393,-1.88523,0.220922,1.7248,-1.62828,0.192418,1.60683,-1.55553,0.338246,1.60856,-1.63034,0.425758,1.6007,-1.65426,0.266904,1.90642,-2.12837,0.344756,1.82831,-1.96251,0.132598,1.87731,-2.03774,0.049981,1.7539,-2.2042,0.056532,1.6589,-2.26747,0.193046,1.5178,-2.2154,0.226045,1.46276,-2.22689,0.226323,1.40342,-1.81556,0.04005,1.46054,-1.90994,0.047381,1.48333,-1.96185,0.04719,1.45183,-2.02272,0.242818,1.40442,-2.08339,0.196814,1.08814,-1.76249,0.067454,1.07391,-1.79753,0.073092,0.991045,-1.82051,0.138192,0.875137,-1.80458,0.108552,0.688681,-1.80498,0.083725,0.6179,-1.81921,0.002742,0.72493,-1.81587,-0.020735,0.65774,-1.82437,-0.054527,0.433615,-1.84651,-0.165675,0.379185,-1.9255,0.091019,0.382535,-1.88481,0.059916,0.335901,-1.81183,0.360214,1.17422,-2.13004,0.415717,1.1112,-2.11056,0.252686,1.08135,-2.10302,0.307454,1.02305,-2.08559,0.424538,0.944747,-2.08275,0.286007,0.826776,-2.06901,0.246704,0.932169,-2.09016,0.182208,0.903511,-2.08441,-0.019584,0.786683,-2.05593,-0.130677,0.827585,-2.00199,0.012221,0.586283,-2.01966,-0.049191,0.604854,-2.08485,0.151337,1.31496,-1.84118,0.163445,1.31186,-2.05605},
/*1650*/{0.275892,1.88472,-1.73367,0.341468,1.82785,-1.88721,0.227044,1.72942,-1.62836,0.200003,1.61189,-1.55485,0.343681,1.61699,-1.63322,0.430776,1.61072,-1.65822,0.263625,1.91123,-2.12897,0.343932,1.83274,-1.9647,0.131184,1.88068,-2.0362,0.042877,1.76359,-2.20449,0.049088,1.66676,-2.26715,0.183696,1.52573,-2.21603,0.217714,1.4711,-2.22722,0.226393,1.40367,-1.81512,0.040399,1.46368,-1.90831,0.046968,1.4867,-1.96115,0.047779,1.45608,-2.02196,0.243329,1.4092,-2.08261,0.190582,1.08805,-1.76537,0.055622,1.07816,-1.79938,0.062476,0.996337,-1.8201,0.126572,0.877786,-1.80653,0.091049,0.690669,-1.80632,0.065048,0.62104,-1.82054,-0.015114,0.727937,-1.81644,-0.038116,0.660556,-1.82578,-0.073531,0.438218,-1.84772,-0.18547,0.384101,-1.92553,0.071366,0.382073,-1.8842,0.039739,0.335943,-1.8123,0.363,1.18237,-2.12983,0.419051,1.12148,-2.11189,0.257107,1.08765,-2.10258,0.31407,1.03041,-2.08486,0.432083,0.956061,-2.08432,0.299283,0.830529,-2.07111,0.25417,0.933541,-2.08978,0.191036,0.902204,-2.0839,-0.008066,0.775101,-2.05807,-0.117935,0.808093,-2.00205,0.039373,0.574311,-2.02206,-0.022971,0.590982,-2.08641,0.150861,1.3162,-1.84223,0.163452,1.31641,-2.05709},
/*1651*/{0.278108,1.89056,-1.73545,0.34193,1.8319,-1.88911,0.232986,1.73436,-1.62935,0.20666,1.61676,-1.55462,0.34818,1.62495,-1.63503,0.434621,1.62067,-1.66234,0.259139,1.91598,-2.12887,0.344269,1.83706,-1.96653,0.129746,1.88316,-2.03439,0.037561,1.77145,-2.20395,0.042252,1.67482,-2.26667,0.175631,1.5338,-2.21568,0.209504,1.47922,-2.22777,0.227445,1.40522,-1.81375,0.041912,1.46703,-1.90762,0.047906,1.49055,-1.95957,0.048967,1.46041,-2.02175,0.244493,1.41344,-2.08144,0.182126,1.08956,-1.76723,0.049247,1.08522,-1.79926,0.051674,1.00058,-1.81993,0.114238,0.880571,-1.80862,0.073386,0.694214,-1.80656,0.04852,0.62443,-1.82142,-0.032117,0.73204,-1.81734,-0.056319,0.664263,-1.82585,-0.091892,0.441048,-1.84728,-0.204055,0.389247,-1.92432,0.051936,0.381007,-1.8847,0.019684,0.336321,-1.81256,0.366391,1.18936,-2.13008,0.422864,1.12992,-2.11159,0.261704,1.09303,-2.1017,0.318801,1.03702,-2.08445,0.439127,0.967326,-2.08353,0.311791,0.833856,-2.07195,0.260573,0.935463,-2.09043,0.199886,0.899223,-2.08329,0.009161,0.761704,-2.05622,-0.104033,0.787487,-2.00052,0.066674,0.564275,-2.0247,0.003948,0.577233,-2.08856,0.151252,1.31847,-1.84235,0.16441,1.32065,-2.05717},
/*1652*/{0.279976,1.89625,-1.73672,0.343046,1.83722,-1.89142,0.239196,1.7399,-1.62994,0.212984,1.62299,-1.55485,0.3524,1.63326,-1.6378,0.438182,1.63121,-1.66635,0.255509,1.92113,-2.12881,0.343415,1.84193,-1.96858,0.128243,1.88609,-2.03306,0.032851,1.77901,-2.20436,0.036241,1.68261,-2.26577,0.167902,1.54313,-2.2148,0.201294,1.48803,-2.22798,0.228092,1.4065,-1.81222,0.042795,1.47087,-1.90671,0.048645,1.4945,-1.95784,0.049636,1.46563,-2.02198,0.245665,1.41782,-2.07953,0.175519,1.0921,-1.76939,0.040855,1.09123,-1.79951,0.040567,1.00725,-1.82179,0.10078,0.883263,-1.81003,0.056839,0.69811,-1.80777,0.030201,0.627595,-1.82158,-0.049287,0.736039,-1.81862,-0.072671,0.669901,-1.8277,-0.109133,0.444771,-1.84733,-0.221822,0.395821,-1.92454,0.033914,0.380912,-1.88516,-0.000586,0.336902,-1.81408,0.368653,1.19655,-2.1306,0.426576,1.13818,-2.11173,0.265181,1.09981,-2.1011,0.323162,1.0439,-2.08352,0.444715,0.977997,-2.0832,0.323765,0.837512,-2.07445,0.266654,0.936501,-2.09031,0.207011,0.896651,-2.08302,0.026551,0.748183,-2.05721,-0.088705,0.766335,-2.0006,0.095244,0.555366,-2.02873,0.030571,0.564826,-2.09106,0.150777,1.32077,-1.84249,0.164998,1.32527,-2.05721},
/*1653*/{0.28188,1.90165,-1.73828,0.342718,1.84199,-1.89295,0.243917,1.74513,-1.63096,0.219272,1.62782,-1.554,0.35585,1.64129,-1.63988,0.440848,1.64082,-1.67004,0.252733,1.92582,-2.12881,0.343383,1.8468,-1.97062,0.126541,1.88981,-2.03119,0.030575,1.78506,-2.20313,0.029143,1.69093,-2.2648,0.160709,1.55216,-2.2133,0.194268,1.49608,-2.22815,0.22803,1.40823,-1.81184,0.044267,1.47417,-1.90696,0.049408,1.49824,-1.95641,0.051547,1.46987,-2.02181,0.246216,1.42227,-2.07818,0.171869,1.09572,-1.77095,0.034412,1.0955,-1.79901,0.030376,1.01328,-1.82199,0.084848,0.887761,-1.81082,0.039203,0.702801,-1.80757,0.01225,0.633437,-1.82279,-0.064814,0.742065,-1.81914,-0.090179,0.675569,-1.82819,-0.127088,0.449357,-1.84748,-0.239181,0.402739,-1.92569,0.014826,0.379415,-1.88504,-0.019887,0.337417,-1.81359,0.37148,1.20422,-2.13042,0.42951,1.14609,-2.1113,0.268487,1.10679,-2.10171,0.327472,1.05157,-2.08349,0.44922,0.988598,-2.08307,0.335386,0.842147,-2.07638,0.272793,0.936338,-2.08931,0.215511,0.894036,-2.08317,0.044487,0.733949,-2.05677,-0.073802,0.745593,-1.99987,0.124695,0.54549,-2.03156,0.058104,0.552045,-2.09378,0.150721,1.32302,-1.84307,0.165892,1.32963,-2.05767},
/*1654*/{0.284332,1.90738,-1.74003,0.343473,1.84692,-1.89497,0.249159,1.75089,-1.63176,0.225779,1.63431,-1.55423,0.359427,1.65084,-1.64287,0.443058,1.6508,-1.67386,0.250041,1.93058,-2.12827,0.34333,1.85202,-1.97233,0.125412,1.89315,-2.0295,0.025621,1.79269,-2.20274,0.023331,1.69902,-2.26393,0.153481,1.55976,-2.21218,0.187477,1.50524,-2.22789,0.229045,1.41015,-1.81116,0.045384,1.47781,-1.90622,0.051325,1.502,-1.95494,0.052652,1.47553,-2.02115,0.246749,1.42693,-2.07667,0.162611,1.09367,-1.77406,0.026889,1.10429,-1.7997,0.020301,1.01989,-1.82261,0.068967,0.893542,-1.81063,0.023411,0.708743,-1.80775,-0.001426,0.641075,-1.82149,-0.081634,0.748531,-1.8209,-0.106113,0.681379,-1.82987,-0.144851,0.454321,-1.84706,-0.255837,0.411098,-1.92577,-0.003183,0.378893,-1.88554,-0.040416,0.33803,-1.81491,0.373087,1.21176,-2.13096,0.432274,1.1539,-2.11117,0.271442,1.11343,-2.10144,0.330713,1.05865,-2.08357,0.452444,0.997702,-2.08304,0.34501,0.844348,-2.07796,0.27831,0.935853,-2.08869,0.222843,0.890682,-2.08345,0.05991,0.721242,-2.05868,-0.056507,0.723447,-1.99981,0.153359,0.537529,-2.03566,0.087291,0.540402,-2.09684,0.151011,1.3256,-1.84347,0.166559,1.33448,-2.05796},
/*1655*/{0.285339,1.91387,-1.74197,0.344077,1.8518,-1.89714,0.254143,1.75672,-1.6324,0.229646,1.64089,-1.55367,0.360831,1.65793,-1.64424,0.44537,1.65984,-1.67772,0.247142,1.93538,-2.12851,0.342899,1.85657,-1.97455,0.124354,1.89701,-2.02866,0.021251,1.8003,-2.20222,0.017207,1.70691,-2.26257,0.146474,1.56858,-2.21035,0.18134,1.51405,-2.22785,0.229783,1.41149,-1.81071,0.046514,1.48218,-1.90566,0.051475,1.50649,-1.95296,0.054109,1.48044,-2.02114,0.247374,1.43155,-2.07561,0.154686,1.09787,-1.77646,0.021948,1.11011,-1.79959,0.01241,1.02716,-1.82159,0.051974,0.899294,-1.81048,0.007407,0.715053,-1.80762,-0.019809,0.646029,-1.82064,-0.097786,0.756807,-1.82136,-0.121836,0.689354,-1.83034,-0.160045,0.461562,-1.84821,-0.272636,0.420315,-1.92639,-0.022018,0.377865,-1.88556,-0.059978,0.339077,-1.81539,0.375334,1.21876,-2.13101,0.435096,1.16163,-2.11003,0.2743,1.12054,-2.10149,0.333565,1.06405,-2.08357,0.454544,1.00635,-2.08368,0.354966,0.847845,-2.07992,0.283259,0.934735,-2.08828,0.231734,0.886558,-2.08371,0.077993,0.707247,-2.05891,-0.038352,0.700554,-1.99899,0.182769,0.530416,-2.03981,0.115666,0.529865,-2.0999,0.150771,1.32812,-1.84414,0.166745,1.33935,-2.05849},
/*1656*/{0.286798,1.91804,-1.74374,0.345282,1.85714,-1.89952,0.258204,1.76225,-1.63363,0.234615,1.64634,-1.55329,0.362875,1.66619,-1.64669,0.446723,1.66859,-1.68107,0.244998,1.93976,-2.12854,0.342087,1.86232,-1.97586,0.123537,1.90139,-2.02689,0.017867,1.80749,-2.20185,0.012502,1.71487,-2.26123,0.141686,1.57706,-2.20888,0.175265,1.5225,-2.22776,0.230567,1.41271,-1.81107,0.048341,1.48522,-1.9041,0.052839,1.51248,-1.95262,0.055071,1.48597,-2.02095,0.247112,1.43572,-2.0743,0.1502,1.10254,-1.77572,0.016077,1.11848,-1.79988,0.003029,1.03544,-1.82131,0.036277,0.906006,-1.80947,-0.008467,0.722513,-1.80657,-0.035293,0.652753,-1.81958,-0.112001,0.763422,-1.82214,-0.136267,0.696995,-1.83061,-0.176546,0.466107,-1.84758,-0.288623,0.430021,-1.92728,-0.039568,0.377755,-1.88666,-0.080463,0.339838,-1.81557,0.376723,1.22519,-2.13043,0.436634,1.16853,-2.10955,0.276272,1.12593,-2.10176,0.335507,1.07137,-2.08386,0.456183,1.01443,-2.08387,0.365512,0.85107,-2.08151,0.287619,0.932832,-2.08825,0.23985,0.881576,-2.083,0.096557,0.693765,-2.05964,-0.02061,0.68048,-1.99878,0.211084,0.523506,-2.04444,0.144028,0.5202,-2.10316,0.15033,1.33056,-1.84515,0.166278,1.34416,-2.05936},
/*1657*/{0.288439,1.92327,-1.74586,0.345769,1.86114,-1.90166,0.261273,1.76781,-1.63468,0.237363,1.65223,-1.55247,0.364406,1.67382,-1.64876,0.447381,1.677,-1.68459,0.243248,1.94382,-2.12859,0.340903,1.86627,-1.97767,0.122496,1.90491,-2.02599,0.015093,1.8141,-2.20109,0.00761,1.72211,-2.26018,0.134911,1.58481,-2.20802,0.170155,1.53049,-2.22736,0.23294,1.41434,-1.81177,0.048986,1.48905,-1.90367,0.05439,1.51474,-1.95043,0.056601,1.49116,-2.02055,0.247879,1.44063,-2.0734,0.143777,1.10433,-1.77658,0.01228,1.12598,-1.79911,-0.003472,1.04318,-1.82033,0.021118,0.913716,-1.80907,-0.02301,0.729374,-1.80608,-0.048921,0.660079,-1.81845,-0.126695,0.770846,-1.82324,-0.15149,0.704603,-1.83178,-0.19441,0.473227,-1.84809,-0.303925,0.440149,-1.92787,-0.058815,0.377488,-1.88671,-0.099934,0.340634,-1.8163,0.378129,1.23173,-2.1301,0.438182,1.17545,-2.10923,0.278099,1.13228,-2.10263,0.33631,1.07647,-2.08387,0.456547,1.02154,-2.08447,0.374032,0.852997,-2.08374,0.292028,0.930936,-2.08767,0.245945,0.877113,-2.08272,0.113812,0.680148,-2.06102,-0.00104,0.658882,-1.99847,0.241054,0.518637,-2.04899,0.172731,0.510007,-2.10699,0.151801,1.33276,-1.84628,0.167365,1.34906,-2.06033},
/*1658*/{0.289706,1.92797,-1.7473,0.345612,1.86596,-1.9037,0.264381,1.77376,-1.63534,0.241112,1.65831,-1.55185,0.365127,1.68062,-1.65061,0.448103,1.68591,-1.68902,0.241951,1.94781,-2.1286,0.341011,1.87107,-1.97935,0.121639,1.90825,-2.02588,0.011536,1.82119,-2.19993,0.002701,1.72929,-2.25749,0.130546,1.59417,-2.20732,0.16532,1.53791,-2.22746,0.233421,1.41615,-1.81202,0.05079,1.4934,-1.90357,0.054724,1.51889,-1.94852,0.057718,1.49626,-2.01947,0.248026,1.44527,-2.07277,0.139107,1.10781,-1.77821,0.006578,1.13276,-1.79914,-0.010561,1.05079,-1.8195,0.009305,0.921975,-1.80879,-0.037074,0.737156,-1.80448,-0.06533,0.667521,-1.81789,-0.140068,0.778999,-1.82451,-0.165852,0.712004,-1.83314,-0.206526,0.479474,-1.84721,-0.318818,0.451844,-1.92818,-0.07682,0.376831,-1.8868,-0.120767,0.340929,-1.81667,0.379414,1.23825,-2.13057,0.439483,1.18208,-2.10767,0.279412,1.13816,-2.10392,0.33881,1.0836,-2.08437,0.456429,1.0277,-2.08469,0.382307,0.854464,-2.0855,0.296652,0.927767,-2.08737,0.253734,0.871225,-2.08066,0.13132,0.666803,-2.06223,0.019912,0.636377,-1.99768,0.270063,0.513955,-2.05306,0.201808,0.501517,-2.1108,0.151843,1.33549,-1.8471,0.167243,1.354,-2.06099},
/*1659*/{0.291491,1.93256,-1.74905,0.345665,1.87043,-1.90526,0.267306,1.77893,-1.63601,0.243427,1.66399,-1.55187,0.365798,1.68777,-1.65223,0.44754,1.6938,-1.69212,0.240613,1.95148,-2.1292,0.340535,1.87596,-1.9805,0.121359,1.91184,-2.02515,0.009874,1.82754,-2.19885,-0.000861,1.73632,-2.25615,0.125827,1.60138,-2.20631,0.161767,1.54407,-2.22673,0.235246,1.41825,-1.81287,0.052837,1.49758,-1.90259,0.055795,1.52292,-1.94732,0.057847,1.50134,-2.01939,0.248482,1.44998,-2.07169,0.134367,1.11098,-1.77767,0.003381,1.13973,-1.79808,-0.017337,1.05955,-1.82065,-0.001893,0.93007,-1.80928,-0.048643,0.74529,-1.80423,-0.0788,0.67579,-1.81718,-0.152409,0.787477,-1.82558,-0.178323,0.720258,-1.83455,-0.2203,0.48688,-1.84617,-0.332826,0.464311,-1.92879,-0.095611,0.377051,-1.88705,-0.140912,0.341889,-1.81793,0.380256,1.24353,-2.12945,0.440669,1.18767,-2.10705,0.280728,1.14285,-2.10578,0.339674,1.08897,-2.08462,0.455458,1.03311,-2.08577,0.390667,0.855029,-2.08688,0.300517,0.923904,-2.08761,0.261452,0.865592,-2.08118,0.147238,0.653053,-2.06363,0.042907,0.615334,-1.99611,0.297909,0.510147,-2.05739,0.230274,0.493971,-2.11441,0.152779,1.33849,-1.84794,0.167517,1.35888,-2.0617},
/*1660*/{0.293007,1.9373,-1.75048,0.34569,1.87548,-1.90727,0.270182,1.78413,-1.63676,0.246173,1.66974,-1.55145,0.366314,1.69381,-1.65423,0.447638,1.70104,-1.69557,0.23924,1.95532,-2.12941,0.340613,1.8808,-1.98239,0.122495,1.91379,-2.02405,0.009982,1.83438,-2.19739,-0.004608,1.74246,-2.2546,0.122919,1.60626,-2.20482,0.159265,1.55021,-2.22663,0.236731,1.42031,-1.81379,0.053842,1.50249,-1.90179,0.057116,1.52752,-1.94568,0.060496,1.50676,-2.01794,0.248708,1.45373,-2.07157,0.130143,1.11546,-1.77715,0.000233,1.14721,-1.79687,-0.023364,1.0679,-1.81997,-0.012269,0.938284,-1.80893,-0.060821,0.753227,-1.80274,-0.08977,0.68359,-1.81492,-0.162781,0.796322,-1.82588,-0.18965,0.729124,-1.83534,-0.234092,0.493599,-1.84606,-0.344004,0.477748,-1.928,-0.114414,0.377094,-1.88739,-0.160779,0.343863,-1.81807,0.381783,1.24897,-2.1288,0.440792,1.19289,-2.10587,0.280813,1.1483,-2.1064,0.339479,1.09279,-2.08592,0.454818,1.03689,-2.08646,0.398315,0.855618,-2.08936,0.305091,0.918759,-2.08762,0.268842,0.857865,-2.08166,0.170089,0.639656,-2.06392,0.063618,0.594631,-1.99889,0.326152,0.507141,-2.06085,0.258801,0.487064,-2.1177,0.153075,1.34159,-1.84853,0.167121,1.36352,-2.06218},
/*1661*/{0.29465,1.94115,-1.75212,0.345611,1.87887,-1.90874,0.271873,1.78881,-1.63693,0.248377,1.67503,-1.55059,0.366187,1.70016,-1.65592,0.446829,1.7085,-1.69861,0.237897,1.9584,-2.12996,0.340017,1.8847,-1.98384,0.123272,1.91604,-2.02385,0.006479,1.83908,-2.19601,-0.007845,1.74885,-2.25239,0.120143,1.61277,-2.20428,0.154023,1.55723,-2.22761,0.238242,1.42304,-1.81369,0.054624,1.50661,-1.90079,0.058278,1.53146,-1.94487,0.061747,1.51133,-2.01789,0.248747,1.45821,-2.07107,0.126849,1.11886,-1.77671,-0.004192,1.15509,-1.79817,-0.029434,1.07461,-1.82159,-0.020968,0.945492,-1.80904,-0.071043,0.761837,-1.80171,-0.098832,0.692848,-1.81367,-0.17245,0.804531,-1.82655,-0.19877,0.738399,-1.83389,-0.24606,0.500716,-1.8446,-0.355557,0.49086,-1.93006,-0.13236,0.377683,-1.88733,-0.181476,0.345419,-1.8185,0.382517,1.25423,-2.12758,0.441289,1.19718,-2.10456,0.280611,1.15332,-2.10703,0.338271,1.09895,-2.09008,0.453206,1.03959,-2.0873,0.405609,0.855017,-2.09039,0.309332,0.913155,-2.08781,0.276319,0.85079,-2.08254,0.187542,0.626821,-2.0661,0.086331,0.57401,-1.9995,0.353932,0.504257,-2.06355,0.287538,0.481353,-2.1205,0.153833,1.34495,-1.84885,0.167523,1.36801,-2.06241},
/*1662*/{0.295581,1.9447,-1.75393,0.346451,1.88365,-1.91104,0.272936,1.79369,-1.63756,0.249435,1.67992,-1.54995,0.366159,1.70538,-1.65742,0.446588,1.71383,-1.70041,0.237526,1.96205,-2.13039,0.339962,1.88801,-1.98514,0.122741,1.91899,-2.02387,0.005571,1.8443,-2.19521,-0.011145,1.75469,-2.25083,0.116738,1.61802,-2.20385,0.151606,1.5629,-2.22783,0.23821,1.42534,-1.81439,0.056094,1.51062,-1.90002,0.059247,1.53583,-1.9434,0.063112,1.51643,-2.01636,0.249084,1.46207,-2.07105,0.12558,1.12328,-1.77639,-0.00486,1.16034,-1.79593,-0.032162,1.08209,-1.81946,-0.027995,0.952322,-1.80917,-0.079439,0.769035,-1.80094,-0.108302,0.699698,-1.81208,-0.181357,0.81135,-1.82682,-0.207879,0.745555,-1.83445,-0.257494,0.509482,-1.84333,-0.365691,0.505938,-1.9309,-0.149197,0.378744,-1.88659,-0.201445,0.348102,-1.81924,0.382794,1.25866,-2.12614,0.440819,1.20022,-2.10355,0.279943,1.15828,-2.10811,0.337685,1.10289,-2.09171,0.451687,1.04146,-2.08802,0.412836,0.853924,-2.09224,0.31326,0.907269,-2.08897,0.284536,0.842176,-2.08287,0.208064,0.614915,-2.06744,0.110815,0.555853,-2.00022,0.380819,0.502252,-2.06593,0.315748,0.475728,-2.12321,0.153711,1.34786,-1.84947,0.167074,1.3726,-2.06286},
/*1663*/{0.297112,1.94924,-1.755,0.346182,1.88649,-1.9123,0.274128,1.79818,-1.63813,0.250606,1.68502,-1.54952,0.366233,1.71071,-1.65867,0.444677,1.71945,-1.70389,0.236734,1.96488,-2.13114,0.340529,1.89171,-1.98629,0.122904,1.92178,-2.02379,0.004675,1.84972,-2.19358,-0.014242,1.76029,-2.2483,0.11404,1.62339,-2.20375,0.149405,1.56809,-2.22745,0.240864,1.42836,-1.81456,0.05738,1.5147,-1.89829,0.060525,1.53985,-1.94221,0.064086,1.521,-2.01513,0.249028,1.46546,-2.07116,0.120252,1.12593,-1.7741,-0.008474,1.16735,-1.7969,-0.035155,1.08879,-1.82021,-0.032706,0.958553,-1.80879,-0.086159,0.776037,-1.80031,-0.116202,0.706219,-1.81115,-0.188038,0.819043,-1.82661,-0.215474,0.75247,-1.83333,-0.267891,0.516725,-1.8418,-0.374928,0.520905,-1.93116,-0.167113,0.379807,-1.88595,-0.221773,0.3523,-1.81925,0.382421,1.26208,-2.12447,0.439528,1.20258,-2.10252,0.278398,1.16262,-2.1092,0.335796,1.10568,-2.09353,0.45008,1.04203,-2.08915,0.419678,0.851901,-2.09352,0.316644,0.899382,-2.09034,0.291907,0.834298,-2.08446,0.227513,0.602321,-2.06832,0.132971,0.53696,-2.00218,0.407177,0.50178,-2.06791,0.343383,0.471793,-2.12589,0.15518,1.35143,-1.84909,0.16679,1.37644,-2.06255},
/*1664*/{0.297336,1.95167,-1.75615,0.346986,1.89053,-1.91293,0.274628,1.80264,-1.6388,0.25148,1.6895,-1.54886,0.364179,1.71572,-1.65942,0.4434,1.72478,-1.7065,0.236336,1.96793,-2.1314,0.339963,1.8946,-1.98802,0.122975,1.92464,-2.02403,0.005482,1.85394,-2.19147,-0.017124,1.76536,-2.24695,0.112368,1.62731,-2.20389,0.147417,1.5726,-2.22788,0.241355,1.43115,-1.81467,0.058946,1.51833,-1.89699,0.062028,1.543,-1.94135,0.06489,1.52519,-2.01424,0.248466,1.4685,-2.07074,0.117889,1.12996,-1.77365,-0.012383,1.17387,-1.80069,-0.038427,1.09423,-1.82111,-0.037146,0.964029,-1.8094,-0.092276,0.781941,-1.79979,-0.121951,0.713436,-1.81045,-0.193388,0.82618,-1.82599,-0.221348,0.760704,-1.83195,-0.278339,0.525031,-1.84066,-0.383916,0.538409,-1.93086,-0.184486,0.382092,-1.88581,-0.242693,0.356825,-1.8208,0.381041,1.265,-2.12346,0.437339,1.20443,-2.10179,0.277011,1.16626,-2.10979,0.333408,1.10842,-2.09437,0.447502,1.04222,-2.09027,0.425887,0.850441,-2.09497,0.32077,0.892326,-2.09179,0.298918,0.82523,-2.08585,0.247321,0.59115,-2.07019,0.156692,0.519487,-2.0054,0.432471,0.500524,-2.06788,0.371038,0.467966,-2.12769,0.155545,1.35451,-1.84875,0.16633,1.3798,-2.06222},
/*1665*/{0.298056,1.95499,-1.75802,0.347577,1.89404,-1.91466,0.274268,1.80694,-1.63853,0.251281,1.69406,-1.54951,0.363978,1.71939,-1.66096,0.442868,1.729,-1.70771,0.23632,1.97018,-2.13277,0.34013,1.89708,-1.98916,0.123993,1.92688,-2.02392,0.004935,1.85797,-2.19051,-0.019243,1.77014,-2.24495,0.111315,1.63209,-2.20454,0.1458,1.5766,-2.22832,0.242793,1.43421,-1.81469,0.060191,1.52137,-1.89642,0.062404,1.54775,-1.93947,0.065523,1.52981,-2.01289,0.248259,1.47208,-2.07039,0.114558,1.1347,-1.77169,-0.012384,1.17825,-1.80131,-0.040077,1.09871,-1.8213,-0.039249,0.968897,-1.80952,-0.096639,0.786176,-1.80058,-0.128088,0.718543,-1.80984,-0.196703,0.833136,-1.82441,-0.225496,0.766821,-1.82988,-0.287843,0.53549,-1.84036,-0.39099,0.554212,-1.92862,-0.203296,0.384105,-1.886,-0.263883,0.362534,-1.82213,0.379855,1.26578,-2.12156,0.435959,1.20495,-2.10115,0.274191,1.16835,-2.11072,0.329958,1.11022,-2.09568,0.444874,1.04135,-2.09185,0.431532,0.847719,-2.09625,0.325021,0.883642,-2.0923,0.306348,0.815985,-2.08729,0.265994,0.579893,-2.07139,0.180155,0.503247,-2.00676,0.456657,0.499903,-2.06876,0.397162,0.464821,-2.12852,0.156251,1.35785,-1.84861,0.165976,1.38395,-2.06203},
/*1666*/{0.299584,1.95926,-1.7591,0.347437,1.89786,-1.91576,0.274163,1.81061,-1.63938,0.250727,1.69724,-1.5482,0.362854,1.72349,-1.66184,0.439895,1.73323,-1.71065,0.236113,1.97284,-2.13317,0.34047,1.89942,-1.99049,0.123743,1.92958,-2.02466,0.00425,1.8621,-2.18814,-0.020921,1.77441,-2.24361,0.11024,1.6358,-2.20445,0.144405,1.58064,-2.22887,0.242662,1.43663,-1.81468,0.061686,1.52554,-1.89456,0.062517,1.55123,-1.93868,0.065266,1.53346,-2.01099,0.24833,1.47505,-2.07022,0.114871,1.13926,-1.7702,-0.012446,1.18059,-1.79927,-0.041085,1.10207,-1.82209,-0.040022,0.972341,-1.80982,-0.100033,0.790699,-1.80026,-0.133181,0.723138,-1.80957,-0.199482,0.839061,-1.82333,-0.230679,0.774287,-1.83001,-0.298087,0.54498,-1.83979,-0.397738,0.572003,-1.92632,-0.221054,0.388597,-1.88815,-0.283571,0.369338,-1.82431,0.378159,1.26657,-2.1208,0.433313,1.20424,-2.10027,0.270907,1.16937,-2.11113,0.325392,1.11043,-2.0958,0.440882,1.0392,-2.09255,0.437287,0.845595,-2.09712,0.328502,0.876751,-2.09538,0.312936,0.806909,-2.08878,0.286568,0.570255,-2.0728,0.202997,0.488744,-2.00981,0.479992,0.500636,-2.06962,0.422713,0.462008,-2.12937,0.156128,1.36089,-1.84802,0.164981,1.38733,-2.06144},
/*1667*/{0.299663,1.96136,-1.7603,0.347753,1.90056,-1.91687,0.27423,1.81422,-1.63962,0.251039,1.70157,-1.54782,0.361589,1.72674,-1.66365,0.439481,1.73604,-1.7118,0.236775,1.97537,-2.13442,0.340445,1.90172,-1.9921,0.124707,1.9316,-2.02443,0.004392,1.86537,-2.18791,-0.022798,1.77781,-2.24217,0.109263,1.63874,-2.20486,0.143602,1.58426,-2.22908,0.243335,1.43982,-1.81444,0.061815,1.52891,-1.89437,0.063157,1.55461,-1.93655,0.066385,1.53743,-2.0105,0.247702,1.47792,-2.0701,0.1132,1.14075,-1.76885,-0.011548,1.18347,-1.79971,-0.040236,1.1048,-1.82262,-0.038358,0.975037,-1.81068,-0.102071,0.793923,-1.80002,-0.13737,0.726897,-1.8098,-0.200877,0.844064,-1.82211,-0.23295,0.779784,-1.82693,-0.305642,0.553339,-1.83739,-0.404121,0.5894,-1.92263,-0.239288,0.394072,-1.88925,-0.302498,0.376956,-1.8267,0.375471,1.26576,-2.12041,0.429871,1.20268,-2.1003,0.267032,1.17013,-2.11125,0.320795,1.11053,-2.09712,0.435292,1.03719,-2.09427,0.441281,0.842585,-2.09815,0.330622,0.867686,-2.0985,0.319808,0.798497,-2.09154,0.303928,0.559802,-2.07422,0.22519,0.473556,-2.01079,0.502426,0.501824,-2.06887,0.448258,0.459677,-2.12913,0.156334,1.36411,-1.84756,0.164511,1.39066,-2.06099},
/*1668*/{0.299867,1.96391,-1.76188,0.34812,1.90387,-1.91859,0.273245,1.8183,-1.63955,0.249154,1.7049,-1.54721,0.360645,1.72882,-1.66288,0.437762,1.73806,-1.71327,0.236932,1.978,-2.13496,0.34114,1.90331,-1.99341,0.125805,1.93446,-2.02553,0.003622,1.86826,-2.18603,-0.023967,1.78089,-2.24122,0.110281,1.64279,-2.20568,0.142984,1.58718,-2.22975,0.244104,1.44273,-1.81442,0.062085,1.53238,-1.89334,0.063075,1.55788,-1.9369,0.065037,1.53994,-2.00875,0.247302,1.48092,-2.06978,0.11274,1.1433,-1.76781,-0.011222,1.18456,-1.80014,-0.039402,1.10628,-1.8222,-0.036576,0.976223,-1.81161,-0.104454,0.796543,-1.80007,-0.140886,0.730591,-1.80971,-0.200423,0.850324,-1.82028,-0.235,0.787144,-1.82406,-0.313309,0.561667,-1.83537,-0.411283,0.606979,-1.91849,-0.2577,0.400978,-1.89334,-0.320155,0.385236,-1.82941,0.371959,1.2641,-2.11998,0.424638,1.2004,-2.10017,0.261988,1.16984,-2.11233,0.315208,1.10911,-2.0981,0.430083,1.03436,-2.09542,0.445909,0.840136,-2.0993,0.33372,0.859399,-2.10123,0.325205,0.789195,-2.09379,0.323187,0.552304,-2.07609,0.247057,0.462428,-2.01219,0.522604,0.502478,-2.06892,0.471471,0.457559,-2.12908,0.156738,1.36732,-1.84684,0.163816,1.39349,-2.06037},
/*1669*/{0.300126,1.96602,-1.76241,0.347622,1.90628,-1.91997,0.272115,1.8214,-1.6399,0.247826,1.70778,-1.54731,0.359043,1.73232,-1.66284,0.435713,1.73987,-1.71501,0.237551,1.98006,-2.13612,0.340737,1.90475,-1.99444,0.125655,1.93686,-2.02655,0.00308,1.87083,-2.18478,-0.024462,1.7831,-2.24059,0.109994,1.64564,-2.20577,0.143572,1.58957,-2.22967,0.244892,1.44558,-1.81372,0.062497,1.5349,-1.89117,0.063447,1.5615,-1.9357,0.064609,1.54355,-2.00775,0.247481,1.4834,-2.06971,0.115102,1.14667,-1.76764,-0.013548,1.18557,-1.80267,-0.037488,1.10592,-1.82387,-0.032754,0.977091,-1.81191,-0.105042,0.798396,-1.80137,-0.14337,0.735001,-1.81065,-0.200237,0.856158,-1.81888,-0.237038,0.793438,-1.82413,-0.321521,0.573036,-1.83554,-0.417898,0.623242,-1.91325,-0.276281,0.408958,-1.89736,-0.337918,0.39328,-1.83356,0.367802,1.26165,-2.11951,0.420381,1.19714,-2.10027,0.257022,1.16873,-2.11292,0.308886,1.10726,-2.09832,0.423973,1.03133,-2.0967,0.449057,0.836874,-2.09953,0.336356,0.851371,-2.10394,0.331765,0.780777,-2.09796,0.340701,0.543582,-2.07671,0.268911,0.450346,-2.01296,0.542569,0.503685,-2.06828,0.493697,0.455501,-2.12752,0.157151,1.37027,-1.84595,0.163282,1.39648,-2.0595},
/*1670*/{0.30021,1.96829,-1.76388,0.347954,1.90812,-1.9209,0.270749,1.82499,-1.64082,0.24632,1.71033,-1.54709,0.357421,1.73326,-1.66457,0.434499,1.74206,-1.71627,0.23769,1.98202,-2.13696,0.341052,1.90657,-1.99539,0.126403,1.93872,-2.02699,0.004436,1.87353,-2.18372,-0.025584,1.785,-2.24019,0.11029,1.64747,-2.20615,0.143332,1.59198,-2.23036,0.244957,1.44803,-1.81303,0.063098,1.5377,-1.89086,0.063806,1.56395,-1.93439,0.064383,1.54614,-2.00648,0.247224,1.48545,-2.06921,0.115839,1.14632,-1.76707,-0.009544,1.18743,-1.8024,-0.03326,1.10607,-1.82509,-0.028539,0.977201,-1.81232,-0.104914,0.799762,-1.80169,-0.145895,0.738254,-1.81116,-0.198196,0.861042,-1.81653,-0.236312,0.801216,-1.82049,-0.329555,0.580797,-1.83309,-0.42458,0.640417,-1.90521,-0.293968,0.417712,-1.90244,-0.355385,0.404727,-1.83614,0.363376,1.25832,-2.1193,0.414637,1.19336,-2.10041,0.251317,1.16733,-2.11364,0.302452,1.10511,-2.09863,0.418727,1.02722,-2.09732,0.452025,0.834884,-2.09967,0.337906,0.843907,-2.10733,0.336711,0.771927,-2.10003,0.357239,0.536039,-2.07808,0.288128,0.441361,-2.01387,0.559945,0.504233,-2.06798,0.515217,0.453487,-2.12603,0.15716,1.37281,-1.845,0.162805,1.39873,-2.0586},
/*1671*/{0.30118,1.97044,-1.76489,0.347386,1.90944,-1.9225,0.269001,1.82711,-1.64131,0.24483,1.71399,-1.54758,0.355005,1.73481,-1.6653,0.431681,1.74113,-1.71749,0.237698,1.98346,-2.13799,0.340154,1.90743,-1.99614,0.12672,1.9407,-2.02807,0.003379,1.87487,-2.18238,-0.025833,1.78668,-2.23968,0.109945,1.64937,-2.20689,0.143776,1.59394,-2.23104,0.245408,1.45108,-1.81358,0.063449,1.53972,-1.88964,0.062491,1.56642,-1.93298,0.062864,1.54795,-2.00397,0.246209,1.48722,-2.06818,0.119838,1.14765,-1.76888,-0.006656,1.18714,-1.80156,-0.030296,1.10485,-1.82378,-0.022973,0.976236,-1.81303,-0.104923,0.801178,-1.80281,-0.149279,0.740359,-1.8129,-0.195956,0.866519,-1.81442,-0.236555,0.807516,-1.81911,-0.336311,0.590897,-1.83257,-0.432338,0.655944,-1.8982,-0.311692,0.429211,-1.90712,-0.36895,0.41545,-1.83911,0.359145,1.25512,-2.11967,0.409215,1.18851,-2.10057,0.245805,1.16577,-2.11357,0.294423,1.10282,-2.09785,0.412201,1.02299,-2.0987,0.453496,0.832948,-2.09954,0.340173,0.835584,-2.11005,0.342831,0.765941,-2.10298,0.373182,0.529682,-2.07887,0.306467,0.433198,-2.01487,0.577133,0.50525,-2.06624,0.533958,0.450323,-2.12409,0.157704,1.37541,-1.84358,0.161551,1.40065,-2.0573},
/*1672*/{0.300886,1.97125,-1.76629,0.347133,1.91126,-1.92383,0.267151,1.82962,-1.64167,0.241844,1.71566,-1.54786,0.353501,1.73521,-1.66626,0.429445,1.74165,-1.71786,0.238746,1.98531,-2.1388,0.341079,1.90966,-1.99683,0.127155,1.94242,-2.0289,0.00343,1.87618,-2.18182,-0.02561,1.7873,-2.2398,0.111146,1.65105,-2.20723,0.144244,1.59518,-2.23141,0.246057,1.4533,-1.8134,0.06292,1.54164,-1.88984,0.062639,1.56796,-1.933,0.062643,1.54934,-2.00331,0.246234,1.48923,-2.0681,0.124886,1.14707,-1.77025,-0.004349,1.18252,-1.80027,-0.026909,1.10344,-1.82336,-0.018077,0.974641,-1.81413,-0.10216,0.802354,-1.80399,-0.150532,0.743202,-1.81428,-0.191818,0.870204,-1.81276,-0.235342,0.813798,-1.81654,-0.34337,0.600853,-1.83273,-0.439134,0.672513,-1.89135,-0.327039,0.441399,-1.91246,-0.382821,0.427509,-1.84216,0.354704,1.25104,-2.11932,0.403993,1.18323,-2.10094,0.239159,1.16348,-2.11427,0.287646,1.09963,-2.09959,0.406924,1.01854,-2.09954,0.456082,0.831127,-2.09894,0.342899,0.829004,-2.11351,0.348486,0.758996,-2.10537,0.384602,0.522064,-2.0794,0.323054,0.426883,-2.01541,0.591966,0.506208,-2.06422,0.552604,0.45035,-2.12172,0.158269,1.37744,-1.84325,0.161831,1.40237,-2.05701},
/*1673*/{0.301418,1.97193,-1.76693,0.346871,1.91253,-1.92491,0.26512,1.83172,-1.64266,0.240527,1.7174,-1.54773,0.351803,1.73621,-1.66727,0.427481,1.74103,-1.71845,0.23823,1.98581,-2.1395,0.340362,1.91023,-1.99793,0.128082,1.94449,-2.02975,0.002962,1.87674,-2.18071,-0.024699,1.78802,-2.24014,0.112152,1.6514,-2.20703,0.145939,1.59624,-2.23213,0.246339,1.45499,-1.81313,0.063018,1.54255,-1.88874,0.063083,1.56898,-1.93277,0.061765,1.55086,-2.00216,0.246127,1.49002,-2.0672,0.129364,1.14628,-1.77266,1.6e-005,1.18063,-1.80022,-0.021897,1.10192,-1.82352,-0.010797,0.972423,-1.8158,-0.101695,0.803177,-1.80628,-0.14988,0.747149,-1.81536,-0.18777,0.875019,-1.81066,-0.23378,0.820694,-1.81542,-0.35008,0.612682,-1.83164,-0.445822,0.688256,-1.88403,-0.342347,0.454852,-1.91714,-0.39482,0.440346,-1.84433,0.349996,1.24674,-2.11981,0.397424,1.17811,-2.10157,0.232392,1.16123,-2.11435,0.279555,1.0972,-2.09918,0.399909,1.01343,-2.10035,0.457278,0.829388,-2.09738,0.345188,0.822975,-2.11633,0.353298,0.752957,-2.10811,0.400164,0.519275,-2.08091,0.338982,0.422452,-2.01552,0.60558,0.507426,-2.06248,0.568408,0.448633,-2.11855,0.158554,1.37885,-1.84227,0.161592,1.40332,-2.05608},
/*1674*/{0.30087,1.97334,-1.76846,0.34671,1.91325,-1.92517,0.263026,1.83295,-1.64303,0.238062,1.71883,-1.5479,0.349712,1.73508,-1.66696,0.425494,1.73938,-1.71848,0.239375,1.98695,-2.14112,0.339845,1.91103,-1.99832,0.1281,1.94523,-2.03121,0.002842,1.87679,-2.17962,-0.024064,1.7877,-2.24014,0.113382,1.65238,-2.20785,0.146954,1.59675,-2.23292,0.246182,1.45663,-1.81299,0.063315,1.54366,-1.88758,0.062732,1.57025,-1.9321,0.061492,1.55117,-2.00176,0.246772,1.49112,-2.06697,0.13603,1.1454,-1.77622,0.00449,1.1775,-1.79915,-0.015425,1.09808,-1.82268,-0.00339,0.970012,-1.81711,-0.100133,0.803512,-1.80793,-0.151306,0.749403,-1.81826,-0.183185,0.879772,-1.80762,-0.231842,0.826746,-1.81347,-0.35741,0.623005,-1.83226,-0.451457,0.704175,-1.87758,-0.357282,0.468631,-1.92041,-0.407466,0.453825,-1.84666,0.344864,1.24148,-2.1198,0.391654,1.17214,-2.1023,0.225607,1.16016,-2.11322,0.272392,1.09324,-2.10011,0.393566,1.00808,-2.10116,0.457798,0.827521,-2.09686,0.347814,0.816764,-2.11833,0.357542,0.748033,-2.11075,0.412674,0.515065,-2.08173,0.351207,0.415925,-2.01587,0.617208,0.508502,-2.06053,0.58202,0.448419,-2.11628,0.15904,1.38016,-1.84153,0.161831,1.40428,-2.05539},
/*1675*/{0.300077,1.97289,-1.76923,0.345067,1.91331,-1.9263,0.261122,1.83455,-1.6442,0.233706,1.71999,-1.54845,0.347112,1.73436,-1.66763,0.424178,1.73818,-1.71976,0.239574,1.98728,-2.14115,0.339078,1.91215,-1.99895,0.128554,1.94553,-2.03212,0.002695,1.87674,-2.17906,-0.023256,1.78708,-2.24001,0.115037,1.65219,-2.20807,0.148806,1.59701,-2.23354,0.246711,1.4572,-1.81283,0.062888,1.54389,-1.88668,0.062011,1.57163,-1.93133,0.061492,1.55117,-2.00176,0.245793,1.49226,-2.06582,0.130891,1.13989,-1.78106,0.010053,1.17547,-1.79983,-0.010387,1.09503,-1.82298,0.004545,0.966762,-1.81899,-0.097972,0.804146,-1.80968,-0.153039,0.752434,-1.82032,-0.177873,0.884011,-1.80682,-0.228054,0.834091,-1.81179,-0.362332,0.636098,-1.83071,-0.455389,0.720947,-1.87206,-0.37128,0.482841,-1.92335,-0.418299,0.468228,-1.8479,0.339117,1.23648,-2.12155,0.384971,1.16652,-2.10364,0.219262,1.15743,-2.11308,0.265055,1.08978,-2.10045,0.387287,1.004,-2.10217,0.457769,0.826129,-2.09507,0.348541,0.812058,-2.1203,0.36097,0.74342,-2.11217,0.422039,0.512062,-2.08168,0.362883,0.411805,-2.01734,0.626835,0.510367,-2.05666,0.594508,0.447718,-2.11297,0.15918,1.38081,-1.84107,0.161593,1.40509,-2.05492},
/*1676*/{0.299656,1.97286,-1.77005,0.344128,1.91345,-1.92684,0.258385,1.83512,-1.64442,0.231587,1.72074,-1.5491,0.344798,1.73307,-1.66796,0.420752,1.73526,-1.71967,0.239523,1.98697,-2.14139,0.338582,1.91273,-1.99933,0.128309,1.94667,-2.0331,0.00378,1.8754,-2.17841,-0.022338,1.78603,-2.24037,0.116541,1.65196,-2.2083,0.150499,1.59621,-2.23408,0.246548,1.45755,-1.81241,0.062545,1.54365,-1.88626,0.061917,1.57162,-1.93123,0.063972,1.54891,-2.00052,0.245812,1.49232,-2.06451,0.150106,1.14016,-1.78272,0.016775,1.17168,-1.7971,-0.003425,1.09086,-1.82199,0.012225,0.963257,-1.82057,-0.096563,0.805034,-1.81236,-0.15411,0.755543,-1.82182,-0.172248,0.888341,-1.80602,-0.225145,0.840481,-1.8109,-0.368109,0.651092,-1.83062,-0.457904,0.737997,-1.86769,-0.383357,0.497708,-1.92414,-0.430137,0.483632,-1.84902,0.335184,1.23146,-2.12079,0.379352,1.16066,-2.10453,0.213045,1.15491,-2.11325,0.258009,1.08563,-2.10029,0.381076,0.998695,-2.10261,0.457845,0.824319,-2.09416,0.348529,0.807686,-2.1211,0.362413,0.738733,-2.11307,0.429632,0.508757,-2.08135,0.373162,0.407451,-2.01701,0.635061,0.512085,-2.05474,0.60483,0.448738,-2.10971,0.159775,1.38071,-1.83994,0.162688,1.40446,-2.05385},
/*1677*/{0.299326,1.97209,-1.77098,0.343922,1.91299,-1.92716,0.256405,1.83547,-1.64507,0.228649,1.72064,-1.54958,0.342466,1.73113,-1.66799,0.419337,1.73235,-1.72018,0.239805,1.98653,-2.14162,0.33728,1.91253,-1.99974,0.1286,1.94716,-2.0344,0.003834,1.87387,-2.179,-0.021163,1.78483,-2.24048,0.117918,1.65094,-2.20917,0.15261,1.59587,-2.23505,0.246419,1.45714,-1.81227,0.061943,1.54248,-1.8862,0.061448,1.57064,-1.93054,0.062706,1.54744,-2.00072,0.246399,1.49246,-2.06412,0.157301,1.13958,-1.78585,0.023305,1.16744,-1.79612,0.002973,1.08635,-1.82213,0.021044,0.959212,-1.8223,-0.09399,0.806467,-1.81361,-0.153076,0.76018,-1.82268,-0.166539,0.892993,-1.80548,-0.221344,0.846773,-1.81045,-0.371726,0.662758,-1.82736,-0.458974,0.75569,-1.86429,-0.393787,0.513309,-1.92348,-0.441353,0.500799,-1.8473,0.330477,1.22616,-2.12119,0.374099,1.15441,-2.10585,0.20734,1.15186,-2.11231,0.250813,1.0829,-2.10014,0.373848,0.993386,-2.10289,0.455368,0.82277,-2.09358,0.346581,0.802849,-2.12061,0.362817,0.734439,-2.11238,0.435249,0.50541,-2.08163,0.380837,0.404816,-2.01743,0.639921,0.512897,-2.05284,0.612803,0.448283,-2.10674,0.16017,1.37992,-1.83995,0.163296,1.40407,-2.0538},
/*1678*/{0.298651,1.97221,-1.77138,0.342617,1.91287,-1.92745,0.25399,1.83513,-1.64606,0.225211,1.72024,-1.55039,0.33931,1.72878,-1.66862,0.416462,1.72878,-1.71989,0.239703,1.98562,-2.14216,0.336272,1.91093,-1.99999,0.128795,1.94705,-2.03538,0.004206,1.87217,-2.17744,-0.02021,1.78286,-2.24117,0.118934,1.65018,-2.21061,0.153985,1.59517,-2.23561,0.246387,1.45687,-1.81237,0.062155,1.54143,-1.88589,0.061876,1.56933,-1.93035,0.063242,1.54585,-2.00046,0.246627,1.49238,-2.06366,0.164193,1.13608,-1.78909,0.028375,1.16069,-1.79617,0.01015,1.08177,-1.82247,0.030209,0.95537,-1.82468,-0.092071,0.808299,-1.81501,-0.153171,0.764295,-1.82399,-0.160175,0.896818,-1.80543,-0.215918,0.853665,-1.80947,-0.374329,0.677194,-1.82781,-0.458776,0.77381,-1.86315,-0.404568,0.528784,-1.92246,-0.451469,0.518109,-1.84624,0.326874,1.22182,-2.12268,0.368936,1.14932,-2.10712,0.202662,1.14833,-2.11201,0.244588,1.07937,-2.10007,0.367491,0.989227,-2.10359,0.453275,0.820777,-2.09349,0.343541,0.798752,-2.11925,0.361135,0.731096,-2.1113,0.440907,0.503552,-2.08046,0.386144,0.401213,-2.01695,0.644746,0.513957,-2.04975,0.620267,0.44873,-2.10504,0.161008,1.37912,-1.83977,0.164197,1.40339,-2.05361},
/*1679*/{0.297582,1.97,-1.77192,0.342154,1.91146,-1.92759,0.251344,1.83481,-1.64653,0.222093,1.71975,-1.55151,0.337251,1.726,-1.66856,0.413946,1.72443,-1.72017,0.239843,1.98477,-2.14219,0.33588,1.91029,-2.00031,0.129074,1.94605,-2.03588,0.00427,1.8704,-2.17849,-0.019081,1.7803,-2.24238,0.121569,1.64926,-2.21129,0.156724,1.59373,-2.23685,0.246814,1.45603,-1.81257,0.062089,1.54018,-1.88506,0.061867,1.56869,-1.93037,0.061929,1.54435,-2.00002,0.24608,1.49133,-2.06301,0.170826,1.1327,-1.79244,0.03604,1.15704,-1.79519,0.017855,1.07715,-1.82463,0.039586,0.95064,-1.82733,-0.089286,0.810209,-1.81601,-0.152494,0.768965,-1.82398,-0.152738,0.90219,-1.80516,-0.211436,0.861201,-1.80996,-0.378469,0.693062,-1.82648,-0.457228,0.792191,-1.8627,-0.412595,0.544256,-1.9195,-0.461873,0.537121,-1.84319,0.323527,1.21697,-2.12379,0.36451,1.1439,-2.1088,0.198056,1.14602,-2.1118,0.239084,1.076,-2.09949,0.360994,0.98437,-2.10403,0.448666,0.817692,-2.09385,0.339122,0.79446,-2.11726,0.358008,0.726801,-2.10934,0.443007,0.500514,-2.08025,0.390382,0.398324,-2.01623,0.648772,0.513834,-2.04738,0.622999,0.448092,-2.10294,0.161241,1.37827,-1.83928,0.163708,1.40219,-2.05316},
/*1680*/{0.296947,1.96853,-1.77225,0.3407,1.91037,-1.92755,0.248374,1.83343,-1.64698,0.216782,1.71842,-1.55271,0.333855,1.72281,-1.66847,0.411255,1.71982,-1.72026,0.240137,1.98294,-2.1421,0.335163,1.90937,-2.00018,0.12804,1.94474,-2.03742,0.006181,1.86737,-2.17843,-0.017528,1.77788,-2.24377,0.123304,1.64667,-2.21202,0.158652,1.59174,-2.23766,0.248006,1.45516,-1.81372,0.061626,1.53788,-1.88517,0.060949,1.56632,-1.93118,0.062878,1.54241,-2.00033,0.246259,1.48941,-2.06277,0.17702,1.13052,-1.7947,0.04225,1.15166,-1.79483,0.02508,1.07118,-1.8243,0.049095,0.946183,-1.82928,-0.08514,0.813097,-1.8166,-0.149894,0.773789,-1.82443,-0.145542,0.906715,-1.80585,-0.20673,0.868274,-1.81075,-0.379856,0.708017,-1.82473,-0.454045,0.810553,-1.86341,-0.42012,0.560183,-1.91615,-0.470279,0.555935,-1.84071,0.320872,1.21258,-2.12491,0.360001,1.13847,-2.11102,0.194205,1.1434,-2.11121,0.23371,1.07345,-2.09908,0.353857,0.979568,-2.1048,0.444391,0.815183,-2.09466,0.334784,0.789335,-2.11498,0.354887,0.722385,-2.10695,0.444116,0.498224,-2.07849,0.393006,0.394099,-2.01531,0.648558,0.513943,-2.04772,0.624927,0.447639,-2.10173,0.162302,1.37678,-1.83938,0.16447,1.40019,-2.05333},
/*1681*/{0.295009,1.96699,-1.77321,0.339856,1.90889,-1.92794,0.246145,1.83204,-1.6479,0.213167,1.7173,-1.5532,0.330505,1.71932,-1.66899,0.408454,1.71474,-1.7191,0.239832,1.98119,-2.1424,0.333603,1.90729,-1.99972,0.127219,1.94324,-2.03894,0.006024,1.8656,-2.17949,-0.016494,1.77441,-2.24443,0.125241,1.64376,-2.21306,0.161505,1.58958,-2.23916,0.248411,1.45478,-1.81421,0.061752,1.53589,-1.8851,0.059934,1.56426,-1.93105,0.062596,1.5401,-2.00046,0.245679,1.48783,-2.06303,0.184351,1.12903,-1.79797,0.047776,1.14683,-1.796,0.033669,1.06522,-1.82444,0.059223,0.941527,-1.83162,-0.081,0.815722,-1.81707,-0.147004,0.778661,-1.82489,-0.138762,0.911956,-1.80663,-0.199067,0.87518,-1.81027,-0.379952,0.722337,-1.8242,-0.448831,0.828662,-1.86417,-0.426586,0.57567,-1.91113,-0.477746,0.575764,-1.83693,0.317659,1.20835,-2.12659,0.355367,1.13423,-2.11352,0.190466,1.14152,-2.111,0.229157,1.07066,-2.09827,0.348178,0.975198,-2.10463,0.439057,0.8123,-2.09548,0.329827,0.785123,-2.11335,0.350665,0.718356,-2.10483,0.443241,0.495584,-2.07622,0.39355,0.391763,-2.01181,0.648895,0.512487,-2.04581,0.624556,0.446867,-2.10144,0.163234,1.37568,-1.83904,0.164515,1.39823,-2.05308},
/*1682*/{0.293815,1.96446,-1.77311,0.338256,1.9058,-1.92761,0.243161,1.83,-1.64834,0.20981,1.71548,-1.55454,0.326819,1.71543,-1.66893,0.405261,1.70877,-1.71843,0.239585,1.97901,-2.14223,0.333026,1.90536,-1.99949,0.127175,1.94271,-2.03941,0.006595,1.86193,-2.17979,-0.015033,1.77076,-2.24654,0.12717,1.64089,-2.21464,0.163762,1.58741,-2.24006,0.248292,1.45282,-1.81387,0.061936,1.533,-1.88442,0.060892,1.56108,-1.93104,0.062334,1.53663,-2.00136,0.245783,1.48604,-2.06365,0.190839,1.12666,-1.80003,0.053958,1.13871,-1.79535,0.040668,1.0596,-1.82471,0.068916,0.937674,-1.83202,-0.07629,0.818593,-1.81676,-0.14478,0.785302,-1.82331,-0.130339,0.917067,-1.80736,-0.192524,0.88303,-1.81063,-0.37743,0.735335,-1.8276,-0.443336,0.84573,-1.86589,-0.431641,0.591011,-1.90641,-0.483727,0.594471,-1.8331,0.315159,1.20407,-2.12884,0.352055,1.12982,-2.11469,0.187249,1.13978,-2.11012,0.225483,1.06814,-2.09738,0.341903,0.970079,-2.10499,0.433626,0.80887,-2.09545,0.324951,0.780872,-2.11162,0.346417,0.714005,-2.10274,0.439694,0.491801,-2.07339,0.392976,0.389246,-2.00793,0.647552,0.509617,-2.04521,0.622093,0.443902,-2.10107,0.164135,1.37321,-1.83907,0.165268,1.39567,-2.05313},
/*1683*/{0.292719,1.96171,-1.77289,0.337157,1.9041,-1.9277,0.240605,1.8275,-1.64816,0.204132,1.71281,-1.55518,0.322612,1.7105,-1.66863,0.402183,1.7025,-1.7179,0.237844,1.97618,-2.14237,0.332254,1.903,-1.9996,0.125427,1.93939,-2.04078,0.005175,1.86117,-2.18247,-0.014307,1.76688,-2.24759,0.128751,1.63753,-2.21633,0.166695,1.58418,-2.2415,0.248492,1.45113,-1.81512,0.062115,1.52981,-1.88462,0.060039,1.55852,-1.93189,0.061861,1.53432,-2.0014,0.245045,1.48431,-2.06441,0.196697,1.12332,-1.80303,0.06035,1.13353,-1.79515,0.048379,1.05362,-1.82744,0.077193,0.932903,-1.83446,-0.071878,0.821322,-1.81613,-0.140916,0.790099,-1.82296,-0.121486,0.921954,-1.80855,-0.185071,0.890459,-1.81026,-0.378243,0.752823,-1.82033,-0.436399,0.862629,-1.86757,-0.434377,0.606967,-1.90157,-0.48678,0.614756,-1.82878,0.313222,1.20002,-2.13043,0.34917,1.12507,-2.1171,0.185121,1.13789,-2.1092,0.221663,1.06614,-2.09711,0.33724,0.965581,-2.1047,0.429196,0.804756,-2.09496,0.320053,0.776615,-2.10974,0.342357,0.710154,-2.1005,0.438193,0.489233,-2.07137,0.390157,0.385975,-2.00385,0.643552,0.506523,-2.04601,0.618793,0.440324,-2.10031,0.164822,1.37095,-1.83993,0.16515,1.39363,-2.05396},
/*1684*/{0.290742,1.95919,-1.77286,0.337214,1.90193,-1.9281,0.237595,1.82479,-1.64869,0.199579,1.70997,-1.55664,0.319174,1.70539,-1.6683,0.398714,1.69566,-1.71649,0.237403,1.97298,-2.14245,0.331307,1.90016,-1.99957,0.124843,1.93773,-2.04212,0.006258,1.85478,-2.18311,-0.012796,1.76225,-2.25018,0.130706,1.634,-2.21777,0.169138,1.58105,-2.24297,0.248233,1.44924,-1.81611,0.062163,1.52729,-1.88429,0.058996,1.55619,-1.93235,0.061563,1.53195,-2.00135,0.244356,1.48225,-2.06587,0.2022,1.12169,-1.80429,0.06596,1.12798,-1.7964,0.055826,1.04903,-1.82726,0.086118,0.928563,-1.83534,-0.065931,0.824093,-1.81628,-0.136691,0.795763,-1.82202,-0.112826,0.927201,-1.80975,-0.177671,0.897669,-1.81063,-0.375029,0.769174,-1.81554,-0.429154,0.878624,-1.86969,-0.435208,0.622036,-1.89599,-0.489521,0.63417,-1.8245,0.311149,1.19573,-2.13286,0.346843,1.12103,-2.11854,0.182408,1.13593,-2.10875,0.21849,1.06341,-2.09679,0.333317,0.962337,-2.10467,0.424982,0.801325,-2.09426,0.315677,0.773271,-2.10825,0.337542,0.70602,-2.09916,0.432782,0.484804,-2.06878,0.385054,0.383701,-2.00371,0.638595,0.501917,-2.04659,0.612905,0.435538,-2.09929,0.165066,1.36876,-1.84058,0.164463,1.39148,-2.05462},
/*1685*/{0.289729,1.95643,-1.77211,0.335489,1.89888,-1.92764,0.234776,1.82159,-1.64864,0.194168,1.70652,-1.5574,0.314385,1.7002,-1.6677,0.394881,1.68858,-1.7152,0.237352,1.97007,-2.14286,0.330489,1.89734,-1.99911,0.123603,1.93405,-2.04247,0.006675,1.84923,-2.18456,-0.012117,1.75683,-2.25187,0.132878,1.63028,-2.21986,0.172477,1.57749,-2.24411,0.248798,1.44719,-1.81739,0.062166,1.52409,-1.88425,0.059944,1.55276,-1.93213,0.060619,1.5281,-2.00115,0.244412,1.48034,-2.06724,0.207669,1.11797,-1.80405,0.07177,1.12223,-1.79612,0.062294,1.0431,-1.82658,0.094104,0.924603,-1.83593,-0.060242,0.827945,-1.81567,-0.131315,0.80049,-1.82142,-0.103622,0.930962,-1.8114,-0.170062,0.904342,-1.81174,-0.370213,0.782858,-1.81236,-0.419628,0.893575,-1.87143,-0.435723,0.636611,-1.89075,-0.490094,0.652693,-1.82054,0.309696,1.19254,-2.13456,0.34356,1.11619,-2.1195,0.179718,1.13462,-2.1077,0.215506,1.06092,-2.09579,0.330772,0.959017,-2.10412,0.420213,0.79697,-2.09407,0.310879,0.768987,-2.10641,0.331933,0.702065,-2.09741,0.427349,0.480463,-2.0666,0.378518,0.380206,-1.99875,0.633231,0.496118,-2.04649,0.607074,0.429067,-2.09784,0.166674,1.36601,-1.84128,0.164813,1.38888,-2.05529},
/*1686*/{0.287732,1.95247,-1.77177,0.335426,1.89611,-1.92773,0.231148,1.8176,-1.64885,0.18904,1.70292,-1.55872,0.31021,1.69435,-1.66738,0.390759,1.68067,-1.71355,0.236153,1.96637,-2.14301,0.329559,1.89386,-1.99931,0.122676,1.93084,-2.04322,0.006586,1.84362,-2.18578,-0.010802,1.7514,-2.25398,0.134659,1.62534,-2.22152,0.175515,1.57363,-2.24557,0.249398,1.44483,-1.81835,0.061185,1.5205,-1.88416,0.059181,1.54942,-1.93269,0.060785,1.52422,-2.00088,0.243216,1.4788,-2.06832,0.21274,1.1165,-1.80511,0.077145,1.11975,-1.79847,0.069636,1.03777,-1.82737,0.102614,0.921755,-1.83618,-0.054515,0.830336,-1.81506,-0.125458,0.805376,-1.82158,-0.093467,0.934863,-1.81277,-0.161045,0.910659,-1.81219,-0.364503,0.796581,-1.8111,-0.411725,0.907503,-1.87269,-0.435383,0.650684,-1.88608,-0.487894,0.670171,-1.81552,0.308223,1.18843,-2.13579,0.341158,1.11214,-2.12072,0.177133,1.13169,-2.10735,0.212376,1.05854,-2.09516,0.328637,0.956547,-2.10303,0.415486,0.792189,-2.09326,0.305837,0.765167,-2.10567,0.327532,0.698236,-2.09559,0.418513,0.474894,-2.06418,0.371138,0.375685,-1.99564,0.626647,0.489479,-2.0459,0.598761,0.422053,-2.09718,0.16777,1.36311,-1.84217,0.164901,1.38645,-2.05612},
/*1687*/{0.286255,1.94891,-1.77098,0.334372,1.89251,-1.92662,0.228104,1.81345,-1.64917,0.183582,1.69992,-1.55982,0.305652,1.68785,-1.66771,0.38675,1.67289,-1.71257,0.235809,1.96228,-2.14398,0.328715,1.88989,-1.99896,0.121474,1.92639,-2.04443,0.007026,1.83869,-2.19005,-0.010196,1.74537,-2.25592,0.137514,1.62072,-2.22393,0.177876,1.56872,-2.24676,0.248909,1.44211,-1.81999,0.061369,1.51686,-1.88371,0.058859,1.54584,-1.93269,0.058639,1.52061,-2.00115,0.242385,1.47632,-2.06977,0.218644,1.11283,-1.80621,0.081049,1.11258,-1.79835,0.076696,1.03289,-1.82774,0.110224,0.918481,-1.83613,-0.047908,0.832171,-1.81565,-0.120756,0.810109,-1.81941,-0.083372,0.939644,-1.81406,-0.150446,0.916731,-1.8135,-0.35911,0.809713,-1.81048,-0.403204,0.920937,-1.87424,-0.432035,0.664475,-1.88172,-0.485264,0.686864,-1.81149,0.305683,1.1849,-2.13642,0.338709,1.10819,-2.12223,0.17511,1.12906,-2.10673,0.209684,1.05527,-2.09448,0.327293,0.953887,-2.1022,0.411281,0.787099,-2.09289,0.300962,0.760885,-2.10444,0.321711,0.693805,-2.09437,0.410755,0.47061,-2.06312,0.360936,0.373821,-1.99086,0.618041,0.480678,-2.04636,0.588402,0.413239,-2.09609,0.168283,1.3599,-1.84319,0.163995,1.38356,-2.05707},
/*1688*/{0.284899,1.94546,-1.77013,0.333849,1.8891,-1.92661,0.225381,1.80897,-1.6491,0.177571,1.69501,-1.56105,0.301467,1.68154,-1.66704,0.382705,1.66424,-1.71076,0.234644,1.95833,-2.14386,0.327708,1.88636,-1.9984,0.11998,1.92293,-2.04532,0.00604,1.83231,-2.19109,-0.008322,1.73888,-2.25827,0.140553,1.61538,-2.22512,0.181276,1.56398,-2.24816,0.248981,1.4391,-1.82142,0.060693,1.5117,-1.88337,0.057494,1.54147,-1.93314,0.057995,1.51675,-2.00064,0.241774,1.47357,-2.07174,0.222669,1.11161,-1.80598,0.086335,1.10824,-1.80048,0.083089,1.02786,-1.82929,0.118776,0.915048,-1.83593,-0.040942,0.835213,-1.81426,-0.113912,0.815088,-1.81878,-0.073747,0.942935,-1.81543,-0.141652,0.922618,-1.81389,-0.352379,0.823801,-1.81087,-0.394344,0.932954,-1.8748,-0.428514,0.677291,-1.87759,-0.48121,0.701606,-1.80803,0.303256,1.18135,-2.13811,0.335887,1.10482,-2.1239,0.172535,1.12629,-2.10608,0.207694,1.05232,-2.09414,0.324798,0.950873,-2.10119,0.406891,0.781247,-2.09216,0.296155,0.756849,-2.10336,0.315133,0.689548,-2.09336,0.399655,0.464169,-2.0611,0.350381,0.368448,-1.98671,0.60837,0.471332,-2.04421,0.576536,0.404043,-2.09397,0.169296,1.35599,-1.84449,0.163753,1.38042,-2.05826},
/*1689*/{0.282977,1.94085,-1.76941,0.33262,1.88397,-1.92615,0.221657,1.80423,-1.64918,0.171281,1.69215,-1.56237,0.295544,1.67492,-1.66657,0.377875,1.65546,-1.70905,0.23402,1.95415,-2.14412,0.326875,1.88236,-1.99817,0.118374,1.91733,-2.04562,0.005803,1.82683,-2.19247,-0.006982,1.73218,-2.26069,0.14305,1.61101,-2.22796,0.184282,1.55901,-2.24916,0.249296,1.43664,-1.82356,0.059996,1.5074,-1.88355,0.057084,1.53695,-1.93264,0.056702,1.51143,-2.00001,0.239762,1.47033,-2.07354,0.225304,1.10781,-1.80415,0.09023,1.10607,-1.80195,0.08813,1.02363,-1.83003,0.126436,0.912024,-1.83485,-0.034064,0.837553,-1.81353,-0.10663,0.819516,-1.81685,-0.062778,0.946288,-1.8163,-0.131783,0.928159,-1.81475,-0.345964,0.834745,-1.80981,-0.385585,0.944654,-1.87566,-0.422412,0.689346,-1.87342,-0.475248,0.715299,-1.80411,0.300911,1.17756,-2.1393,0.334367,1.10097,-2.12428,0.17051,1.12261,-2.10531,0.20553,1.04864,-2.09329,0.32302,0.947832,-2.10057,0.400359,0.775424,-2.09264,0.291361,0.750662,-2.09796,0.308204,0.685434,-2.09262,0.390031,0.459072,-2.05907,0.338153,0.364968,-1.98499,0.599169,0.462457,-2.04336,0.564737,0.394519,-2.09235,0.17071,1.35257,-1.84514,0.162697,1.37643,-2.0589},
/*1690*/{0.28103,1.93612,-1.76928,0.331393,1.87974,-1.92502,0.217949,1.79985,-1.64926,0.16574,1.68754,-1.56406,0.290712,1.66789,-1.66597,0.371718,1.64611,-1.70719,0.232227,1.94956,-2.14465,0.32626,1.87752,-1.99829,0.116903,1.91256,-2.04639,0.004038,1.82047,-2.19384,-0.005157,1.72471,-2.26288,0.146297,1.60382,-2.2288,0.18837,1.55284,-2.2497,0.249619,1.43301,-1.82586,0.059555,1.50209,-1.88401,0.055492,1.53253,-1.93451,0.054895,1.50675,-2.00006,0.23839,1.46679,-2.07563,0.230989,1.10474,-1.80162,0.093803,1.09974,-1.80345,0.093089,1.01967,-1.83176,0.13469,0.909549,-1.83383,-0.025268,0.840603,-1.81121,-0.099891,0.825639,-1.81386,-0.052118,0.949333,-1.81889,-0.122394,0.933395,-1.81601,-0.337275,0.84656,-1.8084,-0.377312,0.954716,-1.87668,-0.416992,0.699869,-1.86965,-0.467752,0.72817,-1.80067,0.298441,1.17395,-2.14077,0.33227,1.09799,-2.1256,0.169348,1.11859,-2.10542,0.204653,1.04508,-2.09302,0.320404,0.943235,-2.1008,0.395219,0.768403,-2.09226,0.284349,0.748259,-2.10243,0.301243,0.681148,-2.09146,0.378684,0.452939,-2.05863,0.325515,0.360159,-1.98263,0.587784,0.453202,-2.04165,0.552745,0.384895,-2.09017,0.171402,1.34844,-1.8469,0.161753,1.37244,-2.06058},
/*1691*/{0.279324,1.93102,-1.76806,0.330897,1.87523,-1.92481,0.213885,1.79424,-1.64897,0.159827,1.68405,-1.56575,0.285231,1.66011,-1.66557,0.367123,1.6369,-1.70552,0.231995,1.94467,-2.14492,0.326114,1.87378,-1.99749,0.115344,1.90739,-2.04746,0.005656,1.81019,-2.19829,-0.003966,1.71736,-2.26512,0.149695,1.59774,-2.2299,0.191775,1.54721,-2.25072,0.249217,1.43052,-1.8275,0.059443,1.49783,-1.88254,0.05593,1.52733,-1.9339,0.053745,1.50139,-1.99896,0.237178,1.46378,-2.07748,0.234788,1.10112,-1.79914,0.096934,1.09467,-1.80527,0.097218,1.01442,-1.83328,0.141847,0.907036,-1.83239,-0.017025,0.842825,-1.81021,-0.092756,0.828596,-1.81251,-0.041246,0.951838,-1.82024,-0.111398,0.937905,-1.81803,-0.329401,0.856456,-1.80799,-0.36916,0.964943,-1.87667,-0.409251,0.709455,-1.86719,-0.459539,0.738955,-1.79638,0.296652,1.16976,-2.14249,0.331076,1.09315,-2.1264,0.167655,1.11484,-2.10549,0.202828,1.04121,-2.09335,0.317918,0.938332,-2.10091,0.390154,0.762843,-2.09211,0.277779,0.744388,-2.10162,0.293065,0.675766,-2.09099,0.367672,0.447606,-2.05834,0.310531,0.355819,-1.98251,0.57517,0.442022,-2.03898,0.539863,0.375374,-2.08821,0.173111,1.34484,-1.84723,0.161166,1.36854,-2.06082},
/*1692*/{0.278105,1.9258,-1.76687,0.330919,1.86952,-1.92375,0.210006,1.78901,-1.64938,0.153451,1.67953,-1.56726,0.280206,1.65311,-1.66531,0.361695,1.62712,-1.70351,0.232119,1.94004,-2.14552,0.325809,1.86911,-1.99736,0.114351,1.90124,-2.04805,0.007745,1.80164,-2.20086,-0.001558,1.70916,-2.2673,0.152447,1.59197,-2.23198,0.19555,1.54018,-2.25101,0.249315,1.42678,-1.8298,0.057986,1.4928,-1.88381,0.054683,1.52164,-1.93494,0.052392,1.49581,-1.99911,0.235681,1.45923,-2.07978,0.235577,1.09951,-1.80005,0.098911,1.09251,-1.80848,0.103025,1.00986,-1.83415,0.149364,0.903904,-1.83102,-0.009955,0.845489,-1.80718,-0.085111,0.832378,-1.81138,-0.029659,0.95367,-1.82258,-0.101321,0.942112,-1.81932,-0.32045,0.865101,-1.80649,-0.360221,0.973426,-1.87672,-0.400539,0.718282,-1.86388,-0.451127,0.748316,-1.79485,0.294741,1.16543,-2.14396,0.330007,1.08951,-2.12736,0.166477,1.11022,-2.10495,0.201629,1.03661,-2.09304,0.316547,0.932816,-2.1014,0.385096,0.755502,-2.09179,0.271641,0.739978,-2.1014,0.285718,0.671246,-2.09109,0.3544,0.441204,-2.05712,0.295231,0.351198,-1.98483,0.563813,0.431215,-2.03651,0.52608,0.364086,-2.08561,0.173679,1.34046,-1.84859,0.160163,1.36357,-2.06216},
/*1693*/{0.276447,1.92065,-1.76595,0.330336,1.86356,-1.92304,0.206165,1.78394,-1.64972,0.147884,1.67581,-1.56948,0.273953,1.64497,-1.66472,0.355241,1.61791,-1.70133,0.231197,1.9348,-2.1462,0.325391,1.86391,-1.99711,0.113368,1.89574,-2.04867,0.008618,1.79232,-2.20373,0.00037,1.70135,-2.26966,0.156656,1.58492,-2.23282,0.200054,1.53381,-2.2517,0.248943,1.42303,-1.83205,0.057491,1.48673,-1.88379,0.0532,1.51573,-1.93557,0.05162,1.48972,-1.99865,0.235294,1.4557,-2.08169,0.239673,1.09539,-1.79523,0.102957,1.08542,-1.80859,0.108198,1.00442,-1.83507,0.157182,0.901768,-1.82908,0.000205,0.847238,-1.8053,-0.074059,0.836081,-1.80804,-0.018523,0.956253,-1.82379,-0.089599,0.945477,-1.82024,-0.310615,0.872746,-1.80479,-0.351263,0.981535,-1.87709,-0.390932,0.726141,-1.86149,-0.440788,0.758018,-1.79229,0.291962,1.16095,-2.14543,0.327786,1.08513,-2.1291,0.164138,1.1056,-2.10573,0.201248,1.0316,-2.09264,0.314021,0.926692,-2.1009,0.377121,0.748232,-2.09226,0.264853,0.735148,-2.10151,0.277325,0.666363,-2.0912,0.34211,0.436373,-2.05616,0.277433,0.354045,-1.98259,0.54887,0.418266,-2.03514,0.509245,0.353794,-2.08397,0.175094,1.33564,-1.85008,0.160278,1.35921,-2.06351},
/*1694*/{0.275102,1.91444,-1.76525,0.329915,1.85825,-1.92223,0.202439,1.77797,-1.65038,0.139724,1.67141,-1.57095,0.268407,1.63749,-1.66497,0.350049,1.60823,-1.70021,0.231262,1.9291,-2.14664,0.325274,1.85831,-1.99641,0.112337,1.88895,-2.04863,0.008906,1.78305,-2.20573,0.003647,1.69231,-2.27137,0.160943,1.57766,-2.23358,0.204467,1.52633,-2.25216,0.249316,1.41917,-1.83345,0.057244,1.48167,-1.883,0.052927,1.51022,-1.93666,0.049811,1.48353,-1.99842,0.23464,1.45168,-2.08402,0.239986,1.09316,-1.79395,0.105973,1.07998,-1.81021,0.113079,0.999143,-1.83667,0.165644,0.899566,-1.82705,0.008751,0.848894,-1.80377,-0.066165,0.839778,-1.80687,-0.006865,0.958126,-1.82516,-0.07775,0.949182,-1.82114,-0.300461,0.881331,-1.80589,-0.341867,0.988305,-1.87683,-0.380972,0.733307,-1.85894,-0.43016,0.765014,-1.78909,0.289575,1.15535,-2.14623,0.325785,1.08003,-2.12947,0.162504,1.09989,-2.10514,0.199256,1.02645,-2.09254,0.311743,0.920974,-2.10095,0.371293,0.74104,-2.09197,0.257705,0.73031,-2.10241,0.267481,0.661483,-2.09226,0.328227,0.432364,-2.05627,0.25749,0.357161,-1.98419,0.532745,0.403859,-2.03395,0.487643,0.34143,-2.08207,0.176493,1.33129,-1.85095,0.15988,1.35435,-2.0643},
/*1695*/{0.273294,1.90869,-1.76431,0.329391,1.85184,-1.92068,0.198373,1.77224,-1.65077,0.134229,1.6671,-1.57242,0.262405,1.63045,-1.66404,0.343526,1.59871,-1.69833,0.231411,1.92399,-2.14749,0.325804,1.8532,-1.99619,0.110135,1.88381,-2.05001,0.009275,1.77415,-2.20866,0.007106,1.68303,-2.27375,0.164727,1.56977,-2.23397,0.209452,1.51939,-2.25223,0.248712,1.41449,-1.83543,0.0557,1.47564,-1.88355,0.052347,1.50441,-1.93763,0.048467,1.47846,-1.99787,0.234106,1.44699,-2.08604,0.244317,1.08873,-1.79018,0.108431,1.07425,-1.81191,0.118387,0.99331,-1.83729,0.173175,0.897576,-1.82408,0.018542,0.850004,-1.80191,-0.056091,0.843233,-1.8032,0.004936,0.959173,-1.82674,-0.066263,0.951179,-1.82253,-0.29034,0.888937,-1.8058,-0.331708,0.994339,-1.87733,-0.369974,0.739078,-1.85698,-0.420079,0.772059,-1.78762,0.287106,1.15018,-2.14752,0.323781,1.07483,-2.13099,0.16076,1.09388,-2.10567,0.197316,1.02061,-2.09256,0.308393,0.915305,-2.10103,0.363745,0.733876,-2.09213,0.250485,0.725281,-2.10262,0.259159,0.655897,-2.09226,0.314296,0.427124,-2.05529,0.238295,0.356497,-1.98192,0.520195,0.389042,-2.02822,0.471291,0.33748,-2.08134,0.176569,1.32599,-1.85251,0.15907,1.34957,-2.06573},
/*1696*/{0.271243,1.90244,-1.76369,0.328133,1.84548,-1.91999,0.193661,1.76653,-1.65148,0.127238,1.66293,-1.57422,0.256474,1.62211,-1.66359,0.336178,1.58965,-1.69683,0.231823,1.919,-2.148,0.325735,1.84735,-1.99589,0.109275,1.87669,-2.05059,0.0119,1.76429,-2.21159,0.01102,1.67394,-2.27494,0.169151,1.56165,-2.23425,0.214355,1.51129,-2.25261,0.248852,1.40999,-1.83571,0.054406,1.46949,-1.88401,0.051641,1.49864,-1.93854,0.046756,1.47263,-1.99808,0.23302,1.4417,-2.08869,0.245811,1.0869,-1.78752,0.111968,1.06774,-1.81282,0.123252,0.987526,-1.84004,0.181704,0.896639,-1.82218,0.029204,0.85101,-1.8003,-0.045643,0.846065,-1.80207,0.01788,0.959544,-1.82796,-0.054726,0.953531,-1.82376,-0.277656,0.893475,-1.80494,-0.321289,0.999375,-1.87678,-0.35874,0.744236,-1.8544,-0.407665,0.776935,-1.78549,0.283712,1.14482,-2.14842,0.320531,1.06939,-2.13234,0.157496,1.08857,-2.10519,0.194287,1.01585,-2.09328,0.304401,0.910163,-2.1018,0.35624,0.726878,-2.09095,0.243583,0.720312,-2.10261,0.251527,0.651694,-2.09243,0.297527,0.422945,-2.04955,0.215749,0.356346,-1.97976,0.497517,0.384507,-2.02072,0.447323,0.340318,-2.08242,0.176901,1.32102,-1.85328,0.158299,1.34395,-2.06648},
/*1697*/{0.269723,1.89603,-1.76283,0.32803,1.83888,-1.91887,0.189351,1.76077,-1.65193,0.119022,1.65886,-1.57623,0.24962,1.61414,-1.66348,0.330007,1.58058,-1.69496,0.231657,1.91368,-2.1484,0.325365,1.84125,-1.99532,0.109098,1.87115,-2.05131,0.013107,1.75461,-2.21445,0.015607,1.66457,-2.27748,0.174512,1.55317,-2.23473,0.219621,1.50373,-2.25272,0.247552,1.40506,-1.83627,0.052965,1.46447,-1.88405,0.049738,1.49236,-1.93874,0.04507,1.46681,-1.998,0.231225,1.43536,-2.09064,0.249715,1.08231,-1.78542,0.117043,1.06322,-1.81349,0.130281,0.980774,-1.83985,0.190315,0.894348,-1.82116,0.040183,0.851574,-1.79826,-0.035413,0.847556,-1.80038,0.030269,0.959027,-1.82996,-0.040869,0.955251,-1.82357,-0.266982,0.897524,-1.80406,-0.310591,1.0036,-1.87761,-0.34603,0.74815,-1.85099,-0.394922,0.781813,-1.78213,0.279588,1.13981,-2.15085,0.316682,1.06431,-2.13528,0.154022,1.08435,-2.10569,0.190472,1.01125,-2.09373,0.299075,0.904285,-2.10336,0.349302,0.718843,-2.08826,0.237092,0.715552,-2.10276,0.242751,0.647061,-2.09119,0.276367,0.424131,-2.04348,0.191425,0.354479,-1.97956,0.471496,0.385262,-2.02451,0.422943,0.340326,-2.08279,0.175898,1.3159,-1.85335,0.156245,1.3377,-2.06657},
/*1698*/{0.267451,1.88983,-1.7622,0.328159,1.83275,-1.91796,0.184458,1.75458,-1.65272,0.113256,1.65533,-1.57861,0.243413,1.60742,-1.66348,0.323414,1.57225,-1.69218,0.232232,1.90831,-2.14957,0.325495,1.83558,-1.99518,0.108981,1.86601,-2.0512,0.016092,1.74482,-2.21754,0.020138,1.6554,-2.27919,0.178993,1.54587,-2.235,0.225021,1.49546,-2.25296,0.247314,1.39939,-1.83795,0.050936,1.45885,-1.88427,0.048023,1.48598,-1.93925,0.042154,1.46147,-1.99836,0.22991,1.43002,-2.09253,0.254374,1.07743,-1.78237,0.12099,1.05659,-1.8142,0.137625,0.974962,-1.83946,0.200149,0.89248,-1.81857,0.050841,0.851784,-1.7964,-0.02388,0.847574,-1.79864,0.04282,0.958506,-1.82957,-0.027872,0.955477,-1.82318,-0.25376,0.900519,-1.80119,-0.299763,1.00647,-1.87743,-0.332995,0.750827,-1.84963,-0.381469,0.785176,-1.77985,0.275944,1.13583,-2.15499,0.311046,1.05923,-2.13999,0.149918,1.08224,-2.10556,0.186031,1.00892,-2.09367,0.293757,0.897544,-2.10493,0.343325,0.712257,-2.08403,0.230934,0.712349,-2.10105,0.232855,0.644045,-2.08735,0.203194,0.411213,-2.03642,0.168413,0.355787,-1.97703,0.447498,0.38329,-2.01928,0.399091,0.340534,-2.08244,0.17518,1.31022,-1.85479,0.154335,1.33233,-2.06787},
/*1699*/{0.265541,1.88398,-1.76133,0.328581,1.8265,-1.91771,0.179232,1.7495,-1.65372,0.106343,1.65213,-1.58091,0.236697,1.6009,-1.66241,0.31513,1.56432,-1.6911,0.232972,1.90307,-2.15049,0.327082,1.82938,-1.99463,0.10974,1.86175,-2.05089,0.020434,1.73413,-2.22053,0.025471,1.6454,-2.28115,0.185121,1.537,-2.23553,0.230554,1.48753,-2.25311,0.24628,1.39417,-1.83883,0.048343,1.45304,-1.88533,0.044485,1.47964,-1.93906,0.038833,1.45726,-1.99975,0.226874,1.42431,-2.09429,0.256928,1.07491,-1.78103,0.125973,1.05025,-1.81451,0.143825,0.968385,-1.83992,0.209157,0.889332,-1.81684,0.062946,0.851131,-1.79462,-0.011494,0.847157,-1.79665,0.056032,0.9581,-1.82878,-0.015504,0.955286,-1.82295,-0.243323,0.905794,-1.80464,-0.287817,1.00847,-1.87812,-0.320168,0.752763,-1.84772,-0.366914,0.787417,-1.77783,0.270986,1.13272,-2.15971,0.306276,1.05551,-2.14552,0.146703,1.08081,-2.10618,0.182565,1.00789,-2.09374,0.286702,0.892327,-2.10557,0.336039,0.708578,-2.07955,0.223907,0.71466,-2.09803,0.221179,0.645914,-2.08266,0.228944,0.426201,-2.03606,0.144317,0.356972,-1.97807,0.425098,0.381427,-2.02068,0.375109,0.34068,-2.08169,0.173187,1.30484,-1.85603,0.151333,1.32697,-2.06901},
/*1700*/{0.264079,1.87832,-1.76047,0.3279,1.81944,-1.91625,0.174636,1.74451,-1.65445,0.099909,1.64847,-1.58371,0.22995,1.59473,-1.66156,0.307812,1.55654,-1.68927,0.233463,1.89797,-2.15155,0.327343,1.82344,-1.9941,0.109604,1.85851,-2.05184,0.02395,1.72576,-2.22432,0.031567,1.63556,-2.28255,0.191895,1.52966,-2.23637,0.236538,1.48042,-2.25338,0.245422,1.38942,-1.84026,0.046077,1.44764,-1.88633,0.042004,1.47437,-1.93851,0.03569,1.4539,-2.00033,0.224121,1.42033,-2.09506,0.259958,1.07155,-1.77916,0.131269,1.04327,-1.81446,0.151581,0.962472,-1.83894,0.220535,0.887163,-1.81367,0.074546,0.849111,-1.79349,0.001037,0.847101,-1.79547,0.068591,0.956333,-1.82819,-0.002341,0.954765,-1.82222,-0.227389,0.904232,-1.80232,-0.276733,1.00881,-1.87902,-0.304797,0.753559,-1.84505,-0.353399,0.788025,-1.77596,0.267862,1.12993,-2.16286,0.302332,1.05316,-2.14847,0.144322,1.08032,-2.1061,0.179303,1.00672,-2.09404,0.282065,0.890603,-2.10627,0.325566,0.707279,-2.07735,0.214656,0.719961,-2.09475,0.209516,0.651462,-2.08123,0.209813,0.428878,-2.03339,0.121079,0.357372,-1.97517,0.402617,0.381789,-2.01679,0.352322,0.341197,-2.08016,0.171627,1.29989,-1.85766,0.148766,1.32312,-2.07041},
/*1701*/{0.2625,1.87342,-1.75909,0.328207,1.81341,-1.91484,0.170301,1.7401,-1.6549,0.092586,1.64491,-1.58548,0.22267,1.58968,-1.66082,0.300593,1.55019,-1.68723,0.233324,1.89316,-2.15303,0.327707,1.81762,-1.99311,0.110018,1.85563,-2.05269,0.029151,1.7178,-2.22876,0.03922,1.62645,-2.28523,0.197313,1.52132,-2.237,0.243619,1.4735,-2.2537,0.243466,1.38435,-1.84157,0.043101,1.4434,-1.88595,0.038904,1.46972,-1.93888,0.032373,1.44936,-2.00153,0.221607,1.41673,-2.09664,0.264665,1.06836,-1.77757,0.137032,1.03631,-1.81456,0.158985,0.957049,-1.83945,0.232017,0.884919,-1.80807,0.086509,0.847,-1.79257,0.012608,0.845166,-1.79489,0.081744,0.954668,-1.82661,0.0107,0.953946,-1.82111,-0.215168,0.905472,-1.80322,-0.265339,1.00879,-1.87916,-0.290067,0.753028,-1.84318,-0.337882,0.787567,-1.77415,0.265216,1.12879,-2.16369,0.300961,1.05217,-2.14812,0.142284,1.07677,-2.1055,0.178496,1.00557,-2.09319,0.280633,0.891404,-2.10752,0.31462,0.706109,-2.07763,0.203988,0.725867,-2.09396,0.19374,0.656975,-2.08128,0.188671,0.430284,-2.03189,0.096983,0.359076,-1.9749,0.379999,0.380269,-2.01744,0.329254,0.341697,-2.07943,0.169296,1.29513,-1.85923,0.14582,1.31926,-2.07181},
/*1702*/{0.261182,1.86851,-1.75782,0.327426,1.80831,-1.91413,0.165566,1.73562,-1.65608,0.084006,1.64329,-1.58763,0.215682,1.58482,-1.66102,0.292595,1.5449,-1.68602,0.234886,1.88911,-2.15385,0.327698,1.81343,-1.99241,0.109893,1.85275,-2.0525,0.036605,1.70826,-2.23369,0.046285,1.61638,-2.28582,0.205644,1.51451,-2.23808,0.251445,1.46692,-2.25344,0.24171,1.3797,-1.84292,0.039165,1.43894,-1.88701,0.037909,1.46721,-1.93866,0.029321,1.44611,-2.00099,0.218888,1.41362,-2.09731,0.268758,1.06924,-1.77647,0.142904,1.03138,-1.81414,0.16811,0.952653,-1.83939,0.242717,0.881683,-1.80892,0.099239,0.844627,-1.79168,0.025214,0.842661,-1.79427,0.094845,0.952876,-1.82433,0.024118,0.952291,-1.81876,-0.201989,0.904443,-1.80196,-0.254708,1.00717,-1.87994,-0.274052,0.751512,-1.84065,-0.32196,0.785433,-1.772,0.26164,1.12857,-2.16191,0.298543,1.05213,-2.14695,0.138826,1.07362,-2.10649,0.177614,1.00114,-2.09337,0.280261,0.891148,-2.10756,0.30227,0.70572,-2.08017,0.191619,0.729025,-2.09372,0.180605,0.661189,-2.08096,0.16953,0.43112,-2.03083,0.075378,0.359679,-1.97266,0.358186,0.379753,-2.01623,0.307255,0.341135,-2.07863,0.166595,1.29072,-1.86078,0.142666,1.3164,-2.07314},
/*1703*/{0.259289,1.86432,-1.75668,0.326995,1.80386,-1.91264,0.160803,1.73258,-1.65681,0.07572,1.64188,-1.58997,0.208296,1.58088,-1.66087,0.28425,1.53894,-1.6834,0.236315,1.88501,-2.15432,0.32724,1.80944,-1.99132,0.110131,1.85068,-2.05186,0.04351,1.69945,-2.23747,0.055004,1.60684,-2.28689,0.213448,1.50842,-2.23834,0.259559,1.46103,-2.25292,0.239124,1.37663,-1.84402,0.036949,1.43513,-1.88728,0.035192,1.46681,-1.93879,0.026771,1.44395,-1.99998,0.217027,1.4113,-2.09795,0.275621,1.07113,-1.77562,0.147558,1.02699,-1.81285,0.177019,0.950605,-1.83628,0.254833,0.881787,-1.80719,0.11212,0.842716,-1.79131,0.036674,0.841333,-1.79617,0.108708,0.951961,-1.82238,0.037605,0.951531,-1.81845,-0.188714,0.902918,-1.80248,-0.245151,1.00424,-1.8804,-0.257203,0.747853,-1.83907,-0.306459,0.781295,-1.77099,0.259287,1.12836,-2.16111,0.295782,1.05155,-2.14698,0.136204,1.07157,-2.10678,0.174646,0.999168,-2.09424,0.280035,0.890633,-2.10696,0.28973,0.705194,-2.08531,0.179573,0.730765,-2.09472,0.166381,0.66245,-2.07981,0.152124,0.432681,-2.03022,0.053137,0.359048,-1.97173,0.336327,0.378749,-2.0163,0.284107,0.340619,-2.07906,0.163876,1.28771,-1.8618,0.139751,1.31458,-2.07399},
/*1704*/{0.25918,1.86071,-1.75484,0.326591,1.80069,-1.91128,0.154777,1.73043,-1.65728,0.067988,1.64119,-1.59297,0.200653,1.5784,-1.66137,0.276956,1.5346,-1.68128,0.236409,1.8816,-2.1541,0.327065,1.80591,-1.98944,0.110332,1.84894,-2.05297,0.048342,1.69149,-2.24002,0.0639,1.59809,-2.2872,0.222341,1.50267,-2.23826,0.268555,1.45658,-2.252,0.237216,1.3721,-1.84411,0.034963,1.43306,-1.88633,0.034211,1.4665,-1.93858,0.025913,1.44277,-1.99965,0.214763,1.40974,-2.09891,0.27869,1.07355,-1.77607,0.155641,1.02691,-1.80989,0.185735,0.949163,-1.83357,0.267404,0.88228,-1.80592,0.124648,0.841056,-1.79172,0.049368,0.839528,-1.79624,0.121465,0.950641,-1.82013,0.049043,0.950294,-1.81716,-0.182867,0.903347,-1.80312,-0.236373,0.999754,-1.88023,-0.239218,0.743881,-1.8383,-0.289545,0.776915,-1.76954,0.255299,1.12663,-2.16154,0.291846,1.04992,-2.14794,0.132531,1.07018,-2.10687,0.170135,0.997182,-2.0953,0.279796,0.889971,-2.10579,0.27749,0.703451,-2.08776,0.167294,0.730888,-2.09633,0.153437,0.662779,-2.08005,0.127228,0.432305,-2.03054,0.031219,0.362932,-1.97281,0.314094,0.378233,-2.01561,0.261158,0.340329,-2.07883,0.160844,1.28433,-1.86311,0.13668,1.31346,-2.07499},
/*1705*/{0.258137,1.85724,-1.75339,0.325046,1.79859,-1.91041,0.149348,1.72968,-1.65886,0.060515,1.6418,-1.59573,0.193327,1.57571,-1.66196,0.268805,1.53076,-1.67958,0.237896,1.87846,-2.15307,0.326912,1.8033,-1.98954,0.110191,1.84693,-2.05306,0.055053,1.6838,-2.24253,0.072926,1.59094,-2.28718,0.2307,1.49848,-2.23761,0.278724,1.45307,-2.2504,0.233954,1.36894,-1.84288,0.033831,1.43124,-1.88575,0.031583,1.46508,-1.9394,0.024746,1.44245,-1.99737,0.21305,1.40891,-2.09962,0.285158,1.07735,-1.77612,0.162395,1.02595,-1.80819,0.194666,0.949299,-1.83109,0.281249,0.883381,-1.80415,0.137065,0.839739,-1.79062,0.062872,0.838026,-1.79546,0.133566,0.950142,-1.81723,0.06201,0.948124,-1.81504,-0.163057,0.89711,-1.80448,-0.228573,0.993992,-1.88004,-0.221871,0.738423,-1.83735,-0.272,0.769187,-1.7684,0.250942,1.12404,-2.16267,0.28673,1.0468,-2.14885,0.127583,1.06874,-2.10703,0.164603,0.995478,-2.09527,0.275576,0.889335,-2.10486,0.265024,0.699212,-2.08835,0.155569,0.73054,-2.09733,0.139945,0.664011,-2.08241,0.107307,0.432813,-2.0319,0.010062,0.36338,-1.97453,0.292688,0.377383,-2.01718,0.238813,0.339887,-2.07888,0.157797,1.28176,-1.86366,0.134285,1.31281,-2.07535},
/*1706*/{0.257313,1.85486,-1.75284,0.325245,1.79631,-1.90965,0.143899,1.72955,-1.65962,0.052172,1.64287,-1.59911,0.186437,1.57386,-1.66109,0.260801,1.52811,-1.6793,0.238934,1.8763,-2.15271,0.326366,1.80065,-1.98784,0.110788,1.84606,-2.05291,0.060677,1.67765,-2.24378,0.079924,1.58508,-2.28643,0.240082,1.49445,-2.23626,0.288667,1.45066,-2.24868,0.231058,1.36598,-1.84365,0.031378,1.43041,-1.88473,0.030243,1.46411,-1.93873,0.02391,1.44214,-1.99622,0.211958,1.40816,-2.10027,0.292087,1.08187,-1.7754,0.170009,1.02563,-1.80665,0.205771,0.949932,-1.82779,0.294418,0.886446,-1.80301,0.150805,0.839914,-1.79006,0.074891,0.836757,-1.79671,0.144321,0.950492,-1.81514,0.072792,0.94774,-1.81447,-0.152124,0.891685,-1.80418,-0.221402,0.986994,-1.88216,-0.20312,0.731537,-1.83715,-0.253794,0.761144,-1.76804,0.245601,1.12048,-2.1643,0.280674,1.04334,-2.14933,0.122969,1.06732,-2.10696,0.157186,0.993994,-2.09514,0.267195,0.886762,-2.10626,0.251597,0.695406,-2.08913,0.143524,0.72822,-2.09933,0.125532,0.661598,-2.0839,0.08986,0.435299,-2.0326,-0.013559,0.363936,-1.9745,0.269168,0.376169,-2.01699,0.216473,0.339583,-2.0796,0.15489,1.27937,-1.86468,0.131697,1.31256,-2.07607},
/*1707*/{0.256354,1.85329,-1.75197,0.32277,1.79424,-1.90839,0.138621,1.73031,-1.66064,0.04438,1.64567,-1.60252,0.179063,1.57376,-1.66133,0.252197,1.52623,-1.67855,0.241206,1.87399,-2.1514,0.325872,1.79885,-1.98727,0.110907,1.84442,-2.05324,0.066772,1.67171,-2.24305,0.087204,1.58045,-2.28556,0.249739,1.49234,-2.23428,0.2995,1.4498,-2.24595,0.22914,1.36428,-1.84173,0.031174,1.42954,-1.88394,0.02848,1.46263,-1.93917,0.022462,1.44215,-1.9962,0.211236,1.40751,-2.10051,0.297849,1.08611,-1.77567,0.179074,1.02696,-1.8038,0.216455,0.952208,-1.82652,0.306724,0.890406,-1.80395,0.162644,0.839998,-1.79058,0.08666,0.836178,-1.79647,0.155043,0.951237,-1.81312,0.084258,0.94714,-1.8127,-0.139793,0.885755,-1.80489,-0.214807,0.978457,-1.88161,-0.183718,0.72404,-1.83716,-0.234724,0.749871,-1.76722,0.240452,1.11621,-2.16495,0.274228,1.03885,-2.1504,0.116367,1.06575,-2.10667,0.150871,0.991108,-2.09588,0.257572,0.88178,-2.10733,0.23802,0.690393,-2.08944,0.131784,0.725852,-2.10116,0.112943,0.659646,-2.08428,0.06353,0.434613,-2.03447,-0.035511,0.365147,-1.97587,0.247785,0.376498,-2.01839,0.193341,0.338943,-2.08043,0.153039,1.2781,-1.86446,0.130669,1.31188,-2.07585},
/*1708*/{0.254759,1.85225,-1.75204,0.322193,1.7923,-1.90776,0.133928,1.73192,-1.66197,0.037858,1.64807,-1.60592,0.171092,1.5739,-1.66234,0.24493,1.52522,-1.67695,0.243003,1.87261,-2.15102,0.325938,1.79696,-1.98572,0.111204,1.84365,-2.05356,0.072114,1.66805,-2.24159,0.093793,1.57646,-2.28518,0.259815,1.49233,-2.23143,0.310057,1.45042,-2.2428,0.227017,1.36314,-1.83956,0.029749,1.42924,-1.88524,0.028118,1.46155,-1.93951,0.022462,1.44215,-1.9962,0.210076,1.40662,-2.10113,0.305268,1.09159,-1.77579,0.187166,1.02814,-1.80176,0.22672,0.954829,-1.82438,0.320548,0.893905,-1.80348,0.175189,0.841001,-1.7911,0.100487,0.835761,-1.79716,0.165399,0.952741,-1.81166,0.093376,0.947073,-1.81179,-0.128252,0.881914,-1.80688,-0.207919,0.968138,-1.88157,-0.163917,0.716133,-1.83796,-0.21577,0.740292,-1.76646,0.234405,1.11334,-2.16636,0.265983,1.03442,-2.1517,0.109088,1.06533,-2.10813,0.142432,0.98957,-2.09698,0.245499,0.877409,-2.10848,0.2237,0.6849,-2.08879,0.118483,0.724483,-2.10183,0.099361,0.656127,-2.08447,0.046321,0.435447,-2.03544,-0.057593,0.364824,-1.97504,0.224749,0.375731,-2.01977,0.171199,0.338532,-2.08175,0.150917,1.27723,-1.86418,0.129861,1.31105,-2.0757},
/*1709*/{0.253113,1.85194,-1.75105,0.320872,1.79108,-1.90626,0.128415,1.73383,-1.66314,0.030155,1.6517,-1.60882,0.164072,1.57477,-1.66237,0.237355,1.52519,-1.67612,0.245198,1.87157,-2.14983,0.32526,1.79572,-1.98508,0.111775,1.84272,-2.05439,0.076318,1.6647,-2.23997,0.100797,1.57373,-2.28359,0.268595,1.49222,-2.22831,0.319473,1.45214,-2.23894,0.224433,1.36235,-1.83831,0.028804,1.42881,-1.8858,0.026729,1.46133,-1.93982,0.021306,1.44206,-1.99691,0.210893,1.40572,-2.10128,0.311818,1.09818,-1.77577,0.19603,1.02909,-1.79895,0.237449,0.958436,-1.82194,0.332496,0.900237,-1.80283,0.187286,0.842681,-1.7914,0.1125,0.835073,-1.79788,0.174599,0.953524,-1.80989,0.103887,0.945742,-1.80912,-0.11529,0.871745,-1.80691,-0.200976,0.956982,-1.88209,-0.143343,0.707873,-1.83828,-0.193977,0.729255,-1.76593,0.228041,1.1093,-2.16694,0.258288,1.0298,-2.15254,0.103273,1.06416,-2.10818,0.133369,0.988282,-2.09739,0.232876,0.873149,-2.10883,0.209173,0.678922,-2.08745,0.105309,0.722198,-2.10252,0.081326,0.658362,-2.08753,0.024416,0.436643,-2.03647,-0.080494,0.364058,-1.97658,0.202794,0.374963,-2.02029,0.149239,0.338264,-2.08256,0.148727,1.27659,-1.86393,0.129475,1.31051,-2.0756},
/*1710*/{0.250368,1.85186,-1.75092,0.32045,1.79069,-1.90578,0.123015,1.73679,-1.66435,0.023647,1.65544,-1.61178,0.157499,1.57638,-1.662,0.229992,1.52626,-1.67608,0.247655,1.87076,-2.14952,0.324311,1.79498,-1.98342,0.112897,1.84243,-2.0553,0.081001,1.66257,-2.23804,0.10791,1.571,-2.28268,0.2771,1.49355,-2.22412,0.329303,1.45522,-2.23402,0.222885,1.3622,-1.83613,0.026875,1.42944,-1.88717,0.026354,1.46075,-1.94069,0.021227,1.44135,-1.99805,0.210997,1.4047,-2.10152,0.318004,1.10451,-1.77571,0.205444,1.03442,-1.79717,0.247143,0.96161,-1.82028,0.344274,0.905977,-1.80254,0.199661,0.844377,-1.79162,0.126426,0.833408,-1.79888,0.183106,0.955002,-1.80802,0.112019,0.944337,-1.8082,-0.102372,0.865818,-1.80885,-0.194141,0.944325,-1.88291,-0.122149,0.699066,-1.83863,-0.173334,0.717755,-1.76613,0.221212,1.10521,-2.16653,0.249203,1.02515,-2.1527,0.09367,1.06422,-2.10907,0.122592,0.986904,-2.09868,0.218645,0.867341,-2.1082,0.192681,0.674677,-2.08669,0.089781,0.720096,-2.10286,0.064599,0.656983,-2.08812,-0.000129,0.436954,-2.03783,-0.10065,0.368198,-1.97735,0.181139,0.374784,-2.02142,0.127006,0.338054,-2.08318,0.147016,1.27667,-1.863,0.129619,1.30941,-2.07502},
/*1711*/{0.248299,1.85332,-1.75028,0.319186,1.7902,-1.90383,0.11774,1.73989,-1.66547,0.016666,1.65972,-1.61519,0.150907,1.57823,-1.66233,0.222614,1.52837,-1.67635,0.24917,1.87074,-2.14913,0.324011,1.79477,-1.98233,0.113398,1.84235,-2.05666,0.085375,1.66067,-2.23622,0.114636,1.56963,-2.28172,0.285577,1.4973,-2.22023,0.338746,1.4601,-2.2288,0.220575,1.36252,-1.83399,0.026875,1.42944,-1.88717,0.025466,1.46094,-1.9413,0.021571,1.44104,-1.99932,0.21086,1.40446,-2.10147,0.324313,1.11135,-1.77563,0.21187,1.03749,-1.7959,0.257606,0.966647,-1.81928,0.356138,0.912104,-1.80217,0.211768,0.846202,-1.79278,0.137833,0.833022,-1.80027,0.190795,0.956002,-1.80699,0.120432,0.942726,-1.80712,-0.090394,0.855069,-1.81099,-0.186887,0.930011,-1.88327,-0.101338,0.689739,-1.8394,-0.151761,0.70633,-1.76592,0.214635,1.10221,-2.16616,0.239848,1.02106,-2.15237,0.085476,1.06392,-2.10947,0.113029,0.986421,-2.09885,0.204674,0.86309,-2.10831,0.175788,0.671764,-2.08549,0.073375,0.717503,-2.10274,0.047141,0.654398,-2.08871,-0.018462,0.43767,-2.03789,-0.122886,0.368874,-1.97792,0.158694,0.374754,-2.02188,0.105541,0.338289,-2.0835,0.14563,1.27693,-1.86213,0.129839,1.30897,-2.07438},
/*1712*/{0.244855,1.85492,-1.75022,0.318542,1.79082,-1.90214,0.112435,1.74315,-1.667,0.010844,1.66388,-1.61801,0.14372,1.58142,-1.6636,0.215541,1.53059,-1.67604,0.251164,1.871,-2.14743,0.32387,1.79518,-1.98055,0.113921,1.84243,-2.05755,0.089468,1.65972,-2.23389,0.12107,1.56777,-2.28049,0.293275,1.50027,-2.21506,0.347915,1.46529,-2.22298,0.218406,1.36307,-1.83232,0.025294,1.43041,-1.88948,0.025288,1.4611,-1.94345,0.021192,1.44135,-2.00025,0.210445,1.40341,-2.10169,0.329999,1.11867,-1.77581,0.219474,1.04106,-1.79546,0.266713,0.972201,-1.81738,0.366537,0.919771,-1.80194,0.224246,0.848332,-1.79313,0.151328,0.832634,-1.80089,0.198899,0.957184,-1.80519,0.129165,0.941062,-1.80675,-0.077761,0.845016,-1.81086,-0.178345,0.915411,-1.88492,-0.079791,0.680169,-1.84008,-0.130156,0.694959,-1.76675,0.207273,1.09877,-2.16569,0.229678,1.01701,-2.15212,0.076517,1.06547,-2.10983,0.101238,0.986798,-2.0985,0.188821,0.857746,-2.10813,0.158099,0.669228,-2.08495,0.056617,0.715887,-2.1025,0.029135,0.651897,-2.08724,-0.042243,0.439347,-2.03819,-0.145446,0.370273,-1.97866,0.13635,0.374556,-2.02146,0.084372,0.33867,-2.08338,0.143345,1.27761,-1.8615,0.129522,1.30816,-2.0741},
/*1713*/{0.242206,1.85738,-1.74949,0.316945,1.79265,-1.90104,0.107532,1.747,-1.66811,0.004132,1.66821,-1.6207,0.137721,1.58528,-1.66433,0.208668,1.53345,-1.67569,0.253289,1.87207,-2.14657,0.32427,1.79655,-1.97889,0.114865,1.84289,-2.05865,0.093654,1.65807,-2.23106,0.128182,1.56739,-2.27953,0.300708,1.50598,-2.21025,0.357143,1.47224,-2.2162,0.216731,1.36493,-1.83155,0.025283,1.43028,-1.89051,0.02569,1.46171,-1.94452,0.020624,1.44184,-2.00341,0.211126,1.40263,-2.10199,0.337178,1.12512,-1.77433,0.228678,1.04547,-1.79298,0.274542,0.976182,-1.81734,0.376538,0.926317,-1.80191,0.23604,0.850044,-1.79423,0.164036,0.831826,-1.80064,0.206104,0.958117,-1.80376,0.136765,0.93931,-1.8057,-0.065869,0.834995,-1.81252,-0.169719,0.899882,-1.88667,-0.057438,0.670924,-1.84057,-0.108955,0.682404,-1.76776,0.199759,1.09645,-2.16532,0.219526,1.01353,-2.15151,0.068944,1.06649,-2.10977,0.090196,0.987468,-2.09866,0.172434,0.854011,-2.10785,0.139931,0.667323,-2.08402,0.038883,0.715701,-2.10163,0.011169,0.652151,-2.08667,-0.063198,0.440926,-2.03953,-0.167953,0.372437,-1.97987,0.114103,0.374915,-2.02292,0.061769,0.33912,-2.0833,0.14254,1.27877,-1.86105,0.130235,1.30766,-2.07398},
/*1714*/{0.238649,1.85959,-1.74909,0.316032,1.79436,-1.89858,0.102607,1.75073,-1.66915,-0.003761,1.67193,-1.62324,0.13083,1.5897,-1.66556,0.201551,1.53759,-1.67643,0.254985,1.87383,-2.14555,0.32398,1.79797,-1.97717,0.11531,1.84411,-2.06015,0.096972,1.65793,-2.22951,0.134048,1.56703,-2.27763,0.307128,1.51083,-2.20455,0.364936,1.47942,-2.21029,0.215621,1.36698,-1.83023,0.024798,1.43119,-1.89234,0.026348,1.46166,-1.94586,0.020954,1.44258,-2.00433,0.21183,1.40159,-2.10218,0.339462,1.13289,-1.77547,0.235361,1.04966,-1.79264,0.283676,0.982594,-1.81537,0.386618,0.935211,-1.80127,0.248718,0.851869,-1.79381,0.176942,0.830113,-1.80263,0.212547,0.958378,-1.80253,0.14361,0.935856,-1.80527,-0.052339,0.825033,-1.8139,-0.160672,0.883748,-1.88841,-0.035092,0.661824,-1.84153,-0.087862,0.670261,-1.76869,0.191848,1.09428,-2.16415,0.208989,1.01091,-2.15029,0.060038,1.06863,-2.10981,0.079466,0.988729,-2.09757,0.155211,0.852021,-2.10722,0.121644,0.666915,-2.08346,0.021534,0.717181,-2.10008,-0.006164,0.653536,-2.08597,-0.084361,0.442441,-2.03921,-0.188814,0.375375,-1.97795,0.092144,0.374781,-2.02224,0.038108,0.338845,-2.08353,0.141908,1.28023,-1.85994,0.131038,1.30699,-2.07323},
/*1715*/{0.235526,1.86229,-1.74817,0.315653,1.79574,-1.89648,0.09745,1.75477,-1.6696,-0.008653,1.67633,-1.62562,0.124786,1.59444,-1.66648,0.195295,1.5417,-1.6763,0.256163,1.87558,-2.14418,0.323437,1.79965,-1.975,0.11575,1.84443,-2.06069,0.101095,1.65657,-2.22707,0.141134,1.5681,-2.27712,0.314198,1.51749,-2.19888,0.373187,1.48818,-2.20353,0.21575,1.36924,-1.83029,0.02437,1.43266,-1.89511,0.026082,1.46301,-1.94714,0.021334,1.44308,-2.00673,0.211614,1.40066,-2.10257,0.344298,1.14075,-1.77393,0.241492,1.05391,-1.79262,0.290764,0.988562,-1.81602,0.395458,0.943263,-1.80028,0.260349,0.854287,-1.79351,0.189312,0.828334,-1.80219,0.219222,0.958731,-1.80139,0.151113,0.932749,-1.80468,-0.040903,0.813589,-1.81714,-0.150189,0.866391,-1.89072,-0.013423,0.651932,-1.8425,-0.066577,0.658066,-1.76938,0.184346,1.09333,-2.16258,0.199319,1.00908,-2.14812,0.05104,1.07166,-2.10984,0.067343,0.991045,-2.09806,0.13772,0.852547,-2.10666,0.103349,0.667547,-2.0827,0.003308,0.718973,-2.09894,-0.025388,0.655736,-2.08469,-0.105235,0.445294,-2.03901,-0.209882,0.377141,-1.97879,0.070089,0.374526,-2.02234,0.017711,0.339163,-2.08332,0.141423,1.28226,-1.85953,0.131253,1.30651,-2.07316},
/*1716*/{0.231569,1.86538,-1.74822,0.314926,1.79792,-1.89453,0.092866,1.75889,-1.67114,-0.015237,1.68189,-1.62826,0.118661,1.59932,-1.66812,0.189616,1.54637,-1.67715,0.258227,1.87783,-2.14311,0.323693,1.80208,-1.97307,0.116545,1.84583,-2.06119,0.105894,1.65586,-2.22499,0.148598,1.56864,-2.27552,0.32174,1.52556,-2.19366,0.380566,1.49692,-2.19706,0.215799,1.37139,-1.83011,0.023824,1.43301,-1.89708,0.026276,1.46423,-1.94897,0.022074,1.4445,-2.00831,0.21254,1.40023,-2.10268,0.34935,1.14769,-1.77319,0.245408,1.05572,-1.79269,0.29958,0.994747,-1.81474,0.404801,0.951006,-1.80076,0.271352,0.855693,-1.79363,0.202478,0.826217,-1.80241,0.225817,0.957827,-1.8011,0.160342,0.928505,-1.80376,-0.026781,0.804001,-1.81773,-0.139177,0.84882,-1.89303,0.009036,0.642807,-1.84275,-0.044992,0.645797,-1.77034,0.177861,1.09177,-2.16091,0.189338,1.00801,-2.14583,0.043304,1.07475,-2.11031,0.057205,0.99369,-2.09819,0.120198,0.853992,-2.1051,0.084867,0.668293,-2.08178,-0.014062,0.721896,-2.09779,-0.044127,0.658281,-2.08414,-0.126311,0.447981,-2.03908,-0.232215,0.382929,-1.97816,0.047521,0.374564,-2.02174,-0.006754,0.339377,-2.08414,0.141167,1.28391,-1.85937,0.132272,1.30665,-2.07322},
/*1717*/{0.228131,1.86822,-1.74783,0.314168,1.80053,-1.89273,0.08814,1.76323,-1.67243,-0.02192,1.68599,-1.63098,0.113009,1.60482,-1.6702,0.183654,1.55109,-1.6775,0.260207,1.88097,-2.14176,0.323787,1.8046,-1.97159,0.117342,1.84609,-2.0612,0.109077,1.65518,-2.22336,0.154972,1.57007,-2.27478,0.328023,1.533,-2.18822,0.387928,1.50628,-2.19005,0.216258,1.37461,-1.82968,0.024166,1.43514,-1.89845,0.026545,1.46603,-1.95093,0.023394,1.44603,-2.01105,0.21403,1.39962,-2.10245,0.351491,1.15408,-1.77307,0.251951,1.06318,-1.79237,0.305407,1.00121,-1.81451,0.412389,0.959298,-1.80035,0.282025,0.857163,-1.79339,0.215062,0.823049,-1.80292,0.231596,0.956863,-1.79992,0.166842,0.924234,-1.80501,-0.012949,0.790054,-1.81841,-0.127805,0.831263,-1.89612,0.031205,0.632785,-1.8436,-0.023454,0.632801,-1.7723,0.17096,1.09123,-2.159,0.180192,1.00708,-2.14336,0.034725,1.07878,-2.11136,0.04553,0.996098,-2.09878,0.103523,0.856292,-2.10437,0.066523,0.670485,-2.0804,-0.032051,0.724463,-2.09674,-0.06246,0.662498,-2.08322,-0.146669,0.45212,-2.03889,-0.252896,0.387176,-1.98003,0.02571,0.374525,-2.02196,-0.030301,0.338874,-2.08293,0.141198,1.2868,-1.85836,0.133682,1.30671,-2.07254},
/*1718*/{0.225221,1.87116,-1.74729,0.313116,1.80493,-1.8916,0.083331,1.76765,-1.67336,-0.026555,1.69164,-1.63345,0.107592,1.61001,-1.67126,0.178029,1.55687,-1.67803,0.260489,1.88383,-2.14077,0.323633,1.80724,-1.96939,0.11821,1.84824,-2.06197,0.113221,1.65571,-2.22187,0.161886,1.57145,-2.2734,0.334002,1.53987,-2.18269,0.39458,1.51598,-2.18309,0.216369,1.37754,-1.8308,0.025026,1.43729,-1.89938,0.028044,1.46767,-1.95235,0.024603,1.44746,-2.01157,0.214501,1.39974,-2.10282,0.353892,1.16124,-1.77266,0.257073,1.06694,-1.79257,0.312755,1.0072,-1.81392,0.420522,0.968038,-1.80028,0.293128,0.858821,-1.79358,0.22634,0.822206,-1.80281,0.237465,0.955591,-1.80032,0.174614,0.919789,-1.8063,0.000587,0.77743,-1.81955,-0.115196,0.812003,-1.89963,0.053889,0.623254,-1.84405,-0.002377,0.619854,-1.77305,0.163651,1.09127,-2.15685,0.170371,1.00666,-2.14047,0.026068,1.08293,-2.11145,0.035979,0.999793,-2.09921,0.08796,0.858759,-2.10264,0.047726,0.672864,-2.07928,-0.049117,0.72825,-2.09532,-0.080902,0.666217,-2.08235,-0.168101,0.455598,-2.03833,-0.273319,0.393389,-1.98009,0.003175,0.375007,-2.02141,-0.052341,0.339003,-2.08268,0.141775,1.28927,-1.85802,0.13422,1.30728,-2.07237},
/*1719*/{0.2215,1.87467,-1.74766,0.312438,1.80854,-1.88977,0.079633,1.77153,-1.67416,-0.03155,1.69645,-1.63564,0.101852,1.61578,-1.67275,0.172441,1.56208,-1.67917,0.261818,1.8877,-2.13953,0.323946,1.81073,-1.96738,0.119087,1.84973,-2.06279,0.118815,1.65694,-2.22112,0.1685,1.57345,-2.27232,0.340334,1.54847,-2.17733,0.401937,1.52466,-2.17585,0.217046,1.38112,-1.83173,0.025422,1.44018,-1.90103,0.02964,1.46967,-1.95378,0.026107,1.44908,-2.01317,0.215929,1.39939,-2.10266,0.357449,1.16885,-1.77204,0.260427,1.07339,-1.79257,0.316845,1.01287,-1.81507,0.426512,0.976181,-1.79998,0.303681,0.86046,-1.79276,0.238063,0.820639,-1.80367,0.242887,0.953994,-1.80159,0.181623,0.915574,-1.80697,0.012297,0.766572,-1.82305,-0.101488,0.793457,-1.90222,0.077134,0.613688,-1.84538,0.019806,0.607316,-1.77456,0.15836,1.09096,-2.15407,0.161516,1.00655,-2.13812,0.018939,1.08752,-2.10954,0.026455,1.00377,-2.09932,0.073443,0.860445,-2.10036,0.030802,0.675723,-2.07745,-0.066684,0.731958,-2.09443,-0.098849,0.66994,-2.0816,-0.185726,0.460227,-2.0371,-0.293952,0.400591,-1.97993,-0.018566,0.374822,-2.01988,-0.074212,0.339431,-2.0821,0.142298,1.29247,-1.85721,0.13536,1.30767,-2.0718},
/*1720*/{0.218753,1.87779,-1.74774,0.312143,1.81038,-1.88716,0.07502,1.77642,-1.67528,-0.036449,1.70181,-1.63775,0.09715,1.62127,-1.67494,0.167136,1.56778,-1.68009,0.262294,1.89095,-2.13802,0.324626,1.81304,-1.96511,0.119625,1.85185,-2.06351,0.125373,1.65906,-2.22029,0.175346,1.57567,-2.27142,0.345513,1.5564,-2.17212,0.407466,1.53511,-2.16923,0.217835,1.38466,-1.83221,0.026221,1.4423,-1.90291,0.029965,1.47178,-1.95571,0.02817,1.4513,-2.01473,0.21692,1.39907,-2.10258,0.359214,1.17534,-1.77162,0.263539,1.07809,-1.79323,0.322265,1.01947,-1.81398,0.43293,0.984849,-1.79986,0.3134,0.860995,-1.79224,0.250843,0.817995,-1.80276,0.248308,0.952456,-1.80212,0.190869,0.911398,-1.80611,0.028679,0.752646,-1.82286,-0.087116,0.774206,-1.90466,0.10012,0.604678,-1.84572,0.042427,0.594859,-1.77656,0.151865,1.0912,-2.1517,0.15244,1.00748,-2.13439,0.013414,1.09151,-2.11174,0.017014,1.00855,-2.09887,0.059887,0.863219,-2.09802,0.012939,0.679357,-2.0763,-0.083973,0.736767,-2.09307,-0.116631,0.675198,-2.08061,-0.207577,0.465348,-2.03744,-0.314565,0.406084,-1.97837,-0.041167,0.374466,-2.01975,-0.095835,0.339929,-2.08134,0.142694,1.29559,-1.85661,0.136499,1.30821,-2.07138},
/*1721*/{0.216066,1.8813,-1.74744,0.31052,1.81552,-1.88624,0.071554,1.78083,-1.67612,-0.042339,1.70692,-1.64034,0.092366,1.62692,-1.67682,0.162939,1.57351,-1.68128,0.263186,1.89526,-2.13694,0.324919,1.81659,-1.96308,0.120924,1.85373,-2.06342,0.130034,1.66118,-2.22121,0.181856,1.57861,-2.27038,0.349935,1.56423,-2.16723,0.4136,1.54596,-2.16233,0.219543,1.38808,-1.83356,0.027524,1.44604,-1.90287,0.03246,1.47441,-1.95665,0.029914,1.45366,-2.01543,0.218619,1.39898,-2.10254,0.36086,1.18171,-1.77094,0.268808,1.08323,-1.79217,0.326226,1.02534,-1.81449,0.437994,0.993028,-1.79927,0.323175,0.861545,-1.79197,0.262531,0.816109,-1.80297,0.253579,0.950054,-1.80314,0.197537,0.905852,-1.80884,0.044845,0.738907,-1.82481,-0.07257,0.755643,-1.90702,0.123233,0.595731,-1.84624,0.065961,0.583332,-1.77797,0.14591,1.09221,-2.14889,0.144178,1.00858,-2.13145,0.005881,1.09597,-2.11209,0.006854,1.01366,-2.09908,0.046932,0.866661,-2.09497,-0.00451,0.684178,-2.07557,-0.101407,0.742059,-2.09209,-0.133434,0.68046,-2.08021,-0.229149,0.469616,-2.03958,-0.333456,0.414714,-1.97883,-0.063162,0.375206,-2.02105,-0.117208,0.34036,-2.08057,0.143933,1.29904,-1.85568,0.137328,1.30913,-2.07058},
/*1722*/{0.213295,1.88419,-1.74744,0.310842,1.81957,-1.88476,0.06811,1.78558,-1.67687,-0.046147,1.71267,-1.64244,0.088118,1.63244,-1.67795,0.158039,1.57891,-1.68215,0.264905,1.89955,-2.13595,0.325172,1.81994,-1.96152,0.121391,1.8567,-2.0639,0.129908,1.6655,-2.2247,0.188968,1.58101,-2.2694,0.355089,1.57274,-2.16201,0.418446,1.55617,-2.15621,0.220617,1.39173,-1.83519,0.029273,1.44977,-1.90412,0.032964,1.47711,-1.95881,0.032382,1.4565,-2.0161,0.220548,1.39856,-2.10273,0.362635,1.18815,-1.77073,0.271377,1.08737,-1.79162,0.329765,1.03098,-1.81467,0.442472,1.00053,-1.79822,0.331933,0.862088,-1.79097,0.27455,0.814981,-1.80256,0.259258,0.947895,-1.80336,0.203845,0.902252,-1.81039,0.059766,0.726755,-1.82823,-0.057173,0.736295,-1.90902,0.147865,0.587591,-1.84735,0.089973,0.570927,-1.77962,0.140725,1.0932,-2.1462,0.135734,1.00926,-2.12824,-0.000253,1.10221,-2.11238,-0.002236,1.0192,-2.09874,0.034117,0.870615,-2.09292,-0.021529,0.689981,-2.07578,-0.117655,0.74846,-2.09154,-0.152096,0.686549,-2.07984,-0.25016,0.475304,-2.03728,-0.352193,0.42332,-1.97798,-0.085645,0.3755,-2.01903,-0.141572,0.34075,-2.08161,0.144607,1.30271,-1.8551,0.138195,1.31004,-2.07012},
/*1723*/{0.211261,1.88728,-1.74716,0.31094,1.82182,-1.88288,0.065004,1.78959,-1.67849,-0.050991,1.71751,-1.64463,0.083799,1.63754,-1.68001,0.154553,1.58429,-1.6832,0.266674,1.90364,-2.13433,0.32538,1.82352,-1.96002,0.122856,1.85943,-2.06402,0.135747,1.66768,-2.22696,0.196842,1.58471,-2.26824,0.359494,1.58184,-2.15715,0.422811,1.5664,-2.15009,0.222137,1.39516,-1.83568,0.031037,1.45339,-1.90415,0.035566,1.4799,-1.95971,0.034713,1.45926,-2.0165,0.221663,1.39857,-2.10267,0.364745,1.19416,-1.77008,0.273272,1.09108,-1.79003,0.334937,1.03647,-1.81349,0.445714,1.00671,-1.79814,0.340731,0.862334,-1.79085,0.285369,0.811661,-1.80279,0.265128,0.944354,-1.80372,0.212598,0.895742,-1.81095,0.076212,0.712872,-1.82784,-0.039745,0.714753,-1.91137,0.172226,0.579584,-1.84911,0.114992,0.55912,-1.78137,0.134858,1.09476,-2.14392,0.126813,1.01052,-2.12505,-0.006456,1.10804,-2.11264,-0.010664,1.02565,-2.09835,0.019604,0.877289,-2.09173,-0.038476,0.695872,-2.07538,-0.133477,0.755828,-2.09139,-0.167485,0.694188,-2.07939,-0.267768,0.480934,-2.03792,-0.370391,0.433225,-1.97888,-0.108169,0.37521,-2.01818,-0.162939,0.341581,-2.07979,0.145703,1.30623,-1.85399,0.138936,1.3111,-2.06907},
/*1724*/{0.209604,1.89047,-1.74704,0.309844,1.82671,-1.88225,0.061877,1.79399,-1.67972,-0.05503,1.72295,-1.64744,0.080384,1.6432,-1.68139,0.149438,1.58953,-1.68467,0.268361,1.90855,-2.13266,0.32573,1.82741,-1.95838,0.124059,1.8621,-2.0638,0.141488,1.6712,-2.22926,0.204063,1.58797,-2.26779,0.362498,1.58879,-2.15118,0.426981,1.57543,-2.14397,0.223463,1.39848,-1.83765,0.032006,1.45714,-1.90484,0.036912,1.48275,-1.9606,0.037791,1.46181,-2.01661,0.22373,1.39809,-2.10231,0.366454,1.19995,-1.77,0.277082,1.09904,-1.79027,0.336913,1.04192,-1.81328,0.449133,1.01275,-1.7984,0.349914,0.862661,-1.79014,0.296846,0.809264,-1.80208,0.269935,0.940538,-1.80467,0.220724,0.889011,-1.81252,0.095024,0.6997,-1.82877,-0.023219,0.695094,-1.91272,0.1961,0.571463,-1.85002,0.140102,0.548041,-1.7834,0.128912,1.09582,-2.14148,0.118407,1.01291,-2.12223,-0.011856,1.1136,-2.11235,-0.018863,1.03223,-2.09785,0.004343,0.883343,-2.09138,-0.054568,0.702174,-2.07545,-0.149763,0.76286,-2.09038,-0.185123,0.700993,-2.07786,-0.285561,0.487367,-2.0388,-0.388558,0.444107,-1.98188,-0.130857,0.374952,-2.01753,-0.186844,0.341949,-2.07975,0.146567,1.30966,-1.85314,0.139771,1.31207,-2.06825},
/*1725*/{0.208132,1.89295,-1.74688,0.309908,1.83088,-1.88068,0.059425,1.79798,-1.6805,-0.059011,1.72807,-1.65005,0.076703,1.64787,-1.68312,0.145416,1.59455,-1.68466,0.269362,1.91262,-2.13118,0.325977,1.83102,-1.95694,0.124997,1.86536,-2.06468,0.14788,1.67427,-2.23134,0.211137,1.59163,-2.26698,0.367381,1.59848,-2.14781,0.431173,1.58565,-2.13831,0.225172,1.40218,-1.83814,0.034092,1.46138,-1.90398,0.038971,1.4855,-1.96178,0.039563,1.46558,-2.01695,0.224921,1.39804,-2.10173,0.366312,1.20621,-1.77028,0.276594,1.1033,-1.79119,0.339701,1.0471,-1.81272,0.450823,1.01736,-1.79832,0.357366,0.862263,-1.79012,0.307832,0.806349,-1.80244,0.274224,0.936126,-1.80722,0.227037,0.883097,-1.81314,0.111835,0.684783,-1.82996,-0.005331,0.675605,-1.914,0.221144,0.564423,-1.85199,0.166157,0.537358,-1.78507,0.124083,1.09821,-2.13818,0.110817,1.01516,-2.11991,-0.015757,1.12081,-2.11304,-0.026519,1.0394,-2.09803,-0.01,0.889231,-2.09125,-0.070851,0.708835,-2.0762,-0.164851,0.770818,-2.09058,-0.200343,0.709093,-2.0778,-0.302531,0.494136,-2.04004,-0.403132,0.454341,-1.97716,-0.154292,0.376488,-2.01762,-0.207488,0.342748,-2.07859,0.147529,1.31366,-1.85172,0.14017,1.31341,-2.06682},
/*1726*/{0.206542,1.89614,-1.74705,0.309893,1.83429,-1.87964,0.0567,1.80218,-1.68219,-0.0617,1.73283,-1.6524,0.07293,1.65322,-1.68458,0.142553,1.59931,-1.68596,0.270649,1.91672,-2.13015,0.326006,1.83379,-1.95545,0.126669,1.86742,-2.06463,0.154366,1.67777,-2.23387,0.21785,1.59539,-2.26603,0.370101,1.60624,-2.14262,0.434676,1.59488,-2.13381,0.226128,1.40533,-1.83936,0.036517,1.46575,-1.90475,0.041509,1.48943,-1.96292,0.042917,1.46872,-2.01734,0.226457,1.39764,-2.10109,0.367801,1.21039,-1.76937,0.281983,1.1093,-1.7895,0.34052,1.05203,-1.81256,0.451675,1.02202,-1.79816,0.36588,0.861915,-1.78936,0.318449,0.803395,-1.80244,0.279069,0.931584,-1.80669,0.23442,0.876392,-1.81432,0.129133,0.671277,-1.83156,0.013543,0.655555,-1.91473,0.245192,0.558025,-1.85403,0.192653,0.526575,-1.78744,0.118281,1.09983,-2.13672,0.102672,1.01764,-2.11723,-0.021151,1.12787,-2.11315,-0.034188,1.04675,-2.09779,-0.024243,0.895611,-2.09164,-0.084881,0.716378,-2.07707,-0.180328,0.777385,-2.08948,-0.215433,0.719999,-2.0789,-0.310724,0.503935,-2.04153,-0.418956,0.468397,-1.97886,-0.176609,0.376208,-2.01745,-0.230664,0.343009,-2.07862,0.147913,1.31741,-1.85073,0.140642,1.31467,-2.06582},
/*1727*/{0.205006,1.89837,-1.74726,0.309731,1.83749,-1.87889,0.054486,1.80596,-1.68337,-0.065124,1.73741,-1.65467,0.069459,1.65756,-1.68595,0.139351,1.60403,-1.68607,0.273505,1.92085,-2.12803,0.326058,1.83709,-1.95402,0.127915,1.87049,-2.06489,0.160954,1.68114,-2.23623,0.225013,1.59904,-2.26538,0.372911,1.61353,-2.13853,0.437515,1.60347,-2.1282,0.228298,1.40868,-1.84034,0.038188,1.47017,-1.90342,0.042759,1.49236,-1.96383,0.044772,1.4716,-2.01755,0.229034,1.39765,-2.10043,0.369304,1.2153,-1.76853,0.28363,1.11346,-1.78797,0.341159,1.05659,-1.8115,0.451636,1.02545,-1.79834,0.372907,0.86083,-1.78913,0.329191,0.800451,-1.80244,0.283758,0.9272,-1.80919,0.239913,0.869206,-1.81708,0.148649,0.659034,-1.83281,0.032572,0.63614,-1.91565,0.270522,0.550855,-1.85538,0.219285,0.516887,-1.79028,0.113809,1.10195,-2.13487,0.094404,1.02076,-2.11558,-0.024336,1.13437,-2.11273,-0.04319,1.05377,-2.09714,-0.036391,0.903622,-2.09171,-0.098665,0.723952,-2.07795,-0.192823,0.786435,-2.08954,-0.229231,0.726172,-2.0784,-0.323527,0.509892,-2.04306,-0.433223,0.481354,-1.97749,-0.19924,0.376894,-2.01762,-0.253588,0.344498,-2.07843,0.149316,1.32129,-1.84932,0.141578,1.31606,-2.06435},
/*1728*/{0.203811,1.90074,-1.74729,0.310306,1.83944,-1.8775,0.052631,1.80976,-1.68491,-0.06771,1.74276,-1.65672,0.066934,1.66184,-1.68735,0.135804,1.60759,-1.68712,0.274867,1.924,-2.12699,0.326309,1.84078,-1.95306,0.129203,1.87295,-2.06542,0.167559,1.6839,-2.23829,0.231712,1.60282,-2.26459,0.376971,1.62222,-2.13434,0.440775,1.61206,-2.12334,0.228778,1.41239,-1.84148,0.040252,1.47489,-1.90361,0.044563,1.49567,-1.96444,0.046165,1.47443,-2.01845,0.228473,1.39802,-2.10041,0.370052,1.21916,-1.76786,0.28138,1.1157,-1.78879,0.342035,1.06054,-1.81046,0.451082,1.02751,-1.79678,0.38069,0.859902,-1.78956,0.339302,0.796415,-1.80232,0.287642,0.920824,-1.80979,0.249027,0.861463,-1.81819,0.16621,0.644429,-1.83367,0.052804,0.616822,-1.91595,0.295248,0.545795,-1.85789,0.247039,0.507473,-1.79239,0.108841,1.10368,-2.13372,0.086855,1.02387,-2.11403,-0.028758,1.14063,-2.11211,-0.050067,1.06167,-2.09703,-0.049054,0.910981,-2.09228,-0.111124,0.732015,-2.07916,-0.206336,0.794089,-2.08955,-0.241703,0.733872,-2.07776,-0.33666,0.517427,-2.04418,-0.446574,0.495494,-1.97839,-0.221274,0.377528,-2.01821,-0.27647,0.345464,-2.07784,0.149634,1.32547,-1.84839,0.140824,1.31753,-2.0633},
/*1729*/{0.203634,1.90285,-1.7472,0.304053,1.84531,-1.87829,0.050284,1.81407,-1.68612,-0.071892,1.74603,-1.6598,0.063885,1.66562,-1.68883,0.135252,1.6115,-1.68738,0.276673,1.92777,-2.12485,0.326447,1.84395,-1.95173,0.130759,1.87496,-2.06535,0.174545,1.6875,-2.2406,0.238256,1.6065,-2.26422,0.379448,1.62946,-2.13089,0.443428,1.62089,-2.11809,0.229499,1.41507,-1.84077,0.041615,1.4797,-1.90464,0.046862,1.49978,-1.96497,0.049626,1.4772,-2.01745,0.229504,1.39833,-2.09941,0.370683,1.22238,-1.76774,0.28112,1.11729,-1.78786,0.341757,1.0648,-1.80908,0.449747,1.03085,-1.79678,0.387597,0.857864,-1.78919,0.349692,0.793386,-1.80244,0.291071,0.914229,-1.8118,0.25615,0.853179,-1.8192,0.186183,0.631757,-1.83495,0.073153,0.596731,-1.91672,0.319649,0.540044,-1.86047,0.274146,0.498552,-1.79453,0.104604,1.1056,-2.13315,0.079494,1.02596,-2.11295,-0.032253,1.14748,-2.11181,-0.054862,1.06957,-2.09673,-0.059161,0.918638,-2.09253,-0.122277,0.740268,-2.08072,-0.216799,0.802559,-2.0895,-0.252972,0.741733,-2.07794,-0.34879,0.524629,-2.04585,-0.456425,0.511047,-1.97754,-0.242283,0.378248,-2.01913,-0.300771,0.347908,-2.07825,0.149379,1.32918,-1.8468,0.141093,1.31919,-2.06165},
/*1730*/{0.202857,1.90463,-1.74699,0.303827,1.84736,-1.87697,0.049472,1.81734,-1.68806,-0.07273,1.75047,-1.66219,0.061614,1.66937,-1.68945,0.132037,1.61444,-1.68772,0.277693,1.93043,-2.12385,0.327268,1.84673,-1.95067,0.132987,1.87809,-2.06572,0.18075,1.69129,-2.24241,0.244522,1.60993,-2.26393,0.38095,1.63458,-2.12749,0.445012,1.62813,-2.11395,0.229921,1.41898,-1.8418,0.043212,1.48384,-1.90383,0.048619,1.5032,-1.96598,0.052261,1.48035,-2.0171,0.231977,1.39845,-2.09864,0.370485,1.22528,-1.76713,0.282727,1.12495,-1.78478,0.339873,1.06754,-1.80905,0.447866,1.0322,-1.79775,0.394,0.855452,-1.78963,0.359676,0.789492,-1.80261,0.295499,0.907113,-1.81263,0.263073,0.843943,-1.81898,0.205137,0.617974,-1.83612,0.094305,0.578068,-1.91778,0.344139,0.535237,-1.86265,0.301222,0.490548,-1.79627,0.100522,1.10765,-2.13211,0.073289,1.02913,-2.11205,-0.034598,1.15332,-2.11126,-0.059369,1.07588,-2.09571,-0.067837,0.926619,-2.09312,-0.132703,0.747937,-2.08191,-0.227463,0.810353,-2.09017,-0.263317,0.749075,-2.07819,-0.359216,0.531426,-2.04704,-0.466652,0.525555,-1.97818,-0.262836,0.377898,-2.0197,-0.322676,0.350367,-2.07769,0.150086,1.33324,-1.8454,0.142,1.32092,-2.06013},
/*1731*/{0.202831,1.90667,-1.74678,0.310329,1.84788,-1.87469,0.048595,1.82004,-1.68917,-0.07504,1.75424,-1.66503,0.059993,1.6725,-1.69081,0.129833,1.61768,-1.68795,0.279177,1.93307,-2.1217,0.328668,1.84867,-1.94877,0.134404,1.87846,-2.0674,0.187918,1.69447,-2.24389,0.248971,1.61339,-2.26425,0.382753,1.64109,-2.12476,0.44678,1.63524,-2.10943,0.230353,1.42231,-1.84244,0.044785,1.48791,-1.90317,0.049128,1.50644,-1.96669,0.052618,1.48396,-2.01811,0.232702,1.39837,-2.09814,0.370084,1.22693,-1.76683,0.280812,1.12769,-1.78495,0.338314,1.06947,-1.80677,0.445868,1.03296,-1.79736,0.400295,0.853029,-1.79009,0.368618,0.784943,-1.80257,0.299971,0.900059,-1.81329,0.269506,0.834018,-1.82073,0.224534,0.606476,-1.83702,0.115805,0.559874,-1.91792,0.367716,0.530398,-1.86288,0.327388,0.482367,-1.79781,0.096612,1.11029,-2.13216,0.067555,1.03256,-2.1124,-0.038619,1.15856,-2.11095,-0.064332,1.08139,-2.09539,-0.076082,0.932858,-2.09287,-0.141418,0.755774,-2.08373,-0.237157,0.816728,-2.08973,-0.271425,0.756736,-2.0791,-0.373788,0.539168,-2.04925,-0.474095,0.541271,-1.97813,-0.281036,0.37908,-2.02096,-0.344831,0.354615,-2.07735,0.149901,1.33715,-1.84434,0.141328,1.32254,-2.05891},
/*1732*/{0.202615,1.90794,-1.74641,0.305348,1.85251,-1.87491,0.047146,1.82363,-1.69111,-0.076904,1.75755,-1.66716,0.058546,1.67513,-1.69117,0.129098,1.62022,-1.68768,0.280754,1.93551,-2.12063,0.328671,1.8517,-1.94837,0.136599,1.8805,-2.06769,0.193313,1.69711,-2.24431,0.253391,1.61644,-2.26425,0.384161,1.64569,-2.12172,0.448177,1.64128,-2.10557,0.229828,1.4254,-1.84353,0.046748,1.49169,-1.90256,0.051994,1.50978,-1.96743,0.053899,1.48645,-2.01777,0.233114,1.39926,-2.09705,0.368807,1.22921,-1.76734,0.277498,1.1296,-1.78415,0.334351,1.07079,-1.80691,0.443259,1.0331,-1.79708,0.406058,0.849798,-1.78969,0.378527,0.780245,-1.80305,0.303667,0.891674,-1.81469,0.278141,0.82397,-1.82168,0.242601,0.59315,-1.83776,0.136887,0.542204,-1.91903,0.390206,0.525893,-1.86472,0.353149,0.475153,-1.80002,0.092827,1.11289,-2.13255,0.062731,1.03492,-2.11325,-0.041018,1.16314,-2.10944,-0.067969,1.08652,-2.09463,-0.082947,0.938561,-2.09253,-0.15006,0.761876,-2.08533,-0.243469,0.824497,-2.09031,-0.280084,0.762941,-2.07958,-0.381313,0.547264,-2.05205,-0.48176,0.557348,-1.97878,-0.301307,0.378579,-2.02251,-0.36627,0.359874,-2.07563,0.14999,1.34058,-1.84333,0.141134,1.32433,-2.05776},
/*1733*/{0.202662,1.90959,-1.74617,0.306763,1.855,-1.87436,0.047124,1.82634,-1.69222,-0.078596,1.75993,-1.66938,0.057435,1.67723,-1.69225,0.127059,1.62188,-1.68748,0.282445,1.93749,-2.11914,0.329423,1.8542,-1.94728,0.137843,1.88244,-2.06808,0.198791,1.70039,-2.24575,0.257999,1.61902,-2.26418,0.38568,1.65164,-2.11967,0.449503,1.64666,-2.10204,0.229215,1.42785,-1.84427,0.048249,1.49433,-1.90292,0.052636,1.51288,-1.96749,0.054974,1.48927,-2.01785,0.23358,1.39979,-2.09681,0.368436,1.22945,-1.76658,0.274077,1.12955,-1.78319,0.332135,1.07162,-1.80555,0.439987,1.03195,-1.79773,0.411478,0.846597,-1.78945,0.387739,0.77533,-1.8024,0.30707,0.883692,-1.8153,0.284333,0.815539,-1.82254,0.261792,0.580112,-1.83808,0.159353,0.525411,-1.92099,0.41292,0.521835,-1.86558,0.378262,0.468583,-1.8007,0.088891,1.11526,-2.13318,0.058621,1.03716,-2.11419,-0.042996,1.16762,-2.10795,-0.07117,1.09138,-2.09324,-0.089088,0.943465,-2.09175,-0.156454,0.768041,-2.08587,-0.250006,0.83191,-2.0902,-0.285951,0.770541,-2.0809,-0.388777,0.555766,-2.05239,-0.487748,0.574046,-1.9791,-0.319099,0.379134,-2.02369,-0.39043,0.366715,-2.07546,0.149559,1.34324,-1.84296,0.14068,1.32607,-2.05732},
/*1734*/{0.202996,1.91078,-1.74614,0.311565,1.85342,-1.87179,0.046431,1.828,-1.69332,-0.079645,1.76251,-1.672,0.056949,1.67981,-1.69318,0.126878,1.62315,-1.68697,0.28402,1.93832,-2.11788,0.330525,1.85537,-1.94555,0.139935,1.88393,-2.06816,0.200915,1.70293,-2.24542,0.261812,1.62125,-2.26426,0.387235,1.65517,-2.11818,0.450561,1.65066,-2.09861,0.229406,1.4304,-1.845,0.049191,1.49778,-1.90215,0.053996,1.51611,-1.96771,0.055992,1.49256,-2.01803,0.233586,1.40091,-2.09627,0.36789,1.22958,-1.76666,0.271034,1.13055,-1.78292,0.328448,1.07128,-1.80499,0.43602,1.02988,-1.79829,0.41559,0.842472,-1.78963,0.39516,0.76963,-1.80221,0.310542,0.874132,-1.81698,0.290366,0.805279,-1.82486,0.280541,0.569709,-1.8393,0.181199,0.508741,-1.92177,0.43507,0.518564,-1.86677,0.401634,0.461452,-1.80126,0.086655,1.11843,-2.13367,0.054249,1.0414,-2.11489,-0.044538,1.17169,-2.10693,-0.073645,1.09538,-2.09215,-0.091762,0.947865,-2.09074,-0.163127,0.772482,-2.08596,-0.255114,0.83707,-2.09075,-0.291753,0.777266,-2.08162,-0.399308,0.564536,-2.05459,-0.491446,0.59031,-1.9797,-0.338529,0.378721,-2.02441,-0.411383,0.373505,-2.0736,0.14938,1.34626,-1.84244,0.140039,1.32828,-2.05672},
/*1735*/{0.203729,1.91204,-1.74532,0.308336,1.85803,-1.87229,0.046771,1.82991,-1.69446,-0.080841,1.76349,-1.67369,0.057247,1.68114,-1.69338,0.126544,1.62434,-1.68696,0.287031,1.94048,-2.11684,0.331544,1.85803,-1.94487,0.142267,1.88517,-2.06868,0.205066,1.7053,-2.24632,0.266264,1.62338,-2.26497,0.389232,1.65707,-2.1161,0.450424,1.65376,-2.09611,0.229177,1.4327,-1.84519,0.049268,1.50102,-1.90262,0.053856,1.51786,-1.9683,0.05728,1.4942,-2.01737,0.234235,1.40199,-2.09579,0.364979,1.22964,-1.76761,0.269678,1.13147,-1.78293,0.324422,1.07092,-1.80488,0.43145,1.02724,-1.79896,0.418931,0.838667,-1.78919,0.403195,0.765069,-1.80164,0.313142,0.864578,-1.81916,0.297209,0.794294,-1.82534,0.298448,0.558144,-1.84015,0.203505,0.492735,-1.92383,0.455802,0.515611,-1.86575,0.425014,0.457477,-1.8024,0.084794,1.12068,-2.13377,0.052062,1.04445,-2.11625,-0.046371,1.17464,-2.10493,-0.075307,1.09819,-2.09036,-0.093124,0.951138,-2.09024,-0.167562,0.776664,-2.08648,-0.258695,0.844372,-2.09085,-0.297385,0.78407,-2.08239,-0.404747,0.573647,-2.05626,-0.495841,0.607002,-1.98118,-0.357016,0.379074,-2.02386,-0.430325,0.383358,-2.07273,0.149226,1.34889,-1.84176,0.140249,1.32975,-2.05596},
/*1736*/{0.204451,1.91287,-1.74443,0.308202,1.85895,-1.87153,0.046964,1.83132,-1.69517,-0.08127,1.7644,-1.67511,0.056694,1.68197,-1.6936,0.127637,1.6248,-1.68528,0.28902,1.94153,-2.11605,0.332048,1.85889,-1.94411,0.143561,1.8866,-2.06907,0.209579,1.7081,-2.24716,0.268555,1.62446,-2.26522,0.38961,1.65941,-2.11552,0.45116,1.65591,-2.09371,0.229602,1.43443,-1.84517,0.049706,1.50384,-1.90291,0.054241,1.52064,-1.96805,0.058206,1.49737,-2.01726,0.234269,1.40409,-2.09566,0.362783,1.22817,-1.76773,0.266176,1.13105,-1.78299,0.320325,1.07048,-1.80345,0.426492,1.02397,-1.79873,0.42189,0.834007,-1.78882,0.410004,0.759983,-1.80126,0.314878,0.854196,-1.81992,0.302357,0.784273,-1.82719,0.317283,0.546369,-1.84064,0.224904,0.478035,-1.92532,0.475617,0.511996,-1.86571,0.447031,0.452102,-1.80258,0.083683,1.12338,-2.13428,0.051176,1.04613,-2.11677,-0.04688,1.17666,-2.10315,-0.075998,1.10049,-2.08928,-0.093084,0.953334,-2.08947,-0.171529,0.780624,-2.08682,-0.261934,0.848992,-2.09027,-0.300593,0.790127,-2.08276,-0.417079,0.582282,-2.05757,-0.499878,0.623575,-1.98361,-0.375552,0.376241,-2.02213,-0.450412,0.392896,-2.0715,0.148959,1.35108,-1.8419,0.139995,1.33233,-2.05613},
/*1737*/{0.205389,1.91383,-1.74401,0.3135,1.85712,-1.8695,0.046772,1.83241,-1.69715,-0.08036,1.76541,-1.67733,0.057096,1.68175,-1.69365,0.128445,1.62473,-1.68413,0.291563,1.94223,-2.11475,0.333329,1.8604,-1.94231,0.145175,1.88816,-2.06927,0.212818,1.70986,-2.2474,0.27184,1.62567,-2.26594,0.390346,1.66066,-2.11443,0.451178,1.65703,-2.09222,0.228955,1.43642,-1.84531,0.05035,1.50648,-1.9028,0.054718,1.5235,-1.96811,0.05761,1.49936,-2.0172,0.234591,1.40583,-2.09506,0.359421,1.22498,-1.76779,0.26177,1.13058,-1.78207,0.314911,1.06936,-1.80356,0.420706,1.01937,-1.79902,0.425255,0.82945,-1.78826,0.415965,0.753998,-1.8019,0.31665,0.843611,-1.82091,0.308472,0.771633,-1.82793,0.333535,0.535348,-1.84098,0.24638,0.464492,-1.92687,0.494524,0.50948,-1.86481,0.467294,0.447997,-1.80132,0.082989,1.12472,-2.13447,0.051547,1.0479,-2.1171,-0.047062,1.17823,-2.10138,-0.075105,1.10215,-2.08787,-0.092051,0.954939,-2.08894,-0.174917,0.783037,-2.08683,-0.26249,0.853952,-2.0909,-0.304163,0.796594,-2.08473,-0.42154,0.5917,-2.05843,-0.50339,0.637969,-1.98583,-0.398006,0.376582,-2.02068,-0.467064,0.403735,-2.06897,0.14842,1.35343,-1.84157,0.139614,1.33439,-2.05578},
/*1738*/{0.206217,1.91463,-1.74335,0.314753,1.85764,-1.86889,0.046921,1.83238,-1.69735,-0.079809,1.76484,-1.67844,0.057348,1.68123,-1.69414,0.128981,1.62451,-1.68389,0.293157,1.94266,-2.11395,0.333997,1.86059,-1.9418,0.146708,1.88988,-2.06953,0.215635,1.71122,-2.2473,0.274606,1.62645,-2.26664,0.390736,1.6608,-2.11362,0.452174,1.65681,-2.08988,0.226162,1.43909,-1.84526,0.050417,1.50861,-1.90232,0.055239,1.52606,-1.96853,0.058359,1.50217,-2.01657,0.234138,1.40765,-2.09539,0.358069,1.22163,-1.76693,0.255904,1.12972,-1.78271,0.310086,1.06702,-1.80421,0.414681,1.01493,-1.79792,0.425527,0.823555,-1.78862,0.423011,0.748376,-1.8024,0.317637,0.832869,-1.82027,0.312819,0.760795,-1.82751,0.349593,0.527464,-1.84211,0.266669,0.451322,-1.92927,0.511569,0.507197,-1.86391,0.4871,0.444462,-1.80102,0.083856,1.12699,-2.13457,0.051826,1.04898,-2.11768,-0.046178,1.17893,-2.10038,-0.073491,1.1024,-2.08609,-0.089784,0.955017,-2.08898,-0.176646,0.784334,-2.08716,-0.261982,0.859049,-2.09115,-0.305907,0.802482,-2.08352,-0.432391,0.600872,-2.05942,-0.50698,0.653525,-1.98856,-0.419438,0.387703,-2.01721,-0.485772,0.415335,-2.06715,0.146884,1.3556,-1.8415,0.138821,1.33678,-2.05576},
/*1739*/{0.207265,1.91531,-1.74263,0.315183,1.85868,-1.86795,0.047521,1.83229,-1.69773,-0.079099,1.76391,-1.67895,0.058738,1.68096,-1.69336,0.130504,1.6235,-1.68284,0.294443,1.94284,-2.11358,0.334677,1.86121,-1.94081,0.148201,1.89222,-2.07047,0.218681,1.7126,-2.24756,0.276365,1.62721,-2.267,0.391991,1.66111,-2.11346,0.452588,1.65651,-2.08875,0.229701,1.44086,-1.84496,0.049676,1.5098,-1.90212,0.054477,1.52783,-1.96811,0.05882,1.50364,-2.01592,0.234327,1.40978,-2.09527,0.352908,1.21786,-1.76823,0.251391,1.12592,-1.78234,0.303186,1.06334,-1.80429,0.409319,1.00938,-1.79758,0.427062,0.81762,-1.78906,0.427951,0.743603,-1.80316,0.317594,0.820859,-1.82038,0.316951,0.749874,-1.82778,0.365537,0.518525,-1.84285,0.286035,0.439142,-1.93107,0.52884,0.50508,-1.86212,0.505093,0.440774,-1.80097,0.085166,1.12766,-2.13437,0.05447,1.0502,-2.1184,-0.044746,1.17861,-2.09816,-0.072059,1.10202,-2.08568,-0.087304,0.95415,-2.089,-0.179227,0.785255,-2.08668,-0.261585,0.86188,-2.09109,-0.307123,0.807146,-2.08349,-0.441604,0.609458,-2.05973,-0.512578,0.668429,-1.99074,-0.437416,0.400561,-2.01259,-0.50255,0.428749,-2.06452,0.149026,1.35752,-1.84121,0.139817,1.33848,-2.0554},
/*1740*/{0.208216,1.91551,-1.7418,0.316303,1.85755,-1.86746,0.049333,1.8319,-1.69762,-0.078206,1.76247,-1.67984,0.060402,1.67984,-1.693,0.132151,1.62194,-1.68074,0.296175,1.94254,-2.11231,0.33549,1.86208,-1.93988,0.149483,1.8938,-2.07022,0.21941,1.71299,-2.24776,0.277163,1.62694,-2.26715,0.393309,1.65911,-2.11262,0.453647,1.65404,-2.0875,0.229086,1.44251,-1.84466,0.04818,1.51146,-1.90204,0.054156,1.52992,-1.96855,0.057839,1.50478,-2.01624,0.23447,1.41137,-2.09529,0.349167,1.21211,-1.7676,0.244793,1.12273,-1.78266,0.296039,1.05975,-1.80471,0.403202,1.00356,-1.79796,0.42874,0.812336,-1.78933,0.430646,0.736846,-1.80268,0.318357,0.810709,-1.81974,0.321467,0.738465,-1.82726,0.380738,0.509071,-1.8423,0.304615,0.428527,-1.93217,0.543816,0.503593,-1.86182,0.524562,0.438643,-1.80142,0.087117,1.12824,-2.13439,0.057881,1.04961,-2.11775,-0.042968,1.17841,-2.09726,-0.069154,1.10036,-2.08414,-0.084134,0.952707,-2.08909,-0.180098,0.785347,-2.08559,-0.25952,0.865971,-2.09205,-0.306764,0.812097,-2.08592,-0.44227,0.621414,-2.06079,-0.517304,0.68433,-1.99615,-0.45387,0.410107,-2.00844,-0.515499,0.441969,-2.06203,0.148218,1.35925,-1.84116,0.139566,1.34007,-2.05536},
/*1741*/{0.209213,1.91598,-1.74141,0.316297,1.85919,-1.86758,0.049651,1.83093,-1.69758,-0.07688,1.75951,-1.67978,0.06167,1.67722,-1.6925,0.133937,1.61956,-1.67929,0.298452,1.94194,-2.11194,0.335486,1.86219,-1.93968,0.150806,1.89487,-2.0704,0.219701,1.71386,-2.24725,0.277827,1.62661,-2.26773,0.394169,1.65704,-2.11186,0.45463,1.65135,-2.08677,0.230316,1.44401,-1.84483,0.048327,1.51247,-1.90179,0.053621,1.53134,-1.96869,0.057725,1.506,-2.01557,0.235428,1.41293,-2.09531,0.343262,1.20704,-1.76832,0.238341,1.11999,-1.78552,0.287562,1.05579,-1.80493,0.396376,0.996519,-1.79801,0.429373,0.806558,-1.78938,0.436046,0.73192,-1.80361,0.319628,0.800005,-1.81869,0.325579,0.72782,-1.82747,0.392724,0.503075,-1.84278,0.321595,0.418594,-1.93309,0.558315,0.50183,-1.86014,0.539676,0.437368,-1.80087,0.090383,1.12805,-2.13386,0.061003,1.04956,-2.11788,-0.040151,1.17642,-2.09651,-0.066292,1.09851,-2.08306,-0.079655,0.951053,-2.08878,-0.179976,0.785604,-2.08489,-0.258242,0.867899,-2.09203,-0.306377,0.817738,-2.08556,-0.452858,0.633126,-2.06122,-0.523513,0.699573,-1.99867,-0.469185,0.423309,-2.00343,-0.528314,0.455666,-2.05909,0.149316,1.36069,-1.8411,0.14034,1.34149,-2.05529},
/*1742*/{0.210541,1.916,-1.7408,0.316952,1.85919,-1.86732,0.05069,1.82884,-1.69607,-0.075638,1.75689,-1.68004,0.063986,1.67464,-1.69139,0.135973,1.61677,-1.67672,0.299669,1.94138,-2.11108,0.335835,1.86213,-1.93898,0.152252,1.89654,-2.07008,0.219849,1.71373,-2.24692,0.278168,1.62617,-2.26766,0.394055,1.65371,-2.11139,0.454646,1.64771,-2.08637,0.23125,1.4449,-1.84434,0.04829,1.5125,-1.90166,0.053551,1.53144,-1.96852,0.057418,1.50703,-2.01567,0.235382,1.41436,-2.09501,0.341154,1.20057,-1.76799,0.232769,1.11615,-1.78408,0.279149,1.05092,-1.80573,0.38958,0.989962,-1.79844,0.429855,0.801916,-1.78982,0.439416,0.726878,-1.80444,0.320568,0.790773,-1.81746,0.3297,0.718759,-1.82477,0.40561,0.497145,-1.84244,0.33683,0.409842,-1.93348,0.568991,0.500409,-1.86072,0.554254,0.433693,-1.80013,0.094004,1.12711,-2.13301,0.066039,1.04786,-2.1166,-0.036734,1.174,-2.09568,-0.062064,1.09574,-2.08189,-0.074251,0.948,-2.08857,-0.180592,0.785447,-2.08387,-0.253547,0.872489,-2.09397,-0.305064,0.82314,-2.08737,-0.456846,0.644056,-2.06178,-0.529444,0.715439,-2.00145,-0.481713,0.437561,-1.99955,-0.541708,0.469907,-2.05722,0.150028,1.36129,-1.84111,0.140974,1.34239,-2.05532},
/*1743*/{0.211521,1.91558,-1.73966,0.317225,1.85954,-1.86704,0.052063,1.82744,-1.69609,-0.073882,1.75331,-1.67961,0.066367,1.67223,-1.68957,0.138714,1.61409,-1.6757,0.300587,1.94021,-2.11005,0.3359,1.86205,-1.93883,0.15207,1.89775,-2.07011,0.219491,1.7135,-2.2468,0.277119,1.62524,-2.26768,0.394459,1.65175,-2.11137,0.454695,1.64306,-2.08497,0.228763,1.44606,-1.84446,0.04829,1.5125,-1.90166,0.053512,1.53161,-1.96834,0.057444,1.50711,-2.01564,0.235402,1.41511,-2.09506,0.335145,1.1933,-1.76797,0.224147,1.11234,-1.78531,0.270137,1.04511,-1.80732,0.381615,0.981865,-1.79845,0.430944,0.797309,-1.79082,0.442261,0.72352,-1.80602,0.321424,0.781644,-1.81558,0.332636,0.710689,-1.82425,0.416054,0.490485,-1.84294,0.348504,0.402458,-1.93357,0.580088,0.499497,-1.85988,0.566154,0.432988,-1.80201,0.098326,1.12589,-2.13236,0.071022,1.04645,-2.116,-0.034607,1.17175,-2.0955,-0.057834,1.09247,-2.08186,-0.068404,0.944652,-2.08836,-0.180344,0.785482,-2.08249,-0.249412,0.874974,-2.09496,-0.303563,0.828106,-2.08779,-0.460423,0.656343,-2.06117,-0.534585,0.730644,-2.00452,-0.494544,0.452346,-1.99446,-0.552757,0.484343,-2.05502,0.149237,1.36166,-1.84111,0.141041,1.34292,-2.05537},
/*1744*/{0.212973,1.91502,-1.73895,0.317624,1.85883,-1.86715,0.05267,1.82554,-1.69615,-0.070495,1.7499,-1.67868,0.068837,1.66836,-1.68806,0.140439,1.61081,-1.67294,0.300387,1.9387,-2.10927,0.335823,1.86141,-1.93857,0.15261,1.89805,-2.06937,0.218033,1.71194,-2.24561,0.27616,1.62376,-2.26697,0.394521,1.64743,-2.11076,0.454931,1.63778,-2.08516,0.227669,1.44593,-1.84441,0.04659,1.51133,-1.90313,0.053363,1.53158,-1.96819,0.057324,1.5066,-2.01568,0.236144,1.41606,-2.09444,0.329661,1.18681,-1.76796,0.219203,1.11179,-1.78676,0.262177,1.04044,-1.80854,0.373747,0.975246,-1.79963,0.430893,0.792549,-1.79166,0.442052,0.718046,-1.80747,0.321441,0.773353,-1.81499,0.33502,0.70286,-1.82475,0.424076,0.484512,-1.8424,0.359797,0.395999,-1.93324,0.587555,0.497907,-1.85998,0.57729,0.43076,-1.80004,0.102751,1.1238,-2.13112,0.076737,1.04441,-2.11469,-0.03065,1.16762,-2.09461,-0.053333,1.08872,-2.08199,-0.061987,0.941217,-2.08765,-0.180046,0.785892,-2.08068,-0.244373,0.877912,-2.09544,-0.301023,0.834381,-2.08834,-0.465853,0.668971,-2.06076,-0.538434,0.746613,-2.0081,-0.506296,0.466705,-1.99087,-0.560385,0.499801,-2.05258,0.148492,1.36105,-1.84161,0.141932,1.34324,-2.05601},
/*1745*/{0.213694,1.91415,-1.73811,0.31744,1.85744,-1.86677,0.053697,1.82219,-1.69513,-0.06824,1.74556,-1.67773,0.071571,1.66444,-1.68557,0.143333,1.60686,-1.67067,0.300405,1.93705,-2.10876,0.336111,1.86085,-1.93801,0.15309,1.89795,-2.06913,0.215611,1.71087,-2.24487,0.273963,1.62274,-2.2661,0.395701,1.64212,-2.11063,0.455235,1.63253,-2.08533,0.227669,1.44593,-1.84441,0.046924,1.50899,-1.90264,0.053363,1.53158,-1.96819,0.057689,1.5061,-2.01545,0.236947,1.41682,-2.09408,0.324043,1.17926,-1.76789,0.20874,1.10679,-1.78851,0.253357,1.03555,-1.81035,0.365445,0.96811,-1.79999,0.429896,0.788682,-1.79302,0.444607,0.715241,-1.80795,0.321168,0.766562,-1.81359,0.33596,0.696581,-1.8209,0.431192,0.480067,-1.842,0.368306,0.389427,-1.93219,0.596459,0.49875,-1.86049,0.585706,0.428714,-1.80217,0.107822,1.12194,-2.13001,0.083134,1.04084,-2.11353,-0.026396,1.16299,-2.09497,-0.047994,1.08433,-2.08191,-0.054712,0.937265,-2.08713,-0.178711,0.787015,-2.07935,-0.239889,0.881456,-2.09624,-0.297118,0.840225,-2.08881,-0.468802,0.682691,-2.05982,-0.540807,0.76244,-2.00888,-0.516534,0.482471,-1.98813,-0.569967,0.515579,-2.05157,0.149309,1.3602,-1.84193,0.143289,1.34337,-2.05642},
/*1746*/{0.214659,1.9124,-1.73751,0.317097,1.8571,-1.86632,0.056096,1.81928,-1.6936,-0.06475,1.74101,-1.67594,0.075014,1.66049,-1.68372,0.147252,1.60312,-1.66817,0.301102,1.93509,-2.10811,0.33542,1.85921,-1.93783,0.152868,1.89806,-2.06869,0.213065,1.71012,-2.24331,0.271709,1.62088,-2.26554,0.396067,1.63675,-2.11094,0.454554,1.62557,-2.08502,0.227669,1.44593,-1.84441,0.046806,1.50752,-1.90312,0.053276,1.53094,-1.96837,0.057417,1.50459,-2.01566,0.23728,1.4164,-2.09427,0.318807,1.17231,-1.76781,0.202382,1.0996,-1.78974,0.245135,1.03043,-1.81213,0.356635,0.960059,-1.8004,0.427048,0.784912,-1.79363,0.444864,0.711351,-1.80799,0.318536,0.759319,-1.81442,0.33571,0.689492,-1.82085,0.435285,0.475355,-1.84126,0.374539,0.383836,-1.93048,0.600814,0.496883,-1.86099,0.592517,0.427057,-1.80177,0.112955,1.11926,-2.1286,0.089968,1.03796,-2.11219,-0.02253,1.15855,-2.09554,-0.042563,1.07848,-2.08148,-0.047365,0.932822,-2.08633,-0.177623,0.788188,-2.07848,-0.235105,0.884473,-2.09631,-0.29363,0.845973,-2.08833,-0.471301,0.696726,-2.05948,-0.54112,0.779145,-2.00976,-0.526076,0.498662,-1.98563,-0.575735,0.532483,-2.04983,0.14987,1.35972,-1.84193,0.144014,1.34252,-2.0564},
/*1747*/{0.215753,1.91041,-1.73661,0.317279,1.85642,-1.86636,0.057032,1.815,-1.69169,-0.062619,1.73557,-1.67435,0.077377,1.65563,-1.6814,0.150346,1.59871,-1.66538,0.299359,1.93232,-2.10745,0.334589,1.85786,-1.93753,0.15252,1.89782,-2.06798,0.208832,1.70818,-2.24224,0.268119,1.61927,-2.26432,0.395036,1.63022,-2.11082,0.454131,1.61838,-2.08591,0.228359,1.44572,-1.84401,0.046335,1.50562,-1.9043,0.053556,1.5288,-1.96823,0.058089,1.50249,-2.01564,0.238505,1.4158,-2.0939,0.313072,1.16477,-1.76754,0.195763,1.09555,-1.79131,0.236921,1.02599,-1.81397,0.347569,0.953613,-1.80119,0.424014,0.780718,-1.79393,0.442859,0.707746,-1.80858,0.315658,0.753409,-1.81439,0.333504,0.684252,-1.82132,0.439479,0.469895,-1.84038,0.378427,0.378409,-1.92962,0.602704,0.494047,-1.86174,0.597096,0.425137,-1.80289,0.118372,1.11564,-2.12723,0.096935,1.03471,-2.11063,-0.017214,1.1529,-2.09582,-0.036277,1.07274,-2.08199,-0.039764,0.928148,-2.08576,-0.175558,0.789085,-2.07734,-0.228364,0.887931,-2.09649,-0.28951,0.851478,-2.08764,-0.473072,0.70995,-2.05866,-0.540345,0.79603,-2.01058,-0.534014,0.515145,-1.98525,-0.584439,0.550117,-2.04978,0.151111,1.35882,-1.84166,0.14601,1.34112,-2.05611},
/*1748*/{0.216388,1.90815,-1.73561,0.317698,1.85303,-1.86588,0.05868,1.8109,-1.69023,-0.058532,1.73013,-1.6712,0.080286,1.65011,-1.67812,0.153346,1.59413,-1.66249,0.299721,1.93066,-2.10695,0.334338,1.856,-1.93758,0.151486,1.89651,-2.06689,0.205334,1.70692,-2.24108,0.264532,1.61721,-2.2637,0.394463,1.62491,-2.11219,0.452983,1.61068,-2.08697,0.227324,1.44341,-1.84376,0.045724,1.50328,-1.90442,0.052754,1.52711,-1.96838,0.058116,1.50034,-2.01565,0.23914,1.41477,-2.09316,0.307603,1.15771,-1.76701,0.188201,1.09398,-1.79318,0.23006,1.02017,-1.81466,0.338624,0.946287,-1.80171,0.41972,0.776423,-1.79434,0.438923,0.703797,-1.808,0.312061,0.747828,-1.81488,0.33112,0.678988,-1.822,0.440885,0.465272,-1.84002,0.380431,0.373371,-1.92874,0.603004,0.489608,-1.86335,0.5978,0.422737,-1.80527,0.124694,1.1124,-2.12615,0.104627,1.03119,-2.10981,-0.012047,1.14721,-2.09594,-0.029914,1.06653,-2.08172,-0.031571,0.92347,-2.08575,-0.173296,0.790708,-2.07817,-0.222434,0.890843,-2.09547,-0.284481,0.856881,-2.08708,-0.4746,0.723064,-2.06404,-0.537467,0.812546,-2.00996,-0.542355,0.531815,-1.98521,-0.591356,0.568599,-2.04997,0.150319,1.35642,-1.84192,0.146498,1.33968,-2.05646},
/*1749*/{0.217101,1.90539,-1.73527,0.31788,1.85203,-1.86603,0.060369,1.80618,-1.68781,-0.057207,1.72374,-1.66847,0.083803,1.64416,-1.67534,0.156873,1.58959,-1.65976,0.297708,1.9274,-2.1068,0.33391,1.85437,-1.93756,0.151214,1.89497,-2.06556,0.201809,1.70512,-2.23958,0.261672,1.61527,-2.26245,0.39272,1.61707,-2.11302,0.45181,1.60229,-2.08857,0.224573,1.44055,-1.84369,0.045864,1.5004,-1.904,0.053325,1.52414,-1.96858,0.058179,1.4975,-2.0169,0.239934,1.41362,-2.09276,0.304241,1.15158,-1.76587,0.184119,1.08896,-1.79291,0.223506,1.01581,-1.81739,0.331988,0.940061,-1.80246,0.413691,0.771637,-1.79417,0.43532,0.700023,-1.80781,0.307304,0.74258,-1.8158,0.328434,0.673475,-1.82229,0.438408,0.46152,-1.84047,0.379893,0.367984,-1.92861,0.602992,0.486499,-1.86442,0.600784,0.419489,-1.80518,0.130802,1.10895,-2.12554,0.111224,1.02737,-2.10881,-0.007273,1.14167,-2.09789,-0.022904,1.06069,-2.08159,-0.023998,0.917502,-2.08646,-0.170091,0.790786,-2.07584,-0.214562,0.894066,-2.09497,-0.278858,0.862402,-2.08616,-0.471658,0.737426,-2.05794,-0.531339,0.828749,-2.00851,-0.54866,0.548329,-1.98579,-0.596397,0.588475,-2.05051,0.149125,1.35305,-1.84265,0.147265,1.33781,-2.05734},
/*1750*/{0.217496,1.9029,-1.73433,0.317356,1.85052,-1.86644,0.061819,1.80158,-1.68519,-0.053074,1.71774,-1.66495,0.087462,1.63926,-1.67193,0.161582,1.58504,-1.65674,0.296681,1.92483,-2.10702,0.332693,1.85149,-1.93724,0.149449,1.89254,-2.06452,0.195729,1.7027,-2.23814,0.256386,1.61249,-2.26144,0.391102,1.61078,-2.11451,0.450557,1.59405,-2.0914,0.225845,1.43826,-1.84262,0.045807,1.49765,-1.9044,0.052956,1.52116,-1.96909,0.058791,1.49525,-2.01769,0.241442,1.41164,-2.0918,0.298982,1.14523,-1.76454,0.177815,1.08442,-1.79467,0.218516,1.01185,-1.81851,0.326224,0.934696,-1.80265,0.409181,0.767264,-1.79408,0.430218,0.694607,-1.80738,0.302734,0.736734,-1.81658,0.323545,0.668348,-1.82428,0.437504,0.457879,-1.84088,0.37656,0.363322,-1.92853,0.600143,0.480471,-1.86487,0.595608,0.412781,-1.80543,0.13668,1.10524,-2.12474,0.118565,1.02301,-2.10763,-0.002489,1.13421,-2.09799,-0.016787,1.054,-2.08162,-0.015877,0.91304,-2.0844,-0.166571,0.79198,-2.07548,-0.207329,0.896441,-2.09429,-0.271538,0.868459,-2.086,-0.473583,0.752789,-2.05988,-0.526635,0.845139,-2.00738,-0.555586,0.564393,-1.98685,-0.601315,0.606946,-2.04953,0.149732,1.35073,-1.84246,0.14902,1.33547,-2.05715},
/*1751*/{0.218724,1.8994,-1.73347,0.315677,1.84712,-1.86612,0.063904,1.79608,-1.68294,-0.050046,1.71133,-1.66168,0.091035,1.63249,-1.66828,0.165454,1.57979,-1.65392,0.294362,1.92179,-2.10775,0.332195,1.84904,-1.937,0.148506,1.88957,-2.0628,0.191495,1.70037,-2.23658,0.252557,1.60965,-2.26082,0.388461,1.60256,-2.11589,0.448155,1.58417,-2.09336,0.223756,1.43448,-1.84187,0.046074,1.49401,-1.90401,0.054104,1.51779,-1.96933,0.058956,1.49104,-2.01748,0.242842,1.40965,-2.09031,0.296017,1.13956,-1.76395,0.174391,1.08166,-1.79566,0.214491,1.00757,-1.82058,0.322408,0.930722,-1.80192,0.404179,0.761441,-1.79369,0.423422,0.690234,-1.80798,0.297265,0.731054,-1.81714,0.31866,0.660801,-1.82487,0.433074,0.450785,-1.84094,0.372401,0.358161,-1.92921,0.596104,0.475078,-1.86541,0.592976,0.407886,-1.80705,0.142136,1.10101,-2.12426,0.126085,1.0188,-2.10677,0.003148,1.12785,-2.09825,-0.009879,1.04749,-2.08247,-0.007646,0.906468,-2.0829,-0.161686,0.793105,-2.07545,-0.198488,0.899928,-2.09502,-0.263946,0.873445,-2.08488,-0.471569,0.768184,-2.06023,-0.519238,0.860362,-2.00593,-0.560457,0.580661,-1.98862,-0.603668,0.627113,-2.05056,0.14894,1.34672,-1.84236,0.150347,1.33262,-2.05712},
/*1752*/{0.219112,1.89555,-1.73263,0.316907,1.84399,-1.86635,0.065775,1.79033,-1.68049,-0.046132,1.70452,-1.65788,0.094956,1.62751,-1.66451,0.169862,1.57495,-1.65099,0.292192,1.91863,-2.10787,0.33166,1.84628,-1.93704,0.146557,1.88648,-2.06168,0.185379,1.69773,-2.23531,0.247673,1.60666,-2.26044,0.386097,1.59452,-2.1177,0.446427,1.57384,-2.0967,0.223635,1.43041,-1.84013,0.045552,1.49032,-1.90419,0.054327,1.51501,-1.96919,0.058972,1.48778,-2.01881,0.243427,1.40749,-2.08913,0.29318,1.13459,-1.76322,0.172182,1.07684,-1.79644,0.210205,1.00295,-1.82132,0.319524,0.927473,-1.80129,0.397871,0.756528,-1.79419,0.419497,0.684031,-1.80813,0.291296,0.725031,-1.81814,0.312618,0.656679,-1.82468,0.426951,0.446204,-1.84262,0.366108,0.353499,-1.93147,0.590308,0.468394,-1.86586,0.586798,0.399913,-1.80783,0.147682,1.09673,-2.12504,0.133546,1.0144,-2.10604,0.007571,1.12094,-2.09845,-0.003776,1.04071,-2.08242,0.000963,0.901287,-2.08231,-0.156145,0.794145,-2.07527,-0.189787,0.902374,-2.0951,-0.255273,0.877851,-2.0843,-0.462748,0.778378,-2.05835,-0.511296,0.875307,-2.00388,-0.562912,0.597159,-1.99081,-0.604988,0.646208,-2.05223,0.148105,1.3429,-1.84251,0.151242,1.32994,-2.05734},
/*1753*/{0.219213,1.89142,-1.73226,0.309819,1.84362,-1.86861,0.067423,1.78413,-1.67765,-0.042149,1.69674,-1.65284,0.098888,1.62134,-1.66109,0.173911,1.57013,-1.6484,0.290395,1.91467,-2.10891,0.330274,1.84379,-1.93733,0.144744,1.88242,-2.0608,0.181401,1.69438,-2.2337,0.242678,1.60268,-2.26013,0.382232,1.58549,-2.12047,0.442943,1.56335,-2.09976,0.222887,1.42671,-1.83873,0.045185,1.48653,-1.90472,0.053627,1.51139,-1.969,0.059248,1.4837,-2.01883,0.244374,1.4043,-2.08836,0.290776,1.13035,-1.762,0.169129,1.07136,-1.79681,0.208451,0.998579,-1.82158,0.317398,0.924186,-1.80053,0.392758,0.749928,-1.79381,0.413597,0.676882,-1.80837,0.285705,0.720091,-1.81894,0.30705,0.650174,-1.82462,0.419531,0.441129,-1.8436,0.357728,0.348168,-1.93256,0.584296,0.461997,-1.86766,0.577716,0.391685,-1.80918,0.153773,1.09255,-2.12488,0.14005,1.00974,-2.10599,0.013095,1.11384,-2.09941,0.0028,1.03346,-2.08226,0.008736,0.895961,-2.08192,-0.15055,0.794652,-2.07513,-0.180002,0.903667,-2.09316,-0.246999,0.882361,-2.08585,-0.461848,0.79487,-2.06073,-0.502452,0.888954,-2.00256,-0.563125,0.612376,-1.99371,-0.606903,0.66431,-2.05326,0.147501,1.33915,-1.84214,0.152112,1.32644,-2.05695},
/*1754*/{0.219903,1.88652,-1.73075,0.309062,1.83965,-1.86835,0.070153,1.77758,-1.67474,-0.039483,1.68909,-1.64806,0.103283,1.61558,-1.6574,0.180097,1.56573,-1.64672,0.288377,1.91107,-2.10939,0.329661,1.84061,-1.93745,0.143288,1.87797,-2.05864,0.175962,1.69108,-2.23304,0.23704,1.59882,-2.25923,0.378797,1.57579,-2.12191,0.439952,1.55215,-2.10408,0.22278,1.4222,-1.83811,0.046303,1.48295,-1.90454,0.053453,1.50789,-1.96915,0.060431,1.48012,-2.01897,0.245603,1.40147,-2.08631,0.288076,1.12648,-1.76196,0.167318,1.06922,-1.79747,0.204554,0.994428,-1.82123,0.315266,0.920848,-1.80082,0.38696,0.743211,-1.79459,0.406466,0.672147,-1.80962,0.280064,0.714503,-1.81896,0.29964,0.645198,-1.82556,0.408946,0.435532,-1.84648,0.345279,0.348901,-1.93435,0.576011,0.454216,-1.86862,0.568053,0.382371,-1.81085,0.158863,1.08807,-2.12448,0.14766,1.00565,-2.1053,0.018514,1.10691,-2.10008,0.009352,1.02639,-2.0822,0.01728,0.890198,-2.08135,-0.145273,0.795066,-2.07642,-0.169551,0.905536,-2.09182,-0.237809,0.884565,-2.08389,-0.454112,0.807153,-2.06049,-0.491695,0.901718,-2.00116,-0.562332,0.627149,-1.99581,-0.605142,0.682114,-2.05472,0.147223,1.33501,-1.84201,0.153371,1.32324,-2.05683},
/*1755*/{0.219892,1.882,-1.7306,0.314993,1.8345,-1.86678,0.072536,1.77043,-1.67115,-0.035607,1.6812,-1.64317,0.107557,1.60983,-1.65278,0.184857,1.5607,-1.64313,0.286173,1.90699,-2.10999,0.32983,1.83621,-1.93723,0.141159,1.87283,-2.0572,0.169908,1.68723,-2.23187,0.231298,1.59486,-2.25894,0.376777,1.56736,-2.12558,0.436228,1.54017,-2.10781,0.222396,1.41778,-1.83584,0.044653,1.47851,-1.90485,0.053296,1.50369,-1.96857,0.061366,1.47593,-2.01952,0.246332,1.39816,-2.08567,0.28624,1.1212,-1.7616,0.164183,1.06695,-1.79874,0.201484,0.992044,-1.82089,0.312724,0.916492,-1.8011,0.379965,0.736549,-1.79538,0.398516,0.663169,-1.80963,0.272704,0.709137,-1.81889,0.292275,0.639702,-1.82709,0.397904,0.43164,-1.84602,0.327467,0.352932,-1.93432,0.56316,0.441988,-1.87108,0.553134,0.372607,-1.81182,0.164291,1.08471,-2.12429,0.154812,1.00139,-2.10548,0.022993,1.10007,-2.09981,0.016562,1.01913,-2.08219,0.026254,0.884504,-2.08156,-0.138597,0.795296,-2.07488,-0.158832,0.905219,-2.08934,-0.227866,0.88953,-2.08354,-0.446222,0.818525,-2.06106,-0.481352,0.913148,-2.00003,-0.559469,0.641453,-1.99818,-0.602853,0.701222,-2.0606,0.146442,1.33051,-1.84177,0.154457,1.31956,-2.05657},
/*1756*/{0.220572,1.87749,-1.72917,0.315026,1.82912,-1.86689,0.075234,1.76349,-1.66751,-0.032332,1.67249,-1.63776,0.112429,1.60336,-1.64895,0.190737,1.55581,-1.64042,0.283786,1.90256,-2.11101,0.329894,1.83289,-1.93731,0.139871,1.86836,-2.05638,0.166004,1.68202,-2.23017,0.225437,1.59033,-2.25886,0.371788,1.55613,-2.12878,0.431424,1.52815,-2.11203,0.221248,1.41275,-1.83388,0.044328,1.47334,-1.90588,0.052522,1.499,-1.96829,0.060205,1.47022,-2.02013,0.246014,1.39366,-2.08522,0.283612,1.1173,-1.76103,0.163387,1.06382,-1.79831,0.198059,0.98811,-1.82004,0.309367,0.911347,-1.80083,0.373667,0.729714,-1.79545,0.391135,0.656213,-1.81029,0.265653,0.703751,-1.81932,0.284731,0.63402,-1.82688,0.384764,0.427239,-1.84774,0.310713,0.35231,-1.93731,0.550666,0.428861,-1.87217,0.533445,0.35973,-1.81363,0.169631,1.07987,-2.12403,0.16161,0.996475,-2.10596,0.028211,1.09307,-2.09988,0.023152,1.01203,-2.08263,0.034312,0.878773,-2.08166,-0.131382,0.794707,-2.07591,-0.148806,0.907698,-2.09096,-0.217557,0.892268,-2.08528,-0.434859,0.825467,-2.05853,-0.470109,0.923823,-1.99939,-0.553503,0.654959,-2.00062,-0.594653,0.713115,-2.05856,0.145311,1.32556,-1.84141,0.154442,1.31456,-2.05617},
/*1757*/{0.221224,1.87214,-1.72849,0.314971,1.82562,-1.86707,0.078157,1.75605,-1.6641,-0.028644,1.66378,-1.63199,0.117881,1.59601,-1.64488,0.196029,1.55073,-1.63822,0.281384,1.89773,-2.11183,0.328583,1.82917,-1.93768,0.137715,1.86316,-2.05472,0.160436,1.67728,-2.2294,0.218868,1.58655,-2.25882,0.366885,1.54583,-2.13162,0.426541,1.51523,-2.11703,0.221503,1.40885,-1.8323,0.043846,1.46904,-1.90523,0.053057,1.49475,-1.96726,0.060188,1.46536,-2.021,0.246873,1.39103,-2.08349,0.281817,1.11408,-1.76245,0.158227,1.06072,-1.80019,0.196138,0.98383,-1.8195,0.30487,0.904976,-1.79968,0.365772,0.723134,-1.79653,0.382844,0.649592,-1.81099,0.257662,0.698007,-1.82025,0.273759,0.62934,-1.82678,0.370364,0.420991,-1.84944,0.291645,0.355576,-1.93876,0.537235,0.414123,-1.87442,0.51555,0.347746,-1.81536,0.17543,1.07548,-2.12386,0.169108,0.992082,-2.10631,0.033595,1.08594,-2.10014,0.029281,1.00508,-2.08191,0.044104,0.872948,-2.0821,-0.123776,0.795062,-2.07648,-0.137443,0.908201,-2.08999,-0.205989,0.894451,-2.08371,-0.429391,0.838816,-2.06074,-0.458479,0.934176,-1.99862,-0.549389,0.664652,-2.0032,-0.591003,0.730657,-2.06362,0.145701,1.32148,-1.84072,0.156041,1.31095,-2.05545},
/*1758*/{0.221437,1.86637,-1.72769,0.313935,1.82101,-1.8666,0.081394,1.74798,-1.66041,-0.024273,1.65499,-1.62581,0.124434,1.59034,-1.64098,0.20252,1.54663,-1.63573,0.279319,1.89339,-2.11278,0.32912,1.82479,-1.93759,0.136208,1.85712,-2.05298,0.155951,1.67361,-2.22924,0.212335,1.58191,-2.25921,0.361452,1.53483,-2.13523,0.420641,1.50306,-2.12173,0.220269,1.40413,-1.83068,0.043194,1.46415,-1.90598,0.051199,1.48941,-1.96738,0.059915,1.46102,-2.02137,0.247211,1.38725,-2.08237,0.280646,1.11007,-1.76023,0.157265,1.05774,-1.79908,0.1932,0.98102,-1.81878,0.299903,0.898872,-1.79906,0.357856,0.716805,-1.79726,0.372807,0.643005,-1.81221,0.249365,0.69551,-1.82118,0.264391,0.626527,-1.82905,0.353813,0.416366,-1.85066,0.270606,0.35492,-1.93821,0.520477,0.401517,-1.87697,0.49787,0.337026,-1.81603,0.181669,1.07111,-2.12416,0.176825,0.987317,-2.10658,0.039577,1.07884,-2.09982,0.036765,0.997888,-2.08232,0.053437,0.867531,-2.08231,-0.115052,0.794877,-2.07691,-0.126216,0.90801,-2.08955,-0.194219,0.894829,-2.08411,-0.418919,0.846568,-2.0607,-0.44788,0.942652,-1.99869,-0.543343,0.675908,-2.00644,-0.577664,0.735431,-2.06433,0.144529,1.31665,-1.84056,0.156649,1.30671,-2.05523},
/*1759*/{0.222139,1.86112,-1.72653,0.314253,1.81631,-1.86673,0.084783,1.74035,-1.65679,-0.018586,1.64633,-1.62053,0.128921,1.58396,-1.63817,0.209177,1.54184,-1.63294,0.27673,1.88852,-2.11411,0.328125,1.82025,-1.93806,0.134283,1.85175,-2.05232,0.150212,1.66906,-2.22884,0.205558,1.57727,-2.26021,0.356042,1.52411,-2.13918,0.414305,1.49034,-2.12664,0.219658,1.39957,-1.8288,0.040931,1.45967,-1.90616,0.050762,1.4845,-1.96779,0.058739,1.45618,-2.02162,0.247147,1.38352,-2.08117,0.277989,1.10616,-1.75961,0.155796,1.05405,-1.79867,0.192385,0.977593,-1.81801,0.293269,0.892908,-1.79793,0.349657,0.710548,-1.79842,0.36269,0.637144,-1.81367,0.239879,0.694235,-1.82173,0.252485,0.623593,-1.83226,0.336529,0.416488,-1.85287,0.249037,0.35612,-1.9366,0.502575,0.394956,-1.8845,0.476451,0.338463,-1.81851,0.188577,1.06538,-2.12374,0.183931,0.982629,-2.10699,0.045833,1.07122,-2.09891,0.04515,0.991126,-2.08192,0.063556,0.86166,-2.08277,-0.106534,0.794424,-2.07774,-0.115027,0.907696,-2.08838,-0.182026,0.895401,-2.08348,-0.411134,0.854961,-2.05943,-0.435494,0.950783,-1.99884,-0.534296,0.684336,-2.00757,-0.568367,0.74575,-2.06523,0.143388,1.3122,-1.84003,0.156921,1.30237,-2.05461},
/*1760*/{0.222933,1.85582,-1.72534,0.315007,1.81031,-1.86656,0.088438,1.73166,-1.65311,-0.013775,1.63763,-1.61403,0.135668,1.57795,-1.63342,0.216338,1.53741,-1.62964,0.275306,1.88408,-2.11507,0.328801,1.81608,-1.93851,0.133419,1.84596,-2.05053,0.143996,1.66405,-2.22862,0.198556,1.57249,-2.26084,0.350829,1.51394,-2.14323,0.406623,1.4774,-2.13196,0.217171,1.39502,-1.82783,0.03838,1.45573,-1.90663,0.048545,1.47971,-1.96885,0.057384,1.45149,-2.02261,0.24703,1.37948,-2.07949,0.274979,1.10461,-1.75797,0.154684,1.05261,-1.79645,0.18954,0.975648,-1.81752,0.286618,0.886467,-1.79828,0.341599,0.707346,-1.79932,0.351767,0.634213,-1.81551,0.232052,0.696247,-1.82148,0.241462,0.62622,-1.83224,0.318323,0.416298,-1.85649,0.227517,0.356181,-1.93821,0.480279,0.392811,-1.88887,0.45515,0.338953,-1.81934,0.193536,1.06214,-2.12363,0.191421,0.978817,-2.1069,0.051415,1.06494,-2.0988,0.052374,0.983652,-2.08193,0.073535,0.855572,-2.08292,-0.096466,0.793874,-2.07823,-0.10223,0.907628,-2.08939,-0.170983,0.898683,-2.08033,-0.396472,0.861413,-2.06168,-0.423802,0.956755,-1.99761,-0.524069,0.6927,-2.01109,-0.55733,0.753525,-2.06746,0.140692,1.30787,-1.83977,0.156489,1.29804,-2.0542},
/*1761*/{0.22397,1.85057,-1.72414,0.315488,1.80445,-1.86561,0.093309,1.72342,-1.64877,-0.005785,1.62909,-1.6082,0.143114,1.57264,-1.62963,0.223498,1.53331,-1.62719,0.273772,1.87976,-2.11631,0.329253,1.8111,-1.93854,0.131977,1.84163,-2.04879,0.139683,1.6601,-2.22816,0.191144,1.56781,-2.26107,0.344033,1.50301,-2.14758,0.399766,1.4659,-2.13733,0.21435,1.39098,-1.82665,0.034347,1.45211,-1.90796,0.045633,1.47468,-1.97045,0.056259,1.44676,-2.0227,0.246792,1.37548,-2.07895,0.272345,1.10451,-1.75469,0.149851,1.05094,-1.7961,0.188352,0.976027,-1.81766,0.280382,0.88228,-1.7988,0.334256,0.709268,-1.80028,0.335514,0.632122,-1.82085,0.224784,0.70077,-1.82121,0.231274,0.62982,-1.83165,0.297994,0.419752,-1.85917,0.204928,0.357597,-1.93981,0.45908,0.39118,-1.89198,0.431155,0.339746,-1.82051,0.198686,1.05852,-2.12338,0.198298,0.974464,-2.10613,0.055656,1.05833,-2.09869,0.059112,0.976312,-2.08059,0.083245,0.84852,-2.08353,-0.086304,0.79283,-2.07899,-0.088821,0.906965,-2.08737,-0.15899,0.89972,-2.08006,-0.384871,0.86655,-2.06222,-0.411069,0.963236,-1.9978,-0.51373,0.698125,-2.01384,-0.545365,0.759762,-2.07051,0.137753,1.30387,-1.83963,0.155863,1.29377,-2.05386},
/*1762*/{0.225076,1.84636,-1.72297,0.316346,1.7994,-1.86545,0.097593,1.71471,-1.64511,-0.000168,1.61992,-1.60168,0.14974,1.56737,-1.6274,0.2309,1.52946,-1.62511,0.27167,1.87583,-2.11738,0.329865,1.80717,-1.93877,0.130665,1.83864,-2.04575,0.134386,1.65579,-2.22841,0.183588,1.56339,-2.2619,0.337389,1.49265,-2.15193,0.39172,1.45454,-2.1426,0.211615,1.38718,-1.8253,0.030284,1.44878,-1.90948,0.042677,1.46967,-1.97155,0.052687,1.44248,-2.02481,0.243967,1.37157,-2.07821,0.265926,1.10648,-1.75444,0.147369,1.05183,-1.79455,0.185571,0.977656,-1.81733,0.277089,0.883995,-1.79722,0.329968,0.710968,-1.80017,0.322911,0.631025,-1.82192,0.218338,0.70659,-1.82054,0.223038,0.636931,-1.83144,0.278029,0.420462,-1.85995,0.183596,0.358619,-1.94094,0.436951,0.391159,-1.89195,0.408889,0.338544,-1.81999,0.20434,1.05468,-2.12253,0.205503,0.97141,-2.10604,0.060924,1.05003,-2.09821,0.066372,0.969515,-2.08022,0.093969,0.841652,-2.08408,-0.074994,0.792482,-2.08128,-0.075886,0.905775,-2.08833,-0.146177,0.89986,-2.07998,-0.372307,0.871834,-2.06346,-0.398253,0.966663,-1.99865,-0.501077,0.702996,-2.01677,-0.533291,0.764623,-2.07339,0.134103,1.30036,-1.83953,0.153545,1.28941,-2.05361},
/*1763*/{0.226049,1.84255,-1.72158,0.316106,1.79553,-1.86533,0.103324,1.70661,-1.64148,0.007283,1.61133,-1.59548,0.157388,1.56208,-1.62394,0.238548,1.52672,-1.62319,0.271073,1.87278,-2.11912,0.330187,1.8033,-1.93928,0.129666,1.83712,-2.043,0.130318,1.6526,-2.22799,0.175804,1.55931,-2.26213,0.329767,1.48406,-2.15662,0.383801,1.44421,-2.14746,0.208606,1.38501,-1.82353,0.026708,1.44569,-1.91131,0.03981,1.46669,-1.97259,0.049708,1.43815,-2.0259,0.242512,1.36788,-2.07668,0.267071,1.10742,-1.75038,0.147229,1.05105,-1.79411,0.185245,0.978254,-1.81582,0.277546,0.88946,-1.7954,0.323228,0.711064,-1.79971,0.315097,0.632369,-1.82083,0.212323,0.711666,-1.81876,0.213573,0.64169,-1.83037,0.257549,0.422519,-1.86062,0.16102,0.359684,-1.94131,0.416252,0.389602,-1.89072,0.387833,0.338887,-1.82046,0.209072,1.05326,-2.12211,0.213756,0.969948,-2.10487,0.066624,1.0435,-2.09699,0.074064,0.963844,-2.07959,0.104633,0.834122,-2.08247,-0.061751,0.79066,-2.07854,-0.061198,0.906062,-2.08792,-0.131222,0.89889,-2.08072,-0.358445,0.87486,-2.06416,-0.386433,0.971469,-2.00004,-0.488064,0.706027,-2.0202,-0.519171,0.767967,-2.075,0.13067,1.2982,-1.83847,0.152062,1.28553,-2.05227},
/*1764*/{0.226804,1.83917,-1.72061,0.316303,1.79152,-1.86493,0.109843,1.6997,-1.63839,0.016917,1.60318,-1.58916,0.165692,1.55769,-1.62044,0.247965,1.5244,-1.62153,0.271048,1.8697,-2.12066,0.330984,1.79918,-1.94029,0.129157,1.83691,-2.04142,0.126559,1.65003,-2.22808,0.168939,1.55578,-2.26173,0.321796,1.47459,-2.15979,0.373928,1.43517,-2.153,0.205569,1.38439,-1.82141,0.022266,1.44285,-1.91441,0.037137,1.46354,-1.97414,0.045702,1.43397,-2.02864,0.243521,1.3642,-2.07214,0.265259,1.11026,-1.74606,0.145207,1.05402,-1.79448,0.183674,0.979201,-1.8146,0.281368,0.89532,-1.79267,0.316176,0.711454,-1.7989,0.312931,0.636058,-1.81634,0.203303,0.715436,-1.81706,0.202413,0.644704,-1.82851,0.237393,0.423833,-1.86047,0.14007,0.360679,-1.94089,0.395031,0.388962,-1.89077,0.365598,0.336442,-1.81831,0.213502,1.05364,-2.12103,0.220604,0.97057,-2.10422,0.071498,1.03983,-2.09728,0.080823,0.959034,-2.07929,0.115601,0.830972,-2.08189,-0.049637,0.790783,-2.07747,-0.046699,0.901389,-2.08778,-0.117472,0.89858,-2.08151,-0.343613,0.877357,-2.06561,-0.373587,0.973308,-2.00035,-0.472972,0.70836,-2.02182,-0.504175,0.769654,-2.07835,0.12681,1.29734,-1.83648,0.152321,1.28166,-2.04962},
/*1765*/{0.227084,1.83651,-1.72009,0.316587,1.78833,-1.86497,0.115673,1.69434,-1.6364,0.025983,1.59673,-1.58407,0.174854,1.55444,-1.61858,0.256325,1.5223,-1.61943,0.270739,1.86732,-2.12178,0.331538,1.79587,-1.94108,0.129151,1.83691,-2.03949,0.123016,1.64917,-2.22713,0.162467,1.55413,-2.2607,0.31286,1.46859,-2.16261,0.364958,1.42633,-2.15807,0.201881,1.38449,-1.81823,0.01892,1.44025,-1.91754,0.034361,1.46087,-1.97442,0.043147,1.42939,-2.03085,0.240849,1.36161,-2.07089,0.259469,1.10853,-1.74611,0.142122,1.05335,-1.79423,0.180214,0.978364,-1.81436,0.285524,0.900605,-1.79247,0.306731,0.71026,-1.79879,0.301639,0.635569,-1.81509,0.194242,0.718545,-1.81401,0.191303,0.648061,-1.82599,0.219279,0.424351,-1.86023,0.11857,0.361508,-1.94057,0.373299,0.387987,-1.89061,0.344802,0.336866,-1.81986,0.218623,1.05529,-2.11972,0.228099,0.971456,-2.10272,0.076699,1.03606,-2.09727,0.089394,0.955838,-2.07877,0.128955,0.829241,-2.08048,-0.035629,0.78882,-2.07565,-0.031659,0.900151,-2.0873,-0.101964,0.897614,-2.08094,-0.325214,0.875593,-2.06326,-0.360748,0.974727,-2.00296,-0.457307,0.708423,-2.02403,-0.488019,0.769514,-2.08125,0.123402,1.29678,-1.83486,0.151156,1.27827,-2.04749},
/*1766*/{0.227099,1.83514,-1.71963,0.316812,1.78616,-1.86549,0.121456,1.69083,-1.63502,0.035137,1.59075,-1.57911,0.18396,1.55164,-1.61639,0.266446,1.52105,-1.61797,0.271115,1.86534,-2.12111,0.33052,1.79378,-1.94207,0.129077,1.83717,-2.03887,0.118333,1.65026,-2.22515,0.15529,1.55445,-2.25969,0.304143,1.46358,-2.16449,0.355318,1.41954,-2.16303,0.198648,1.38581,-1.81526,0.017615,1.43842,-1.91975,0.032919,1.46046,-1.97545,0.040235,1.42525,-2.03296,0.239191,1.35996,-2.06951,0.254338,1.10673,-1.74495,0.13783,1.05206,-1.79455,0.176119,0.977236,-1.81375,0.290661,0.902894,-1.7928,0.296411,0.709198,-1.79711,0.288414,0.635529,-1.81464,0.184218,0.721612,-1.81223,0.178055,0.650085,-1.82414,0.198688,0.42497,-1.86049,0.09771,0.362032,-1.93997,0.352826,0.387706,-1.89008,0.323332,0.337238,-1.81774,0.224564,1.05594,-2.11783,0.236978,0.973333,-2.10108,0.08214,1.03401,-2.09755,0.098132,0.953796,-2.07895,0.142986,0.828708,-2.07865,-0.021997,0.787449,-2.07384,-0.016577,0.898823,-2.08791,-0.086999,0.898023,-2.08224,-0.314964,0.879513,-2.06839,-0.347275,0.973891,-2.00541,-0.440033,0.706197,-2.02625,-0.470724,0.767028,-2.08397,0.120837,1.29754,-1.83308,0.150552,1.27587,-2.04515},
/*1767*/{0.22735,1.83436,-1.71985,0.315401,1.78615,-1.86706,0.126319,1.68879,-1.63342,0.044466,1.58696,-1.5754,0.193921,1.55057,-1.61501,0.276144,1.52164,-1.61725,0.272018,1.86379,-2.12037,0.330314,1.79137,-1.9427,0.129374,1.83733,-2.0397,0.112606,1.65205,-2.22294,0.147387,1.55711,-2.25823,0.295731,1.46108,-2.16661,0.345478,1.41392,-2.16793,0.19479,1.38625,-1.8122,0.016274,1.43789,-1.92077,0.031369,1.46108,-1.97668,0.03873,1.42347,-2.03393,0.237357,1.3588,-2.06838,0.250343,1.10681,-1.74383,0.132264,1.05154,-1.7958,0.169647,0.975058,-1.8147,0.289044,0.900974,-1.79268,0.284307,0.706962,-1.79594,0.275959,0.634065,-1.8127,0.173727,0.72226,-1.81073,0.165433,0.650157,-1.82339,0.179546,0.425362,-1.85919,0.076299,0.362633,-1.93913,0.332438,0.386426,-1.88879,0.302508,0.337371,-1.81753,0.230681,1.05788,-2.11742,0.245153,0.97543,-2.09967,0.089055,1.03281,-2.09817,0.107082,0.951823,-2.07883,0.158123,0.829151,-2.0764,-0.007784,0.786208,-2.072,-0.001069,0.896829,-2.08831,-0.071153,0.894281,-2.08343,-0.294872,0.874133,-2.06533,-0.336867,0.973247,-2.00952,-0.422418,0.70275,-2.02707,-0.45272,0.762582,-2.08677,0.117222,1.29802,-1.83186,0.149057,1.27466,-2.04344},
/*1768*/{0.228285,1.83396,-1.72048,0.315314,1.78351,-1.86763,0.130854,1.68772,-1.63238,0.055772,1.58501,-1.57186,0.203325,1.55041,-1.61422,0.286294,1.52257,-1.61637,0.273264,1.86211,-2.11982,0.330292,1.78971,-1.94366,0.130638,1.8383,-2.04052,0.108089,1.65472,-2.22029,0.139262,1.56005,-2.25667,0.286386,1.45864,-2.16862,0.335086,1.41003,-2.17276,0.191713,1.38628,-1.80985,0.013841,1.43902,-1.9217,0.029888,1.46222,-1.97641,0.036871,1.42423,-2.03433,0.236079,1.35796,-2.06771,0.242991,1.10136,-1.74175,0.125188,1.05016,-1.79633,0.162906,0.973009,-1.81552,0.28054,0.896805,-1.79095,0.271977,0.704339,-1.79389,0.26048,0.630448,-1.81145,0.161094,0.722519,-1.81114,0.150337,0.650725,-1.82309,0.159589,0.424385,-1.85866,0.055081,0.363492,-1.93898,0.310909,0.385682,-1.88638,0.280802,0.336379,-1.81679,0.23821,1.06002,-2.11626,0.254601,0.978455,-2.09812,0.096959,1.0309,-2.09848,0.116468,0.950128,-2.07939,0.173457,0.830612,-2.07505,0.009182,0.783435,-2.0712,0.014372,0.894736,-2.0885,-0.055084,0.893288,-2.08294,-0.2852,0.875828,-2.0697,-0.325648,0.971638,-2.01243,-0.403235,0.698221,-2.02824,-0.43336,0.756764,-2.08931,0.113381,1.29859,-1.83118,0.146657,1.27465,-2.04248},
/*1769*/{0.229903,1.83398,-1.72092,0.314913,1.78253,-1.86785,0.135694,1.68764,-1.631,0.06466,1.58398,-1.5691,0.21325,1.55049,-1.61332,0.296701,1.52539,-1.61648,0.27377,1.8619,-2.11951,0.329667,1.78833,-1.94399,0.130894,1.83826,-2.04089,0.101771,1.66047,-2.2177,0.131722,1.56398,-2.25567,0.277281,1.45816,-2.17211,0.325106,1.40734,-2.17643,0.188345,1.38671,-1.80789,0.013007,1.43996,-1.92224,0.028339,1.46283,-1.97609,0.035544,1.42481,-2.03437,0.234926,1.35794,-2.0663,0.23609,1.09786,-1.74162,0.120855,1.04981,-1.79732,0.154886,0.972154,-1.81647,0.269289,0.892682,-1.79004,0.258543,0.700292,-1.79418,0.244724,0.627375,-1.81127,0.147841,0.720871,-1.80988,0.135976,0.651333,-1.82192,0.138409,0.424974,-1.85761,0.033725,0.363788,-1.93813,0.289561,0.385411,-1.88571,0.258695,0.336376,-1.81656,0.245132,1.06293,-2.11557,0.264356,0.98187,-2.09661,0.104505,1.02946,-2.09872,0.126455,0.948825,-2.07951,0.189786,0.833186,-2.07332,0.024451,0.781855,-2.06922,0.028931,0.893902,-2.08922,-0.04092,0.893805,-2.08314,-0.269763,0.872695,-2.07074,-0.315932,0.967552,-2.01495,-0.38351,0.692536,-2.02998,-0.413865,0.749004,-2.09172,0.110247,1.29923,-1.83031,0.145115,1.27487,-2.0413},
/*1770*/{0.231139,1.83512,-1.72178,0.314263,1.78354,-1.86856,0.139914,1.68877,-1.63014,0.073058,1.58251,-1.566,0.223414,1.5521,-1.61232,0.307152,1.52876,-1.61651,0.273976,1.86172,-2.11954,0.329129,1.78761,-1.94438,0.13096,1.83893,-2.04146,0.09639,1.66503,-2.21381,0.123422,1.56859,-2.25493,0.267529,1.45723,-2.17453,0.315117,1.40748,-2.1812,0.18572,1.38752,-1.80529,0.012827,1.44007,-1.92194,0.025991,1.4633,-1.97603,0.033871,1.42649,-2.03403,0.233074,1.35877,-2.06607,0.227975,1.09376,-1.73958,0.112465,1.04739,-1.7989,0.14664,0.970972,-1.81735,0.257209,0.887843,-1.78931,0.244138,0.696298,-1.79395,0.229749,0.623776,-1.8117,0.134202,0.719491,-1.80967,0.120726,0.648867,-1.82283,0.118208,0.425202,-1.85694,0.012942,0.364137,-1.93788,0.268539,0.385249,-1.88493,0.237634,0.335502,-1.81628,0.253409,1.06623,-2.11439,0.275055,0.986111,-2.0956,0.113674,1.02871,-2.09912,0.138395,0.948048,-2.07919,0.205866,0.834826,-2.07197,0.039861,0.780429,-2.0683,0.044234,0.892248,-2.08845,-0.025836,0.89148,-2.08344,-0.251506,0.867146,-2.07013,-0.305845,0.963674,-2.01773,-0.361532,0.685777,-2.03028,-0.393925,0.739632,-2.09379,0.108021,1.29982,-1.82975,0.143592,1.27575,-2.04065},
/*1771*/{0.23304,1.83615,-1.72212,0.313844,1.7832,-1.86977,0.144058,1.68965,-1.62857,0.082389,1.58314,-1.56383,0.233384,1.5546,-1.61172,0.317722,1.53326,-1.6172,0.273903,1.86189,-2.11949,0.328584,1.7873,-1.94449,0.130692,1.84035,-2.04174,0.09079,1.67085,-2.21076,0.114516,1.57372,-2.25418,0.259409,1.45881,-2.17822,0.304582,1.40811,-2.18494,0.183749,1.38893,-1.80346,0.011043,1.44134,-1.92192,0.025299,1.46357,-1.97496,0.033024,1.42799,-2.03304,0.232994,1.36068,-2.06546,0.219224,1.09055,-1.74164,0.103096,1.04486,-1.79859,0.136158,0.96907,-1.81938,0.245091,0.883247,-1.78929,0.228714,0.692651,-1.7943,0.212191,0.620761,-1.81194,0.119239,0.717453,-1.80992,0.104616,0.648536,-1.82271,0.098331,0.426,-1.85652,-0.008175,0.364765,-1.9374,0.247668,0.384735,-1.88448,0.217576,0.336379,-1.81533,0.261188,1.07055,-2.11359,0.284765,0.991209,-2.09391,0.12361,1.02868,-2.09913,0.15013,0.949388,-2.07886,0.222087,0.837156,-2.06917,0.055966,0.778634,-2.06438,0.059332,0.891864,-2.08843,-0.01128,0.890153,-2.08424,-0.24082,0.864505,-2.07219,-0.295075,0.957255,-2.02018,-0.33875,0.677426,-2.02939,-0.372511,0.729499,-2.09612,0.106739,1.30084,-1.82904,0.143451,1.27737,-2.03982},
/*1772*/{0.233703,1.83831,-1.72257,0.313356,1.78316,-1.87021,0.147777,1.69175,-1.62742,0.091288,1.58324,-1.56101,0.242483,1.55794,-1.6107,0.32811,1.53868,-1.61805,0.273765,1.86282,-2.11968,0.3271,1.78802,-1.94519,0.130361,1.84207,-2.04221,0.084553,1.67792,-2.2078,0.10559,1.57974,-2.2539,0.250187,1.46045,-2.18114,0.294214,1.40988,-2.18881,0.180882,1.3901,-1.80223,0.008935,1.44177,-1.92144,0.024135,1.46431,-1.97461,0.032143,1.42994,-2.03266,0.228749,1.3618,-2.06561,0.213431,1.08652,-1.74239,0.098063,1.04582,-1.79883,0.125694,0.968785,-1.82166,0.232436,0.878122,-1.78957,0.213603,0.688708,-1.79448,0.19516,0.616408,-1.81184,0.10342,0.715399,-1.81105,0.088718,0.646183,-1.82309,0.078031,0.424644,-1.85604,-0.028572,0.364574,-1.93685,0.226993,0.384804,-1.88515,0.196624,0.336306,-1.8144,0.26906,1.07547,-2.11277,0.295569,0.997327,-2.09295,0.132894,1.02786,-2.09876,0.162435,0.950371,-2.07873,0.237111,0.839596,-2.06878,0.071573,0.779104,-2.06349,0.073891,0.891301,-2.08825,0.003308,0.888819,-2.08579,-0.225722,0.860054,-2.07259,-0.286331,0.949806,-2.02213,-0.31613,0.668653,-2.03091,-0.351011,0.718624,-2.09835,0.104086,1.30168,-1.82877,0.140783,1.27844,-2.03958},
/*1773*/{0.235813,1.84038,-1.72301,0.313853,1.7836,-1.87109,0.151104,1.69368,-1.62686,0.099353,1.58421,-1.55865,0.251437,1.56189,-1.61022,0.337826,1.54474,-1.61969,0.272555,1.86403,-2.11986,0.326577,1.78947,-1.94613,0.129613,1.84443,-2.04209,0.080055,1.68525,-2.20544,0.096882,1.58597,-2.25392,0.241358,1.46505,-2.18497,0.284049,1.41298,-2.19151,0.179005,1.39101,-1.80095,0.007593,1.44274,-1.92043,0.022553,1.46529,-1.97385,0.030743,1.43075,-2.03024,0.227895,1.36439,-2.06541,0.205766,1.08392,-1.74273,0.088499,1.04723,-1.79953,0.114744,0.969173,-1.82157,0.217219,0.873487,-1.79046,0.196102,0.684921,-1.79579,0.178775,0.613869,-1.81301,0.088609,0.713232,-1.8118,0.072151,0.645256,-1.82393,0.0581,0.426666,-1.85702,-0.04884,0.365457,-1.93683,0.206708,0.384881,-1.8858,0.175791,0.336216,-1.81475,0.276461,1.08106,-2.11202,0.306091,1.00339,-2.09226,0.142687,1.02959,-2.09862,0.17343,0.955202,-2.07996,0.251756,0.842974,-2.06751,0.087362,0.778541,-2.06293,0.088872,0.891882,-2.08776,0.018202,0.888309,-2.08505,-0.211425,0.853037,-2.07459,-0.27688,0.941454,-2.02461,-0.292788,0.659268,-2.03187,-0.328674,0.706878,-2.10019,0.103219,1.30238,-1.82817,0.140128,1.28031,-2.03906},
/*1774*/{0.237282,1.84302,-1.72395,0.313814,1.78484,-1.87247,0.15544,1.69604,-1.62667,0.106898,1.58534,-1.55687,0.260366,1.56662,-1.61065,0.346714,1.55159,-1.62153,0.271056,1.86543,-2.12056,0.325724,1.79012,-1.94683,0.129047,1.84588,-2.04197,0.073575,1.69181,-2.20334,0.08804,1.59306,-2.25388,0.231733,1.46967,-2.18711,0.273618,1.41715,-2.19464,0.178394,1.39197,-1.80117,0.007242,1.44317,-1.91982,0.021532,1.46663,-1.97362,0.028841,1.43249,-2.02926,0.22651,1.36722,-2.06528,0.197164,1.08313,-1.74132,0.079609,1.04863,-1.79943,0.103908,0.97023,-1.82077,0.201959,0.870608,-1.79061,0.180432,0.682504,-1.79625,0.161078,0.610898,-1.81465,0.07245,0.712305,-1.81181,0.054477,0.643786,-1.82447,0.038481,0.427183,-1.85713,-0.069213,0.365696,-1.93744,0.186389,0.384489,-1.88598,0.156311,0.336858,-1.8142,0.282852,1.0881,-2.11365,0.315555,1.01058,-2.09166,0.151256,1.03098,-2.09767,0.1842,0.958152,-2.07896,0.267528,0.847825,-2.06806,0.104825,0.779924,-2.06197,0.102335,0.891955,-2.08746,0.032911,0.886882,-2.08469,-0.196741,0.846386,-2.07433,-0.267654,0.931803,-2.02525,-0.268277,0.649109,-2.03286,-0.305609,0.695486,-2.1023,0.103044,1.30314,-1.82852,0.139467,1.28244,-2.03964},
/*1775*/{0.239345,1.84607,-1.7246,0.313991,1.78699,-1.87232,0.160081,1.69919,-1.62607,0.114489,1.58647,-1.55473,0.267676,1.57182,-1.61062,0.355498,1.55864,-1.62267,0.270305,1.86812,-2.12105,0.32513,1.79208,-1.94766,0.127953,1.84872,-2.04188,0.067681,1.69952,-2.20178,0.07969,1.60012,-2.25397,0.222945,1.47445,-2.18872,0.26374,1.42182,-2.19643,0.177735,1.39217,-1.79964,0.005812,1.44514,-1.91941,0.02045,1.46785,-1.97242,0.027179,1.43432,-2.0287,0.225451,1.37002,-2.06518,0.191487,1.08205,-1.74407,0.067283,1.05276,-1.80201,0.092692,0.971025,-1.82148,0.18374,0.868071,-1.79156,0.164101,0.681621,-1.79768,0.144062,0.609894,-1.81579,0.056096,0.711947,-1.81259,0.038815,0.644085,-1.82466,0.016335,0.428286,-1.85857,-0.089687,0.366086,-1.93744,0.166308,0.384688,-1.88515,0.133386,0.335529,-1.81566,0.289657,1.09418,-2.11222,0.324705,1.01888,-2.0916,0.159652,1.03348,-2.09675,0.195411,0.961824,-2.07881,0.281504,0.852561,-2.06699,0.12076,0.78068,-2.0614,0.114998,0.895025,-2.08659,0.04594,0.885176,-2.08469,-0.183511,0.838383,-2.07476,-0.259058,0.921115,-2.0288,-0.244714,0.638575,-2.03386,-0.281935,0.682186,-2.10452,0.10201,1.30381,-1.82862,0.138492,1.28471,-2.03988},
/*1776*/{0.242361,1.84885,-1.7253,0.314195,1.78895,-1.87421,0.164925,1.7023,-1.62549,0.12311,1.58916,-1.55244,0.275905,1.57765,-1.61053,0.364217,1.56635,-1.62551,0.267817,1.87029,-2.12151,0.32424,1.79399,-1.94878,0.126864,1.85145,-2.04081,0.062229,1.70659,-2.20029,0.070333,1.60762,-2.2541,0.214527,1.48151,-2.19046,0.253911,1.42831,-2.19818,0.177505,1.3929,-1.80035,0.005675,1.4468,-1.9188,0.021414,1.46919,-1.97127,0.026172,1.4356,-2.02742,0.224319,1.37297,-2.06527,0.183064,1.08182,-1.74484,0.060186,1.05442,-1.79939,0.082031,0.973645,-1.8198,0.166255,0.866332,-1.79334,0.147987,0.680871,-1.79896,0.127796,0.609701,-1.81653,0.041048,0.713327,-1.81309,0.020525,0.644434,-1.82797,-0.001705,0.427156,-1.8579,-0.109939,0.366283,-1.93817,0.145695,0.38443,-1.88607,0.113595,0.337145,-1.81505,0.294827,1.10206,-2.1122,0.332474,1.02756,-2.09087,0.16718,1.0378,-2.09596,0.205771,0.967031,-2.0776,0.29539,0.858849,-2.06669,0.136666,0.782973,-2.06169,0.128796,0.895929,-2.0869,0.059264,0.885072,-2.08603,-0.170269,0.829462,-2.0751,-0.249222,0.908861,-2.02902,-0.219235,0.627073,-2.03544,-0.258738,0.669063,-2.1063,0.102359,1.30464,-1.82894,0.138029,1.28687,-2.04045},
/*1777*/{0.245294,1.85246,-1.7261,0.313646,1.79108,-1.87492,0.170115,1.70501,-1.62521,0.13026,1.59149,-1.55118,0.283282,1.58406,-1.61161,0.371485,1.57457,-1.62827,0.264858,1.87335,-2.12253,0.323951,1.79663,-1.95063,0.125185,1.85342,-2.03954,0.055679,1.71346,-2.19927,0.062917,1.61529,-2.25399,0.205627,1.48858,-2.19162,0.244923,1.43485,-2.19905,0.177727,1.39338,-1.80032,0.005062,1.44973,-1.91693,0.020247,1.47165,-1.96982,0.024895,1.43789,-2.02656,0.222662,1.37513,-2.06545,0.176288,1.08265,-1.74638,0.051419,1.05718,-1.79981,0.07162,0.9738,-1.81982,0.15019,0.865313,-1.79428,0.131818,0.680444,-1.8003,0.109495,0.609753,-1.81805,0.024974,0.714312,-1.81458,0.004294,0.646624,-1.82634,-0.022055,0.427507,-1.85808,-0.130119,0.367546,-1.93827,0.125313,0.383983,-1.88661,0.093136,0.336987,-1.81524,0.300416,1.10918,-2.11201,0.340355,1.03707,-2.091,0.174949,1.0419,-2.09581,0.214045,0.972271,-2.07604,0.309389,0.866883,-2.06619,0.153446,0.785182,-2.06149,0.141493,0.896418,-2.08754,0.072078,0.884532,-2.08736,-0.150316,0.819505,-2.07391,-0.241121,0.894984,-2.02969,-0.193201,0.616125,-2.03776,-0.236668,0.65642,-2.10796,0.101724,1.30596,-1.82885,0.13593,1.28917,-2.04068},
/*1778*/{0.24827,1.8566,-1.72724,0.314983,1.79494,-1.87646,0.175797,1.70923,-1.62483,0.138352,1.5952,-1.55066,0.289796,1.58967,-1.61379,0.377755,1.58294,-1.6309,0.261808,1.87663,-2.12293,0.323814,1.79889,-1.95192,0.123711,1.85599,-2.03876,0.049471,1.72051,-2.19824,0.054748,1.62267,-2.25447,0.196658,1.4959,-2.19264,0.235821,1.44238,-2.19987,0.177815,1.3938,-1.80052,0.00607,1.45229,-1.91516,0.020105,1.47439,-1.96836,0.024894,1.43977,-2.02551,0.221984,1.37769,-2.06529,0.167708,1.08032,-1.74791,0.043008,1.06055,-1.7998,0.060267,0.976848,-1.81959,0.13306,0.864427,-1.79619,0.115022,0.680832,-1.80167,0.092375,0.610771,-1.81939,0.008418,0.716238,-1.81554,-0.014442,0.648562,-1.82826,-0.042356,0.428629,-1.85781,-0.150203,0.368101,-1.93861,0.105352,0.383636,-1.88633,0.073461,0.337225,-1.81474,0.305414,1.11778,-2.11224,0.347734,1.04686,-2.09118,0.181727,1.04576,-2.09391,0.224312,0.978196,-2.07531,0.322793,0.876435,-2.06572,0.169192,0.78803,-2.06233,0.153732,0.899081,-2.08721,0.084625,0.883573,-2.08629,-0.137158,0.81039,-2.07432,-0.23166,0.880794,-2.02896,-0.167988,0.604278,-2.03997,-0.211666,0.643077,-2.11011,0.101791,1.30709,-1.82887,0.135061,1.29159,-2.04095},
/*1779*/{0.250989,1.86053,-1.72829,0.315753,1.79828,-1.87779,0.181078,1.71269,-1.62445,0.146141,1.59953,-1.54949,0.296145,1.59688,-1.61447,0.38335,1.59107,-1.63406,0.259293,1.88046,-2.12391,0.323447,1.80238,-1.95364,0.121739,1.85915,-2.03665,0.043151,1.72754,-2.19721,0.047321,1.62997,-2.25415,0.190105,1.5037,-2.19277,0.227671,1.45008,-2.20031,0.17836,1.39426,-1.80011,0.005372,1.45565,-1.91357,0.019383,1.4769,-1.96731,0.023944,1.44322,-2.02478,0.22159,1.38069,-2.06499,0.159526,1.08129,-1.75075,0.033426,1.06091,-1.79675,0.049024,0.980281,-1.81908,0.116212,0.865205,-1.79707,0.09703,0.681593,-1.80393,0.072838,0.611026,-1.82068,-0.008754,0.716977,-1.81522,-0.032092,0.650883,-1.82787,-0.059164,0.429882,-1.85837,-0.170101,0.369612,-1.93844,0.084928,0.383658,-1.88675,0.05312,0.336904,-1.81522,0.309296,1.12679,-2.11213,0.354041,1.05599,-2.09082,0.188107,1.0508,-2.09252,0.232255,0.984285,-2.07419,0.336034,0.886632,-2.06504,0.185005,0.791239,-2.06249,0.163995,0.901146,-2.08799,0.095466,0.884443,-2.08575,-0.120675,0.800298,-2.07392,-0.220114,0.864329,-2.02914,-0.14018,0.593934,-2.04281,-0.186316,0.630042,-2.11227,0.101233,1.30852,-1.82912,0.133906,1.29473,-2.04141},
/*1780*/{0.253894,1.86531,-1.72926,0.315467,1.80168,-1.87947,0.18729,1.7169,-1.62393,0.151685,1.60387,-1.54957,0.301548,1.60377,-1.61711,0.389298,1.59969,-1.63704,0.25593,1.88486,-2.1244,0.323436,1.80558,-1.95534,0.119831,1.86129,-2.03548,0.036754,1.73468,-2.19661,0.040567,1.63791,-2.25429,0.18136,1.51157,-2.19301,0.220367,1.45825,-2.20098,0.179031,1.39511,-1.79997,0.00551,1.4589,-1.91225,0.019832,1.48046,-1.96495,0.024264,1.44618,-2.02304,0.220302,1.3835,-2.06458,0.152349,1.08047,-1.7524,0.024365,1.06444,-1.7975,0.036032,0.983551,-1.81893,0.101327,0.867096,-1.79828,0.079288,0.682888,-1.80463,0.055723,0.612159,-1.82174,-0.026126,0.719429,-1.81774,-0.047275,0.65186,-1.82913,-0.079477,0.431536,-1.85924,-0.190223,0.372196,-1.93783,0.065505,0.383748,-1.8879,0.0326,0.337314,-1.81559,0.313967,1.13567,-2.11076,0.359834,1.06622,-2.09072,0.194363,1.05646,-2.09171,0.240409,0.991551,-2.0728,0.34778,0.897502,-2.06457,0.200571,0.79529,-2.06317,0.174556,0.90427,-2.08773,0.106229,0.88449,-2.08604,-0.107028,0.790701,-2.07408,-0.208569,0.847136,-2.02774,-0.117557,0.581046,-2.04405,-0.160253,0.616844,-2.11433,0.101082,1.31025,-1.82885,0.13255,1.29773,-2.0414},
/*1781*/{0.256258,1.86987,-1.73073,0.315931,1.80517,-1.88028,0.194017,1.72124,-1.62356,0.159653,1.60765,-1.54788,0.306859,1.61103,-1.61883,0.394081,1.60753,-1.64118,0.25225,1.88888,-2.12525,0.322614,1.8093,-1.9572,0.118726,1.86419,-2.03309,0.030406,1.74166,-2.19611,0.033712,1.64517,-2.25391,0.174123,1.52079,-2.19278,0.212507,1.46652,-2.20091,0.179669,1.39633,-1.7999,0.00663,1.46134,-1.90932,0.01985,1.48349,-1.96321,0.023454,1.44947,-2.02194,0.219782,1.38658,-2.06402,0.144976,1.08278,-1.75477,0.016519,1.07145,-1.79797,0.025259,0.988035,-1.81814,0.089297,0.869529,-1.8006,0.062876,0.684068,-1.80617,0.038055,0.614379,-1.82286,-0.043492,0.72158,-1.81864,-0.067035,0.654172,-1.83085,-0.098348,0.43427,-1.85835,-0.209656,0.375474,-1.93746,0.04784,0.383829,-1.88808,0.0125,0.337392,-1.81545,0.318109,1.1437,-2.11059,0.365646,1.07644,-2.09056,0.2,1.06117,-2.08975,0.248632,0.998181,-2.0714,0.359389,0.90918,-2.06426,0.215431,0.799116,-2.0641,0.184166,0.907308,-2.08836,0.118268,0.88323,-2.08639,-0.092321,0.779743,-2.07474,-0.198185,0.830157,-2.02619,-0.084993,0.572413,-2.04816,-0.136274,0.603403,-2.11605,0.101552,1.31191,-1.82854,0.131714,1.30088,-2.04137},
/*1782*/{0.258983,1.87541,-1.73224,0.316839,1.80923,-1.88254,0.200375,1.72534,-1.62396,0.166797,1.61251,-1.5471,0.31247,1.61848,-1.62058,0.397827,1.61724,-1.64299,0.249226,1.89362,-2.12527,0.32253,1.81286,-1.95923,0.117061,1.86774,-2.03176,0.024323,1.74938,-2.19603,0.027245,1.65281,-2.25359,0.167725,1.52932,-2.19272,0.205741,1.47521,-2.20108,0.179908,1.3967,-1.79952,0.007741,1.46513,-1.90818,0.020181,1.4867,-1.96068,0.022744,1.45418,-2.02022,0.219367,1.39068,-2.06369,0.141522,1.08127,-1.75533,0.008732,1.07419,-1.79631,0.014241,0.991908,-1.81827,0.077744,0.872158,-1.80285,0.044238,0.686871,-1.80808,0.019836,0.616267,-1.82451,-0.061048,0.724559,-1.82009,-0.083635,0.656694,-1.83156,-0.118785,0.436384,-1.85856,-0.228961,0.380093,-1.93676,0.025426,0.382823,-1.88756,-0.007598,0.336923,-1.81555,0.321573,1.15239,-2.11051,0.370279,1.08583,-2.09042,0.205366,1.06775,-2.08867,0.254987,1.00471,-2.07066,0.370422,0.921537,-2.06382,0.22999,0.80371,-2.06511,0.192857,0.910031,-2.08726,0.12829,0.882623,-2.08586,-0.076289,0.767785,-2.07343,-0.184813,0.810137,-2.02517,-0.056571,0.561343,-2.04987,-0.108817,0.590646,-2.11853,0.101237,1.31337,-1.8291,0.13066,1.30511,-2.04215},
/*1783*/{0.261809,1.88064,-1.73357,0.317867,1.81304,-1.88438,0.205567,1.73043,-1.62392,0.173106,1.61857,-1.54732,0.316469,1.6254,-1.62297,0.402415,1.62562,-1.64722,0.24541,1.89855,-2.12601,0.322319,1.81657,-1.96107,0.115789,1.87096,-2.02972,0.020572,1.7569,-2.19553,0.020838,1.66003,-2.25298,0.160826,1.53844,-2.19158,0.199229,1.48422,-2.20104,0.18079,1.39754,-1.7988,0.008449,1.46833,-1.90643,0.020854,1.4893,-1.95896,0.02389,1.45741,-2.01924,0.218671,1.39444,-2.06345,0.133896,1.08287,-1.7579,-0.00033,1.07998,-1.7974,0.002961,0.99695,-1.81875,0.065232,0.875339,-1.80506,0.026763,0.689713,-1.80909,0.001755,0.619178,-1.82502,-0.078822,0.727651,-1.82089,-0.102018,0.661065,-1.83193,-0.138069,0.439561,-1.85736,-0.247724,0.385625,-1.93703,0.006483,0.382558,-1.88806,-0.028114,0.337585,-1.81618,0.324716,1.16118,-2.11038,0.375498,1.09617,-2.09029,0.210474,1.0743,-2.08814,0.261218,1.01261,-2.0703,0.378503,0.933224,-2.06406,0.244078,0.808281,-2.06578,0.201417,0.912137,-2.08666,0.138385,0.881446,-2.08459,-0.060107,0.756794,-2.07305,-0.174854,0.792396,-2.0238,-0.028132,0.55194,-2.0526,-0.081618,0.578402,-2.12051,0.101697,1.31493,-1.82922,0.130476,1.30855,-2.04243},
/*1784*/{0.263914,1.88498,-1.73518,0.319388,1.81782,-1.88666,0.212262,1.73525,-1.62476,0.178475,1.62281,-1.54618,0.320648,1.63315,-1.62508,0.405857,1.63428,-1.65016,0.242387,1.90316,-2.12623,0.322498,1.82132,-1.96301,0.114702,1.8741,-2.0285,0.01478,1.76401,-2.19525,0.0145,1.6672,-2.2521,0.154403,1.54696,-2.19095,0.193093,1.4928,-2.20115,0.182861,1.39908,-1.79836,0.008911,1.47189,-1.9039,0.020885,1.4938,-1.95659,0.024274,1.4614,-2.01865,0.218856,1.39894,-2.06269,0.125862,1.08414,-1.75948,-0.007687,1.08703,-1.79746,-0.006987,1.00236,-1.81834,0.05165,0.878016,-1.80675,0.009485,0.694165,-1.80964,-0.016799,0.623261,-1.82607,-0.095501,0.732498,-1.8222,-0.119713,0.663907,-1.83362,-0.155397,0.444352,-1.8586,-0.266742,0.39232,-1.93637,-0.011566,0.382931,-1.88766,-0.04774,0.339159,-1.81659,0.327187,1.1697,-2.11023,0.379869,1.10432,-2.08965,0.215593,1.08109,-2.0876,0.268097,1.02054,-2.06899,0.386224,0.94436,-2.06395,0.256935,0.813318,-2.06672,0.209732,0.914948,-2.08563,0.147463,0.88015,-2.08416,-0.047352,0.746665,-2.07512,-0.160673,0.772443,-2.02244,0.001724,0.543616,-2.05592,-0.054044,0.566443,-2.12238,0.102665,1.31734,-1.8292,0.130426,1.31303,-2.04259},
/*1785*/{0.266204,1.89159,-1.73712,0.320601,1.82279,-1.88815,0.218056,1.74058,-1.62517,0.184889,1.62876,-1.54598,0.324205,1.64046,-1.62672,0.408754,1.64228,-1.65524,0.238917,1.90782,-2.12622,0.32173,1.82545,-1.96486,0.113257,1.87778,-2.02586,0.009602,1.76978,-2.19491,0.008509,1.67456,-2.25097,0.148479,1.55571,-2.18995,0.187577,1.5018,-2.20109,0.183928,1.40004,-1.79755,0.010016,1.47588,-1.90226,0.021321,1.49696,-1.95395,0.02313,1.46661,-2.01691,0.219106,1.40364,-2.06153,0.120898,1.08771,-1.76158,-0.015491,1.09118,-1.79619,-0.017172,1.00854,-1.81842,0.036974,0.882229,-1.80753,-0.006504,0.69895,-1.81032,-0.034427,0.627753,-1.82575,-0.111967,0.737104,-1.82307,-0.13626,0.671153,-1.83425,-0.172853,0.448407,-1.85815,-0.284143,0.399259,-1.93632,-0.030599,0.381779,-1.88801,-0.067273,0.339186,-1.8172,0.329568,1.17838,-2.11049,0.383555,1.11526,-2.09036,0.219647,1.08742,-2.08726,0.274133,1.02627,-2.06862,0.393127,0.956167,-2.06387,0.269744,0.817687,-2.06781,0.21649,0.916727,-2.08518,0.156719,0.8791,-2.08305,-0.026032,0.732759,-2.07196,-0.14398,0.751285,-2.02133,0.032283,0.53415,-2.05811,-0.026352,0.555227,-2.12497,0.102925,1.31934,-1.82933,0.130035,1.31777,-2.04285},
/*1786*/{0.26872,1.89701,-1.73897,0.320484,1.82624,-1.89017,0.223096,1.74592,-1.62589,0.190478,1.63444,-1.54525,0.327322,1.64766,-1.62877,0.411435,1.65036,-1.65749,0.235707,1.91275,-2.12682,0.321167,1.83012,-1.96655,0.111792,1.88102,-2.0249,0.006202,1.77683,-2.19462,0.003308,1.68159,-2.24993,0.142257,1.5639,-2.18842,0.182597,1.51023,-2.20083,0.185034,1.40126,-1.79721,0.012294,1.47905,-1.90178,0.022788,1.50088,-1.95193,0.023295,1.47272,-2.01656,0.218957,1.40825,-2.061,0.113503,1.08848,-1.76306,-0.021337,1.09632,-1.79567,-0.026164,1.01427,-1.81814,0.020371,0.887342,-1.80827,-0.023458,0.704011,-1.80987,-0.048978,0.6347,-1.82662,-0.127881,0.743601,-1.82411,-0.152472,0.677338,-1.83496,-0.190339,0.454438,-1.85877,-0.301566,0.407373,-1.93727,-0.049709,0.381843,-1.88677,-0.087606,0.339787,-1.8169,0.332103,1.18629,-2.11035,0.38658,1.12445,-2.09018,0.223724,1.09421,-2.08669,0.279443,1.03417,-2.0679,0.399271,0.967131,-2.06361,0.282109,0.822175,-2.06883,0.222661,0.918186,-2.08441,0.16446,0.876662,-2.08244,-0.009685,0.720433,-2.07107,-0.129135,0.731725,-2.02046,0.062025,0.525981,-2.06021,0.002694,0.545299,-2.12702,0.103237,1.32145,-1.83043,0.129972,1.32268,-2.04399},
/*1787*/{0.270806,1.90253,-1.74058,0.321179,1.83078,-1.89227,0.227775,1.75158,-1.62699,0.194827,1.64095,-1.54512,0.329741,1.65478,-1.63138,0.414105,1.65824,-1.66127,0.233014,1.91722,-2.1264,0.321223,1.83429,-1.96877,0.111076,1.88418,-2.02237,0.00326,1.78318,-2.19485,-0.002429,1.68858,-2.24863,0.137074,1.57221,-2.18753,0.177666,1.51809,-2.20092,0.187235,1.4029,-1.79785,0.013572,1.48201,-1.90049,0.023237,1.50488,-1.94962,0.026059,1.4762,-2.01491,0.21881,1.41278,-2.06089,0.105866,1.09025,-1.76594,-0.027377,1.10334,-1.79496,-0.036246,1.0223,-1.81932,0.004908,0.893518,-1.80815,-0.039817,0.709638,-1.80991,-0.06674,0.640399,-1.8259,-0.143748,0.750389,-1.82441,-0.167982,0.684244,-1.83618,-0.207345,0.459838,-1.8585,-0.318631,0.416289,-1.93793,-0.067921,0.379601,-1.88863,-0.107543,0.340421,-1.81686,0.334423,1.1946,-2.11071,0.389363,1.1338,-2.09034,0.226758,1.10115,-2.08669,0.283207,1.04223,-2.06725,0.403625,0.976919,-2.06336,0.293844,0.826693,-2.06963,0.228775,0.918487,-2.08303,0.173797,0.874672,-2.08157,0.007738,0.708452,-2.07127,-0.111747,0.710558,-2.01901,0.092399,0.51907,-2.06368,0.0325,0.535499,-2.12973,0.105011,1.32355,-1.83095,0.130575,1.32701,-2.04463},
/*1788*/{0.273214,1.90747,-1.74239,0.322246,1.83526,-1.89391,0.232372,1.75717,-1.62707,0.199831,1.64668,-1.54444,0.332269,1.66248,-1.63327,0.415496,1.66592,-1.66536,0.230429,1.92113,-2.12616,0.320824,1.83862,-1.97074,0.110265,1.88787,-2.02148,-0.00072,1.78821,-2.19497,-0.007499,1.69542,-2.24724,0.13295,1.58017,-2.18633,0.172669,1.52551,-2.20037,0.188292,1.40383,-1.79815,0.015031,1.486,-1.8982,0.023504,1.5089,-1.94743,0.026774,1.4813,-2.01372,0.21891,1.41891,-2.06078,0.100766,1.09371,-1.76741,-0.033843,1.11084,-1.79599,-0.044597,1.02894,-1.8173,-0.011854,0.900193,-1.80707,-0.054293,0.716653,-1.80917,-0.082468,0.646567,-1.82453,-0.159582,0.758645,-1.82581,-0.184546,0.69155,-1.83702,-0.222143,0.465431,-1.85719,-0.335226,0.426233,-1.93795,-0.086636,0.379066,-1.88866,-0.128301,0.34026,-1.81787,0.336722,1.20254,-2.11081,0.39177,1.14232,-2.08935,0.229754,1.10807,-2.08632,0.286311,1.05006,-2.06667,0.407509,0.986785,-2.06311,0.304398,0.830673,-2.07085,0.232994,0.918328,-2.0822,0.181739,0.870795,-2.07976,0.025888,0.696249,-2.07027,-0.095835,0.691452,-2.01806,0.123318,0.513224,-2.06683,0.061664,0.526035,-2.13152,0.105844,1.32551,-1.83231,0.13067,1.33281,-2.04598},
/*1789*/{0.274336,1.91343,-1.74441,0.322509,1.83983,-1.89675,0.236028,1.76277,-1.62763,0.204284,1.65261,-1.5441,0.333879,1.66884,-1.63484,0.417649,1.67344,-1.66902,0.22826,1.92498,-2.12638,0.321067,1.84325,-1.97207,0.109092,1.89143,-2.01999,-0.004532,1.79456,-2.19384,-0.012419,1.70188,-2.24526,0.127379,1.587,-2.1855,0.168349,1.53322,-2.20035,0.190838,1.4052,-1.79896,0.016448,1.4895,-1.89755,0.024962,1.51325,-1.94516,0.026949,1.4866,-2.01279,0.218887,1.42361,-2.0602,0.095775,1.09677,-1.76777,-0.037281,1.11906,-1.79361,-0.052455,1.03755,-1.81742,-0.025373,0.907478,-1.80684,-0.069917,0.723467,-1.80812,-0.098018,0.654321,-1.82235,-0.173252,0.765579,-1.82645,-0.199754,0.699067,-1.83712,-0.238811,0.471208,-1.85728,-0.350944,0.436231,-1.93896,-0.104299,0.37791,-1.88904,-0.148695,0.341423,-1.81848,0.338094,1.21056,-2.11049,0.394986,1.15154,-2.08769,0.232527,1.11538,-2.08637,0.290097,1.05725,-2.06627,0.410347,0.995417,-2.06272,0.314544,0.834167,-2.07133,0.238878,0.918649,-2.08159,0.189551,0.866503,-2.07825,0.040325,0.683223,-2.06988,-0.074157,0.668828,-2.01452,0.153275,0.507915,-2.0692,0.089499,0.516978,-2.13334,0.107001,1.3279,-1.83336,0.130601,1.3378,-2.04707},
/*1790*/{0.276279,1.91717,-1.74598,0.323365,1.84379,-1.89807,0.239661,1.7681,-1.62846,0.20803,1.65818,-1.54359,0.336249,1.67556,-1.63693,0.418502,1.68063,-1.6727,0.225949,1.92923,-2.12664,0.320784,1.84763,-1.97327,0.108529,1.8952,-2.01965,-0.006287,1.80014,-2.19304,-0.016841,1.70784,-2.2437,0.123332,1.59377,-2.1845,0.164193,1.53957,-2.2002,0.19192,1.40708,-1.79928,0.017969,1.49248,-1.895,0.026138,1.5169,-1.94341,0.028065,1.49152,-2.01156,0.219612,1.42931,-2.06035,0.089799,1.10018,-1.76933,-0.040048,1.1256,-1.79173,-0.059833,1.04508,-1.81618,-0.037828,0.914766,-1.80637,-0.084651,0.730809,-1.80633,-0.112143,0.66171,-1.82088,-0.187076,0.773487,-1.82725,-0.212835,0.707317,-1.83769,-0.254171,0.477478,-1.85666,-0.366064,0.447445,-1.93868,-0.123953,0.377471,-1.88879,-0.16867,0.342216,-1.81869,0.339721,1.21811,-2.11026,0.3968,1.15917,-2.087,0.235075,1.12131,-2.08651,0.292397,1.06455,-2.06594,0.410961,1.00429,-2.06233,0.325339,0.837592,-2.07243,0.244147,0.916088,-2.08001,0.198016,0.862588,-2.0778,0.062096,0.669733,-2.06717,-0.054874,0.647651,-2.01268,0.183684,0.503403,-2.07154,0.118373,0.509436,-2.13464,0.108497,1.33007,-1.83447,0.131426,1.34324,-2.04808},
/*1791*/{0.278233,1.92171,-1.74737,0.323795,1.84773,-1.90023,0.242719,1.7732,-1.62859,0.209975,1.66311,-1.54279,0.337015,1.68153,-1.63825,0.419241,1.68737,-1.67573,0.224509,1.93274,-2.12668,0.320936,1.85122,-1.97455,0.107332,1.89856,-2.01885,-0.010476,1.80486,-2.19185,-0.021427,1.71376,-2.24186,0.1195,1.5989,-2.18354,0.161114,1.54604,-2.20008,0.193131,1.40788,-1.80008,0.018468,1.49633,-1.89438,0.026616,1.52118,-1.94118,0.028543,1.49631,-2.01057,0.220186,1.43435,-2.06025,0.085811,1.10315,-1.76948,-0.046023,1.134,-1.79234,-0.06593,1.05297,-1.81545,-0.049331,0.922709,-1.8068,-0.09896,0.738448,-1.80483,-0.126549,0.668995,-1.81855,-0.200404,0.781452,-1.82789,-0.226597,0.715521,-1.83769,-0.270215,0.484316,-1.855,-0.379978,0.458461,-1.9393,-0.142601,0.376968,-1.88887,-0.189042,0.343319,-1.81983,0.341107,1.22494,-2.10999,0.398096,1.16673,-2.08618,0.237822,1.12582,-2.08814,0.294256,1.07149,-2.06572,0.411382,1.0117,-2.06265,0.335027,0.840078,-2.07319,0.248791,0.913428,-2.07881,0.205829,0.857255,-2.07693,0.081147,0.657565,-2.06669,-0.03181,0.626583,-2.0083,0.213107,0.499151,-2.07367,0.146996,0.500849,-2.13551,0.10879,1.33209,-1.83606,0.131339,1.34854,-2.04947},
/*1792*/{0.279387,1.92533,-1.74896,0.324389,1.85142,-1.90138,0.244857,1.77805,-1.62919,0.213861,1.66882,-1.5422,0.337888,1.68743,-1.64013,0.42012,1.69348,-1.67874,0.223223,1.93586,-2.12662,0.320276,1.85517,-1.97664,0.106752,1.90203,-2.01751,-0.013503,1.81004,-2.18966,-0.025276,1.71979,-2.2399,0.11699,1.60508,-2.18288,0.157875,1.55199,-2.19994,0.195644,1.40966,-1.80099,0.019917,1.49989,-1.89256,0.027569,1.52503,-1.93928,0.030174,1.50086,-2.00913,0.220484,1.43956,-2.06039,0.081645,1.10615,-1.77,-0.04954,1.14137,-1.79073,-0.072479,1.06029,-1.81461,-0.059876,0.930251,-1.80527,-0.111513,0.746358,-1.80319,-0.138406,0.677989,-1.81622,-0.212948,0.790185,-1.82883,-0.238528,0.723732,-1.83836,-0.284311,0.49095,-1.85377,-0.393259,0.471604,-1.93926,-0.160759,0.376961,-1.88902,-0.209953,0.343885,-1.82059,0.342752,1.2321,-2.10897,0.399895,1.17385,-2.08518,0.23879,1.13272,-2.08917,0.295209,1.07758,-2.06619,0.410808,1.01784,-2.06278,0.343382,0.841341,-2.07293,0.25372,0.910339,-2.07801,0.214161,0.851522,-2.07628,0.100726,0.645514,-2.0659,-0.009746,0.606225,-2.00672,0.242989,0.496558,-2.07528,0.175197,0.494564,-2.13629,0.110706,1.33455,-1.83708,0.131856,1.35368,-2.05042},
/*1793*/{0.28116,1.92962,-1.75013,0.325423,1.85518,-1.90302,0.247609,1.78255,-1.62975,0.216589,1.67405,-1.54221,0.338577,1.69277,-1.6416,0.421035,1.69914,-1.68152,0.222074,1.93945,-2.12655,0.319763,1.85862,-1.97762,0.106078,1.90519,-2.01679,-0.015607,1.8151,-2.18812,-0.029485,1.72509,-2.23741,0.114092,1.61005,-2.18207,0.15424,1.55718,-2.20013,0.196918,1.41154,-1.8018,0.021558,1.50332,-1.8915,0.028736,1.52833,-1.93675,0.031355,1.50621,-2.00797,0.21873,1.44425,-2.06092,0.077143,1.10956,-1.76958,-0.05347,1.14904,-1.79129,-0.077373,1.06858,-1.81298,-0.067445,0.937151,-1.80481,-0.123192,0.755179,-1.80118,-0.15134,0.685584,-1.81405,-0.224187,0.798448,-1.82865,-0.250932,0.732581,-1.83769,-0.296256,0.498488,-1.852,-0.405359,0.485485,-1.94021,-0.180423,0.37709,-1.88828,-0.232188,0.345059,-1.82053,0.343505,1.23846,-2.10833,0.400602,1.18015,-2.08365,0.239498,1.1388,-2.08982,0.2968,1.08313,-2.06791,0.41066,1.02408,-2.06288,0.353077,0.843183,-2.07341,0.259291,0.906903,-2.07725,0.223949,0.844758,-2.0744,0.113404,0.63027,-2.06344,0.013393,0.585334,-2.00403,0.27191,0.494029,-2.07522,0.204982,0.4876,-2.13626,0.111498,1.337,-1.83817,0.130896,1.35854,-2.05145},
/*1794*/{0.282792,1.93303,-1.75151,0.324707,1.85863,-1.90454,0.24938,1.78731,-1.63047,0.218404,1.67857,-1.54118,0.33945,1.69777,-1.64362,0.420138,1.70451,-1.68486,0.220199,1.94246,-2.12672,0.319741,1.86232,-1.97841,0.108253,1.90641,-2.01612,-0.017225,1.8203,-2.18551,-0.032752,1.73033,-2.23585,0.110602,1.61476,-2.18183,0.151259,1.56238,-2.20028,0.19885,1.41345,-1.80215,0.023487,1.50643,-1.89032,0.029475,1.53159,-1.9355,0.032458,1.51104,-2.00631,0.218881,1.4494,-2.06114,0.073484,1.11415,-1.76886,-0.053887,1.15448,-1.78972,-0.080824,1.0743,-1.81321,-0.075606,0.944621,-1.80362,-0.133287,0.763534,-1.79924,-0.161256,0.694263,-1.81088,-0.233662,0.806896,-1.82877,-0.260951,0.740731,-1.83787,-0.309151,0.506085,-1.84933,-0.415004,0.499631,-1.93884,-0.198662,0.377635,-1.88711,-0.253133,0.346609,-1.82103,0.344159,1.24445,-2.10734,0.400702,1.18587,-2.0825,0.23973,1.14485,-2.09122,0.296371,1.08943,-2.07143,0.409061,1.02817,-2.06333,0.361541,0.843284,-2.07401,0.264527,0.90159,-2.07642,0.231692,0.838715,-2.07509,0.141933,0.621365,-2.06284,0.036498,0.568299,-2.00295,0.299644,0.491981,-2.07488,0.232556,0.481706,-2.13543,0.113142,1.33944,-1.83924,0.131445,1.36353,-2.05234},
/*1795*/{0.284361,1.93626,-1.75265,0.324839,1.86158,-1.90593,0.250482,1.79127,-1.63015,0.220476,1.68221,-1.53994,0.340038,1.70209,-1.6449,0.420322,1.70951,-1.6879,0.220264,1.94572,-2.1277,0.3192,1.86507,-1.97955,0.107908,1.90943,-2.01646,-0.019683,1.82586,-2.18342,-0.03547,1.73536,-2.23332,0.10805,1.61959,-2.18154,0.148523,1.56711,-2.2005,0.199942,1.41566,-1.80244,0.024283,1.50929,-1.88929,0.0304,1.53517,-1.93413,0.033335,1.51561,-2.00464,0.218624,1.45306,-2.06149,0.069568,1.11595,-1.7677,-0.057361,1.15907,-1.78895,-0.086117,1.08257,-1.81249,-0.082938,0.951721,-1.80255,-0.142856,0.771631,-1.79721,-0.172033,0.702473,-1.80898,-0.24269,0.815196,-1.82848,-0.268907,0.74949,-1.83705,-0.322349,0.513941,-1.84751,-0.425718,0.514069,-1.93796,-0.216048,0.379352,-1.88566,-0.27338,0.349412,-1.82182,0.344204,1.24945,-2.10588,0.400249,1.19026,-2.08085,0.239871,1.15022,-2.09222,0.295772,1.09397,-2.07383,0.407582,1.03128,-2.06422,0.369621,0.843696,-2.07414,0.269463,0.89716,-2.07674,0.240761,0.831565,-2.07425,0.158256,0.609467,-2.06388,0.059587,0.549845,-2.00212,0.3283,0.490905,-2.07342,0.261932,0.476235,-2.13437,0.113768,1.34202,-1.8397,0.131061,1.36764,-2.05271},
/*1796*/{0.285835,1.93952,-1.75376,0.326118,1.86587,-1.90677,0.252571,1.79535,-1.63036,0.223086,1.68672,-1.53972,0.340525,1.70625,-1.64582,0.419989,1.71341,-1.68954,0.219533,1.94816,-2.12754,0.319189,1.86845,-1.98071,0.107329,1.91229,-2.01629,-0.021561,1.83247,-2.18131,-0.038842,1.74064,-2.23142,0.106111,1.62405,-2.18097,0.145723,1.57149,-2.20098,0.201437,1.41808,-1.80303,0.026542,1.51408,-1.8876,0.031373,1.53906,-1.93277,0.034943,1.52005,-2.00402,0.218226,1.45715,-2.06109,0.067586,1.12031,-1.76579,-0.060649,1.16408,-1.79035,-0.089783,1.08874,-1.81469,-0.089953,0.958978,-1.80233,-0.150743,0.77878,-1.7956,-0.180234,0.70969,-1.80631,-0.249587,0.823297,-1.82802,-0.277793,0.75725,-1.83626,-0.333937,0.521213,-1.84493,-0.434583,0.530752,-1.93804,-0.234769,0.380734,-1.88426,-0.294763,0.352852,-1.8234,0.344332,1.25355,-2.10436,0.400233,1.19387,-2.08,0.239784,1.15504,-2.09366,0.295276,1.09779,-2.07513,0.406458,1.03295,-2.06501,0.376737,0.843374,-2.07565,0.273857,0.89054,-2.07659,0.249164,0.824356,-2.07339,0.18246,0.598348,-2.06036,0.083512,0.532249,-2.00101,0.355347,0.490169,-2.07152,0.291053,0.471928,-2.13185,0.114607,1.34536,-1.83981,0.130735,1.37195,-2.05279},
/*1797*/{0.28719,1.94231,-1.75465,0.326895,1.86888,-1.90842,0.253508,1.79895,-1.63083,0.2246,1.6901,-1.53896,0.3409,1.71066,-1.64714,0.419602,1.7173,-1.69218,0.218642,1.95094,-2.12763,0.319185,1.87141,-1.98221,0.107698,1.9151,-2.01557,-0.022689,1.83754,-2.17863,-0.041199,1.74471,-2.22939,0.104345,1.62797,-2.18104,0.14378,1.57476,-2.20148,0.203095,1.41981,-1.80373,0.027391,1.51782,-1.88664,0.031478,1.54174,-1.93129,0.035083,1.5242,-2.00285,0.218695,1.46073,-2.06114,0.062865,1.12457,-1.76384,-0.062838,1.16952,-1.79157,-0.091946,1.09495,-1.8147,-0.09443,0.964937,-1.80238,-0.156817,0.784988,-1.79415,-0.186325,0.717684,-1.80507,-0.255042,0.830747,-1.82698,-0.283434,0.76543,-1.8332,-0.343756,0.53077,-1.84341,-0.442659,0.546905,-1.93728,-0.252493,0.382983,-1.88438,-0.316301,0.358869,-1.82321,0.343941,1.25707,-2.10336,0.399267,1.19689,-2.07932,0.239282,1.15913,-2.09486,0.293994,1.10208,-2.07669,0.405033,1.03399,-2.06651,0.383998,0.842917,-2.07538,0.280058,0.884119,-2.07676,0.257485,0.817671,-2.07343,0.202685,0.588231,-2.05973,0.107206,0.517211,-1.9987,0.382102,0.489415,-2.06835,0.319298,0.467313,-2.12889,0.115451,1.34781,-1.84034,0.130538,1.3759,-2.0532},
/*1798*/{0.288448,1.9452,-1.75554,0.326619,1.87159,-1.90867,0.254681,1.80269,-1.63084,0.225074,1.69331,-1.53743,0.340022,1.71398,-1.6479,0.418129,1.72133,-1.69522,0.218654,1.95363,-2.12775,0.319798,1.87406,-1.98208,0.108041,1.91795,-2.01504,-0.022916,1.83963,-2.17526,-0.04392,1.74887,-2.22658,0.101836,1.63276,-2.18206,0.14171,1.57851,-2.20194,0.203787,1.42263,-1.80377,0.028258,1.52166,-1.88522,0.03247,1.54524,-1.93021,0.035885,1.52753,-2.00135,0.218571,1.464,-2.06108,0.061061,1.12889,-1.76187,-0.061891,1.1771,-1.79123,-0.092726,1.09886,-1.81546,-0.096741,0.969513,-1.8017,-0.161992,0.790791,-1.79258,-0.192498,0.722698,-1.80313,-0.259437,0.837632,-1.82478,-0.289274,0.772949,-1.83212,-0.354701,0.540109,-1.84139,-0.450397,0.564663,-1.93439,-0.271793,0.387069,-1.88467,-0.337021,0.365975,-1.82527,0.344201,1.25958,-2.10167,0.398461,1.19828,-2.07834,0.237238,1.16203,-2.09523,0.292151,1.10397,-2.07807,0.401709,1.03396,-2.06805,0.391231,0.840621,-2.07623,0.284491,0.8777,-2.07674,0.266019,0.810672,-2.07168,0.221385,0.577753,-2.06101,0.133168,0.500553,-1.99889,0.407966,0.490154,-2.0644,0.346625,0.463827,-2.12576,0.116005,1.35095,-1.83984,0.130164,1.37934,-2.05273},
/*1799*/{0.289286,1.9476,-1.75648,0.328042,1.87518,-1.91056,0.25497,1.80586,-1.63127,0.225774,1.69631,-1.53728,0.339673,1.71722,-1.64955,0.418013,1.72347,-1.69743,0.217708,1.9559,-2.12784,0.319798,1.87702,-1.98348,0.108008,1.92026,-2.01408,-0.024747,1.84588,-2.17286,-0.045956,1.75297,-2.22486,0.100905,1.63625,-2.18199,0.1398,1.58157,-2.20252,0.204181,1.42541,-1.80352,0.0292,1.5239,-1.88418,0.033314,1.54882,-1.93007,0.036355,1.53156,-2.00024,0.218456,1.46722,-2.06046,0.059287,1.13268,-1.75869,-0.062642,1.17985,-1.79323,-0.094674,1.10288,-1.81533,-0.096053,0.973188,-1.80195,-0.165558,0.794914,-1.79132,-0.198747,0.727995,-1.8021,-0.262622,0.844793,-1.82239,-0.292795,0.780176,-1.8282,-0.363249,0.54997,-1.8387,-0.45704,0.581012,-1.93141,-0.290249,0.392034,-1.8862,-0.357013,0.373069,-1.82751,0.342747,1.26104,-2.10073,0.396346,1.19867,-2.07804,0.23531,1.16422,-2.09603,0.289622,1.10521,-2.07851,0.399869,1.03361,-2.06956,0.397771,0.839506,-2.07716,0.28936,0.871413,-2.07786,0.272855,0.806505,-2.07357,0.24197,0.567789,-2.05816,0.15438,0.487079,-1.99871,0.432818,0.490798,-2.05939,0.374475,0.459939,-2.12163,0.116303,1.35378,-1.8397,0.130227,1.38283,-2.05251},
/*1800*/{0.290431,1.94976,-1.75688,0.327197,1.87825,-1.91043,0.255544,1.80873,-1.63139,0.225653,1.69992,-1.53755,0.338976,1.71877,-1.65065,0.417051,1.72515,-1.69955,0.217018,1.9583,-2.12807,0.319556,1.87943,-1.98372,0.108607,1.92234,-2.0139,-0.024881,1.84925,-2.16986,-0.047523,1.75613,-2.22292,0.099108,1.6389,-2.1822,0.138089,1.58443,-2.20307,0.205113,1.42847,-1.80322,0.029752,1.5276,-1.88314,0.032241,1.55208,-1.92925,0.035996,1.53519,-1.99915,0.217926,1.47004,-2.05976,0.057547,1.13717,-1.75758,-0.065429,1.18625,-1.79634,-0.094704,1.10594,-1.8162,-0.09472,0.975337,-1.80138,-0.168125,0.79844,-1.79135,-0.204834,0.732402,-1.80168,-0.264039,0.850577,-1.82002,-0.296693,0.78691,-1.82483,-0.374202,0.559855,-1.83629,-0.465957,0.598841,-1.92706,-0.307744,0.399324,-1.88758,-0.376045,0.382086,-1.83071,0.341316,1.26087,-2.10039,0.394185,1.19838,-2.07776,0.23238,1.16533,-2.09654,0.286008,1.10522,-2.07972,0.397461,1.032,-2.07145,0.404149,0.836346,-2.07706,0.29392,0.864836,-2.07856,0.280044,0.794042,-2.07391,0.260977,0.55862,-2.05734,0.178116,0.475203,-1.99773,0.455571,0.491785,-2.05467,0.400912,0.457057,-2.1166,0.116494,1.35719,-1.83878,0.129459,1.38595,-2.0517},
/*1801*/{0.291681,1.95195,-1.75785,0.32808,1.88057,-1.91213,0.255839,1.81167,-1.63178,0.22603,1.70229,-1.53611,0.338775,1.72038,-1.65201,0.415693,1.72639,-1.70167,0.217347,1.96034,-2.12846,0.320182,1.88092,-1.98477,0.10864,1.92463,-2.01363,-0.025761,1.85297,-2.16789,-0.049205,1.75934,-2.2202,0.097518,1.64029,-2.18185,0.136438,1.587,-2.20398,0.205454,1.43141,-1.80295,0.030622,1.5297,-1.88241,0.032471,1.55524,-1.9275,0.035709,1.53834,-1.99844,0.217485,1.47262,-2.05924,0.058921,1.13998,-1.75532,-0.066247,1.18577,-1.79595,-0.093296,1.10764,-1.81764,-0.091578,0.976605,-1.80163,-0.169807,0.801101,-1.79143,-0.207031,0.736301,-1.80127,-0.264054,0.856562,-1.81732,-0.300032,0.795525,-1.82271,-0.384348,0.569739,-1.83408,-0.474465,0.616014,-1.92122,-0.324301,0.409742,-1.89054,-0.394047,0.390554,-1.83413,0.338996,1.26015,-2.10019,0.391287,1.19649,-2.07794,0.229617,1.16562,-2.09665,0.282233,1.10572,-2.08023,0.39504,1.03006,-2.07336,0.408958,0.834726,-2.07698,0.297771,0.857175,-2.07968,0.287195,0.786824,-2.0745,0.280006,0.55022,-2.05639,0.199604,0.46304,-1.99846,0.477621,0.492756,-2.04913,0.425508,0.453441,-2.11156,0.116876,1.3599,-1.83813,0.129044,1.38878,-2.05107},
/*1802*/{0.29232,1.95339,-1.75828,0.327601,1.8823,-1.91185,0.255819,1.8138,-1.63171,0.226097,1.70484,-1.53608,0.338183,1.72211,-1.65327,0.4144,1.72696,-1.70266,0.216692,1.96225,-2.12846,0.320613,1.88325,-1.98543,0.108986,1.92598,-2.01374,-0.025853,1.85069,-2.16365,-0.050825,1.76188,-2.21873,0.097271,1.64229,-2.18255,0.134965,1.58907,-2.20471,0.205953,1.43441,-1.80266,0.030532,1.53274,-1.88241,0.032396,1.55819,-1.92821,0.035337,1.54068,-1.99819,0.217471,1.47492,-2.05884,0.058053,1.14321,-1.75385,-0.065341,1.18705,-1.7968,-0.091847,1.10925,-1.81833,-0.087615,0.976638,-1.80165,-0.170873,0.802949,-1.79102,-0.211195,0.740112,-1.80134,-0.26324,0.862705,-1.81443,-0.300407,0.802164,-1.81888,-0.392958,0.579957,-1.83228,-0.482668,0.633698,-1.9142,-0.343177,0.417319,-1.89378,-0.411789,0.401123,-1.8359,0.335864,1.25815,-2.10017,0.387939,1.19374,-2.07827,0.225511,1.16551,-2.09727,0.27745,1.10411,-2.08061,0.392087,1.02702,-2.07515,0.412854,0.832437,-2.07758,0.300402,0.849639,-2.0821,0.293021,0.779284,-2.0754,0.297968,0.542161,-2.05577,0.221758,0.451237,-1.99536,0.498126,0.494272,-2.04461,0.449457,0.451066,-2.10646,0.116982,1.36303,-1.8375,0.129015,1.39105,-2.05056},
/*1803*/{0.292732,1.95528,-1.75871,0.327755,1.88511,-1.91338,0.256101,1.81576,-1.63264,0.225483,1.70688,-1.53566,0.337804,1.72206,-1.65269,0.413376,1.72715,-1.70391,0.216304,1.9636,-2.12859,0.320456,1.88403,-1.98594,0.108752,1.9279,-2.01348,-0.023872,1.85289,-2.16092,-0.051755,1.76397,-2.21695,0.096129,1.6442,-2.18289,0.133601,1.59063,-2.20532,0.206396,1.43723,-1.80224,0.029686,1.5344,-1.88269,0.032196,1.56019,-1.9278,0.035376,1.54371,-1.99669,0.217339,1.47639,-2.05826,0.060145,1.1453,-1.75383,-0.060176,1.18861,-1.79556,-0.089039,1.10888,-1.81833,-0.083325,0.976587,-1.80183,-0.171007,0.804964,-1.79124,-0.21522,0.742816,-1.80236,-0.261379,0.868443,-1.81147,-0.301034,0.809128,-1.81634,-0.401179,0.591865,-1.83109,-0.493149,0.650309,-1.90958,-0.361276,0.428461,-1.89761,-0.427372,0.413736,-1.83857,0.333081,1.25536,-2.10024,0.384541,1.1907,-2.07868,0.221178,1.16371,-2.09737,0.272323,1.10244,-2.08206,0.388322,1.0238,-2.07624,0.416271,0.830203,-2.07784,0.303489,0.842323,-2.0836,0.299963,0.772181,-2.07777,0.314846,0.534575,-2.05464,0.241991,0.442653,-1.99477,0.518456,0.495474,-2.0394,0.47138,0.446604,-2.1009,0.116998,1.36541,-1.8367,0.128864,1.39304,-2.04983},
/*1804*/{0.293239,1.95642,-1.75937,0.327697,1.88681,-1.91406,0.255675,1.81783,-1.63283,0.224305,1.70848,-1.53546,0.335318,1.72228,-1.65306,0.412243,1.72554,-1.7056,0.216631,1.96527,-2.12949,0.320858,1.88536,-1.98693,0.109603,1.92955,-2.0139,-0.025106,1.85405,-2.15771,-0.053019,1.76605,-2.21558,0.095395,1.64517,-2.18301,0.133153,1.59202,-2.2063,0.206926,1.43998,-1.80204,0.031833,1.53687,-1.88047,0.031841,1.56243,-1.92745,0.037405,1.54271,-1.99586,0.217762,1.47782,-2.05774,0.063547,1.14601,-1.7536,-0.061427,1.18704,-1.79596,-0.085868,1.10834,-1.81755,-0.077031,0.976098,-1.8019,-0.170616,0.806362,-1.79133,-0.216616,0.746338,-1.80226,-0.25913,0.873593,-1.80848,-0.301211,0.816434,-1.81361,-0.411193,0.60193,-1.8298,-0.502258,0.665733,-1.9016,-0.376157,0.441927,-1.90292,-0.44038,0.425754,-1.84109,0.329048,1.25262,-2.10063,0.380071,1.18687,-2.07999,0.216684,1.16269,-2.09816,0.266559,1.10002,-2.08223,0.384121,1.01956,-2.07749,0.419656,0.82749,-2.07845,0.305488,0.835477,-2.0854,0.305594,0.765024,-2.0784,0.3321,0.528013,-2.05361,0.262054,0.435179,-1.99197,0.535107,0.496627,-2.0357,0.492623,0.444258,-2.09531,0.11865,1.36777,-1.83481,0.12959,1.39377,-2.04819},
/*1805*/{0.292918,1.95638,-1.75984,0.326912,1.88747,-1.91449,0.254789,1.81919,-1.63323,0.224561,1.71024,-1.53571,0.334623,1.72194,-1.65413,0.410284,1.72463,-1.70666,0.216333,1.96594,-2.12954,0.321093,1.88634,-1.98782,0.109608,1.93087,-2.01376,-0.025797,1.85492,-2.15551,-0.054113,1.76725,-2.21398,0.094713,1.64759,-2.18359,0.132386,1.59276,-2.207,0.207298,1.44245,-1.80079,0.030609,1.53765,-1.8816,0.032364,1.56407,-1.9272,0.037112,1.54385,-1.99453,0.217843,1.47893,-2.05735,0.067773,1.14524,-1.75453,-0.057872,1.1854,-1.79442,-0.08108,1.10632,-1.81668,-0.072902,0.974641,-1.80184,-0.170287,0.808091,-1.79189,-0.219593,0.74985,-1.80318,-0.256214,0.878767,-1.80587,-0.300551,0.82371,-1.8113,-0.417646,0.613637,-1.82826,-0.511585,0.682326,-1.89368,-0.390722,0.455339,-1.90752,-0.452475,0.439345,-1.84334,0.326539,1.24895,-2.10104,0.375892,1.18237,-2.08082,0.211794,1.15977,-2.09814,0.26137,1.09751,-2.08232,0.379065,1.01462,-2.07844,0.422189,0.825524,-2.07861,0.308135,0.827611,-2.08695,0.310918,0.756818,-2.07917,0.346376,0.521328,-2.05275,0.28033,0.426698,-1.98969,0.55103,0.497901,-2.03151,0.512112,0.441564,-2.08933,0.118928,1.36966,-1.83377,0.130045,1.3948,-2.04724},
/*1806*/{0.292964,1.9566,-1.76003,0.326256,1.88852,-1.9153,0.253043,1.81989,-1.63359,0.221341,1.71064,-1.53615,0.333111,1.72155,-1.65575,0.408324,1.72257,-1.70788,0.216452,1.96673,-2.13013,0.320341,1.88652,-1.98782,0.109983,1.93232,-2.01387,-0.02561,1.85568,-2.154,-0.054612,1.76806,-2.21251,0.095061,1.64683,-2.18364,0.131543,1.59273,-2.20807,0.207326,1.44492,-1.80013,0.030436,1.53853,-1.88194,0.032506,1.56571,-1.92795,0.036404,1.54471,-1.99436,0.218368,1.47964,-2.0562,0.073632,1.14466,-1.75577,-0.053651,1.18412,-1.79389,-0.076899,1.1039,-1.81475,-0.065643,0.97287,-1.80199,-0.16906,0.808757,-1.79269,-0.22055,0.754154,-1.80332,-0.251596,0.883958,-1.80393,-0.298582,0.831133,-1.80813,-0.426122,0.6256,-1.8274,-0.520089,0.698293,-1.88641,-0.405877,0.469107,-1.91192,-0.464267,0.452455,-1.84565,0.32186,1.24467,-2.10237,0.371471,1.17697,-2.08201,0.206966,1.15716,-2.09813,0.255233,1.0932,-2.08276,0.374697,1.01022,-2.07951,0.423557,0.82337,-2.07826,0.310523,0.820387,-2.08871,0.316152,0.750989,-2.08027,0.361689,0.515266,-2.05174,0.295966,0.420453,-1.9873,0.566629,0.499353,-2.02777,0.529432,0.439964,-2.08439,0.119069,1.37165,-1.83265,0.130653,1.39546,-2.04625},
/*1807*/{0.292447,1.9572,-1.76049,0.326123,1.88892,-1.91573,0.251667,1.82122,-1.63453,0.220302,1.71223,-1.53643,0.331523,1.72021,-1.65598,0.406997,1.72003,-1.70853,0.217146,1.96716,-2.13047,0.319744,1.88712,-1.98804,0.110497,1.93323,-2.01451,-0.026021,1.85587,-2.15278,-0.055006,1.76851,-2.2113,0.094959,1.64675,-2.1845,0.131384,1.59296,-2.20908,0.207651,1.44691,-1.79993,0.031787,1.53991,-1.88043,0.03225,1.56658,-1.92768,0.036377,1.54464,-1.99439,0.218444,1.4798,-2.05527,0.078919,1.14309,-1.7581,-0.049026,1.18094,-1.79199,-0.071819,1.10128,-1.81326,-0.058958,0.969878,-1.8026,-0.167812,0.810467,-1.79359,-0.221857,0.757667,-1.80433,-0.24781,0.889913,-1.80162,-0.296828,0.838502,-1.80674,-0.432633,0.638034,-1.82657,-0.527325,0.715147,-1.87878,-0.419296,0.484562,-1.91605,-0.474997,0.466553,-1.84713,0.318367,1.24005,-2.10291,0.366562,1.17206,-2.08326,0.20184,1.15411,-2.09807,0.24973,1.08988,-2.08313,0.369369,1.00501,-2.0805,0.42622,0.821357,-2.07734,0.31314,0.813383,-2.09001,0.32111,0.74422,-2.08133,0.373296,0.510016,-2.05044,0.310618,0.414097,-1.98554,0.57862,0.500231,-2.02397,0.545539,0.439201,-2.07921,0.11984,1.3733,-1.83101,0.130718,1.39547,-2.04483},
/*1808*/{0.292146,1.958,-1.76122,0.325481,1.88906,-1.91606,0.250287,1.82163,-1.63503,0.217013,1.71167,-1.53678,0.329771,1.71823,-1.65685,0.404505,1.71716,-1.7095,0.217142,1.96744,-2.13074,0.319433,1.88739,-1.98828,0.110488,1.93345,-2.01437,-0.026932,1.85574,-2.15016,-0.0549,1.76875,-2.21047,0.094703,1.6463,-2.18486,0.131082,1.59197,-2.21048,0.207612,1.44834,-1.79922,0.029521,1.54089,-1.88139,0.031667,1.56678,-1.92794,0.037025,1.54388,-1.9944,0.218944,1.47965,-2.05443,0.086612,1.14156,-1.76004,-0.041137,1.17821,-1.78942,-0.065944,1.09767,-1.81205,-0.052171,0.967654,-1.80325,-0.166683,0.811707,-1.79366,-0.224738,0.762136,-1.80462,-0.243289,0.894622,-1.79967,-0.294939,0.846253,-1.80462,-0.437827,0.651005,-1.82586,-0.532482,0.732214,-1.87223,-0.431883,0.499531,-1.9192,-0.485233,0.482644,-1.84962,0.31465,1.23511,-2.1038,0.362231,1.16674,-2.08453,0.196486,1.1509,-2.0985,0.244085,1.08573,-2.08261,0.364031,1.0004,-2.08149,0.427068,0.819023,-2.0756,0.31523,0.807689,-2.09224,0.326004,0.738937,-2.08271,0.384812,0.505305,-2.04923,0.323849,0.410085,-1.98362,0.59054,0.501342,-2.01885,0.559311,0.437788,-2.07503,0.119559,1.37438,-1.82992,0.131405,1.39515,-2.04383},
/*1809*/{0.291258,1.95653,-1.7619,0.324905,1.88868,-1.91657,0.24866,1.82164,-1.63537,0.214655,1.71232,-1.53753,0.32687,1.7155,-1.65716,0.402593,1.71294,-1.70973,0.216972,1.96746,-2.13109,0.318998,1.88731,-1.98844,0.110739,1.93414,-2.01529,-0.026266,1.85533,-2.14872,-0.055025,1.76827,-2.20952,0.094197,1.64503,-2.18545,0.130974,1.59109,-2.21136,0.207961,1.44922,-1.7983,0.028501,1.54025,-1.88136,0.031077,1.56664,-1.92814,0.036918,1.54285,-1.99451,0.219542,1.47946,-2.05356,0.09307,1.13865,-1.76297,-0.037589,1.17543,-1.78814,-0.060245,1.09411,-1.81064,-0.044526,0.96501,-1.80368,-0.165817,0.813822,-1.79476,-0.22497,0.766796,-1.80584,-0.237836,0.900344,-1.79627,-0.292175,0.854126,-1.80322,-0.444025,0.666987,-1.82396,-0.536302,0.750098,-1.86567,-0.443706,0.515413,-1.92209,-0.496908,0.498041,-1.85066,0.31109,1.23001,-2.10465,0.357462,1.16082,-2.086,0.191365,1.14855,-2.09702,0.238497,1.08183,-2.08272,0.358555,0.995083,-2.08162,0.429199,0.816526,-2.07364,0.317876,0.801763,-2.09299,0.330484,0.733915,-2.08331,0.394143,0.502167,-2.04739,0.333978,0.404405,-1.98351,0.600346,0.502792,-2.01577,0.569998,0.437226,-2.07075,0.120002,1.37471,-1.82893,0.132365,1.3946,-2.04289},
/*1810*/{0.290942,1.95542,-1.76207,0.323888,1.8885,-1.91651,0.245998,1.82156,-1.63611,0.213115,1.71276,-1.5383,0.325331,1.71383,-1.65791,0.400445,1.70876,-1.71035,0.217716,1.96694,-2.13135,0.318383,1.8867,-1.9889,0.111071,1.93411,-2.01629,-0.025729,1.85619,-2.14734,-0.054948,1.76749,-2.20915,0.094093,1.6433,-2.18648,0.131506,1.58985,-2.21214,0.207933,1.44947,-1.79761,0.028259,1.53969,-1.88178,0.031119,1.56566,-1.9283,0.035954,1.54175,-1.9948,0.220151,1.47926,-2.05257,0.099914,1.13708,-1.7651,-0.032032,1.16929,-1.78644,-0.052755,1.08964,-1.8096,-0.037145,0.961514,-1.80501,-0.163558,0.816005,-1.79502,-0.22439,0.77209,-1.80532,-0.232114,0.906119,-1.79596,-0.287355,0.861512,-1.80263,-0.44745,0.680702,-1.82113,-0.537634,0.768763,-1.86063,-0.453726,0.532193,-1.92276,-0.508366,0.514279,-1.85171,0.307021,1.22473,-2.1052,0.352467,1.15485,-2.08696,0.187348,1.145,-2.09669,0.233283,1.07755,-2.08166,0.353773,0.989837,-2.08158,0.430133,0.814129,-2.07147,0.319432,0.796547,-2.09342,0.333033,0.728687,-2.08387,0.401648,0.498759,-2.04589,0.343952,0.399646,-1.98083,0.607376,0.50361,-2.01354,0.579405,0.436544,-2.06837,0.120303,1.37458,-1.8283,0.133254,1.39389,-2.04227},
/*1811*/{0.289205,1.95496,-1.76228,0.3224,1.88826,-1.91639,0.243863,1.82157,-1.63676,0.209525,1.71262,-1.53975,0.322964,1.71102,-1.65806,0.398099,1.70501,-1.71063,0.217569,1.96633,-2.13174,0.317966,1.88611,-1.98904,0.111272,1.93416,-2.01711,-0.027419,1.85771,-2.14828,-0.053802,1.76655,-2.20912,0.094591,1.64209,-2.18724,0.131775,1.58812,-2.21298,0.208087,1.44929,-1.79741,0.029792,1.53725,-1.88027,0.031637,1.56411,-1.92842,0.03624,1.53959,-1.99534,0.220717,1.47825,-2.05171,0.107398,1.13322,-1.76792,-0.026405,1.16437,-1.78466,-0.046737,1.08457,-1.80947,-0.028836,0.957532,-1.80657,-0.16175,0.818696,-1.79485,-0.224099,0.77749,-1.80444,-0.226863,0.912188,-1.79444,-0.284317,0.870207,-1.80114,-0.449717,0.695182,-1.81861,-0.537386,0.787977,-1.85705,-0.464056,0.54826,-1.92221,-0.519101,0.532874,-1.85214,0.303931,1.21945,-2.10575,0.349042,1.14931,-2.0885,0.183304,1.14054,-2.09542,0.228224,1.07325,-2.08128,0.348512,0.984456,-2.08126,0.430066,0.811071,-2.06916,0.320393,0.791611,-2.09274,0.335476,0.724604,-2.08312,0.407759,0.495525,-2.0458,0.352191,0.396847,-1.97963,0.613044,0.503834,-2.01276,0.586658,0.436266,-2.06594,0.121692,1.37349,-1.82752,0.134565,1.39227,-2.04154},
/*1812*/{0.287938,1.95426,-1.7633,0.321556,1.88726,-1.91669,0.241145,1.82103,-1.63742,0.206809,1.71148,-1.54025,0.32011,1.70758,-1.65798,0.394834,1.70008,-1.71008,0.21764,1.96534,-2.13184,0.317323,1.88551,-1.98922,0.110619,1.93373,-2.01751,-0.02719,1.85566,-2.14658,-0.053119,1.76501,-2.20921,0.095513,1.63941,-2.18817,0.131974,1.58583,-2.21441,0.208185,1.44901,-1.79722,0.029438,1.53523,-1.88018,0.030816,1.56344,-1.92876,0.036313,1.53703,-1.99537,0.221225,1.47678,-2.05089,0.113919,1.13063,-1.76974,-0.018749,1.16033,-1.78241,-0.038607,1.07977,-1.80817,-0.019895,0.953708,-1.80721,-0.158747,0.821983,-1.79474,-0.223234,0.782821,-1.80454,-0.220367,0.915995,-1.79482,-0.279402,0.878289,-1.79963,-0.453366,0.709163,-1.81675,-0.535693,0.80716,-1.85384,-0.472318,0.566106,-1.92161,-0.529109,0.551471,-1.85221,0.301088,1.21388,-2.1064,0.345974,1.14393,-2.08955,0.178935,1.13709,-2.09437,0.223463,1.06948,-2.08094,0.343663,0.97938,-2.08091,0.429195,0.808483,-2.0677,0.319484,0.786729,-2.09168,0.336608,0.719728,-2.08166,0.41307,0.492123,-2.04477,0.357879,0.393318,-1.9786,0.617512,0.50303,-2.01176,0.593212,0.435516,-2.06425,0.12213,1.37266,-1.8267,0.135318,1.39053,-2.04079},
/*1813*/{0.285553,1.95323,-1.76376,0.321691,1.88651,-1.91709,0.237546,1.82011,-1.63791,0.203396,1.71065,-1.5411,0.316598,1.70334,-1.65791,0.392853,1.69504,-1.70967,0.217359,1.96385,-2.13221,0.316257,1.88434,-1.98897,0.110365,1.93306,-2.01824,-0.026468,1.85418,-2.14603,-0.052703,1.76292,-2.20947,0.095623,1.63724,-2.18906,0.132191,1.58309,-2.21511,0.208344,1.4485,-1.79704,0.029282,1.53343,-1.88111,0.030028,1.56086,-1.92929,0.036393,1.53484,-1.99611,0.221625,1.47547,-2.05036,0.122226,1.128,-1.77194,-0.013142,1.15485,-1.78058,-0.031395,1.07438,-1.80964,-0.010836,0.949758,-1.808,-0.155413,0.825428,-1.79363,-0.220889,0.789088,-1.80238,-0.212474,0.922654,-1.79505,-0.273899,0.886217,-1.79891,-0.454579,0.724761,-1.81427,-0.53276,0.826487,-1.85176,-0.478469,0.583051,-1.91899,-0.537499,0.570267,-1.85049,0.298706,1.20864,-2.10722,0.341713,1.13792,-2.09146,0.176473,1.13465,-2.09441,0.219905,1.06568,-2.08002,0.339163,0.974751,-2.08056,0.42718,0.805637,-2.06638,0.318418,0.782973,-2.08924,0.334971,0.715801,-2.07924,0.414812,0.48892,-2.04282,0.362008,0.389181,-1.97655,0.620598,0.501735,-2.01122,0.596272,0.434107,-2.06428,0.122738,1.3715,-1.82642,0.136468,1.38865,-2.04053},
/*1814*/{0.284219,1.95113,-1.76322,0.319866,1.88501,-1.91669,0.234283,1.81904,-1.63828,0.197315,1.70893,-1.54259,0.313216,1.69982,-1.65782,0.389788,1.68936,-1.70957,0.217501,1.96283,-2.1324,0.314896,1.88275,-1.98884,0.109271,1.93156,-2.01964,-0.024709,1.8485,-2.14369,-0.051347,1.76054,-2.21048,0.096964,1.63428,-2.18976,0.133708,1.5807,-2.21635,0.208922,1.44729,-1.79692,0.029342,1.53083,-1.88263,0.032537,1.56027,-1.92968,0.036719,1.53129,-1.9964,0.222001,1.47305,-2.05039,0.127982,1.1257,-1.77348,-0.007697,1.14803,-1.77997,-0.022845,1.06846,-1.80866,-0.002053,0.945429,-1.80835,-0.150978,0.82921,-1.79292,-0.218402,0.794862,-1.8014,-0.204607,0.928592,-1.79412,-0.267947,0.894379,-1.79863,-0.45529,0.740492,-1.81147,-0.527851,0.845837,-1.84937,-0.48565,0.600204,-1.9158,-0.54549,0.59023,-1.84842,0.296953,1.20389,-2.10869,0.340344,1.13163,-2.09196,0.173813,1.12957,-2.09236,0.216757,1.06161,-2.07832,0.334559,0.96957,-2.07955,0.424085,0.802515,-2.06593,0.315176,0.778436,-2.08588,0.333146,0.711842,-2.07659,0.416485,0.486255,-2.04125,0.364368,0.385196,-1.9741,0.62193,0.499352,-2.01095,0.597678,0.431828,-2.06446,0.123431,1.37001,-1.82604,0.137333,1.38596,-2.04024},
/*1815*/{0.281934,1.94935,-1.76416,0.319152,1.88377,-1.91679,0.231332,1.81722,-1.63819,0.193512,1.7081,-1.54413,0.309454,1.6958,-1.65753,0.386803,1.68308,-1.70854,0.217391,1.96091,-2.13236,0.314409,1.881,-1.98893,0.109297,1.93081,-2.02055,-0.023937,1.8454,-2.14389,-0.05068,1.75736,-2.21186,0.098159,1.63082,-2.19055,0.134353,1.57719,-2.21775,0.2093,1.44628,-1.79748,0.029911,1.52801,-1.88229,0.031959,1.55698,-1.93025,0.036646,1.52879,-1.99734,0.222216,1.47064,-2.0508,0.136865,1.12407,-1.77401,-0.001786,1.14269,-1.77879,-0.016377,1.06299,-1.80754,0.007042,0.941064,-1.80786,-0.146486,0.83243,-1.79137,-0.21511,0.801274,-1.79988,-0.195783,0.933607,-1.79405,-0.260166,0.901611,-1.79788,-0.454444,0.755791,-1.8093,-0.521193,0.864116,-1.84862,-0.490561,0.616044,-1.91318,-0.551013,0.609845,-1.84663,0.295207,1.19831,-2.10905,0.337002,1.126,-2.09282,0.171979,1.12657,-2.09125,0.214029,1.05716,-2.07727,0.33038,0.964837,-2.07893,0.420703,0.799116,-2.0655,0.311433,0.774578,-2.08377,0.330715,0.707642,-2.07397,0.414597,0.481891,-2.03964,0.364988,0.382352,-1.9723,0.620869,0.497012,-2.01205,0.596232,0.430274,-2.06467,0.124514,1.36815,-1.82592,0.137968,1.38328,-2.0402},
/*1816*/{0.278938,1.94713,-1.76325,0.318011,1.88176,-1.91675,0.228183,1.81587,-1.63825,0.188559,1.70596,-1.54467,0.305567,1.69115,-1.65718,0.382628,1.67672,-1.70697,0.216055,1.9586,-2.13229,0.314008,1.8795,-1.98852,0.10802,1.92919,-2.02166,-0.024259,1.84263,-2.1443,-0.049595,1.75389,-2.21306,0.098069,1.62828,-2.193,0.135263,1.57383,-2.21896,0.210138,1.44469,-1.79828,0.02947,1.52491,-1.8824,0.0318,1.55261,-1.93118,0.037485,1.52605,-1.9977,0.22273,1.46763,-2.0511,0.142367,1.12073,-1.77523,0.004081,1.13668,-1.77794,-0.009455,1.05785,-1.80737,0.014978,0.935942,-1.80851,-0.14128,0.835098,-1.79136,-0.210516,0.806464,-1.79845,-0.187097,0.93756,-1.79408,-0.252019,0.909003,-1.79748,-0.452455,0.771083,-1.80877,-0.513519,0.882516,-1.84815,-0.493456,0.633152,-1.90975,-0.556077,0.629612,-1.84466,0.294563,1.19298,-2.11014,0.335197,1.12099,-2.09382,0.170008,1.12314,-2.0906,0.211432,1.05362,-2.07651,0.326744,0.960058,-2.07783,0.416811,0.795683,-2.06445,0.307808,0.770161,-2.08109,0.327212,0.703485,-2.07182,0.412995,0.477933,-2.03705,0.363845,0.379697,-1.96753,0.620502,0.494433,-2.01259,0.594012,0.426936,-2.06486,0.125706,1.3657,-1.82591,0.13899,1.38011,-2.04025},
/*1817*/{0.277938,1.94591,-1.76321,0.317343,1.87949,-1.91645,0.224374,1.81362,-1.63808,0.184501,1.70429,-1.54606,0.301514,1.68634,-1.65716,0.378913,1.66982,-1.70495,0.215619,1.95588,-2.13244,0.313164,1.87737,-1.98882,0.107507,1.92656,-2.02196,-0.023696,1.83937,-2.14521,-0.048444,1.74982,-2.21538,0.099302,1.62434,-2.19389,0.136647,1.57001,-2.22011,0.210551,1.44264,-1.79925,0.029372,1.52251,-1.88288,0.031747,1.54939,-1.93089,0.036887,1.52281,-1.9987,0.222273,1.46436,-2.05228,0.148012,1.11751,-1.77661,0.010276,1.13158,-1.77746,-0.001794,1.05187,-1.80584,0.02272,0.931957,-1.80828,-0.135375,0.837604,-1.79074,-0.205908,0.812204,-1.79695,-0.177201,0.942643,-1.79357,-0.24301,0.916337,-1.79702,-0.44912,0.786045,-1.80557,-0.50452,0.899325,-1.84718,-0.49563,0.648904,-1.90635,-0.558435,0.649417,-1.84127,0.294237,1.18756,-2.11084,0.333782,1.11493,-2.09408,0.168357,1.1192,-2.08971,0.209223,1.05,-2.07518,0.32379,0.95577,-2.07705,0.412328,0.791489,-2.06449,0.302772,0.765614,-2.0798,0.322441,0.699395,-2.06957,0.409582,0.474448,-2.03481,0.361198,0.375534,-1.96426,0.616966,0.489844,-2.01261,0.590234,0.423291,-2.06499,0.126213,1.36336,-1.82606,0.138484,1.37683,-2.04052},
/*1818*/{0.275543,1.94236,-1.76297,0.315868,1.87725,-1.91663,0.220394,1.81101,-1.63793,0.178374,1.70152,-1.54736,0.297262,1.68141,-1.65631,0.374802,1.66259,-1.70331,0.214845,1.95361,-2.13218,0.312068,1.87526,-1.98889,0.105967,1.92466,-2.02392,-0.023499,1.83526,-2.14574,-0.048094,1.74525,-2.21677,0.100325,1.6188,-2.19567,0.138708,1.56597,-2.22171,0.211022,1.44054,-1.79942,0.029212,1.51893,-1.88322,0.030783,1.54564,-1.93171,0.037251,1.51863,-1.99899,0.222269,1.46141,-2.05311,0.153831,1.11459,-1.77705,0.018042,1.12769,-1.77716,0.005154,1.0462,-1.806,0.030882,0.928226,-1.80846,-0.129044,0.839806,-1.78988,-0.200203,0.816735,-1.79636,-0.167342,0.946358,-1.79339,-0.233987,0.92248,-1.79538,-0.444467,0.80093,-1.80229,-0.494707,0.915468,-1.84674,-0.496403,0.663517,-1.90219,-0.560366,0.667873,-1.83721,0.293213,1.18243,-2.11184,0.332187,1.10935,-2.09487,0.167338,1.11575,-2.08935,0.207508,1.04615,-2.07425,0.32071,0.951267,-2.07665,0.408449,0.786359,-2.06422,0.297796,0.761225,-2.07812,0.317449,0.694258,-2.06719,0.405838,0.470464,-2.03236,0.355704,0.370545,-1.96216,0.611663,0.484689,-2.01196,0.583412,0.417577,-2.06392,0.127227,1.36063,-1.82603,0.139177,1.37332,-2.04055},
/*1819*/{0.272825,1.93964,-1.76266,0.315596,1.87518,-1.91681,0.216634,1.80829,-1.63769,0.173686,1.69925,-1.54828,0.292391,1.67651,-1.65586,0.370462,1.65513,-1.70161,0.213732,1.94997,-2.13201,0.310408,1.87252,-1.98876,0.105132,1.92121,-2.02448,-0.023529,1.83022,-2.14797,-0.04693,1.73999,-2.2193,0.102042,1.61385,-2.19711,0.140313,1.56144,-2.22302,0.210822,1.4375,-1.79919,0.028802,1.51532,-1.8831,0.030987,1.54253,-1.93196,0.036708,1.51469,-1.99973,0.22186,1.45759,-2.0542,0.158204,1.11097,-1.7769,0.023476,1.12217,-1.77658,0.012067,1.04079,-1.80412,0.039225,0.923976,-1.8083,-0.121962,0.842121,-1.78946,-0.195074,0.820704,-1.79571,-0.156686,0.949272,-1.79416,-0.224642,0.927443,-1.79426,-0.437749,0.814601,-1.79925,-0.484253,0.930749,-1.84647,-0.49631,0.678334,-1.89798,-0.560783,0.68592,-1.83314,0.29239,1.17772,-2.11258,0.329611,1.1046,-2.09604,0.16544,1.11338,-2.08846,0.204207,1.04274,-2.07346,0.319387,0.947077,-2.07594,0.402926,0.781287,-2.06408,0.292936,0.756693,-2.07626,0.311404,0.689779,-2.06556,0.39891,0.464971,-2.02946,0.351833,0.366633,-1.95681,0.606699,0.478788,-2.01142,0.575842,0.409736,-2.06311,0.12714,1.35745,-1.82599,0.138724,1.36948,-2.04057},
/*1820*/{0.270137,1.93675,-1.76214,0.313568,1.8718,-1.91573,0.212433,1.80502,-1.63746,0.168265,1.69598,-1.5489,0.287355,1.67054,-1.65528,0.366112,1.64758,-1.70002,0.212913,1.94682,-2.13244,0.309885,1.86974,-1.98854,0.103806,1.91717,-2.02543,-0.022068,1.82479,-2.15044,-0.045969,1.73429,-2.22215,0.103738,1.60904,-2.1993,0.142224,1.55646,-2.22466,0.212438,1.43484,-1.80077,0.028845,1.51126,-1.88346,0.030572,1.53843,-1.93309,0.036901,1.51024,-1.99999,0.221812,1.45482,-2.05497,0.164666,1.10834,-1.77638,0.027073,1.11543,-1.77729,0.018776,1.03592,-1.80533,0.047287,0.920048,-1.8067,-0.115478,0.843206,-1.78895,-0.188469,0.825652,-1.79268,-0.145654,0.951582,-1.79396,-0.214717,0.932215,-1.79304,-0.431129,0.826777,-1.79859,-0.473491,0.94454,-1.84593,-0.494958,0.691629,-1.89357,-0.557641,0.703477,-1.82908,0.290377,1.17376,-2.11421,0.327771,1.09978,-2.09641,0.163554,1.11119,-2.08759,0.201466,1.04005,-2.07305,0.318218,0.94324,-2.07518,0.397871,0.775996,-2.06478,0.288805,0.750682,-2.07028,0.306595,0.685205,-2.06324,0.391155,0.460029,-2.02725,0.34389,0.362502,-1.95369,0.598791,0.469856,-2.01052,0.568031,0.402575,-2.06074,0.129017,1.3542,-1.82669,0.139617,1.36599,-2.04134},
/*1821*/{0.267299,1.93314,-1.76153,0.313656,1.8689,-1.91583,0.208461,1.80194,-1.63711,0.162276,1.69308,-1.54976,0.281815,1.6638,-1.65419,0.360787,1.63965,-1.69807,0.211448,1.94267,-2.13255,0.308939,1.86653,-1.98788,0.102759,1.91276,-2.02729,-0.022864,1.81826,-2.15346,-0.044455,1.72853,-2.22478,0.105911,1.60354,-2.2012,0.144793,1.55129,-2.22656,0.212467,1.43143,-1.80134,0.028979,1.50705,-1.88351,0.030209,1.53487,-1.9331,0.035254,1.50616,-1.99972,0.221484,1.45173,-2.05561,0.170047,1.10536,-1.77532,0.032247,1.11139,-1.77747,0.024745,1.03138,-1.80594,0.054592,0.916236,-1.80685,-0.108338,0.844953,-1.78746,-0.181903,0.82833,-1.79308,-0.134283,0.953334,-1.79399,-0.204075,0.937971,-1.79291,-0.424308,0.840222,-1.796,-0.462812,0.957854,-1.84673,-0.49193,0.705198,-1.88861,-0.553558,0.720162,-1.8242,0.289351,1.16986,-2.11496,0.32555,1.09544,-2.09752,0.161233,1.10871,-2.08724,0.199331,1.03682,-2.07286,0.316429,0.939571,-2.07433,0.393639,0.769925,-2.06385,0.283735,0.745639,-2.06865,0.299488,0.680185,-2.06155,0.382613,0.454325,-2.02567,0.333724,0.359607,-1.94989,0.591576,0.462413,-2.00876,0.558767,0.393603,-2.05741,0.129475,1.35052,-1.8271,0.139302,1.36256,-2.04177},
/*1822*/{0.264572,1.92947,-1.76091,0.312517,1.86582,-1.91525,0.204095,1.79796,-1.63751,0.155845,1.6898,-1.55095,0.276851,1.65825,-1.65371,0.355239,1.63106,-1.69565,0.211391,1.9384,-2.1329,0.308591,1.86333,-1.98781,0.101826,1.90867,-2.0278,-0.022911,1.81251,-2.15613,-0.043074,1.72225,-2.22772,0.108521,1.59775,-2.20312,0.147493,1.54554,-2.22798,0.213367,1.42887,-1.80222,0.028781,1.50226,-1.8834,0.030542,1.52964,-1.93267,0.034187,1.50117,-1.99952,0.220579,1.4478,-2.05654,0.17364,1.10136,-1.77526,0.036668,1.10693,-1.77839,0.030488,1.02586,-1.80511,0.062641,0.912514,-1.80542,-0.100111,0.846303,-1.78558,-0.17475,0.832795,-1.79158,-0.123891,0.955513,-1.79363,-0.193952,0.941706,-1.79271,-0.416294,0.853262,-1.79659,-0.451701,0.96993,-1.84791,-0.487868,0.717085,-1.88436,-0.548606,0.73456,-1.81964,0.287431,1.16574,-2.11535,0.324462,1.09066,-2.09732,0.160198,1.10488,-2.08658,0.19739,1.03284,-2.07229,0.315322,0.936099,-2.0737,0.388756,0.764158,-2.06446,0.27684,0.742461,-2.07224,0.29462,0.675743,-2.05975,0.373768,0.448873,-2.02346,0.322395,0.355521,-1.94664,0.58177,0.453097,-2.00706,0.549545,0.38429,-2.05466,0.131168,1.34692,-1.82686,0.139324,1.35803,-2.04166},
/*1823*/{0.262582,1.926,-1.7603,0.311709,1.86155,-1.91418,0.199938,1.79362,-1.63711,0.150585,1.68722,-1.55172,0.270791,1.65164,-1.65243,0.350363,1.62318,-1.69314,0.211076,1.93347,-2.13362,0.308064,1.85989,-1.98759,0.100353,1.90399,-2.02906,-0.022176,1.80547,-2.15865,-0.041342,1.71542,-2.23044,0.110578,1.59167,-2.2052,0.150248,1.53971,-2.23001,0.214131,1.42532,-1.80322,0.028578,1.49747,-1.88287,0.029636,1.52531,-1.93336,0.033765,1.49592,-1.99996,0.220599,1.44451,-2.05739,0.179472,1.09821,-1.77225,0.041671,1.10338,-1.77948,0.035779,1.02025,-1.80676,0.071299,0.908684,-1.80318,-0.092796,0.846527,-1.78463,-0.168082,0.835791,-1.79027,-0.112011,0.956736,-1.79395,-0.183283,0.944945,-1.79266,-0.40689,0.864394,-1.79399,-0.440379,0.980799,-1.84871,-0.4817,0.72743,-1.88034,-0.542365,0.748183,-1.81456,0.286201,1.1616,-2.11613,0.322873,1.08705,-2.0984,0.15815,1.10085,-2.08597,0.195677,1.02937,-2.07201,0.314247,0.9319,-2.07257,0.383998,0.757551,-2.06313,0.271554,0.738384,-2.07061,0.287112,0.670453,-2.05919,0.361997,0.442256,-2.02059,0.310117,0.350759,-1.94418,0.572688,0.443777,-2.00325,0.538648,0.374164,-2.05055,0.132438,1.34289,-1.82744,0.139838,1.35407,-2.04225},
/*1824*/{0.260195,1.92154,-1.75928,0.31091,1.85778,-1.91415,0.196117,1.78929,-1.63687,0.143444,1.68328,-1.55204,0.26563,1.64509,-1.65219,0.343828,1.61448,-1.69149,0.21022,1.9282,-2.1336,0.307297,1.85566,-1.98761,0.099148,1.89905,-2.0306,-0.022154,1.79799,-2.16189,-0.039582,1.70878,-2.23351,0.113366,1.58511,-2.20774,0.153705,1.5338,-2.23144,0.214402,1.42195,-1.80504,0.028411,1.49229,-1.88274,0.029629,1.51953,-1.93355,0.03082,1.49302,-2.0002,0.218863,1.44106,-2.0582,0.180371,1.09549,-1.77164,0.044352,1.09679,-1.78152,0.042145,1.01554,-1.80529,0.078955,0.905464,-1.80208,-0.084442,0.847723,-1.78129,-0.159513,0.838831,-1.78815,-0.100688,0.957858,-1.7939,-0.171074,0.948165,-1.79293,-0.397523,0.875094,-1.793,-0.429186,0.990461,-1.84999,-0.474498,0.737115,-1.87597,-0.534938,0.759997,-1.81064,0.284776,1.15728,-2.11747,0.320922,1.08285,-2.09896,0.15664,1.09716,-2.08548,0.194332,1.02526,-2.07189,0.311941,0.927566,-2.07228,0.378719,0.750861,-2.06197,0.265413,0.733099,-2.06978,0.280388,0.665442,-2.05798,0.352998,0.437373,-2.01912,0.296468,0.351588,-1.94226,0.560842,0.433595,-2.00004,0.525656,0.364531,-2.04673,0.13315,1.33868,-1.82853,0.138799,1.35037,-2.04338},
/*1825*/{0.257476,1.91719,-1.75854,0.309993,1.85275,-1.91293,0.191877,1.78474,-1.63701,0.137015,1.67955,-1.55238,0.258985,1.63861,-1.65118,0.338398,1.60601,-1.68923,0.210055,1.92324,-2.13431,0.306972,1.85145,-1.98651,0.097923,1.89254,-2.03158,-0.022724,1.78974,-2.1646,-0.037236,1.70094,-2.23734,0.116633,1.5784,-2.20965,0.157325,1.52736,-2.23339,0.214245,1.41788,-1.80584,0.028162,1.48651,-1.88237,0.029118,1.51388,-1.93267,0.031907,1.48542,-1.99846,0.21874,1.43712,-2.05935,0.185311,1.09228,-1.76953,0.049388,1.09282,-1.7819,0.046882,1.01014,-1.80637,0.087713,0.901344,-1.79859,-0.0754,0.847853,-1.78029,-0.14832,0.838879,-1.78971,-0.088416,0.959026,-1.79335,-0.160109,0.951091,-1.79295,-0.387194,0.884136,-1.79241,-0.418067,0.999435,-1.85138,-0.46686,0.745951,-1.8714,-0.524888,0.771584,-1.80548,0.28272,1.15287,-2.11746,0.31948,1.0784,-2.09944,0.154909,1.09286,-2.08574,0.192752,1.0206,-2.07173,0.309416,0.922651,-2.07194,0.371838,0.742887,-2.0613,0.2598,0.729177,-2.06938,0.272916,0.660777,-2.05773,0.340051,0.43541,-2.01938,0.277396,0.355897,-1.9415,0.546871,0.421756,-1.99643,0.507782,0.355785,-2.04323,0.134996,1.33358,-1.82845,0.139643,1.34532,-2.04332},
/*1826*/{0.255267,1.91189,-1.75744,0.309939,1.84851,-1.91226,0.187522,1.78014,-1.63681,0.130685,1.67648,-1.55327,0.253026,1.63186,-1.64975,0.332143,1.59729,-1.68682,0.210562,1.9176,-2.13529,0.306523,1.84689,-1.98661,0.096348,1.88735,-2.03401,-0.022405,1.78193,-2.16822,-0.034622,1.69299,-2.24033,0.120098,1.57118,-2.21206,0.161408,1.51977,-2.23518,0.215867,1.41363,-1.80667,0.027534,1.48072,-1.88214,0.028368,1.50885,-1.93282,0.029342,1.48033,-1.99834,0.217633,1.43405,-2.06058,0.188674,1.0882,-1.76513,0.053177,1.08757,-1.78315,0.053077,1.00334,-1.80674,0.096506,0.897673,-1.79718,-0.065865,0.848528,-1.77877,-0.140889,0.843763,-1.78493,-0.076762,0.95886,-1.79422,-0.147407,0.952951,-1.79248,-0.376291,0.892777,-1.79086,-0.406079,1.0074,-1.85291,-0.457279,0.753651,-1.86656,-0.515885,0.781177,-1.80222,0.28066,1.14882,-2.11855,0.317752,1.07411,-2.10058,0.153742,1.08906,-2.08566,0.19163,1.01662,-2.07133,0.306341,0.916719,-2.07228,0.366533,0.736696,-2.06024,0.253222,0.723938,-2.06921,0.265518,0.655489,-2.05699,0.328471,0.430374,-2.01805,0.257514,0.355286,-1.94021,0.533806,0.406052,-1.99216,0.489626,0.343608,-2.04095,0.136525,1.32891,-1.82951,0.139373,1.34139,-2.04437},
/*1827*/{0.252967,1.90672,-1.75627,0.309807,1.84306,-1.91112,0.183433,1.77516,-1.6365,0.123813,1.67233,-1.55408,0.246791,1.62468,-1.64889,0.325093,1.58885,-1.6843,0.211219,1.91173,-2.13583,0.305897,1.84174,-1.98554,0.094615,1.88036,-2.03468,-0.020686,1.7722,-2.17185,-0.031746,1.68465,-2.244,0.123498,1.5634,-2.21392,0.165629,1.51283,-2.23724,0.215373,1.4093,-1.80864,0.027099,1.47528,-1.88106,0.027473,1.50242,-1.93284,0.027747,1.47329,-1.9973,0.216796,1.43012,-2.06222,0.18766,1.08558,-1.76581,0.05521,1.07956,-1.7844,0.058291,0.997301,-1.80696,0.105234,0.894038,-1.79565,-0.056336,0.848897,-1.7766,-0.131661,0.844146,-1.782,-0.063411,0.959704,-1.79406,-0.13567,0.955311,-1.7934,-0.366246,0.899559,-1.79004,-0.394538,1.0135,-1.85411,-0.447915,0.761102,-1.86196,-0.504628,0.79006,-1.79692,0.278454,1.1445,-2.11897,0.315819,1.06953,-2.10143,0.151517,1.08358,-2.08586,0.189592,1.01229,-2.0712,0.302742,0.910422,-2.07214,0.359825,0.729872,-2.0585,0.246948,0.718991,-2.06877,0.257224,0.650641,-2.05631,0.314134,0.424818,-2.01244,0.238892,0.357274,-1.93762,0.519084,0.392719,-1.98545,0.470564,0.340064,-2.03942,0.137891,1.32376,-1.83016,0.138933,1.33639,-2.04502},
/*1828*/{0.25116,1.90131,-1.75519,0.309571,1.83834,-1.9105,0.178796,1.7703,-1.63643,0.117288,1.66888,-1.55466,0.240474,1.61796,-1.64731,0.319074,1.58044,-1.68154,0.211004,1.90604,-2.13635,0.305637,1.83665,-1.98498,0.09342,1.87453,-2.0364,-0.018381,1.76394,-2.17554,-0.028562,1.6763,-2.24742,0.12768,1.55552,-2.21619,0.170162,1.5049,-2.23902,0.215962,1.40437,-1.80891,0.025957,1.46923,-1.88146,0.027084,1.49648,-1.93271,0.025549,1.46861,-1.99762,0.215782,1.42648,-2.06376,0.194425,1.08089,-1.76113,0.058649,1.07339,-1.78536,0.064904,0.990188,-1.80799,0.115084,0.890398,-1.79225,-0.045695,0.8487,-1.77427,-0.121275,0.846448,-1.78155,-0.05089,0.959867,-1.79376,-0.122217,0.957451,-1.79309,-0.353628,0.906792,-1.789,-0.381889,1.01934,-1.85641,-0.436474,0.765761,-1.85745,-0.493325,0.797393,-1.7936,0.276626,1.13956,-2.11999,0.313549,1.06514,-2.10284,0.149252,1.07919,-2.0854,0.187935,1.0079,-2.07068,0.298594,0.904673,-2.0727,0.353965,0.723248,-2.05568,0.240846,0.714832,-2.06824,0.249027,0.646603,-2.05559,0.296653,0.422691,-2.00467,0.214328,0.354179,-1.93767,0.498068,0.385879,-1.97567,0.4483,0.342935,-2.03926,0.138492,1.31842,-1.83149,0.138558,1.33218,-2.04628},
/*1829*/{0.249147,1.89535,-1.75423,0.308691,1.8323,-1.90908,0.174687,1.76502,-1.63635,0.110356,1.66496,-1.5558,0.23437,1.61157,-1.64607,0.311451,1.57259,-1.6794,0.212151,1.89983,-2.13713,0.30535,1.83113,-1.98476,0.092638,1.8671,-2.03776,-0.017087,1.75426,-2.1793,-0.024335,1.66708,-2.25076,0.132285,1.5481,-2.21821,0.175901,1.49724,-2.24073,0.216209,1.39998,-1.81058,0.024749,1.46388,-1.88035,0.025093,1.49055,-1.93207,0.023049,1.46304,-1.99611,0.214137,1.42183,-2.0659,0.199635,1.07659,-1.75736,0.064897,1.06758,-1.78603,0.069396,0.9839,-1.80891,0.124562,0.886674,-1.78996,-0.035056,0.84889,-1.77183,-0.110959,0.847573,-1.77881,-0.037402,0.959543,-1.79392,-0.109997,0.957985,-1.79283,-0.341721,0.911045,-1.78759,-0.370117,1.02304,-1.8578,-0.424509,0.770218,-1.85379,-0.481288,0.802801,-1.7901,0.273012,1.13601,-2.12281,0.311187,1.06172,-2.1054,0.146629,1.07489,-2.08537,0.185505,1.00404,-2.07036,0.29457,0.898725,-2.07305,0.347488,0.715707,-2.05069,0.234904,0.710927,-2.06764,0.241453,0.642716,-2.0537,0.277327,0.42363,-2.00002,0.191766,0.354901,-1.93457,0.470937,0.387117,-1.97959,0.423959,0.343001,-2.03823,0.139231,1.3135,-1.83204,0.136673,1.32725,-2.04682},
/*1830*/{0.247427,1.88962,-1.75299,0.308431,1.82596,-1.90759,0.170309,1.76023,-1.63661,0.103723,1.66116,-1.5564,0.227627,1.60495,-1.64518,0.305047,1.5645,-1.67672,0.212962,1.89363,-2.13786,0.305728,1.82585,-1.98374,0.091391,1.86127,-2.03993,-0.014355,1.74552,-2.18396,-0.019891,1.65774,-2.25413,0.137717,1.53998,-2.22108,0.181239,1.48902,-2.24265,0.215698,1.39496,-1.81224,0.023192,1.45727,-1.88015,0.023063,1.4842,-1.93174,0.019966,1.45829,-1.99537,0.212084,1.417,-2.06766,0.201882,1.07251,-1.75589,0.067685,1.05875,-1.7869,0.075977,0.977115,-1.80961,0.133436,0.88378,-1.7881,-0.023969,0.848655,-1.77159,-0.099821,0.848054,-1.77841,-0.024141,0.958643,-1.79382,-0.095653,0.958392,-1.7924,-0.328509,0.915941,-1.7859,-0.357242,1.02678,-1.85867,-0.411237,0.773687,-1.84964,-0.468818,0.807938,-1.7862,0.268789,1.13276,-2.12597,0.307353,1.05794,-2.10889,0.143448,1.07306,-2.08574,0.182471,1.00221,-2.06994,0.28803,0.892906,-2.07356,0.341026,0.710282,-2.04569,0.230164,0.709833,-2.06541,0.232351,0.641745,-2.0489,0.251035,0.423992,-1.99394,0.167245,0.354757,-1.93329,0.448603,0.386369,-1.97314,0.399558,0.343149,-2.03755,0.139049,1.30783,-1.8333,0.134608,1.32236,-2.048},
/*1831*/{0.245821,1.88331,-1.75114,0.308157,1.8208,-1.90618,0.165728,1.75527,-1.63668,0.097049,1.65773,-1.55695,0.220597,1.59856,-1.6435,0.296401,1.55675,-1.67414,0.213017,1.88824,-2.13875,0.306174,1.81996,-1.98292,0.090098,1.85405,-2.04091,-0.012821,1.73636,-2.18968,-0.014535,1.64809,-2.2573,0.143457,1.53186,-2.22328,0.18666,1.48066,-2.24464,0.214656,1.3892,-1.81364,0.020325,1.45235,-1.87895,0.020652,1.47809,-1.93053,0.016429,1.45369,-1.99473,0.207929,1.41195,-2.06967,0.205228,1.06848,-1.75329,0.073283,1.05271,-1.78631,0.084254,0.968937,-1.80895,0.144868,0.881695,-1.78378,-0.010707,0.847716,-1.76954,-0.084799,0.849721,-1.77442,-0.010248,0.957987,-1.79328,-0.082995,0.95906,-1.79286,-0.314977,0.918939,-1.78649,-0.344353,1.02853,-1.86,-0.397714,0.77608,-1.84493,-0.454419,0.810856,-1.78188,0.264921,1.12977,-2.13044,0.303213,1.05524,-2.11305,0.141245,1.0717,-2.08506,0.179703,1.00069,-2.06901,0.281883,0.889249,-2.0738,0.334356,0.708011,-2.04057,0.224158,0.713154,-2.06164,0.222557,0.645155,-2.0447,0.227109,0.425131,-1.98991,0.144349,0.355791,-1.93126,0.42648,0.382971,-1.97403,0.376518,0.343813,-2.03515,0.137436,1.3022,-1.83428,0.130381,1.31739,-2.04886},
/*1832*/{0.244245,1.87798,-1.75038,0.308418,1.81386,-1.90506,0.16178,1.74979,-1.63611,0.088992,1.65446,-1.55849,0.213567,1.59232,-1.64162,0.288656,1.55005,-1.67176,0.21417,1.88258,-2.14035,0.307423,1.81406,-1.98267,0.091067,1.85073,-2.04128,-0.008644,1.72654,-2.1939,-0.009412,1.6385,-2.26093,0.149318,1.52307,-2.22623,0.19363,1.47239,-2.24631,0.214446,1.38499,-1.81599,0.018402,1.44749,-1.87822,0.017802,1.47233,-1.9296,0.01216,1.4497,-1.99436,0.205197,1.40933,-2.07136,0.210209,1.06468,-1.75272,0.07627,1.04356,-1.78797,0.09134,0.962189,-1.81017,0.154504,0.877489,-1.78191,0.002441,0.846301,-1.76825,-0.073087,0.848336,-1.77228,0.003565,0.956242,-1.79269,-0.068317,0.957451,-1.79107,-0.300672,0.919958,-1.7853,-0.331267,1.02961,-1.86032,-0.383529,0.776478,-1.84088,-0.438602,0.812546,-1.77711,0.260646,1.12721,-2.13489,0.300005,1.05255,-2.1159,0.137827,1.07116,-2.08454,0.177229,0.999422,-2.06826,0.277441,0.887649,-2.0736,0.326584,0.707147,-2.03777,0.215845,0.717992,-2.05921,0.210901,0.650436,-2.04243,0.209566,0.426544,-1.98815,0.122182,0.356758,-1.92886,0.4044,0.383615,-1.97058,0.354091,0.34391,-2.03432,0.137388,1.29757,-1.83611,0.127789,1.3142,-2.05049},
/*1833*/{0.243145,1.8728,-1.74879,0.308584,1.80868,-1.90342,0.157324,1.74526,-1.63592,0.082658,1.65124,-1.55881,0.206718,1.58679,-1.64025,0.281626,1.54349,-1.66888,0.216011,1.87801,-2.14227,0.307809,1.8088,-1.98145,0.091794,1.84983,-2.04118,-0.003505,1.71683,-2.20075,-0.003004,1.62836,-2.26411,0.155789,1.51424,-2.22896,0.199696,1.46391,-2.24801,0.212208,1.38,-1.81824,0.015197,1.44199,-1.87768,0.01385,1.4675,-1.9284,0.008308,1.44525,-1.9937,0.202807,1.40655,-2.07325,0.213547,1.06196,-1.75178,0.082088,1.03619,-1.78835,0.100956,0.954176,-1.8104,0.165928,0.872708,-1.77967,0.015635,0.844371,-1.76686,-0.059333,0.848065,-1.77214,0.01717,0.955439,-1.79241,-0.05431,0.957259,-1.79179,-0.285242,0.918988,-1.78301,-0.318199,1.02896,-1.86066,-0.369059,0.775899,-1.83742,-0.424168,0.812577,-1.77443,0.25675,1.1247,-2.13641,0.296637,1.05047,-2.11679,0.134891,1.06873,-2.08341,0.174099,0.99805,-2.06751,0.277511,0.887537,-2.07346,0.315415,0.705628,-2.03734,0.204844,0.722319,-2.05744,0.1961,0.654156,-2.04125,0.191367,0.430524,-1.98798,0.100976,0.358056,-1.92678,0.382584,0.380863,-1.97017,0.331148,0.34359,-2.03269,0.135727,1.29224,-1.8382,0.124666,1.31112,-2.05232},
/*1834*/{0.242539,1.86774,-1.74683,0.308555,1.80267,-1.90203,0.152381,1.74074,-1.63579,0.074086,1.64919,-1.56058,0.199799,1.58165,-1.63861,0.273408,1.53769,-1.66705,0.217066,1.87288,-2.14332,0.308017,1.80363,-1.98092,0.092419,1.84733,-2.04152,0.002792,1.7096,-2.20884,0.00381,1.61792,-2.26689,0.163937,1.50618,-2.23179,0.207654,1.45651,-2.24981,0.210559,1.37535,-1.82037,0.011901,1.43799,-1.87618,0.01239,1.46413,-1.92811,0.004293,1.44295,-1.99245,0.199239,1.40471,-2.07459,0.219307,1.06196,-1.75141,0.08864,1.0315,-1.78782,0.109163,0.950322,-1.80997,0.177912,0.869617,-1.77933,0.029124,0.842566,-1.76592,-0.045638,0.846252,-1.77021,0.03189,0.953419,-1.79109,-0.040584,0.955772,-1.79034,-0.270565,0.919571,-1.78311,-0.306342,1.02746,-1.86022,-0.352728,0.774148,-1.83418,-0.408765,0.810532,-1.77323,0.253419,1.12309,-2.13597,0.292226,1.04883,-2.11718,0.130995,1.06646,-2.08245,0.170567,0.996057,-2.06656,0.278868,0.887247,-2.07224,0.303495,0.705227,-2.03924,0.193175,0.726231,-2.05553,0.183705,0.657978,-2.04058,0.172242,0.429284,-1.98407,0.078889,0.359428,-1.92579,0.361966,0.380121,-1.96887,0.309518,0.343735,-2.03223,0.133691,1.28781,-1.8403,0.120723,1.3092,-2.05408},
/*1835*/{0.242034,1.86401,-1.74551,0.309964,1.79851,-1.90113,0.147879,1.73726,-1.63579,0.067098,1.64739,-1.5604,0.193123,1.5779,-1.63841,0.265376,1.53312,-1.66521,0.218756,1.86854,-2.14405,0.308508,1.79976,-1.97917,0.092896,1.84477,-2.04205,0.009701,1.69917,-2.21651,0.012719,1.60743,-2.27045,0.171889,1.49856,-2.23405,0.216068,1.44911,-2.25062,0.208286,1.37182,-1.82186,0.009844,1.43347,-1.87467,0.009057,1.46239,-1.92741,0.003362,1.43908,-1.98946,0.196608,1.40315,-2.07631,0.225003,1.06402,-1.75184,0.094786,1.0275,-1.78631,0.1207,0.947534,-1.80912,0.191699,0.868071,-1.7777,0.044,0.840478,-1.76532,-0.032773,0.842848,-1.77217,0.04634,0.950955,-1.78979,-0.025842,0.954329,-1.78927,-0.255954,0.918492,-1.78249,-0.294967,1.02494,-1.85987,-0.33616,0.770522,-1.83145,-0.391615,0.806474,-1.76914,0.24779,1.12124,-2.13662,0.287865,1.04654,-2.11773,0.127171,1.06207,-2.0805,0.166573,0.993852,-2.06492,0.280646,0.88741,-2.07094,0.29107,0.704057,-2.04317,0.181319,0.726987,-2.05542,0.169193,0.660909,-2.04028,0.156342,0.431379,-1.98292,0.056266,0.360722,-1.92378,0.339409,0.379342,-1.96918,0.28691,0.343114,-2.03166,0.132528,1.284,-1.84151,0.117936,1.30732,-2.05498},
/*1836*/{0.241826,1.85898,-1.74356,0.309678,1.79498,-1.89944,0.143326,1.73501,-1.63612,0.060348,1.64677,-1.56204,0.185268,1.57456,-1.63771,0.25828,1.52778,-1.6637,0.220261,1.86471,-2.14438,0.309186,1.7964,-1.97734,0.093054,1.84415,-2.04258,0.017554,1.68973,-2.22336,0.022501,1.59769,-2.27314,0.181163,1.49153,-2.23488,0.225783,1.44331,-2.25159,0.205792,1.36799,-1.82284,0.007404,1.43057,-1.87311,0.007388,1.46111,-1.92706,0.000379,1.43778,-1.98666,0.193246,1.40205,-2.07761,0.231937,1.06589,-1.75188,0.100986,1.02573,-1.78627,0.128637,0.945764,-1.8064,0.206136,0.867559,-1.77808,0.057874,0.838414,-1.76506,-0.016248,0.840907,-1.77028,0.059923,0.949703,-1.78814,-0.010851,0.951927,-1.78762,-0.242669,0.914818,-1.78147,-0.284546,1.02077,-1.85894,-0.318572,0.76552,-1.82961,-0.372823,0.799914,-1.76652,0.242639,1.1183,-2.13678,0.282247,1.04334,-2.11847,0.122157,1.06026,-2.07831,0.160635,0.992137,-2.06443,0.280362,0.887659,-2.068,0.278037,0.702114,-2.0459,0.167881,0.726848,-2.05606,0.154238,0.66071,-2.03945,0.127955,0.429469,-1.98262,0.035071,0.361344,-1.9248,0.318309,0.378604,-1.96851,0.264111,0.342232,-2.03249,0.129934,1.2806,-1.84293,0.113856,1.30638,-2.05601},
/*1837*/{0.241379,1.85565,-1.74223,0.309461,1.79168,-1.8985,0.138384,1.73388,-1.63688,0.052789,1.64742,-1.56438,0.178784,1.57236,-1.63721,0.250211,1.5237,-1.66179,0.220612,1.8616,-2.14349,0.309318,1.79325,-1.97657,0.092818,1.84193,-2.0427,0.023472,1.6813,-2.22889,0.033354,1.58818,-2.27464,0.190696,1.48635,-2.23541,0.236503,1.43871,-2.25131,0.202937,1.36452,-1.8232,0.004826,1.42912,-1.87123,0.005441,1.4602,-1.92592,-0.001024,1.43639,-1.98515,0.190766,1.40112,-2.07916,0.236657,1.068,-1.75289,0.112109,1.02398,-1.78339,0.139979,0.944183,-1.80406,0.221289,0.867426,-1.77854,0.072082,0.837154,-1.76477,-0.003299,0.839009,-1.77139,0.074021,0.948579,-1.78684,0.002173,0.950888,-1.78675,-0.227524,0.913093,-1.78148,-0.275648,1.01608,-1.85763,-0.299888,0.759606,-1.82758,-0.355059,0.792301,-1.76327,0.236226,1.11466,-2.13698,0.274726,1.03934,-2.11876,0.114819,1.06169,-2.07822,0.154909,0.987874,-2.06139,0.272764,0.886828,-2.06742,0.263436,0.69814,-2.04767,0.154187,0.726008,-2.05596,0.13915,0.65874,-2.03955,0.107184,0.429116,-1.9825,0.012462,0.362763,-1.92536,0.295756,0.377958,-1.96891,0.242423,0.343058,-2.03197,0.12712,1.2778,-1.84387,0.110327,1.30562,-2.05664},
/*1838*/{0.241368,1.85349,-1.74115,0.308437,1.78964,-1.89683,0.133054,1.73448,-1.63754,0.045964,1.64849,-1.56704,0.171541,1.57094,-1.63712,0.242433,1.52059,-1.65968,0.222185,1.85936,-2.1424,0.309186,1.7905,-1.97501,0.093713,1.84041,-2.04276,0.030911,1.67325,-2.2338,0.043986,1.58066,-2.27621,0.20095,1.48132,-2.2351,0.247471,1.43544,-2.25086,0.201323,1.36184,-1.82457,0.003135,1.4279,-1.8705,0.00298,1.45947,-1.92578,-0.002777,1.43596,-1.98299,0.188508,1.40033,-2.08046,0.246943,1.07066,-1.75224,0.121031,1.02347,-1.78201,0.15169,0.944184,-1.80165,0.236126,0.868342,-1.77864,0.085814,0.836058,-1.76509,0.011354,0.837174,-1.77205,0.08726,0.948049,-1.78531,0.015826,0.949196,-1.78609,-0.213114,0.905413,-1.78056,-0.267572,1.0091,-1.8561,-0.280963,0.752123,-1.82562,-0.334288,0.781931,-1.76098,0.231311,1.11077,-2.13688,0.267726,1.03547,-2.11881,0.109769,1.05788,-2.07675,0.147322,0.986095,-2.0605,0.261897,0.882615,-2.06885,0.249294,0.692439,-2.04647,0.141,0.724812,-2.05824,0.12447,0.657592,-2.03999,0.089336,0.431884,-1.98457,-0.008597,0.361868,-1.92642,0.273952,0.377947,-1.96894,0.220133,0.342515,-2.03237,0.125021,1.27568,-1.84517,0.107031,1.30522,-2.05761},
/*1839*/{0.240457,1.85149,-1.74062,0.306987,1.78763,-1.89551,0.128267,1.73545,-1.63852,0.038468,1.65071,-1.57004,0.165047,1.56961,-1.63742,0.235353,1.51859,-1.65804,0.223523,1.85738,-2.14126,0.308675,1.78832,-1.97367,0.093821,1.83861,-2.043,0.038067,1.66689,-2.23554,0.053711,1.57481,-2.27685,0.212378,1.47859,-2.23409,0.259153,1.43376,-2.24935,0.198289,1.35952,-1.82405,0.001716,1.42743,-1.86951,0.001402,1.45897,-1.9255,-0.00462,1.43598,-1.98249,0.186465,1.39954,-2.08142,0.254563,1.07423,-1.75298,0.129451,1.02158,-1.78053,0.162449,0.945455,-1.80026,0.251198,0.871185,-1.77877,0.100135,0.835343,-1.76531,0.023086,0.838422,-1.77186,0.099425,0.947069,-1.78385,0.027927,0.946935,-1.78471,-0.200839,0.899352,-1.78113,-0.260378,1.00123,-1.85473,-0.260204,0.743632,-1.82566,-0.314117,0.771634,-1.75717,0.224832,1.1074,-2.13777,0.260387,1.03141,-2.11921,0.102266,1.05643,-2.07662,0.139047,0.984075,-2.06046,0.250281,0.877266,-2.06978,0.234575,0.688312,-2.04743,0.127928,0.722237,-2.05933,0.108703,0.655673,-2.04166,0.067696,0.432783,-1.99004,-0.032409,0.362738,-1.92764,0.251466,0.377418,-1.96964,0.197858,0.342082,-2.03294,0.121951,1.27404,-1.84565,0.104078,1.3048,-2.05793},
/*1840*/{0.239727,1.8503,-1.74039,0.306172,1.78473,-1.89413,0.124112,1.73685,-1.63938,0.032782,1.65434,-1.57364,0.157543,1.56958,-1.63825,0.227505,1.51707,-1.65741,0.226308,1.8554,-2.14035,0.307615,1.78673,-1.97303,0.094329,1.83708,-2.04308,0.046024,1.66299,-2.23544,0.062796,1.57082,-2.27721,0.223166,1.47796,-2.23268,0.271281,1.43324,-2.2471,0.196415,1.35819,-1.823,0.000317,1.42771,-1.87016,-0.000218,1.45886,-1.92551,-0.00585,1.43593,-1.98237,0.185017,1.39928,-2.08202,0.26173,1.07861,-1.7539,0.13942,1.02261,-1.77912,0.174691,0.947157,-1.79829,0.266126,0.87433,-1.77885,0.114199,0.835379,-1.76564,0.038697,0.833163,-1.77232,0.111243,0.946425,-1.78181,0.039276,0.944486,-1.78339,-0.186102,0.892592,-1.78014,-0.25259,0.991993,-1.85314,-0.238691,0.73472,-1.82407,-0.292064,0.759166,-1.75454,0.218284,1.10402,-2.13746,0.252296,1.02734,-2.11999,0.094557,1.05648,-2.07728,0.130983,0.981398,-2.06115,0.23817,0.872832,-2.07109,0.220125,0.682462,-2.04667,0.114399,0.719146,-2.06012,0.093669,0.651989,-2.04174,0.046408,0.431603,-1.98751,-0.053217,0.362904,-1.92817,0.229751,0.376811,-1.97057,0.175947,0.342173,-2.03454,0.119625,1.27337,-1.84585,0.102316,1.30462,-2.0581},
/*1841*/{0.239123,1.85001,-1.73957,0.305328,1.78438,-1.89327,0.119559,1.73858,-1.64048,0.026073,1.65723,-1.57588,0.151512,1.57043,-1.63796,0.221099,1.5174,-1.65683,0.229126,1.85445,-2.13966,0.307699,1.78537,-1.97081,0.095134,1.83658,-2.0434,0.052418,1.65917,-2.23448,0.070774,1.56769,-2.2768,0.234163,1.47773,-2.23015,0.283683,1.43471,-2.24356,0.194003,1.35768,-1.82163,-0.001281,1.42744,-1.87003,-0.001663,1.45865,-1.92591,-0.006522,1.43594,-1.98261,0.183742,1.39843,-2.0825,0.268559,1.086,-1.75436,0.149806,1.02528,-1.77694,0.185746,0.949885,-1.79734,0.280077,0.877666,-1.77875,0.127445,0.835695,-1.76637,0.053109,0.83153,-1.77332,0.122599,0.947081,-1.78118,0.050622,0.943389,-1.78278,-0.172086,0.88431,-1.78302,-0.246063,0.981083,-1.85213,-0.217411,0.724949,-1.82365,-0.2693,0.74731,-1.75294,0.211449,1.10107,-2.1375,0.24401,1.02329,-2.12018,0.087004,1.05536,-2.078,0.120074,0.980906,-2.06259,0.225012,0.868477,-2.07162,0.205865,0.677515,-2.04542,0.100865,0.716396,-2.06097,0.078502,0.648563,-2.0417,0.025923,0.431825,-1.98884,-0.074103,0.362602,-1.9294,0.208467,0.376205,-1.97156,0.154205,0.340895,-2.03552,0.117343,1.27299,-1.84541,0.100902,1.30398,-2.05776},
/*1842*/{0.237952,1.85021,-1.73926,0.304402,1.7837,-1.89196,0.114292,1.74094,-1.64157,0.01961,1.6614,-1.5791,0.144772,1.5717,-1.63783,0.213836,1.51785,-1.65641,0.231265,1.85349,-2.13849,0.307456,1.78455,-1.97002,0.095801,1.83629,-2.04383,0.059963,1.65707,-2.23366,0.079148,1.56513,-2.27698,0.244091,1.47751,-2.2268,0.295413,1.43684,-2.23947,0.191567,1.35728,-1.81999,-0.002862,1.42792,-1.87079,-0.00191,1.45844,-1.92602,-0.008023,1.43688,-1.98354,0.182954,1.39768,-2.08291,0.275535,1.09264,-1.75439,0.157537,1.02639,-1.77548,0.196487,0.953401,-1.79581,0.293851,0.883091,-1.77929,0.143046,0.835191,-1.76631,0.069133,0.830899,-1.774,0.134325,0.947313,-1.77885,0.061964,0.942494,-1.7806,-0.157944,0.875958,-1.78227,-0.238779,0.96888,-1.85061,-0.194735,0.714784,-1.82306,-0.246006,0.734126,-1.75039,0.205027,1.09853,-2.13723,0.234842,1.01935,-2.12039,0.078835,1.05615,-2.08025,0.110604,0.980721,-2.06449,0.21124,0.864656,-2.07142,0.190963,0.672448,-2.04395,0.086021,0.713845,-2.06137,0.062384,0.650208,-2.04505,0.008989,0.433096,-1.98818,-0.097145,0.365531,-1.93044,0.186167,0.376015,-1.97202,0.132961,0.341297,-2.03555,0.114735,1.27289,-1.84509,0.099587,1.30367,-2.05757},
/*1843*/{0.236049,1.85086,-1.73923,0.303808,1.78369,-1.891,0.110679,1.74379,-1.64207,0.014323,1.6658,-1.58192,0.13868,1.57355,-1.63877,0.20694,1.5192,-1.65568,0.233789,1.85301,-2.1383,0.307123,1.78435,-1.9683,0.096718,1.83604,-2.04599,0.065273,1.65478,-2.23243,0.087484,1.56345,-2.27703,0.254208,1.48006,-2.22334,0.307319,1.44129,-2.23489,0.189508,1.3583,-1.81868,-0.003691,1.42764,-1.87158,-0.003509,1.45849,-1.92728,-0.008473,1.43648,-1.98409,0.182464,1.39715,-2.08285,0.283335,1.09841,-1.75272,0.166609,1.03127,-1.7748,0.208534,0.957871,-1.79402,0.307564,0.889814,-1.77922,0.157004,0.83625,-1.76814,0.082353,0.829937,-1.77501,0.144238,0.947944,-1.77843,0.073385,0.940257,-1.77924,-0.143598,0.868512,-1.78297,-0.232108,0.954638,-1.85036,-0.17234,0.704145,-1.82208,-0.222114,0.720235,-1.74919,0.198926,1.09596,-2.13701,0.226369,1.01629,-2.12019,0.0709,1.05637,-2.08118,0.099396,0.979794,-2.06546,0.196602,0.859328,-2.07112,0.173718,0.668217,-2.04393,0.070661,0.71107,-2.0619,0.046144,0.647966,-2.04622,-0.080502,0.416416,-1.98661,-0.118335,0.364984,-1.92976,0.164759,0.375818,-1.97236,0.11103,0.341376,-2.03621,0.113429,1.27348,-1.84429,0.099481,1.30303,-2.05703},
/*1844*/{0.233936,1.85216,-1.73824,0.30273,1.7834,-1.88924,0.106294,1.7468,-1.64312,0.007737,1.67005,-1.58387,0.131962,1.57649,-1.63805,0.200416,1.52133,-1.65552,0.236657,1.85326,-2.13756,0.307165,1.78471,-1.9672,0.097428,1.83613,-2.04614,0.069612,1.65279,-2.23113,0.095092,1.56159,-2.27692,0.263739,1.48329,-2.21893,0.318066,1.44659,-2.2297,0.18807,1.35934,-1.8174,-0.005369,1.42836,-1.87236,-0.005212,1.45869,-1.92826,-0.009114,1.43709,-1.98537,0.181697,1.39642,-2.08263,0.288962,1.10605,-1.7536,0.175005,1.03465,-1.77422,0.218432,0.962861,-1.79455,0.319865,0.896311,-1.77904,0.171062,0.837836,-1.76925,0.098334,0.828779,-1.77591,0.153148,0.949364,-1.77796,0.082985,0.938254,-1.77757,-0.130557,0.856141,-1.78352,-0.224284,0.939851,-1.84997,-0.148767,0.693757,-1.82169,-0.199137,0.707747,-1.74737,0.192583,1.09358,-2.13716,0.217235,1.01245,-2.11964,0.062415,1.05678,-2.08265,0.089989,0.980304,-2.06726,0.182499,0.855167,-2.07127,0.156835,0.665175,-2.04241,0.05422,0.708602,-2.06191,0.028875,0.646399,-2.04613,-0.037262,0.43502,-1.99074,-0.138425,0.365957,-1.93384,0.143549,0.37571,-1.97306,0.089368,0.34137,-2.03632,0.111619,1.27445,-1.84341,0.09884,1.30257,-2.05642},
/*1845*/{0.231569,1.85436,-1.73791,0.301504,1.78552,-1.88855,0.101704,1.75037,-1.64424,0.001047,1.67321,-1.58611,0.126322,1.58063,-1.63901,0.193484,1.52398,-1.65514,0.239005,1.85473,-2.13618,0.306697,1.78537,-1.96585,0.097963,1.83659,-2.04711,0.073348,1.65184,-2.23009,0.103422,1.56043,-2.27678,0.272908,1.48828,-2.21464,0.329243,1.45321,-2.22305,0.186321,1.36093,-1.8161,-0.00693,1.42899,-1.87423,-0.005141,1.45884,-1.92847,-0.009994,1.43796,-1.98662,0.182004,1.39611,-2.08194,0.292631,1.11415,-1.75412,0.183441,1.03939,-1.77332,0.227553,0.967983,-1.79465,0.331883,0.904127,-1.77952,0.185706,0.840079,-1.76927,0.111135,0.826077,-1.77611,0.163055,0.950089,-1.77636,0.091752,0.936097,-1.77762,-0.117363,0.845482,-1.78441,-0.216501,0.923086,-1.85071,-0.125554,0.682878,-1.8207,-0.175746,0.694553,-1.74595,0.185185,1.09125,-2.13661,0.208492,1.01009,-2.11901,0.054556,1.05811,-2.08369,0.078543,0.979886,-2.06766,0.166764,0.851309,-2.07107,0.139988,0.663571,-2.04131,0.037982,0.708561,-2.06216,0.012017,0.646683,-2.04679,-0.057291,0.43533,-1.99085,-0.162225,0.367869,-1.93286,0.120992,0.37576,-1.9734,0.067079,0.341137,-2.03668,0.110147,1.27558,-1.84256,0.099121,1.30253,-2.05582},
/*1846*/{0.228087,1.85666,-1.73773,0.300702,1.7866,-1.88629,0.097022,1.75394,-1.64485,-0.005222,1.67849,-1.58792,0.120091,1.58473,-1.63928,0.187129,1.52757,-1.65485,0.240609,1.85595,-2.13517,0.306574,1.78659,-1.96368,0.098694,1.83818,-2.04848,0.07728,1.65088,-2.22784,0.111072,1.56036,-2.27612,0.281737,1.49422,-2.20963,0.339071,1.46107,-2.21686,0.184525,1.36218,-1.81502,-0.007032,1.42984,-1.87462,-0.005539,1.45998,-1.92975,-0.010215,1.43842,-1.98838,0.181435,1.39534,-2.08155,0.297724,1.12163,-1.75494,0.191523,1.04384,-1.77268,0.23666,0.97386,-1.79395,0.344032,0.91325,-1.78016,0.198598,0.84154,-1.77114,0.126942,0.825465,-1.77559,0.171601,0.951059,-1.77615,0.10022,0.935062,-1.77803,-0.103845,0.835308,-1.78345,-0.208145,0.906356,-1.85129,-0.102189,0.67165,-1.81987,-0.151685,0.68102,-1.74471,0.178554,1.08892,-2.13628,0.198253,1.00752,-2.11793,0.045904,1.05954,-2.0846,0.067558,0.980901,-2.06961,0.150041,0.84891,-2.07113,0.122463,0.663465,-2.04014,0.021352,0.709203,-2.06224,-0.006166,0.645683,-2.04593,-0.075897,0.437923,-1.99039,-0.183754,0.367208,-1.935,0.099958,0.375499,-1.97371,0.046284,0.341502,-2.03719,0.108553,1.27679,-1.84162,0.098719,1.30207,-2.05514},
/*1847*/{0.225858,1.85903,-1.73679,0.299471,1.78859,-1.88522,0.092609,1.75751,-1.6456,-0.009983,1.68297,-1.59071,0.11375,1.58847,-1.64036,0.180752,1.5314,-1.65532,0.242198,1.85817,-2.13403,0.306336,1.78919,-1.96266,0.099191,1.83885,-2.0498,0.081775,1.64988,-2.2262,0.118497,1.56115,-2.27581,0.290778,1.50067,-2.20405,0.348948,1.46921,-2.21023,0.18393,1.36356,-1.81393,-0.008029,1.43114,-1.87702,-0.005578,1.46181,-1.93071,-0.010043,1.44011,-1.99022,0.181103,1.39502,-2.08159,0.302764,1.13035,-1.75291,0.195258,1.04584,-1.77412,0.246994,0.980645,-1.79395,0.354758,0.922755,-1.78044,0.212239,0.843698,-1.77197,0.139042,0.823706,-1.77712,0.179414,0.952657,-1.77429,0.108532,0.932995,-1.77829,-0.09027,0.822953,-1.78527,-0.198496,0.887876,-1.85245,-0.077394,0.660611,-1.81859,-0.12762,0.667916,-1.74414,0.170197,1.08764,-2.13497,0.189011,1.00562,-2.1169,0.037035,1.06208,-2.0864,0.057029,0.982837,-2.07057,0.133784,0.848074,-2.07105,0.104797,0.662819,-2.03944,0.003462,0.710707,-2.0611,-0.024816,0.647546,-2.04514,-0.099571,0.437962,-1.99129,-0.204941,0.368478,-1.93414,0.078935,0.375832,-1.97413,0.024127,0.34137,-2.03727,0.106958,1.27837,-1.84136,0.09851,1.30238,-2.05508},
/*1848*/{0.222977,1.8616,-1.73698,0.298897,1.79104,-1.88312,0.088562,1.76133,-1.64662,-0.016672,1.68784,-1.59221,0.107788,1.59341,-1.64138,0.175027,1.53663,-1.65541,0.24292,1.86109,-2.13259,0.306709,1.79169,-1.96099,0.099852,1.84022,-2.05002,0.085206,1.64964,-2.22414,0.126208,1.56225,-2.27548,0.298388,1.50773,-2.19846,0.358065,1.47858,-2.20319,0.182483,1.36583,-1.81329,-0.008426,1.43279,-1.87885,-0.005883,1.46323,-1.93179,-0.009715,1.44246,-1.99105,0.181296,1.39471,-2.0815,0.307132,1.13813,-1.75326,0.20289,1.05237,-1.77396,0.253451,0.984785,-1.79569,0.364737,0.932264,-1.78109,0.22508,0.846339,-1.77052,0.153299,0.822236,-1.77751,0.186572,0.952856,-1.77393,0.118767,0.927398,-1.77657,-0.075487,0.812442,-1.78458,-0.188868,0.868591,-1.85479,-0.053034,0.650566,-1.81748,-0.104149,0.653952,-1.74197,0.163059,1.08687,-2.13324,0.179292,1.00385,-2.11504,0.028139,1.06403,-2.08722,0.045305,0.984393,-2.07134,0.117597,0.84859,-2.07054,0.086308,0.663405,-2.03957,-0.014948,0.712553,-2.06029,-0.044646,0.650124,-2.04502,-0.185217,0.422553,-1.98719,-0.22407,0.372471,-1.93326,0.056358,0.376146,-1.97444,0.002356,0.341156,-2.03701,0.105474,1.28038,-1.84075,0.098369,1.30292,-2.05469},
/*1849*/{0.220008,1.86478,-1.73652,0.298267,1.79444,-1.88171,0.084354,1.7656,-1.64709,-0.022644,1.69221,-1.59425,0.102723,1.59898,-1.6426,0.168733,1.54131,-1.656,0.244453,1.86424,-2.13113,0.306956,1.79467,-1.95964,0.10052,1.84253,-2.05112,0.089875,1.64979,-2.22251,0.133423,1.56362,-2.27483,0.306557,1.51634,-2.19245,0.367391,1.48869,-2.19621,0.181944,1.36779,-1.81239,-0.008318,1.4348,-1.87982,-0.005553,1.46481,-1.9339,-0.009383,1.44441,-1.99275,0.181554,1.39428,-2.08137,0.311121,1.14419,-1.75305,0.208736,1.0563,-1.7749,0.259911,0.991924,-1.79633,0.374042,0.942558,-1.78095,0.237463,0.849749,-1.77037,0.167036,0.8213,-1.7785,0.193178,0.953623,-1.774,0.126784,0.925666,-1.77659,-0.06134,0.79783,-1.78567,-0.177456,0.848516,-1.85653,-0.028322,0.639617,-1.81615,-0.079797,0.641328,-1.74145,0.155213,1.08583,-2.13265,0.168876,1.00296,-2.11382,0.019041,1.06805,-2.08796,0.032363,0.986829,-2.07119,0.099959,0.849336,-2.06959,0.066789,0.664943,-2.03948,-0.033018,0.715537,-2.0598,-0.062028,0.653083,-2.04364,-0.140833,0.443275,-1.9907,-0.2476,0.375999,-1.93458,0.034859,0.375637,-1.97381,-0.019449,0.341347,-2.03672,0.104355,1.28251,-1.84005,0.098468,1.30313,-2.05421},
/*1850*/{0.217884,1.86791,-1.73563,0.297789,1.79763,-1.87993,0.080305,1.76952,-1.64829,-0.028051,1.69756,-1.59643,0.09735,1.60461,-1.64374,0.163626,1.54573,-1.65539,0.246396,1.86859,-2.13032,0.30688,1.79769,-1.95749,0.100691,1.84331,-2.05118,0.094995,1.64979,-2.22026,0.14112,1.56573,-2.27398,0.313677,1.52364,-2.18711,0.375151,1.4987,-2.18929,0.181154,1.37058,-1.81233,-0.008786,1.4375,-1.88204,-0.005023,1.46747,-1.93507,-0.008248,1.44626,-1.99459,0.182742,1.39404,-2.08132,0.314399,1.15177,-1.75305,0.213824,1.06151,-1.77596,0.268337,0.999655,-1.79704,0.382925,0.953104,-1.78154,0.248616,0.85185,-1.77039,0.180525,0.820619,-1.77816,0.199563,0.952644,-1.77436,0.136161,0.92107,-1.77626,-0.045842,0.784509,-1.78632,-0.16521,0.82763,-1.85879,-0.004151,0.62923,-1.8148,-0.056402,0.628186,-1.74091,0.148281,1.08569,-2.13047,0.158321,1.00199,-2.11152,0.010472,1.07042,-2.08792,0.020564,0.991192,-2.07216,0.083959,0.850815,-2.06884,0.046895,0.666724,-2.03906,-0.051937,0.717627,-2.05867,-0.081754,0.6558,-2.0429,-0.16107,0.446615,-1.99093,-0.26857,0.379553,-1.93488,0.012742,0.375391,-1.97442,-0.041227,0.341504,-2.03674,0.103236,1.28526,-1.83947,0.098937,1.30381,-2.05386},
/*1851*/{0.214413,1.87111,-1.73571,0.297707,1.80198,-1.87918,0.077042,1.77376,-1.6486,-0.033156,1.70265,-1.59833,0.091664,1.60992,-1.64504,0.158117,1.55085,-1.65613,0.247146,1.87226,-2.1292,0.30738,1.80142,-1.95648,0.101176,1.8462,-2.05205,0.099163,1.65111,-2.21849,0.14921,1.56841,-2.27282,0.320568,1.53248,-2.18126,0.383587,1.50872,-2.18143,0.180897,1.37361,-1.81195,-0.007796,1.44,-1.88227,-0.003249,1.46995,-1.93609,-0.007441,1.4484,-1.99607,0.184538,1.39436,-2.08141,0.318085,1.16003,-1.75351,0.219796,1.06608,-1.77649,0.275265,1.006,-1.79814,0.390348,0.963737,-1.78205,0.260394,0.854429,-1.77039,0.194443,0.819096,-1.77773,0.205685,0.952781,-1.7744,0.142456,0.91817,-1.77856,-0.030601,0.770378,-1.78549,-0.152002,0.80636,-1.86006,0.020838,0.618881,-1.81415,-0.031978,0.615119,-1.74035,0.140427,1.08551,-2.12896,0.148133,1.00182,-2.10938,0.001766,1.07482,-2.08887,0.011225,0.993862,-2.07207,0.068237,0.852095,-2.06688,0.029868,0.669704,-2.03912,-0.069803,0.721084,-2.05791,-0.100016,0.660827,-2.04246,-0.213816,0.441726,-1.98918,-0.288531,0.384532,-1.93495,-0.008834,0.375219,-1.97391,-0.063558,0.341479,-2.0367,0.103278,1.28808,-1.83865,0.099931,1.30483,-2.0532},
/*1852*/{0.211927,1.87483,-1.73541,0.296513,1.80524,-1.87682,0.072581,1.77868,-1.64994,-0.037949,1.70842,-1.60047,0.086874,1.61563,-1.647,0.152695,1.55673,-1.65793,0.24795,1.87738,-2.12841,0.307143,1.805,-1.95439,0.102057,1.84803,-2.05229,0.103353,1.65245,-2.21789,0.156456,1.57126,-2.27201,0.327797,1.54263,-2.17578,0.390502,1.52005,-2.17439,0.182198,1.37796,-1.8121,-0.006951,1.44331,-1.88465,-0.002854,1.472,-1.9379,-0.00556,1.45063,-1.99703,0.185307,1.39447,-2.08111,0.319666,1.16696,-1.75281,0.223866,1.07183,-1.77897,0.279907,1.01268,-1.79935,0.397339,0.973583,-1.78259,0.271028,0.856755,-1.76954,0.206567,0.8179,-1.77715,0.211111,0.951753,-1.77637,0.150657,0.913432,-1.7783,-0.015622,0.758413,-1.7871,-0.137946,0.785833,-1.86185,0.046901,0.610025,-1.81267,-0.006359,0.602811,-1.7399,0.132998,1.08515,-2.12701,0.137928,1.00212,-2.10707,-0.00704,1.07999,-2.08869,-0.000187,0.998069,-2.07109,0.052869,0.854747,-2.06549,0.012211,0.672051,-2.03818,-0.08745,0.725373,-2.05687,-0.11845,0.663338,-2.04191,-0.266491,0.438161,-1.98795,-0.306994,0.389833,-1.93547,-0.030075,0.375489,-1.97376,-0.084449,0.341702,-2.0365,0.104062,1.29206,-1.83751,0.101131,1.30554,-2.0523},
/*1853*/{0.208928,1.87831,-1.73513,0.296685,1.80936,-1.8762,0.069352,1.78292,-1.65058,-0.042611,1.71399,-1.60292,0.081604,1.62168,-1.64842,0.148257,1.56271,-1.65844,0.248147,1.88163,-2.12702,0.307706,1.8092,-1.95333,0.102654,1.85088,-2.05325,0.106011,1.65761,-2.21908,0.164333,1.57478,-2.27182,0.333825,1.55191,-2.1707,0.397225,1.5315,-2.16715,0.183378,1.38187,-1.81362,-0.005144,1.44713,-1.88535,-0.001995,1.47485,-1.93978,-0.004631,1.45415,-1.99841,0.18578,1.39445,-2.08193,0.321464,1.17357,-1.75275,0.227073,1.07743,-1.77893,0.284335,1.01861,-1.80134,0.402909,0.983005,-1.7821,0.281795,0.859078,-1.7686,0.219965,0.816415,-1.77712,0.216526,0.950035,-1.77815,0.157199,0.90822,-1.78105,-0.000503,0.74562,-1.78841,-0.122849,0.764048,-1.86383,0.072177,0.600404,-1.81153,0.019327,0.591693,-1.73901,0.125619,1.08709,-2.12526,0.128158,1.00257,-2.10443,-0.01418,1.08441,-2.08877,-0.009669,1.00342,-2.07213,0.038629,0.858167,-2.0634,-0.005858,0.676439,-2.0377,-0.104953,0.729768,-2.05623,-0.136569,0.669425,-2.04128,-0.221932,0.458581,-1.99288,-0.328232,0.396663,-1.93557,-0.051847,0.376304,-1.97287,-0.105937,0.342182,-2.03636,0.104604,1.29599,-1.83718,0.100935,1.30677,-2.05212},
/*1854*/{0.2065,1.88227,-1.73499,0.295898,1.81405,-1.87457,0.065902,1.78739,-1.65148,-0.047653,1.71988,-1.60485,0.077448,1.62732,-1.6507,0.143098,1.56833,-1.65969,0.249986,1.88658,-2.12577,0.309737,1.81281,-1.95058,0.103695,1.85386,-2.05352,0.111197,1.66074,-2.22051,0.171783,1.57842,-2.27081,0.33861,1.56122,-2.16533,0.40237,1.54271,-2.1607,0.184265,1.3856,-1.8135,-0.004767,1.45102,-1.88661,4.5e-005,1.4777,-1.94117,-0.001331,1.45649,-1.99966,0.187032,1.39467,-2.08178,0.323974,1.18071,-1.75369,0.232698,1.08356,-1.77735,0.289267,1.02633,-1.80119,0.408481,0.992626,-1.78244,0.291545,0.860123,-1.76887,0.231909,0.814423,-1.77697,0.222017,0.947633,-1.77858,0.165535,0.903497,-1.78163,0.017909,0.733527,-1.78958,-0.106293,0.742012,-1.86504,0.098031,0.592009,-1.81092,0.045339,0.579338,-1.73832,0.118328,1.08787,-2.12286,0.118903,1.00364,-2.10147,-0.021215,1.0926,-2.08972,-0.019381,1.00839,-2.07166,0.023707,0.862275,-2.06167,-0.02348,0.680856,-2.0371,-0.122212,0.735676,-2.05639,-0.153239,0.673837,-2.04137,-0.242321,0.463876,-1.99277,-0.347069,0.40482,-1.93561,-0.072896,0.376007,-1.97292,-0.128187,0.341982,-2.03589,0.104953,1.29976,-1.8361,0.102166,1.30784,-2.05116},
/*1855*/{0.204296,1.8864,-1.73448,0.296354,1.81745,-1.87316,0.061823,1.79305,-1.65262,-0.051084,1.72586,-1.60762,0.073229,1.63336,-1.65258,0.139217,1.5746,-1.66041,0.251265,1.89189,-2.12496,0.309221,1.81722,-1.9502,0.104896,1.8573,-2.05429,0.116774,1.66439,-2.22271,0.178975,1.58213,-2.2702,0.343387,1.57068,-2.16033,0.407718,1.55409,-2.15422,0.185371,1.38945,-1.81464,-0.003575,1.45469,-1.88668,0.001219,1.48138,-1.94285,-0.000107,1.46039,-2.00052,0.188276,1.39466,-2.08196,0.32599,1.18807,-1.75328,0.235613,1.08988,-1.77769,0.29315,1.03238,-1.8018,0.412329,1.00187,-1.7832,0.30166,0.862222,-1.76852,0.243641,0.812841,-1.77658,0.226327,0.946535,-1.77994,0.173148,0.898102,-1.783,0.035558,0.719829,-1.79108,-0.088431,0.719332,-1.86714,0.1244,0.583713,-1.81065,0.071878,0.568242,-1.73786,0.111728,1.08913,-2.12075,0.109132,1.00555,-2.09946,-0.02861,1.09598,-2.08756,-0.029529,1.01426,-2.07102,0.008602,0.868201,-2.06077,-0.041066,0.68618,-2.03694,-0.137742,0.741461,-2.05591,-0.170195,0.679593,-2.04177,-0.258158,0.470066,-1.99399,-0.365601,0.413495,-1.93567,-0.095241,0.37628,-1.97242,-0.148544,0.343199,-2.03506,0.105209,1.30375,-1.83543,0.102168,1.30943,-2.05057},
/*1856*/{0.202022,1.88992,-1.73456,0.294801,1.82196,-1.87229,0.058858,1.79726,-1.65383,-0.055414,1.73158,-1.61044,0.069689,1.63961,-1.65353,0.135029,1.57999,-1.66187,0.251813,1.89736,-2.12403,0.309629,1.82127,-1.94804,0.106032,1.86031,-2.05474,0.122983,1.66717,-2.22406,0.185906,1.5861,-2.26907,0.347445,1.58023,-2.15491,0.412074,1.56578,-2.14743,0.186611,1.39303,-1.81577,-0.002459,1.45919,-1.88871,0.002506,1.48496,-1.94425,0.002461,1.46301,-2.00218,0.189567,1.39494,-2.08243,0.327456,1.19475,-1.75354,0.239079,1.09577,-1.77691,0.297557,1.03902,-1.80101,0.414801,1.00978,-1.78432,0.310834,0.863089,-1.7687,0.256798,0.810822,-1.77636,0.230661,0.942497,-1.78236,0.180177,0.891691,-1.78559,0.051791,0.704741,-1.79119,-0.070501,0.697803,-1.86807,0.150827,0.576032,-1.81005,0.099163,0.558158,-1.73816,0.105752,1.09071,-2.11867,0.099756,1.00706,-2.09689,-0.035222,1.10196,-2.08737,-0.039148,1.02035,-2.07117,-0.006438,0.873989,-2.06049,-0.057552,0.690795,-2.03668,-0.153995,0.748208,-2.05582,-0.187219,0.687146,-2.04224,-0.273443,0.47635,-1.99378,-0.385442,0.42324,-1.93628,-0.116669,0.376515,-1.97166,-0.169822,0.343218,-2.0346,0.105576,1.30777,-1.83513,0.102784,1.31086,-2.05033},
/*1857*/{0.199787,1.894,-1.73444,0.294988,1.82604,-1.87044,0.055905,1.80218,-1.65454,-0.059711,1.73724,-1.61214,0.06473,1.6448,-1.65566,0.131769,1.58612,-1.66319,0.25311,1.902,-2.12252,0.309616,1.8259,-1.94684,0.107187,1.8635,-2.05504,0.128465,1.67111,-2.22609,0.19262,1.59021,-2.26822,0.351778,1.59058,-2.15008,0.415447,1.5768,-2.14049,0.189244,1.39647,-1.81622,-0.000241,1.46365,-1.88913,0.004699,1.48808,-1.94599,0.004747,1.46669,-2.00201,0.190743,1.39507,-2.08257,0.329217,1.20137,-1.75389,0.24243,1.1021,-1.77673,0.299448,1.04608,-1.80075,0.416298,1.01635,-1.78434,0.31931,0.864166,-1.76859,0.268125,0.808142,-1.77651,0.23631,0.938709,-1.78434,0.188165,0.885376,-1.78754,0.072458,0.692661,-1.79217,-0.051351,0.675913,-1.86939,0.177671,0.568966,-1.80966,0.126431,0.547907,-1.73807,0.099199,1.09244,-2.11674,0.090952,1.00969,-2.09441,-0.041577,1.10898,-2.08676,-0.048475,1.02781,-2.07017,-0.021603,0.879945,-2.06064,-0.073205,0.697268,-2.0372,-0.169794,0.755519,-2.05565,-0.202109,0.693713,-2.04197,-0.291378,0.482647,-1.99403,-0.401838,0.433238,-1.93697,-0.138619,0.376326,-1.97133,-0.193998,0.3446,-2.03628,0.106886,1.31184,-1.83416,0.103304,1.31233,-2.04936},
/*1858*/{0.197075,1.898,-1.73478,0.294632,1.83029,-1.86887,0.052714,1.80714,-1.65589,-0.063918,1.74281,-1.61524,0.061192,1.6507,-1.65701,0.127022,1.59162,-1.66458,0.255353,1.9075,-2.12109,0.309447,1.83065,-1.94509,0.108089,1.86698,-2.05579,0.134939,1.67529,-2.22811,0.199178,1.59488,-2.26774,0.35351,1.59915,-2.14537,0.418984,1.58707,-2.13458,0.190044,1.40012,-1.81752,0.001108,1.46827,-1.88963,0.005799,1.49171,-1.94756,0.007523,1.46968,-2.00305,0.191982,1.39536,-2.08267,0.330549,1.20807,-1.7544,0.241588,1.10452,-1.77722,0.302267,1.05115,-1.80116,0.417419,1.02262,-1.78443,0.328127,0.864025,-1.76864,0.279994,0.805991,-1.77664,0.241134,0.933638,-1.78501,0.196467,0.878795,-1.78715,0.089165,0.67682,-1.79278,-0.030504,0.654187,-1.87122,0.204275,0.562438,-1.81027,0.154497,0.538636,-1.73834,0.09276,1.09505,-2.11377,0.081435,1.01254,-2.09307,-0.047631,1.11551,-2.08654,-0.056517,1.03508,-2.06929,-0.035909,0.885538,-2.06107,-0.088909,0.70411,-2.03801,-0.18542,0.76326,-2.05588,-0.217611,0.701975,-2.04288,-0.312729,0.490703,-1.9986,-0.418675,0.444766,-1.93717,-0.161036,0.376692,-1.97163,-0.216476,0.343576,-2.03503,0.107161,1.31594,-1.83355,0.103619,1.31396,-2.04875},
/*1859*/{0.195265,1.90173,-1.73475,0.294045,1.83536,-1.86831,0.050496,1.81149,-1.65736,-0.066616,1.74776,-1.61763,0.057554,1.656,-1.65898,0.123264,1.59667,-1.66518,0.256217,1.91177,-2.11992,0.309778,1.83467,-1.9435,0.109513,1.86989,-2.05664,0.140063,1.67977,-2.23006,0.205877,1.59888,-2.26724,0.356339,1.60856,-2.14077,0.421143,1.59748,-2.12947,0.191226,1.40367,-1.81794,0.002674,1.47286,-1.89038,0.008414,1.49506,-1.94886,0.009605,1.47254,-2.0039,0.193055,1.39553,-2.08271,0.33263,1.21385,-1.75416,0.242651,1.11124,-1.77654,0.303371,1.05645,-1.79981,0.417482,1.02796,-1.78627,0.336741,0.863949,-1.76869,0.293933,0.804213,-1.77758,0.245463,0.929266,-1.78687,0.203729,0.870697,-1.7894,0.111063,0.664469,-1.79458,-0.009817,0.633094,-1.87161,0.230592,0.555855,-1.81183,0.181604,0.528853,-1.73901,0.087358,1.0969,-2.11217,0.071922,1.0154,-2.09045,-0.052651,1.12258,-2.08521,-0.065046,1.04256,-2.06872,-0.04994,0.891733,-2.06097,-0.104889,0.712303,-2.03933,-0.200326,0.771771,-2.05551,-0.23461,0.708649,-2.04229,-0.323472,0.497358,-1.99637,-0.435461,0.457059,-1.93709,-0.182839,0.377248,-1.9715,-0.236325,0.344509,-2.03401,0.107664,1.32003,-1.83262,0.103994,1.31538,-2.04777},
/*1860*/{0.193282,1.90531,-1.73501,0.29469,1.8387,-1.86687,0.047676,1.81631,-1.65883,-0.070583,1.75297,-1.61979,0.054544,1.66091,-1.66052,0.12008,1.60193,-1.66629,0.2579,1.91682,-2.11806,0.309724,1.83902,-1.94222,0.110545,1.87307,-2.05784,0.145248,1.68431,-2.23218,0.212273,1.60368,-2.26657,0.358376,1.6166,-2.13619,0.423672,1.60762,-2.12343,0.193721,1.40792,-1.81946,0.004821,1.4776,-1.89025,0.010018,1.49905,-1.95081,0.011658,1.4759,-2.00402,0.19437,1.39657,-2.0828,0.334094,1.21889,-1.75396,0.245443,1.11759,-1.77591,0.303918,1.06121,-1.79984,0.416727,1.03226,-1.78645,0.344731,0.863309,-1.76896,0.302838,0.799962,-1.77725,0.250911,0.923949,-1.78793,0.211822,0.862586,-1.79191,0.12816,0.650066,-1.79552,0.012659,0.612031,-1.87311,0.257404,0.550343,-1.81231,0.210337,0.520304,-1.73971,0.08144,1.09958,-2.11085,0.063516,1.01903,-2.08931,-0.057708,1.13044,-2.08487,-0.073536,1.05141,-2.06806,-0.063077,0.898862,-2.06092,-0.11916,0.720275,-2.04094,-0.214965,0.780164,-2.05584,-0.249739,0.719037,-2.04231,-0.340926,0.503243,-1.99837,-0.449932,0.469216,-1.93724,-0.205722,0.377372,-1.97208,-0.260126,0.34476,-2.03446,0.109407,1.32478,-1.8319,0.104643,1.31752,-2.04696},
/*1861*/{0.191533,1.90881,-1.73552,0.293236,1.84274,-1.86546,0.045111,1.82065,-1.66064,-0.073724,1.75738,-1.62302,0.052136,1.66595,-1.66198,0.118479,1.60707,-1.66737,0.260044,1.92143,-2.11707,0.3098,1.84308,-1.94044,0.111985,1.87518,-2.05809,0.151716,1.68816,-2.23458,0.218017,1.60798,-2.26573,0.360182,1.6248,-2.13248,0.425714,1.61705,-2.11881,0.1944,1.41139,-1.81998,0.006097,1.48196,-1.89068,0.011844,1.5023,-1.95195,0.013905,1.47908,-2.00543,0.195634,1.39697,-2.08272,0.333936,1.22446,-1.75527,0.243482,1.12032,-1.77545,0.303958,1.06628,-1.79917,0.413843,1.03577,-1.78747,0.351212,0.861837,-1.76903,0.316488,0.798167,-1.77711,0.255097,0.916425,-1.78988,0.219041,0.85436,-1.79294,0.148292,0.635989,-1.79654,0.035402,0.592065,-1.87382,0.283064,0.544974,-1.81359,0.238409,0.511653,-1.74168,0.076273,1.10241,-2.11004,0.054989,1.0221,-2.08815,-0.06096,1.13836,-2.08429,-0.08055,1.05926,-2.06676,-0.075537,0.906982,-2.06152,-0.132839,0.729616,-2.0427,-0.228224,0.788645,-2.05578,-0.263695,0.727575,-2.04211,-0.353695,0.510876,-1.99974,-0.46201,0.482192,-1.93418,-0.2274,0.377624,-1.97217,-0.283194,0.345885,-2.03441,0.109557,1.32871,-1.83124,0.105056,1.31926,-2.04622},
/*1862*/{0.190583,1.91269,-1.73546,0.286699,1.84941,-1.86621,0.042035,1.82566,-1.66219,-0.077953,1.76193,-1.62623,0.049368,1.67077,-1.6637,0.115754,1.61155,-1.66818,0.26229,1.9253,-2.11484,0.308872,1.84788,-1.93984,0.113408,1.87896,-2.05888,0.157827,1.69203,-2.23635,0.223715,1.61261,-2.26532,0.362056,1.63271,-2.12799,0.426689,1.62594,-2.11411,0.195905,1.41482,-1.82033,0.008695,1.48632,-1.8915,0.013704,1.5062,-1.95314,0.015969,1.48241,-2.00565,0.196743,1.3977,-2.08265,0.334782,1.22836,-1.75504,0.245379,1.12772,-1.77467,0.302451,1.0706,-1.79814,0.411072,1.03875,-1.78833,0.359282,0.860343,-1.76907,0.324621,0.792976,-1.77751,0.259936,0.909026,-1.79126,0.226875,0.845871,-1.79406,0.169403,0.622106,-1.79672,0.058745,0.572802,-1.87505,0.308641,0.54029,-1.81417,0.266144,0.503382,-1.74334,0.070984,1.10535,-2.10881,0.047877,1.02626,-2.087,-0.064857,1.14596,-2.08424,-0.086273,1.06809,-2.06717,-0.086258,0.915788,-2.06223,-0.145205,0.7381,-2.04483,-0.241505,0.797286,-2.05613,-0.275413,0.73588,-2.0424,-0.367358,0.518337,-2.00151,-0.473751,0.497562,-1.93488,-0.249085,0.378152,-1.97379,-0.306222,0.347274,-2.03423,0.110366,1.33285,-1.8305,0.105458,1.32125,-2.04536},
/*1863*/{0.189111,1.91562,-1.73529,0.286723,1.85357,-1.86527,0.039462,1.82966,-1.66417,-0.080359,1.76646,-1.62891,0.04751,1.67456,-1.66551,0.112673,1.61548,-1.66916,0.263432,1.92902,-2.11397,0.30935,1.85192,-1.93836,0.114429,1.88192,-2.05933,0.163796,1.69675,-2.23842,0.228762,1.61683,-2.26528,0.363501,1.63934,-2.1246,0.42753,1.63358,-2.10895,0.197767,1.4189,-1.82111,0.010004,1.49077,-1.89165,0.01608,1.5098,-1.95403,0.018894,1.48498,-2.00526,0.198461,1.39884,-2.08202,0.335308,1.23183,-1.75628,0.243543,1.12929,-1.7731,0.302072,1.07329,-1.79585,0.409616,1.04035,-1.78802,0.365921,0.857636,-1.7692,0.336093,0.789257,-1.77785,0.26525,0.903276,-1.792,0.23566,0.836274,-1.79573,0.189824,0.609327,-1.79742,0.082647,0.553576,-1.87587,0.334508,0.536087,-1.81471,0.293871,0.494715,-1.74422,0.06728,1.1087,-2.10836,0.040839,1.02967,-2.08644,-0.068344,1.1533,-2.08342,-0.091724,1.07622,-2.06678,-0.09636,0.924863,-2.06336,-0.156652,0.746578,-2.04698,-0.253306,0.805194,-2.05588,-0.286042,0.744388,-2.04223,-0.38641,0.52283,-2.00202,-0.483834,0.512986,-1.93462,-0.269927,0.378675,-1.97507,-0.328098,0.349454,-2.03385,0.111949,1.33724,-1.82931,0.106736,1.32329,-2.04403},
/*1864*/{0.187947,1.91853,-1.73569,0.291999,1.85397,-1.86263,0.037725,1.83346,-1.66533,-0.082808,1.77063,-1.63244,0.044129,1.67891,-1.66642,0.110794,1.61965,-1.66902,0.264688,1.93263,-2.11255,0.310161,1.85485,-1.93698,0.116915,1.88469,-2.06049,0.168728,1.70105,-2.23934,0.233124,1.62068,-2.26509,0.364878,1.64666,-2.1222,0.42861,1.64083,-2.10526,0.198594,1.42231,-1.82144,0.0118,1.49518,-1.89134,0.018026,1.51274,-1.95476,0.020371,1.48827,-2.00558,0.20019,1.40017,-2.08185,0.336561,1.23447,-1.75704,0.242138,1.13591,-1.77235,0.299821,1.07663,-1.79492,0.406886,1.04132,-1.78948,0.372606,0.855809,-1.76933,0.345628,0.784742,-1.77854,0.269604,0.894631,-1.79342,0.243567,0.827197,-1.79595,0.210589,0.596164,-1.79815,0.106951,0.535612,-1.87686,0.359622,0.531059,-1.81561,0.321877,0.48767,-1.74739,0.062763,1.1117,-2.10805,0.034369,1.03187,-2.0866,-0.071066,1.16062,-2.08277,-0.096513,1.08395,-2.0661,-0.106396,0.933646,-2.06472,-0.167172,0.755588,-2.04976,-0.263404,0.814269,-2.05576,-0.296776,0.753197,-2.04225,-0.392947,0.532914,-2.00485,-0.492797,0.52925,-1.93453,-0.289049,0.378264,-1.97569,-0.351247,0.352527,-2.03362,0.11272,1.34103,-1.82862,0.107474,1.32559,-2.04323},
/*1865*/{0.186454,1.92119,-1.73608,0.285755,1.86135,-1.86616,0.035794,1.83733,-1.66719,-0.08563,1.77371,-1.63488,0.04284,1.68258,-1.66846,0.109071,1.62297,-1.66976,0.265738,1.93595,-2.11088,0.309637,1.8584,-1.93635,0.117968,1.88748,-2.06166,0.17402,1.70531,-2.24066,0.237726,1.62483,-2.26521,0.365364,1.6517,-2.11987,0.429295,1.64719,-2.10083,0.199561,1.42495,-1.82153,0.014973,1.49886,-1.89157,0.020468,1.51573,-1.95507,0.022815,1.4912,-2.00594,0.20123,1.40137,-2.08102,0.33728,1.23659,-1.75791,0.240551,1.13715,-1.77202,0.297614,1.07907,-1.79337,0.404043,1.04062,-1.789,0.379515,0.852924,-1.76873,0.355017,0.781308,-1.77756,0.274103,0.886613,-1.79498,0.252198,0.818102,-1.7973,0.231163,0.585486,-1.79928,0.130937,0.519425,-1.87757,0.383232,0.52777,-1.81746,0.348414,0.480547,-1.74871,0.058845,1.11475,-2.10918,0.028179,1.03918,-2.08798,-0.073508,1.16741,-2.08217,-0.100433,1.09085,-2.06585,-0.114951,0.941998,-2.06559,-0.175888,0.76385,-2.05183,-0.27305,0.821944,-2.05591,-0.305864,0.761441,-2.04256,-0.402216,0.54254,-2.00681,-0.501005,0.546312,-1.93383,-0.307987,0.37965,-1.97774,-0.373686,0.357099,-2.03274,0.113553,1.34424,-1.82792,0.108251,1.32759,-2.04244},
/*1866*/{0.186118,1.924,-1.73582,0.290987,1.86192,-1.86133,0.033556,1.84148,-1.66944,-0.088636,1.77733,-1.63764,0.040196,1.68579,-1.66923,0.107367,1.62628,-1.6702,0.267205,1.93883,-2.10955,0.310464,1.86098,-1.93434,0.119519,1.89072,-2.06257,0.178631,1.70923,-2.24168,0.241234,1.62825,-2.26503,0.3666,1.65737,-2.11805,0.429138,1.65282,-2.09796,0.200454,1.42827,-1.82151,0.016499,1.50243,-1.89081,0.021983,1.51925,-1.95552,0.024172,1.49392,-2.00582,0.202458,1.40269,-2.08061,0.337654,1.23768,-1.75916,0.239981,1.13985,-1.76906,0.296305,1.07946,-1.79235,0.400784,1.03946,-1.78872,0.38485,0.84977,-1.76875,0.365312,0.777428,-1.77781,0.277999,0.877115,-1.79641,0.259934,0.807982,-1.79906,0.252713,0.573939,-1.80015,0.155087,0.503783,-1.87849,0.407204,0.52378,-1.81931,0.37509,0.473987,-1.75215,0.055869,1.11843,-2.10967,0.023861,1.04248,-2.08902,-0.075144,1.17275,-2.08109,-0.104197,1.09667,-2.06575,-0.121939,0.948778,-2.06608,-0.183464,0.770464,-2.05405,-0.28014,0.830995,-2.05563,-0.313075,0.769869,-2.04342,-0.407676,0.551458,-2.00818,-0.507096,0.563641,-1.93444,-0.327799,0.378551,-1.97822,-0.396125,0.363368,-2.03122,0.114348,1.34785,-1.82694,0.108791,1.32978,-2.04135},
/*1867*/{0.185617,1.92642,-1.73652,0.291379,1.86462,-1.8609,0.032809,1.84458,-1.67106,-0.090955,1.78014,-1.64141,0.038182,1.68848,-1.67041,0.105548,1.62942,-1.67035,0.269291,1.94187,-2.10832,0.310679,1.86396,-1.93351,0.120659,1.89292,-2.06295,0.184038,1.71299,-2.24237,0.244797,1.63185,-2.26493,0.367978,1.66156,-2.11602,0.430452,1.65762,-2.09529,0.200412,1.4324,-1.82191,0.017513,1.50613,-1.89022,0.023595,1.52265,-1.95583,0.026311,1.49788,-2.00567,0.204194,1.40426,-2.08073,0.337874,1.23807,-1.76042,0.238829,1.14195,-1.76901,0.293027,1.07987,-1.79202,0.39839,1.03708,-1.78813,0.390101,0.846453,-1.76845,0.373538,0.772139,-1.77716,0.282449,0.868039,-1.79735,0.268011,0.79758,-1.80024,0.271651,0.562101,-1.80079,0.17916,0.489263,-1.87974,0.429497,0.520795,-1.82241,0.401131,0.467915,-1.75445,0.052957,1.12265,-2.1115,0.020212,1.04609,-2.09114,-0.076724,1.17701,-2.07963,-0.106185,1.10147,-2.06485,-0.126208,0.954766,-2.06675,-0.190379,0.777351,-2.05512,-0.286085,0.838593,-2.05559,-0.320709,0.777761,-2.04447,-0.420232,0.56143,-2.01076,-0.512433,0.581879,-1.93515,-0.345417,0.37835,-1.97968,-0.417836,0.370698,-2.03014,0.114844,1.35172,-1.82633,0.109554,1.33261,-2.04065},
/*1868*/{0.185518,1.92798,-1.73663,0.29204,1.86762,-1.8605,0.031138,1.84803,-1.67321,-0.091303,1.78298,-1.64394,0.037381,1.69089,-1.67197,0.104199,1.63184,-1.67061,0.270817,1.9441,-2.10729,0.310199,1.86671,-1.93329,0.122629,1.89525,-2.06423,0.187913,1.7162,-2.24293,0.248365,1.6346,-2.26536,0.368198,1.66517,-2.11448,0.430862,1.66144,-2.09317,0.202037,1.43539,-1.82154,0.019353,1.50909,-1.89064,0.0245,1.52532,-1.95653,0.028063,1.50009,-2.00558,0.204613,1.40629,-2.07994,0.335792,1.23831,-1.76209,0.24018,1.14442,-1.76732,0.289488,1.07962,-1.79121,0.395407,1.03432,-1.78754,0.394522,0.842723,-1.76779,0.383494,0.767963,-1.77692,0.286015,0.858893,-1.79907,0.276012,0.786848,-1.80077,0.293274,0.552653,-1.80099,0.2017,0.476316,-1.88078,0.452879,0.518001,-1.82349,0.42599,0.462912,-1.75663,0.050407,1.12586,-2.11233,0.017798,1.05029,-2.09329,-0.078527,1.18164,-2.07917,-0.107714,1.10546,-2.06431,-0.128133,0.959273,-2.06677,-0.196802,0.782894,-2.05664,-0.29073,0.845973,-2.05621,-0.326073,0.78595,-2.04593,-0.425467,0.570933,-2.01206,-0.516701,0.598948,-1.93582,-0.363337,0.379375,-1.98003,-0.439117,0.379774,-2.02793,0.116089,1.355,-1.8256,0.110575,1.33463,-2.0398},
/*1869*/{0.184992,1.9298,-1.73661,0.29129,1.86911,-1.85962,0.030421,1.85045,-1.67478,-0.095011,1.78419,-1.64703,0.036431,1.69351,-1.67317,0.103613,1.63345,-1.67117,0.27233,1.94634,-2.10598,0.310935,1.86858,-1.93217,0.122802,1.89797,-2.06488,0.191047,1.72007,-2.24381,0.251248,1.63721,-2.26568,0.368453,1.66778,-2.11341,0.431266,1.66426,-2.09097,0.205477,1.437,-1.82089,0.021122,1.51249,-1.89052,0.02596,1.52841,-1.95626,0.029214,1.50298,-2.00594,0.205488,1.40833,-2.0793,0.334809,1.23707,-1.76273,0.238447,1.14478,-1.76732,0.286306,1.07886,-1.7897,0.391051,1.03082,-1.78711,0.398314,0.838462,-1.76666,0.393179,0.76482,-1.77641,0.289465,0.848421,-1.79989,0.283131,0.777088,-1.80061,0.314459,0.543933,-1.8018,0.225201,0.463511,-1.88214,0.473812,0.515811,-1.82643,0.450671,0.45879,-1.76,0.049524,1.12916,-2.11307,0.016828,1.05314,-2.0943,-0.079003,1.18486,-2.0786,-0.108551,1.10919,-2.06443,-0.128702,0.961932,-2.06696,-0.201635,0.787606,-2.05746,-0.29333,0.852074,-2.05706,-0.330591,0.792833,-2.0467,-0.433717,0.581012,-2.01319,-0.521378,0.616636,-1.93811,-0.383445,0.37703,-1.97693,-0.459332,0.390129,-2.02556,0.117673,1.35774,-1.82519,0.111384,1.33702,-2.03933},
/*1870*/{0.18495,1.93177,-1.73651,0.292628,1.86998,-1.85851,0.02965,1.85246,-1.67618,-0.094506,1.78686,-1.65015,0.035456,1.69511,-1.67425,0.102504,1.63553,-1.67125,0.273061,1.94837,-2.10518,0.311058,1.87106,-1.93172,0.124719,1.90005,-2.06532,0.19234,1.72259,-2.24331,0.253392,1.63968,-2.26612,0.369621,1.67003,-2.11282,0.431275,1.66658,-2.08895,0.206287,1.43989,-1.82073,0.020941,1.51524,-1.89072,0.026093,1.53189,-1.9557,0.030197,1.50626,-2.00578,0.206147,1.4109,-2.07884,0.333105,1.2329,-1.76245,0.233561,1.14326,-1.76676,0.281821,1.0777,-1.78849,0.386214,1.02678,-1.78635,0.400651,0.833959,-1.76712,0.400301,0.760243,-1.77626,0.292342,0.83873,-1.79789,0.288406,0.767178,-1.80134,0.331714,0.53405,-1.8033,0.247115,0.451914,-1.88249,0.493071,0.514093,-1.82948,0.473221,0.455436,-1.76302,0.049686,1.13192,-2.1144,0.016374,1.05613,-2.09626,-0.078971,1.18731,-2.07857,-0.108157,1.11105,-2.06353,-0.127222,0.963447,-2.06655,-0.205164,0.790811,-2.0579,-0.295478,0.858588,-2.05899,-0.333799,0.800148,-2.04809,-0.443088,0.591821,-2.01471,-0.527341,0.634061,-1.94026,-0.406494,0.380163,-1.97559,-0.478766,0.401203,-2.02277,0.117934,1.36072,-1.82493,0.11183,1.33999,-2.03908},
/*1871*/{0.185435,1.93287,-1.7364,0.292323,1.87111,-1.85736,0.029278,1.85422,-1.67795,-0.097167,1.78727,-1.65251,0.034794,1.69681,-1.67511,0.102272,1.63641,-1.67127,0.273943,1.94933,-2.1042,0.311584,1.87293,-1.93102,0.125356,1.90174,-2.06564,0.194575,1.726,-2.24397,0.255708,1.6416,-2.2666,0.369817,1.67219,-2.11184,0.431326,1.66744,-2.08729,0.204192,1.44039,-1.82125,0.021059,1.51753,-1.89093,0.027264,1.5345,-1.95546,0.031364,1.50842,-2.0047,0.206237,1.41336,-2.07867,0.331045,1.2299,-1.76324,0.232335,1.14171,-1.76613,0.277487,1.0754,-1.78652,0.381475,1.02235,-1.78581,0.404581,0.829775,-1.76694,0.404891,0.753596,-1.77721,0.295055,0.828608,-1.79586,0.295665,0.75639,-1.7999,0.35047,0.526586,-1.80392,0.268063,0.440751,-1.8842,0.512838,0.514898,-1.83154,0.495104,0.452617,-1.76552,0.050938,1.13416,-2.11567,0.016691,1.05674,-2.09692,-0.077137,1.18843,-2.07809,-0.106032,1.11155,-2.06379,-0.124395,0.964594,-2.0668,-0.207664,0.793201,-2.05773,-0.295791,0.863465,-2.06031,-0.336527,0.806513,-2.04855,-0.455342,0.601806,-2.01591,-0.533256,0.650963,-1.94304,-0.428205,0.39207,-1.97157,-0.498603,0.413233,-2.01947,0.11643,1.3616,-1.82562,0.111313,1.34258,-2.03995},
/*1872*/{0.186196,1.9344,-1.73544,0.288072,1.8753,-1.85886,0.028168,1.8551,-1.67919,-0.097503,1.78858,-1.6549,0.033928,1.69744,-1.67632,0.101861,1.63715,-1.67106,0.274763,1.95113,-2.10338,0.311959,1.87483,-1.93045,0.126385,1.9033,-2.06582,0.197443,1.72806,-2.24507,0.256524,1.64287,-2.26673,0.370457,1.67291,-2.11167,0.431551,1.6678,-2.08618,0.204532,1.4415,-1.82163,0.022199,1.51953,-1.89015,0.027961,1.53675,-1.95472,0.031722,1.51119,-2.00466,0.207392,1.41579,-2.07833,0.328856,1.22565,-1.76387,0.222609,1.13802,-1.76693,0.27174,1.07251,-1.7867,0.376608,1.01713,-1.78476,0.408114,0.825095,-1.76751,0.41113,0.748778,-1.77737,0.29803,0.81899,-1.79348,0.301666,0.74711,-1.7987,0.36504,0.518742,-1.80509,0.288059,0.431421,-1.88555,0.529339,0.514152,-1.83379,0.515053,0.451018,-1.76923,0.052506,1.13545,-2.11584,0.022479,1.05871,-2.09865,-0.076085,1.18858,-2.07864,-0.103805,1.11193,-2.06353,-0.121844,0.964671,-2.06658,-0.210112,0.794348,-2.05709,-0.295994,0.868397,-2.06142,-0.338706,0.812286,-2.05037,-0.464421,0.612359,-2.01727,-0.540263,0.667376,-1.94583,-0.447989,0.403987,-1.96766,-0.518092,0.427023,-2.01738,0.11676,1.36295,-1.82601,0.111796,1.34519,-2.04045},
/*1873*/{0.186534,1.9351,-1.73509,0.289412,1.87673,-1.85889,0.028373,1.85644,-1.68,-0.099623,1.78837,-1.65726,0.034296,1.69862,-1.67743,0.101591,1.63745,-1.67114,0.27514,1.95168,-2.10299,0.312162,1.87631,-1.93038,0.127743,1.90533,-2.06579,0.198082,1.72895,-2.24491,0.257708,1.64371,-2.26781,0.370617,1.67289,-2.11119,0.432018,1.66704,-2.08514,0.205065,1.44389,-1.82164,0.021961,1.52063,-1.88954,0.027432,1.53857,-1.95448,0.031853,1.51317,-2.00493,0.208134,1.41793,-2.07776,0.325596,1.22099,-1.76408,0.222043,1.1372,-1.76526,0.266712,1.06797,-1.78628,0.373028,1.01135,-1.78461,0.411635,0.820058,-1.76818,0.417745,0.745855,-1.77908,0.30056,0.809213,-1.79009,0.308025,0.738041,-1.79604,0.382024,0.512095,-1.80616,0.306654,0.421561,-1.88622,0.544973,0.515174,-1.83683,0.534854,0.451902,-1.77243,0.056184,1.13634,-2.11641,0.025375,1.05918,-2.09907,-0.073113,1.18858,-2.07897,-0.101133,1.11142,-2.06353,-0.118137,0.963931,-2.06629,-0.211652,0.795019,-2.05672,-0.294422,0.872388,-2.06271,-0.340489,0.818574,-2.05195,-0.474158,0.624286,-2.01795,-0.546875,0.683777,-1.94952,-0.46659,0.415858,-1.96355,-0.536512,0.442334,-2.01608,0.117394,1.36488,-1.82581,0.112661,1.34718,-2.04027},
/*1874*/{0.186979,1.93577,-1.73479,0.294552,1.87375,-1.85695,0.028975,1.85645,-1.68077,-0.09929,1.78799,-1.65955,0.034648,1.69867,-1.6778,0.102964,1.6373,-1.67088,0.275906,1.95205,-2.10269,0.312692,1.87677,-1.92967,0.127551,1.90731,-2.06595,0.199788,1.73053,-2.24563,0.257618,1.64413,-2.26827,0.371217,1.6722,-2.11117,0.432224,1.66634,-2.08482,0.205016,1.44439,-1.82178,0.022367,1.52167,-1.88839,0.02688,1.54043,-1.95397,0.031419,1.51519,-2.00418,0.20858,1.42029,-2.07733,0.32266,1.21549,-1.76393,0.213278,1.13133,-1.76753,0.259622,1.06382,-1.78845,0.367198,1.00467,-1.78435,0.415392,0.815992,-1.76913,0.422425,0.740415,-1.77992,0.303997,0.800653,-1.78789,0.31362,0.730792,-1.79487,0.397366,0.507721,-1.80723,0.323381,0.413929,-1.88736,0.557732,0.516251,-1.83835,0.551138,0.451373,-1.77476,0.059492,1.13631,-2.11621,0.029611,1.05817,-2.09982,-0.07063,1.18691,-2.07909,-0.096934,1.11017,-2.06452,-0.11313,0.961625,-2.06582,-0.212355,0.796059,-2.05582,-0.291862,0.876115,-2.06368,-0.339435,0.825113,-2.05353,-0.482623,0.636873,-2.01874,-0.554049,0.700793,-1.95247,-0.484486,0.429164,-1.96102,-0.552342,0.456799,-2.01278,0.117341,1.36554,-1.82615,0.112659,1.34939,-2.04073},
/*1875*/{0.1878,1.93625,-1.73385,0.294188,1.87451,-1.85602,0.028437,1.85632,-1.6812,-0.098764,1.78748,-1.66072,0.035207,1.69796,-1.67897,0.103417,1.63666,-1.67005,0.275736,1.95178,-2.10233,0.313058,1.87715,-1.92954,0.128115,1.908,-2.06558,0.199647,1.73066,-2.24557,0.2576,1.64411,-2.26828,0.371345,1.67146,-2.11113,0.431759,1.66378,-2.08393,0.205168,1.44571,-1.82222,0.021557,1.52198,-1.88766,0.026791,1.54144,-1.95354,0.032113,1.51616,-2.00346,0.20911,1.42211,-2.07681,0.317506,1.21069,-1.7644,0.206933,1.12798,-1.76749,0.252982,1.05956,-1.78783,0.362007,0.997245,-1.78434,0.41813,0.812447,-1.77023,0.429505,0.738315,-1.78316,0.307219,0.793119,-1.78464,0.319425,0.722802,-1.79187,0.408167,0.50214,-1.80796,0.338559,0.407099,-1.88795,0.569948,0.517379,-1.84062,0.564917,0.451962,-1.77735,0.063465,1.13559,-2.11608,0.034362,1.05697,-2.09928,-0.06758,1.18546,-2.07995,-0.09323,1.1079,-2.06463,-0.107087,0.95916,-2.06502,-0.213212,0.796033,-2.05517,-0.288895,0.880991,-2.0653,-0.339288,0.830402,-2.05425,-0.489737,0.649415,-2.01942,-0.559734,0.718008,-1.95525,-0.500526,0.443903,-1.95776,-0.566533,0.472338,-2.0109,0.117912,1.36631,-1.82615,0.113462,1.35085,-2.04078},
/*1876*/{0.188956,1.93599,-1.73309,0.289633,1.87775,-1.85699,0.029053,1.85529,-1.6825,-0.098479,1.78637,-1.66227,0.035321,1.69649,-1.67878,0.105005,1.63589,-1.66899,0.275785,1.95166,-2.10229,0.312561,1.87794,-1.92951,0.12841,1.90887,-2.06506,0.199443,1.73099,-2.24549,0.256633,1.64371,-2.26866,0.371649,1.66947,-2.1113,0.432406,1.66058,-2.08424,0.205876,1.44618,-1.82217,0.021557,1.52198,-1.88766,0.025981,1.54326,-1.95297,0.031941,1.51636,-2.0027,0.209614,1.42461,-2.07631,0.314841,1.20427,-1.76349,0.203046,1.12576,-1.76766,0.246108,1.0549,-1.78979,0.358197,0.991265,-1.78405,0.421362,0.808483,-1.77295,0.434019,0.734183,-1.78446,0.310347,0.786105,-1.78222,0.325082,0.716477,-1.78864,0.420101,0.499045,-1.80875,0.350563,0.40215,-1.88801,0.580322,0.5181,-1.8424,0.578273,0.452958,-1.78088,0.067952,1.13472,-2.11571,0.039564,1.05606,-2.09836,-0.06309,1.1829,-2.07997,-0.087623,1.10545,-2.06488,-0.10093,0.956745,-2.06429,-0.213644,0.796288,-2.05426,-0.285322,0.884139,-2.06645,-0.337484,0.837606,-2.05632,-0.49332,0.663887,-2.01983,-0.566604,0.735273,-1.95768,-0.515763,0.459252,-1.95435,-0.579419,0.488825,-2.00985,0.118628,1.36672,-1.82647,0.114322,1.35245,-2.04119},
/*1877*/{0.189355,1.93577,-1.73287,0.2898,1.87767,-1.85673,0.029399,1.85437,-1.68311,-0.098254,1.78447,-1.66357,0.037467,1.69534,-1.67943,0.105816,1.63393,-1.66881,0.27572,1.951,-2.1018,0.312788,1.87792,-1.92909,0.128708,1.90915,-2.06346,0.198125,1.73073,-2.24479,0.255884,1.64359,-2.26873,0.372574,1.66606,-2.11126,0.431881,1.65672,-2.08427,0.205816,1.44604,-1.822,0.021242,1.52169,-1.88677,0.025509,1.54307,-1.95227,0.031665,1.5168,-2.00195,0.209763,1.42515,-2.07624,0.309434,1.1976,-1.76412,0.196542,1.11971,-1.76799,0.239053,1.05047,-1.79035,0.3522,0.984128,-1.78391,0.422517,0.806331,-1.77459,0.439056,0.732141,-1.78681,0.312159,0.780241,-1.78198,0.328512,0.710316,-1.78849,0.427084,0.495378,-1.80895,0.360795,0.397479,-1.88854,0.587687,0.517424,-1.84588,0.588664,0.45192,-1.78301,0.072532,1.1331,-2.11498,0.045447,1.05401,-2.09715,-0.059337,1.17972,-2.08056,-0.08239,1.10124,-2.06432,-0.09405,0.953722,-2.06374,-0.213807,0.797712,-2.05268,-0.28009,0.888286,-2.06755,-0.335282,0.843648,-2.05792,-0.497854,0.677945,-2.02013,-0.571326,0.75331,-1.96104,-0.528993,0.475555,-1.95235,-0.590636,0.506224,-2.00969,0.118739,1.36637,-1.82643,0.114332,1.35291,-2.0412},
/*1878*/{0.190622,1.93513,-1.73175,0.295013,1.87473,-1.85491,0.02972,1.85284,-1.68282,-0.096858,1.78196,-1.66418,0.038288,1.69304,-1.6797,0.108209,1.63219,-1.66739,0.275503,1.95012,-2.10092,0.313274,1.87709,-1.92864,0.128973,1.90941,-2.06294,0.195656,1.73015,-2.24452,0.252881,1.64229,-2.26859,0.372335,1.6631,-2.11141,0.431812,1.65245,-2.08419,0.20587,1.44634,-1.82267,0.020525,1.52039,-1.88674,0.025193,1.54293,-1.95139,0.031464,1.51635,-2.00131,0.210301,1.42684,-2.07571,0.307054,1.19044,-1.76294,0.190484,1.11505,-1.76962,0.232999,1.04528,-1.79109,0.346044,0.977039,-1.78431,0.423007,0.803763,-1.77701,0.439863,0.730135,-1.78836,0.313899,0.775209,-1.78197,0.330723,0.705739,-1.78751,0.436446,0.492813,-1.80978,0.368437,0.393218,-1.888,0.593612,0.516822,-1.84772,0.596916,0.450885,-1.78522,0.078335,1.13143,-2.11342,0.052495,1.05163,-2.09572,-0.055405,1.17548,-2.08143,-0.076944,1.09649,-2.06488,-0.087735,0.949923,-2.06333,-0.213985,0.798158,-2.05217,-0.275522,0.892454,-2.06808,-0.332769,0.850372,-2.05771,-0.503449,0.693543,-2.02043,-0.573817,0.771923,-1.96305,-0.542434,0.492112,-1.9509,-0.600051,0.525587,-2.01025,0.119592,1.36586,-1.82687,0.11545,1.35361,-2.04171},
/*1879*/{0.191473,1.93424,-1.73132,0.295917,1.87418,-1.85516,0.030473,1.85099,-1.68315,-0.095506,1.779,-1.66488,0.040651,1.69096,-1.67936,0.109523,1.62959,-1.66616,0.275643,1.94906,-2.10072,0.312845,1.87633,-1.92807,0.128184,1.90904,-2.06234,0.194413,1.72895,-2.24302,0.251304,1.64154,-2.26864,0.371752,1.65877,-2.11222,0.430945,1.64738,-2.08486,0.204999,1.44545,-1.82344,0.020137,1.51909,-1.88614,0.025118,1.54189,-1.95139,0.030699,1.51591,-2.00144,0.210499,1.4274,-2.07551,0.302243,1.18446,-1.763,0.184859,1.11047,-1.77206,0.225871,1.04028,-1.79244,0.339947,0.971059,-1.78432,0.421191,0.801351,-1.77815,0.43879,0.728967,-1.78988,0.312879,0.770765,-1.78256,0.331527,0.701919,-1.78857,0.439519,0.489684,-1.80973,0.374272,0.389647,-1.88736,0.599762,0.517406,-1.84938,0.602297,0.450443,-1.78756,0.083768,1.12874,-2.11216,0.058531,1.04925,-2.09525,-0.050703,1.17103,-2.08159,-0.071305,1.09217,-2.06516,-0.07973,0.946002,-2.06277,-0.211052,0.800565,-2.0515,-0.269351,0.896615,-2.06815,-0.327957,0.860004,-2.06009,-0.507315,0.709551,-2.02151,-0.574651,0.790534,-1.9647,-0.553758,0.510814,-1.95057,-0.610416,0.544797,-2.01069,0.119415,1.36456,-1.82763,0.115681,1.35363,-2.04256},
/*1880*/{0.192902,1.93293,-1.73077,0.295666,1.87304,-1.85515,0.031748,1.84831,-1.68249,-0.094222,1.77564,-1.66498,0.042074,1.68747,-1.6781,0.111498,1.62627,-1.66516,0.274991,1.9476,-2.10049,0.312827,1.87529,-1.92797,0.127965,1.90891,-2.06178,0.191023,1.72787,-2.24239,0.247884,1.63944,-2.26795,0.37091,1.65542,-2.11263,0.430182,1.64252,-2.08683,0.205266,1.44488,-1.82332,0.019857,1.51731,-1.88648,0.025267,1.54067,-1.95026,0.029955,1.5146,-2.00141,0.210746,1.42753,-2.07531,0.299616,1.17683,-1.76236,0.181293,1.10985,-1.77055,0.219629,1.03489,-1.79326,0.333203,0.964454,-1.78512,0.419576,0.799636,-1.77898,0.437926,0.726549,-1.78946,0.309689,0.766707,-1.78439,0.330758,0.698289,-1.78958,0.442041,0.486438,-1.8101,0.378687,0.386096,-1.8873,0.602986,0.516522,-1.85102,0.607163,0.449534,-1.78964,0.090064,1.12608,-2.11119,0.066368,1.04556,-2.09369,-0.045807,1.16519,-2.08152,-0.065431,1.08623,-2.06509,-0.071877,0.940323,-2.06193,-0.208808,0.802542,-2.05073,-0.262743,0.900473,-2.0647,-0.323847,0.864456,-2.05888,-0.513431,0.727593,-2.02286,-0.573321,0.809269,-1.96573,-0.56381,0.528721,-1.95105,-0.617766,0.565583,-2.01218,0.120152,1.36342,-1.82775,0.116438,1.35306,-2.0427},
/*1881*/{0.193709,1.9314,-1.72935,0.294993,1.87195,-1.855,0.032104,1.84465,-1.68193,-0.091978,1.77121,-1.66542,0.044067,1.68467,-1.67841,0.114244,1.62281,-1.6635,0.274711,1.94593,-2.09997,0.313126,1.87413,-1.92802,0.126904,1.90786,-2.05987,0.18761,1.72722,-2.24094,0.244923,1.63827,-2.2674,0.370371,1.64935,-2.11335,0.429303,1.63594,-2.08701,0.207865,1.44446,-1.82328,0.019787,1.51401,-1.88547,0.024059,1.53888,-1.95063,0.029839,1.51278,-2.00074,0.210619,1.42741,-2.0753,0.296161,1.1714,-1.76166,0.175474,1.10234,-1.77088,0.213567,1.03101,-1.79475,0.326389,0.958676,-1.78582,0.414808,0.796512,-1.77954,0.435413,0.723716,-1.7897,0.306538,0.761857,-1.7861,0.328433,0.693205,-1.79046,0.443834,0.484661,-1.81079,0.380651,0.382355,-1.88688,0.602985,0.514442,-1.85345,0.609348,0.448486,-1.79171,0.095377,1.12284,-2.11032,0.074354,1.04079,-2.09174,-0.041824,1.15901,-2.08168,-0.059316,1.07989,-2.06477,-0.062867,0.935131,-2.06163,-0.207165,0.803782,-2.05048,-0.255531,0.905826,-2.06885,-0.317626,0.873068,-2.05883,-0.511792,0.74339,-2.02426,-0.57076,0.828833,-1.96655,-0.571382,0.547256,-1.95215,-0.623517,0.586225,-2.01347,0.122671,1.36216,-1.82768,0.117823,1.35185,-2.04261},
/*1882*/{0.194625,1.92948,-1.72935,0.296079,1.87114,-1.8548,0.03316,1.84149,-1.68137,-0.089281,1.76631,-1.66402,0.047097,1.6807,-1.67623,0.116371,1.61905,-1.6616,0.273862,1.94381,-2.09982,0.312807,1.8721,-1.92761,0.12625,1.90623,-2.059,0.18258,1.72572,-2.23997,0.241193,1.63646,-2.26677,0.367892,1.64381,-2.11424,0.427384,1.62938,-2.08843,0.204577,1.4419,-1.82324,0.019259,1.51185,-1.88547,0.023134,1.53622,-1.95056,0.029355,1.51048,-2.00056,0.210796,1.42613,-2.07473,0.29217,1.16489,-1.76081,0.172484,1.09851,-1.77162,0.209994,1.02706,-1.79563,0.320727,0.95339,-1.78662,0.410431,0.792539,-1.77977,0.431904,0.720728,-1.79028,0.302581,0.757347,-1.78843,0.32527,0.689437,-1.79329,0.444197,0.479926,-1.81086,0.380608,0.378424,-1.88694,0.602031,0.511612,-1.85516,0.609142,0.447029,-1.79248,0.100633,1.11929,-2.10899,0.081465,1.0377,-2.09063,-0.037018,1.15231,-2.08136,-0.053358,1.07277,-2.06394,-0.054211,0.929828,-2.06161,-0.20248,0.805865,-2.05028,-0.246994,0.908889,-2.06771,-0.310631,0.879534,-2.05691,-0.510524,0.760309,-2.0253,-0.565884,0.847549,-1.96733,-0.58028,0.566241,-1.95474,-0.629883,0.60895,-2.01608,0.120777,1.3593,-1.82803,0.117577,1.35021,-2.04305},
/*1883*/{0.194917,1.92703,-1.72861,0.29608,1.86725,-1.85475,0.035138,1.83696,-1.67988,-0.086128,1.76175,-1.66311,0.048866,1.67549,-1.67462,0.119163,1.61404,-1.65907,0.273679,1.94161,-2.0998,0.312622,1.87016,-1.92743,0.125787,1.90496,-2.05836,0.180777,1.72424,-2.23903,0.236708,1.63461,-2.26577,0.366086,1.63817,-2.11514,0.425708,1.62182,-2.08994,0.204679,1.43946,-1.82328,0.018147,1.50892,-1.88546,0.023889,1.53337,-1.94961,0.028578,1.50739,-2.00065,0.211024,1.42511,-2.07486,0.29172,1.16022,-1.75893,0.169708,1.09633,-1.77193,0.206579,1.02286,-1.79816,0.317835,0.950771,-1.78807,0.405168,0.788115,-1.77911,0.426893,0.716466,-1.79099,0.298886,0.752753,-1.78926,0.321276,0.684347,-1.79567,0.441433,0.476895,-1.81302,0.378301,0.373913,-1.88777,0.598771,0.508784,-1.85669,0.606799,0.443821,-1.7947,0.106834,1.11558,-2.10863,0.089443,1.03391,-2.08947,-0.031894,1.14588,-2.08112,-0.04673,1.0662,-2.06388,-0.045516,0.923549,-2.06063,-0.198385,0.80714,-2.05004,-0.238036,0.912682,-2.06722,-0.303106,0.883998,-2.05624,-0.508099,0.776017,-2.02623,-0.559397,0.865472,-1.96814,-0.587313,0.584987,-1.95728,-0.636348,0.630558,-2.0172,0.121334,1.35642,-1.82848,0.118262,1.34832,-2.04354},
/*1884*/{0.195971,1.92443,-1.72788,0.297072,1.86497,-1.85422,0.035959,1.83251,-1.67924,-0.084273,1.75558,-1.66111,0.051551,1.67074,-1.6726,0.122553,1.60996,-1.65768,0.27217,1.93917,-2.09899,0.311492,1.86799,-1.92756,0.124858,1.90266,-2.05641,0.176093,1.72276,-2.23783,0.232947,1.63231,-2.26519,0.364102,1.63158,-2.11688,0.423632,1.61397,-2.0916,0.205376,1.43831,-1.82339,0.018349,1.50601,-1.88457,0.022934,1.53024,-1.94968,0.028244,1.50474,-2.00032,0.211176,1.4232,-2.07501,0.288342,1.15565,-1.75775,0.167591,1.09336,-1.77306,0.203126,1.02006,-1.79872,0.316372,0.948669,-1.78768,0.401518,0.783625,-1.77963,0.423611,0.711479,-1.79155,0.294324,0.747695,-1.79122,0.317625,0.680151,-1.79599,0.437226,0.473757,-1.81501,0.374391,0.370699,-1.88997,0.596942,0.505562,-1.85898,0.603278,0.440906,-1.7964,0.112056,1.11202,-2.10792,0.096202,1.03015,-2.08901,-0.028202,1.13822,-2.08037,-0.040706,1.05827,-2.0622,-0.035678,0.917278,-2.06011,-0.193034,0.808582,-2.05003,-0.228134,0.915751,-2.06658,-0.293946,0.890903,-2.05738,-0.505709,0.791265,-2.02541,-0.550508,0.883499,-1.9671,-0.591434,0.603976,-1.96031,-0.638263,0.653114,-2.01978,0.122704,1.35455,-1.82809,0.118959,1.34591,-2.04311},
/*1885*/{0.196486,1.92089,-1.72734,0.296257,1.86387,-1.85454,0.037866,1.82752,-1.67661,-0.080493,1.74942,-1.65906,0.055539,1.66562,-1.67064,0.12628,1.60556,-1.65509,0.271977,1.93603,-2.09956,0.311737,1.8652,-1.92707,0.12373,1.90098,-2.05532,0.170927,1.72026,-2.23623,0.228109,1.62946,-2.26484,0.361158,1.62506,-2.11829,0.420761,1.60515,-2.09436,0.203874,1.43434,-1.82245,0.017714,1.50248,-1.88444,0.02216,1.52689,-1.94986,0.027638,1.50088,-1.99997,0.211571,1.42151,-2.07459,0.285758,1.15253,-1.75602,0.165141,1.09027,-1.77298,0.200975,1.01744,-1.80027,0.316686,0.948152,-1.78831,0.397433,0.778539,-1.78042,0.417985,0.707703,-1.79298,0.290369,0.743983,-1.79296,0.31264,0.675086,-1.79871,0.431765,0.468638,-1.81758,0.368642,0.366532,-1.89301,0.590795,0.499653,-1.8608,0.597213,0.434341,-1.79782,0.117407,1.10783,-2.10732,0.103321,1.02597,-2.08806,-0.022842,1.1313,-2.08039,-0.033971,1.05077,-2.06279,-0.026834,0.91076,-2.05933,-0.186809,0.809696,-2.04993,-0.218426,0.918364,-2.06689,-0.284466,0.895912,-2.05648,-0.498409,0.80649,-2.02766,-0.539755,0.899638,-1.9668,-0.594997,0.622432,-1.96369,-0.639244,0.673969,-2.02238,0.121789,1.35056,-1.82845,0.119397,1.34336,-2.04355},
/*1886*/{0.197651,1.91727,-1.72636,0.296258,1.85882,-1.85402,0.039207,1.8224,-1.6742,-0.077859,1.74315,-1.65653,0.057792,1.65984,-1.66741,0.129431,1.60029,-1.65289,0.27104,1.93292,-2.09942,0.311614,1.86207,-1.92665,0.123185,1.89786,-2.05472,0.166249,1.71747,-2.23452,0.223226,1.6264,-2.26428,0.357995,1.61735,-2.11919,0.417745,1.59674,-2.09635,0.206738,1.43121,-1.82138,0.017269,1.49882,-1.88455,0.022186,1.52255,-1.94963,0.026961,1.49729,-2.00009,0.211334,1.41898,-2.07395,0.282614,1.15023,-1.75601,0.162323,1.08817,-1.77563,0.199215,1.01458,-1.79974,0.31628,0.947232,-1.78849,0.392972,0.773458,-1.78129,0.414968,0.70103,-1.79376,0.285601,0.73986,-1.79336,0.307108,0.670856,-1.80096,0.427933,0.464747,-1.81967,0.360247,0.361868,-1.89628,0.583597,0.492793,-1.86257,0.589652,0.42669,-1.7996,0.122878,1.1037,-2.10664,0.110578,1.02115,-2.08707,-0.019194,1.12432,-2.08028,-0.027422,1.04349,-2.06235,-0.017317,0.904269,-2.05891,-0.180613,0.810988,-2.04999,-0.207477,0.920681,-2.0667,-0.27532,0.899219,-2.05601,-0.491118,0.820853,-2.02924,-0.528511,0.914863,-1.96654,-0.595855,0.640611,-1.9672,-0.635732,0.695014,-2.02516,0.123453,1.34746,-1.82803,0.120401,1.33996,-2.04311},
/*1887*/{0.19828,1.91349,-1.72586,0.296205,1.85584,-1.8542,0.040961,1.81666,-1.67252,-0.075786,1.73561,-1.65326,0.061289,1.65321,-1.66431,0.133448,1.59482,-1.6501,0.269597,1.9291,-2.09988,0.311303,1.85895,-1.92698,0.122182,1.89473,-2.05314,0.160194,1.71515,-2.23388,0.217769,1.62296,-2.26378,0.354048,1.60957,-2.12192,0.414786,1.58741,-2.09981,0.203249,1.42767,-1.82124,0.016646,1.49498,-1.88434,0.02093,1.51911,-1.94978,0.027143,1.49274,-2.00009,0.211176,1.41595,-2.07369,0.280251,1.14758,-1.75454,0.161455,1.08543,-1.77547,0.197643,1.01215,-1.80094,0.315819,0.944888,-1.78948,0.388719,0.767775,-1.78206,0.408832,0.695738,-1.79469,0.281039,0.735408,-1.79425,0.301415,0.668204,-1.80177,0.416544,0.456952,-1.8212,0.351127,0.357844,-1.90008,0.575326,0.484602,-1.86308,0.580273,0.41835,-1.80157,0.127646,1.09973,-2.10577,0.117967,1.01699,-2.0867,-0.013507,1.11645,-2.07961,-0.020808,1.03605,-2.06177,-0.008899,0.898251,-2.05829,-0.173976,0.811391,-2.04953,-0.195855,0.921493,-2.06535,-0.264741,0.904631,-2.05692,-0.483049,0.835169,-2.03041,-0.515776,0.929039,-1.96671,-0.5952,0.65827,-1.97029,-0.635944,0.715695,-2.02865,0.12166,1.34348,-1.82809,0.12013,1.33657,-2.04321},
/*1888*/{0.198201,1.90898,-1.72512,0.295203,1.85342,-1.85454,0.042449,1.81019,-1.67006,-0.072145,1.7282,-1.64933,0.064527,1.64707,-1.66059,0.137287,1.58942,-1.64769,0.268951,1.92522,-2.10054,0.311093,1.85545,-1.92722,0.120793,1.89081,-2.05151,0.154538,1.71214,-2.23209,0.212113,1.61962,-2.26313,0.351205,1.60275,-2.12312,0.411079,1.57754,-2.10228,0.202125,1.42418,-1.8209,0.015971,1.49113,-1.88491,0.021548,1.51552,-1.949,0.02567,1.48848,-2.00065,0.211196,1.41297,-2.07373,0.279617,1.14428,-1.75404,0.158945,1.08364,-1.77722,0.194466,1.00987,-1.80157,0.314586,0.94087,-1.78998,0.383982,0.761619,-1.78348,0.403146,0.689246,-1.79632,0.275419,0.730987,-1.79491,0.294966,0.661818,-1.80268,0.406019,0.451468,-1.82346,0.340342,0.35378,-1.90398,0.56655,0.476503,-1.8645,0.569693,0.409066,-1.80276,0.133424,1.09618,-2.10631,0.1263,1.01329,-2.08671,-0.007816,1.10962,-2.07911,-0.013359,1.02838,-2.06053,0.000309,0.892246,-2.05871,-0.166663,0.811639,-2.04948,-0.184647,0.922693,-2.06507,-0.253798,0.907396,-2.05675,-0.469529,0.843367,-2.02855,-0.503324,0.9417,-1.96688,-0.593095,0.674872,-1.97382,-0.631461,0.734376,-2.03142,0.121155,1.33972,-1.82825,0.120137,1.33314,-2.04338},
/*1889*/{0.198814,1.90418,-1.7245,0.295744,1.84961,-1.85516,0.044221,1.80265,-1.66768,-0.0698,1.72047,-1.6454,0.068503,1.64032,-1.65695,0.141539,1.58372,-1.64489,0.266924,1.92121,-2.10106,0.311322,1.85199,-1.92696,0.119999,1.88743,-2.05095,0.148273,1.70882,-2.23056,0.205469,1.61517,-2.2625,0.346903,1.59272,-2.12567,0.407088,1.56737,-2.10567,0.202868,1.42162,-1.81977,0.015447,1.48628,-1.8849,0.020444,1.51105,-1.94956,0.025295,1.48427,-2.00133,0.21069,1.40927,-2.07303,0.277203,1.14101,-1.75421,0.157771,1.08091,-1.77814,0.192704,1.00788,-1.80259,0.311778,0.935983,-1.78984,0.378804,0.756064,-1.78383,0.396337,0.683018,-1.79715,0.269412,0.726822,-1.79594,0.286971,0.658021,-1.80439,0.395061,0.445292,-1.82564,0.328306,0.349638,-1.90714,0.5561,0.467598,-1.86498,0.556639,0.399339,-1.80461,0.138577,1.0914,-2.10651,0.133216,1.00812,-2.08674,-0.00199,1.10252,-2.0787,-0.005545,1.02137,-2.06082,0.008841,0.88642,-2.05858,-0.158782,0.812225,-2.04966,-0.172822,0.923698,-2.06453,-0.242706,0.910367,-2.05643,-0.465096,0.857247,-2.03173,-0.490782,0.953902,-1.96774,-0.589911,0.688726,-1.9776,-0.624698,0.751096,-2.03473,0.121755,1.33658,-1.82747,0.120886,1.32889,-2.04257},
/*1890*/{0.199417,1.89913,-1.72403,0.29608,1.84558,-1.85564,0.04618,1.79596,-1.66554,-0.067706,1.71176,-1.64096,0.072192,1.63281,-1.65306,0.147011,1.5779,-1.64264,0.265965,1.91685,-2.10157,0.310363,1.84806,-1.92732,0.118866,1.88265,-2.0503,0.14355,1.70483,-2.22956,0.198981,1.61128,-2.2618,0.342619,1.58416,-2.12739,0.402428,1.55667,-2.1093,0.200405,1.41784,-1.81934,0.014732,1.48212,-1.88488,0.020072,1.50685,-1.94942,0.024419,1.47796,-2.00159,0.21075,1.40635,-2.07277,0.275559,1.13836,-1.75492,0.154529,1.07887,-1.78054,0.192288,1.00385,-1.80258,0.308414,0.930929,-1.78991,0.372054,0.749595,-1.78522,0.387532,0.676638,-1.79946,0.263318,0.72201,-1.79593,0.279844,0.653366,-1.80524,0.381988,0.438849,-1.82785,0.313506,0.345771,-1.90976,0.544247,0.458018,-1.86577,0.543827,0.389649,-1.80619,0.144856,1.08735,-2.10646,0.140335,1.00389,-2.08712,0.003591,1.0949,-2.07765,0.001367,1.01403,-2.05976,0.018363,0.881164,-2.05924,-0.15128,0.81187,-2.04981,-0.160777,0.924206,-2.06496,-0.230868,0.913618,-2.0573,-0.454145,0.86813,-2.03376,-0.477336,0.965438,-1.96758,-0.584099,0.702766,-1.98157,-0.615557,0.765004,-2.03933,0.121012,1.33237,-1.82731,0.121274,1.32484,-2.04242},
/*1891*/{0.20032,1.89368,-1.72322,0.296546,1.84062,-1.85549,0.048697,1.78832,-1.66204,-0.063672,1.7026,-1.63578,0.076814,1.62611,-1.64955,0.151506,1.57174,-1.64046,0.264122,1.91162,-2.10249,0.31079,1.84414,-1.92781,0.117375,1.87873,-2.04929,0.137082,1.70144,-2.22805,0.192807,1.60686,-2.26161,0.337337,1.5749,-2.13006,0.397092,1.5457,-2.11277,0.202284,1.41515,-1.81801,0.013739,1.47684,-1.88569,0.01937,1.50217,-1.94864,0.024121,1.47325,-2.00179,0.210064,1.40208,-2.07235,0.275208,1.13431,-1.75477,0.152324,1.07368,-1.78116,0.189054,0.99969,-1.80269,0.305002,0.92503,-1.79043,0.364495,0.742547,-1.78518,0.380777,0.668722,-1.79941,0.254846,0.717687,-1.79839,0.270962,0.64721,-1.80644,0.368546,0.43447,-1.82897,0.295912,0.351951,-1.91241,0.532513,0.447134,-1.86713,0.525324,0.377778,-1.80791,0.150592,1.08247,-2.10768,0.147931,0.999363,-2.08755,0.009313,1.08785,-2.0768,0.009193,1.00756,-2.05907,0.027136,0.875023,-2.06033,-0.142833,0.811343,-2.05095,-0.148582,0.924042,-2.06473,-0.219373,0.916424,-2.05806,-0.444504,0.877581,-2.03421,-0.463633,0.974156,-1.96915,-0.576329,0.714311,-1.98393,-0.608221,0.778212,-2.03924,0.122259,1.32904,-1.82628,0.122027,1.32015,-2.04133},
/*1892*/{0.20008,1.88802,-1.72249,0.295332,1.83655,-1.85535,0.050989,1.78033,-1.65889,-0.061344,1.69361,-1.63085,0.08097,1.61762,-1.64535,0.157182,1.566,-1.63846,0.262095,1.9066,-2.10385,0.310632,1.8392,-1.92819,0.116186,1.87405,-2.04807,0.132817,1.69599,-2.22732,0.185797,1.6023,-2.26096,0.332126,1.56468,-2.1325,0.391635,1.53414,-2.11699,0.200964,1.41163,-1.8174,0.012813,1.47154,-1.88665,0.019426,1.49753,-1.94896,0.023454,1.46757,-2.00147,0.209937,1.39863,-2.07298,0.273099,1.1294,-1.75454,0.15151,1.07134,-1.78066,0.186911,0.995896,-1.80306,0.300847,0.919639,-1.7902,0.356928,0.735424,-1.78674,0.371124,0.66194,-1.80025,0.247171,0.71301,-1.79933,0.262266,0.642609,-1.80719,0.35577,0.430925,-1.83045,0.277005,0.349562,-1.91417,0.517983,0.434275,-1.86934,0.507268,0.368423,-1.80654,0.155437,1.07944,-2.10821,0.154987,0.994922,-2.08844,0.013808,1.08111,-2.07487,0.016486,1.00011,-2.0582,0.037612,0.870153,-2.06047,-0.133651,0.811231,-2.05184,-0.135275,0.923572,-2.06556,-0.205681,0.91748,-2.05806,-0.432001,0.886201,-2.03487,-0.451112,0.983756,-1.97081,-0.567586,0.725788,-1.9859,-0.59858,0.789286,-2.04199,0.122241,1.32474,-1.82638,0.122665,1.31582,-2.04143},
/*1893*/{0.200731,1.88212,-1.72162,0.296835,1.83135,-1.85581,0.054293,1.77276,-1.65526,-0.056526,1.68467,-1.62568,0.086,1.61036,-1.64172,0.162181,1.55943,-1.63578,0.261825,1.90156,-2.10516,0.310473,1.83513,-1.92864,0.114842,1.86929,-2.0473,0.125918,1.69308,-2.22674,0.179354,1.5982,-2.26083,0.326329,1.55513,-2.1347,0.385468,1.52251,-2.12105,0.201684,1.40833,-1.81624,0.012281,1.46639,-1.88632,0.017875,1.49301,-1.94928,0.021893,1.46194,-2.00232,0.208964,1.3943,-2.0719,0.271481,1.12456,-1.75421,0.14975,1.06658,-1.78146,0.184092,0.991265,-1.80274,0.296428,0.913804,-1.79051,0.348768,0.728728,-1.78718,0.361269,0.654793,-1.80125,0.237924,0.707712,-1.80092,0.252283,0.637372,-1.8099,0.341199,0.424047,-1.83226,0.25848,0.354883,-1.91563,0.503994,0.419854,-1.86992,0.4889,0.35459,-1.80576,0.161201,1.07494,-2.10834,0.162041,0.991248,-2.08922,0.020403,1.07481,-2.07471,0.023094,0.993821,-2.05742,0.04819,0.864885,-2.06182,-0.124239,0.810904,-2.05318,-0.123408,0.924334,-2.06504,-0.19364,0.919592,-2.05854,-0.421819,0.893856,-2.03479,-0.439429,0.99206,-1.9724,-0.557023,0.735566,-1.98892,-0.585655,0.798984,-2.04617,0.122557,1.32118,-1.82531,0.12281,1.31083,-2.0403},
/*1894*/{0.20185,1.87656,-1.72024,0.296853,1.82436,-1.85565,0.057109,1.76348,-1.65256,-0.051494,1.67493,-1.61979,0.091126,1.6023,-1.63847,0.168327,1.55361,-1.63379,0.260051,1.89649,-2.10585,0.310462,1.83053,-1.92948,0.113984,1.86401,-2.04705,0.12111,1.68889,-2.22577,0.172407,1.59386,-2.26059,0.32043,1.54459,-2.13767,0.379074,1.51096,-2.12501,0.20047,1.40485,-1.81529,0.011356,1.4614,-1.88679,0.018095,1.48741,-1.948,0.021022,1.4561,-2.00255,0.208749,1.39066,-2.07189,0.268062,1.12017,-1.75443,0.14643,1.06186,-1.78121,0.182247,0.98691,-1.80268,0.290748,0.907457,-1.7899,0.339814,0.722041,-1.788,0.351581,0.647502,-1.80304,0.229083,0.703224,-1.80255,0.240847,0.632935,-1.81269,0.327043,0.419438,-1.83405,0.237217,0.353629,-1.91511,0.487199,0.405651,-1.87127,0.468898,0.342237,-1.80747,0.166335,1.07151,-2.10911,0.168262,0.987411,-2.09027,0.025501,1.06816,-2.07405,0.030672,0.987601,-2.057,0.058901,0.860098,-2.06397,-0.113123,0.810706,-2.05567,-0.10993,0.925046,-2.06746,-0.180759,0.921763,-2.0586,-0.407551,0.900779,-2.03711,-0.425404,0.99823,-1.97252,-0.546848,0.742617,-1.99164,-0.572417,0.80716,-2.04881,0.122729,1.31685,-1.82481,0.123491,1.30627,-2.03978},
/*1895*/{0.20218,1.87073,-1.71956,0.297727,1.81927,-1.85573,0.061092,1.75498,-1.64828,-0.047151,1.66514,-1.61364,0.09781,1.59501,-1.63419,0.17389,1.54727,-1.63218,0.258616,1.89123,-2.10705,0.310354,1.82551,-1.93015,0.112382,1.85909,-2.04636,0.116486,1.6833,-2.2248,0.165058,1.58899,-2.26028,0.314597,1.53571,-2.14064,0.372743,1.49963,-2.12899,0.201046,1.40165,-1.81367,0.009731,1.45652,-1.88746,0.016376,1.48155,-1.94794,0.020393,1.45073,-2.00299,0.208341,1.38618,-2.07099,0.266246,1.11304,-1.75268,0.143714,1.05781,-1.78031,0.178595,0.982315,-1.80223,0.28351,0.901354,-1.78988,0.331507,0.715834,-1.78886,0.340979,0.640647,-1.8043,0.220621,0.700401,-1.80336,0.231528,0.629617,-1.81359,0.310798,0.417854,-1.83776,0.21753,0.35645,-1.91458,0.472976,0.396104,-1.87571,0.451851,0.33818,-1.80986,0.17108,1.06736,-2.11045,0.175115,0.983933,-2.09154,0.031427,1.06173,-2.0733,0.038709,0.981027,-2.05706,0.069394,0.854836,-2.06508,-0.10261,0.80947,-2.05587,-0.095863,0.924836,-2.06692,-0.166463,0.922121,-2.05868,-0.390102,0.903052,-2.03552,-0.412503,1.00406,-1.97367,-0.534706,0.749798,-1.993,-0.559834,0.813821,-2.05157,0.122904,1.31316,-1.82366,0.124191,1.30122,-2.03856},
/*1896*/{0.20271,1.86511,-1.71884,0.297165,1.81339,-1.85632,0.064492,1.74612,-1.64432,-0.042248,1.65539,-1.60846,0.103352,1.58668,-1.63061,0.181753,1.54164,-1.62998,0.256961,1.88671,-2.10848,0.310594,1.81994,-1.93039,0.111049,1.85423,-2.04597,0.111284,1.67947,-2.22429,0.15713,1.5843,-2.26064,0.308563,1.52529,-2.14364,0.364145,1.4886,-2.13432,0.196658,1.39682,-1.81365,0.007418,1.45191,-1.88832,0.014148,1.47652,-1.94889,0.018152,1.44556,-2.00437,0.208236,1.3814,-2.07026,0.262774,1.10844,-1.75068,0.139287,1.05127,-1.77959,0.173867,0.978426,-1.80375,0.276532,0.894663,-1.7887,0.324786,0.71157,-1.79011,0.330879,0.636406,-1.80562,0.213153,0.699239,-1.80459,0.220993,0.627946,-1.81442,0.291704,0.415643,-1.8393,0.195063,0.356024,-1.91352,0.452249,0.391293,-1.88106,0.427289,0.338639,-1.80919,0.176874,1.06293,-2.11007,0.182377,0.980745,-2.09371,0.036628,1.05533,-2.07327,0.045364,0.974365,-2.05673,0.076453,0.850898,-2.069,-0.090983,0.810002,-2.0588,-0.08205,0.922853,-2.06758,-0.152533,0.923449,-2.06101,-0.383335,0.910914,-2.03734,-0.399797,1.00857,-1.97432,-0.520981,0.753532,-1.99593,-0.546317,0.818735,-2.05421,0.119434,1.30823,-1.82389,0.12305,1.29641,-2.03877},
/*1897*/{0.204088,1.85994,-1.71741,0.298589,1.80859,-1.85691,0.069147,1.73662,-1.64101,-0.035955,1.64568,-1.60222,0.109999,1.57978,-1.62695,0.189036,1.53553,-1.62735,0.255216,1.88194,-2.10924,0.310914,1.81477,-1.93212,0.109757,1.84957,-2.04518,0.105582,1.67494,-2.22393,0.15011,1.57986,-2.26065,0.301982,1.51559,-2.14721,0.356137,1.47695,-2.13863,0.195229,1.39353,-1.81305,0.0052,1.44752,-1.88895,0.012532,1.47056,-1.94981,0.015687,1.43987,-2.00462,0.207971,1.37695,-2.06968,0.255503,1.105,-1.7479,0.133496,1.05031,-1.78019,0.169204,0.976765,-1.80501,0.267886,0.886709,-1.78889,0.316675,0.709842,-1.7907,0.33934,0.639881,-1.80913,0.205763,0.701933,-1.80541,0.210978,0.631195,-1.8155,0.272273,0.419786,-1.84234,0.173549,0.357243,-1.91586,0.42958,0.391938,-1.88531,0.406073,0.339391,-1.81062,0.180819,1.06092,-2.11148,0.188769,0.977102,-2.09472,0.042435,1.04892,-2.07259,0.053071,0.968253,-2.05659,0.09113,0.845404,-2.06613,-0.0779,0.807628,-2.05986,-0.068102,0.921773,-2.06764,-0.137788,0.921993,-2.05974,-0.366683,0.913785,-2.03907,-0.386848,1.01223,-1.97554,-0.506971,0.756837,-1.99802,-0.53147,0.822161,-2.05718,0.118464,1.30453,-1.82313,0.122917,1.29136,-2.03791},
/*1898*/{0.204887,1.85508,-1.71622,0.297901,1.80435,-1.85762,0.074356,1.72719,-1.63685,-0.029709,1.63533,-1.59619,0.117142,1.57286,-1.62445,0.195826,1.53016,-1.62594,0.2537,1.87797,-2.11112,0.312002,1.81015,-1.93303,0.108856,1.84648,-2.04372,0.101002,1.67149,-2.22368,0.142001,1.57524,-2.26039,0.29397,1.50525,-2.1505,0.34851,1.46592,-2.14321,0.19259,1.39029,-1.8133,0.002092,1.44328,-1.88943,0.009365,1.46583,-1.95068,0.013424,1.43518,-2.00594,0.206362,1.37231,-2.06853,0.253214,1.10229,-1.74282,0.128718,1.05091,-1.78253,0.164205,0.976287,-1.80691,0.260772,0.882697,-1.78906,0.312473,0.710564,-1.79174,0.317642,0.635789,-1.80998,0.19906,0.707339,-1.80527,0.201728,0.636031,-1.8155,0.251759,0.422844,-1.84442,0.150789,0.357773,-1.91651,0.407064,0.390199,-1.88527,0.385535,0.339106,-1.81166,0.185371,1.0584,-2.11246,0.19613,0.975346,-2.09565,0.047799,1.04294,-2.0723,0.060514,0.962965,-2.05585,0.102468,0.840252,-2.06846,-0.064183,0.805249,-2.06083,-0.053559,0.920293,-2.06873,-0.122741,0.921883,-2.06028,-0.35446,0.917139,-2.03974,-0.373155,1.01427,-1.97596,-0.491953,0.758929,-2.00051,-0.51617,0.823266,-2.05934,0.11582,1.30102,-1.82266,0.121334,1.28668,-2.03735},
/*1899*/{0.206254,1.85098,-1.71518,0.298829,1.80045,-1.85838,0.079896,1.7186,-1.63369,-0.020441,1.62587,-1.59057,0.125642,1.56557,-1.62025,0.204095,1.52519,-1.62398,0.253085,1.87472,-2.11271,0.31204,1.80542,-1.9348,0.107812,1.84428,-2.04152,0.095492,1.66769,-2.22352,0.13433,1.57149,-2.25984,0.287462,1.4963,-2.15416,0.340026,1.45473,-2.14781,0.189959,1.38788,-1.8133,-0.001675,1.44164,-1.8917,0.006223,1.46148,-1.95221,0.011631,1.43063,-2.00695,0.205219,1.36832,-2.06705,0.250745,1.10088,-1.73859,0.128222,1.05195,-1.7834,0.162048,0.977271,-1.80596,0.259526,0.884899,-1.78795,0.305585,0.709845,-1.79193,0.303694,0.633998,-1.80818,0.193043,0.711925,-1.80411,0.192685,0.64065,-1.81566,0.231087,0.424459,-1.84531,0.129477,0.358846,-1.91837,0.386199,0.388632,-1.88413,0.363334,0.338823,-1.81191,0.190141,1.05687,-2.11326,0.203461,0.974041,-2.09699,0.05195,1.03614,-2.07175,0.068484,0.956498,-2.0562,0.114569,0.837424,-2.06926,-0.050369,0.802296,-2.0614,-0.038285,0.918132,-2.06796,-0.108494,0.920338,-2.06137,-0.338023,0.917968,-2.04235,-0.35962,1.01586,-1.9787,-0.477099,0.759102,-2.0027,-0.500112,0.82372,-2.06227,0.112672,1.29896,-1.82189,0.119978,1.28249,-2.03637},
/*1900*/{0.207448,1.84727,-1.71378,0.299039,1.7947,-1.85945,0.086168,1.71054,-1.63111,-0.011285,1.61708,-1.58471,0.134047,1.55985,-1.61856,0.213142,1.52112,-1.62232,0.252805,1.87176,-2.115,0.313248,1.80151,-1.93684,0.106496,1.843,-2.03977,0.09226,1.66454,-2.22281,0.127256,1.56776,-2.25813,0.27865,1.4865,-2.15795,0.331603,1.44484,-2.1526,0.187206,1.38625,-1.81142,-0.006537,1.43675,-1.89389,0.003704,1.45793,-1.95308,0.007014,1.42467,-2.00799,0.204411,1.36414,-2.06474,0.244663,1.1005,-1.73682,0.124917,1.05088,-1.78453,0.161817,0.976969,-1.80629,0.261163,0.890447,-1.7862,0.298129,0.708594,-1.79271,0.29296,0.635121,-1.80927,0.185052,0.714909,-1.80203,0.181803,0.644319,-1.81346,0.21292,0.425037,-1.84587,0.107107,0.359789,-1.91788,0.364404,0.38756,-1.88454,0.339896,0.338174,-1.81206,0.194886,1.05659,-2.11366,0.210948,0.974674,-2.09759,0.057433,1.03192,-2.07232,0.076715,0.953141,-2.05691,0.126953,0.835365,-2.06983,-0.035983,0.800192,-2.06221,-0.0237,0.91646,-2.06932,-0.093874,0.919317,-2.06264,-0.322386,0.918388,-2.04298,-0.345981,1.01618,-1.98116,-0.460105,0.757223,-2.00441,-0.484492,0.822433,-2.06409,0.109607,1.29673,-1.82016,0.119206,1.27781,-2.03435},
/*1901*/{0.20876,1.84351,-1.7137,0.300225,1.79339,-1.86195,0.093032,1.70372,-1.62913,-0.002056,1.60939,-1.57922,0.143774,1.55574,-1.61644,0.222391,1.51766,-1.6211,0.251291,1.86894,-2.11573,0.312563,1.79816,-1.93844,0.106305,1.84275,-2.03881,0.088231,1.66293,-2.22117,0.120295,1.56605,-2.25544,0.270369,1.47889,-2.16124,0.322109,1.43585,-2.1575,0.183473,1.38465,-1.80972,-0.008092,1.43572,-1.89684,0.002208,1.45698,-1.95381,0.005514,1.42045,-2.01041,0.203992,1.36097,-2.06384,0.239893,1.10036,-1.73602,0.106625,1.06237,-1.80851,0.162328,0.976862,-1.80601,0.264086,0.895675,-1.78525,0.288263,0.707329,-1.79296,0.282746,0.635065,-1.80945,0.176057,0.718178,-1.79884,0.16894,0.646787,-1.81172,0.192272,0.425278,-1.84621,0.086323,0.360556,-1.91877,0.344179,0.38679,-1.88359,0.31883,0.338021,-1.81183,0.199517,1.05762,-2.11404,0.21832,0.976054,-2.09837,0.062815,1.02833,-2.07374,0.085352,0.950284,-2.05721,0.14019,0.833506,-2.07021,-0.021653,0.798238,-2.06219,-0.007733,0.914285,-2.07065,-0.07822,0.916537,-2.06333,-0.307983,0.916643,-2.04476,-0.332985,1.01364,-1.98099,-0.443484,0.754208,-2.00663,-0.467704,0.818436,-2.06649,0.105923,1.2956,-1.81944,0.118174,1.27471,-2.03331},
/*1902*/{0.210033,1.84074,-1.71346,0.299505,1.78986,-1.86234,0.098967,1.69922,-1.62768,0.008385,1.60335,-1.57518,0.152898,1.55175,-1.61468,0.233083,1.51544,-1.61969,0.251495,1.86718,-2.11625,0.312727,1.79519,-1.94003,0.106229,1.84285,-2.03872,0.08343,1.66314,-2.2189,0.113266,1.56664,-2.25343,0.262559,1.47418,-2.16334,0.31247,1.42815,-2.1619,0.181327,1.38397,-1.80769,-0.009141,1.43559,-1.89656,0.000801,1.45646,-1.95489,0.00296,1.41806,-2.01157,0.201365,1.35837,-2.06332,0.239095,1.10117,-1.73624,0.119213,1.04983,-1.78348,0.15813,0.97465,-1.80497,0.269636,0.899231,-1.78573,0.276764,0.70573,-1.7919,0.267322,0.632187,-1.80789,0.165597,0.720085,-1.79864,0.158972,0.648712,-1.80935,0.172555,0.425744,-1.84571,0.065173,0.362158,-1.91789,0.322913,0.386556,-1.88475,0.297989,0.337658,-1.81129,0.205777,1.05954,-2.11389,0.226763,0.978073,-2.09841,0.070103,1.02516,-2.07364,0.093532,0.947455,-2.05819,0.154463,0.832901,-2.07059,-0.006566,0.797067,-2.06177,0.006347,0.912321,-2.07442,-0.062127,0.915578,-2.06452,-0.293232,0.914802,-2.04606,-0.321558,1.01175,-1.98319,-0.425076,0.749601,-2.00799,-0.450135,0.811744,-2.06737,0.10313,1.29549,-1.81809,0.115633,1.27236,-2.03171},
/*1903*/{0.211422,1.83864,-1.71429,0.299828,1.78784,-1.86347,0.104277,1.69615,-1.62665,0.019592,1.59924,-1.57153,0.162947,1.54899,-1.61332,0.24339,1.51391,-1.61903,0.251678,1.86556,-2.1161,0.312639,1.79379,-1.94044,0.106217,1.84287,-2.0387,0.079094,1.66396,-2.21635,0.105525,1.5683,-2.25163,0.252847,1.46966,-2.16495,0.302148,1.4213,-2.16654,0.178909,1.38373,-1.80573,-0.011599,1.43543,-1.89773,-0.00088,1.45672,-1.95507,0.00116,1.41764,-2.01294,0.200047,1.35605,-2.06268,0.234126,1.10162,-1.7364,0.114891,1.04885,-1.78213,0.151321,0.973246,-1.80447,0.269993,0.898446,-1.78631,0.26487,0.703973,-1.79033,0.254156,0.629967,-1.80585,0.154078,0.719798,-1.79704,0.143126,0.649621,-1.80837,0.151957,0.424644,-1.84381,0.044281,0.36227,-1.91732,0.303407,0.386361,-1.88367,0.276314,0.336869,-1.81084,0.212362,1.06125,-2.11413,0.235551,0.980791,-2.09816,0.07737,1.02291,-2.07594,0.103441,0.946402,-2.06019,0.170109,0.833753,-2.06998,0.008636,0.797136,-2.06172,0.022239,0.910511,-2.075,-0.048431,0.913825,-2.06557,-0.278663,0.911034,-2.04723,-0.309587,1.00804,-1.98567,-0.406347,0.743675,-2.00959,-0.434117,0.805639,-2.06979,0.099633,1.29558,-1.8172,0.113464,1.27101,-2.03058},
/*1904*/{0.212674,1.83721,-1.71505,0.298942,1.78794,-1.86436,0.10969,1.69359,-1.62585,0.027765,1.5956,-1.56744,0.173744,1.54798,-1.61288,0.254182,1.51414,-1.61843,0.251804,1.86418,-2.11621,0.311128,1.7916,-1.94133,0.106135,1.84289,-2.03886,0.072946,1.66667,-2.21297,0.098455,1.57101,-2.24921,0.24389,1.46709,-2.16643,0.291652,1.41678,-2.17085,0.176458,1.38362,-1.80449,-0.01243,1.43511,-1.89858,-0.001709,1.4566,-1.95516,0.000732,1.41819,-2.01286,0.197805,1.35508,-2.06259,0.230465,1.09902,-1.73595,0.107698,1.04788,-1.78218,0.145625,0.972008,-1.80304,0.265283,0.894144,-1.7863,0.252184,0.70129,-1.78814,0.239525,0.627734,-1.80471,0.141178,0.719977,-1.79643,0.129286,0.648808,-1.80853,0.13252,0.424399,-1.84357,0.023429,0.36232,-1.91725,0.281701,0.384927,-1.8812,0.25527,0.336309,-1.81009,0.219936,1.06394,-2.11376,0.24527,0.984609,-2.09799,0.085232,1.02195,-2.07737,0.11341,0.94518,-2.06144,0.186189,0.834648,-2.06967,0.02348,0.796402,-2.06093,0.036346,0.907448,-2.07496,-0.031975,0.911558,-2.06641,-0.264686,0.906348,-2.0485,-0.300412,1.00344,-1.98768,-0.38696,0.735079,-2.01027,-0.41428,0.795511,-2.06995,0.097217,1.29543,-1.81686,0.111651,1.27049,-2.03016},
/*1905*/{0.214901,1.83637,-1.7159,0.299169,1.786,-1.86524,0.115804,1.69227,-1.62478,0.038794,1.5937,-1.56406,0.183954,1.54807,-1.6123,0.265351,1.51582,-1.61841,0.251363,1.86318,-2.11625,0.310983,1.79118,-1.94151,0.106134,1.84302,-2.03902,0.068002,1.67072,-2.20948,0.089875,1.57399,-2.24773,0.235651,1.4657,-2.16941,0.281298,1.41404,-2.17522,0.173911,1.38359,-1.80325,-0.013127,1.43556,-1.89787,-0.00334,1.45705,-1.95528,-0.001395,1.41959,-2.01315,0.197326,1.35479,-2.06198,0.222781,1.09608,-1.73563,0.103857,1.04623,-1.78051,0.13785,0.970709,-1.80273,0.254319,0.889284,-1.78542,0.237949,0.696768,-1.78766,0.223549,0.62397,-1.80384,0.126961,0.718245,-1.79649,0.113169,0.648943,-1.80904,0.111123,0.425774,-1.84238,0.001571,0.362861,-1.91546,0.260133,0.385381,-1.88097,0.233235,0.335854,-1.80953,0.228399,1.06776,-2.11409,0.255905,0.988963,-2.0978,0.094762,1.02007,-2.0789,0.125507,0.944995,-2.06322,0.203343,0.837796,-2.06879,0.038626,0.797067,-2.06035,0.051186,0.906384,-2.07531,-0.0185,0.909685,-2.06726,-0.245962,0.899225,-2.04756,-0.290586,0.997413,-1.99132,-0.367768,0.726188,-2.01056,-0.395569,0.784053,-2.07111,0.094654,1.29557,-1.81645,0.10999,1.27083,-2.02971},
/*1906*/{0.215948,1.83597,-1.71665,0.297713,1.78553,-1.86613,0.120741,1.69137,-1.6241,0.047591,1.59149,-1.56136,0.193821,1.54874,-1.61199,0.276285,1.51794,-1.61884,0.250957,1.86302,-2.11653,0.310403,1.79061,-1.94223,0.105918,1.84347,-2.03954,0.062722,1.6751,-2.20582,0.081283,1.57754,-2.24626,0.226429,1.46559,-2.17243,0.270638,1.4125,-2.17851,0.172987,1.38383,-1.80236,-0.014206,1.43623,-1.89805,-0.005211,1.45702,-1.95504,-0.001662,1.41991,-2.01246,0.194756,1.35527,-2.06229,0.217142,1.09416,-1.73619,0.094817,1.04523,-1.78163,0.128287,0.969076,-1.80351,0.242722,0.885266,-1.78417,0.223052,0.693363,-1.78663,0.207596,0.621171,-1.80312,0.113485,0.718172,-1.79552,0.098505,0.648146,-1.80747,0.091756,0.426247,-1.84214,-0.019645,0.364837,-1.91567,0.239236,0.384746,-1.88067,0.214078,0.336035,-1.80707,0.236111,1.07181,-2.11407,0.267115,0.99433,-2.09754,0.10401,1.02017,-2.08052,0.136765,0.945771,-2.06402,0.219582,0.840948,-2.0685,0.055375,0.793957,-2.05839,0.065672,0.906339,-2.076,-0.00432,0.90786,-2.0688,-0.232718,0.893395,-2.04889,-0.283033,0.990371,-1.99418,-0.346024,0.715568,-2.01128,-0.378855,0.771334,-2.07352,0.093463,1.29592,-1.8162,0.108385,1.27111,-2.02947},
/*1907*/{0.217423,1.83686,-1.71757,0.298304,1.78387,-1.86607,0.126555,1.69147,-1.62275,0.05705,1.59079,-1.55827,0.204095,1.55086,-1.61105,0.287101,1.52144,-1.6198,0.250619,1.86333,-2.11721,0.310182,1.7904,-1.94265,0.105421,1.84431,-2.03966,0.056208,1.68106,-2.20213,0.072257,1.58228,-2.24558,0.218013,1.46686,-2.17502,0.259997,1.41298,-2.1823,0.170169,1.38467,-1.80002,-0.015731,1.4361,-1.89828,-0.006063,1.45821,-1.95468,-0.002777,1.42148,-2.01154,0.193341,1.35662,-2.0623,0.209734,1.09087,-1.73655,0.086552,1.04531,-1.78272,0.119958,0.968113,-1.80329,0.229766,0.881066,-1.78324,0.207879,0.689682,-1.78647,0.189473,0.617814,-1.80307,0.099053,0.716317,-1.79579,0.081904,0.646683,-1.80806,0.071774,0.427008,-1.84146,-0.039938,0.364806,-1.91498,0.218819,0.384704,-1.87948,0.192559,0.33556,-1.8071,0.244912,1.07631,-2.11325,0.27785,1.00139,-2.09704,0.113524,1.0237,-2.08337,0.149706,0.947537,-2.06603,0.235687,0.844888,-2.06715,0.07146,0.794149,-2.05797,0.079673,0.90646,-2.07623,0.008905,0.907223,-2.07026,-0.223514,0.888778,-2.0523,-0.274003,0.982706,-1.99714,-0.324058,0.704244,-2.01244,-0.358253,0.758413,-2.07423,0.091196,1.29633,-1.81588,0.107279,1.27243,-2.02918},
/*1908*/{0.21924,1.83821,-1.71759,0.298282,1.78456,-1.86785,0.131006,1.6928,-1.6213,0.066225,1.59013,-1.55516,0.213743,1.55312,-1.60972,0.29821,1.52608,-1.62111,0.248919,1.86391,-2.11755,0.308623,1.7914,-1.94342,0.105293,1.84611,-2.03971,0.050187,1.68745,-2.19918,0.063492,1.5881,-2.2449,0.209478,1.46944,-2.17855,0.250026,1.41445,-2.18493,0.168268,1.38511,-1.79983,-0.017284,1.43605,-1.8984,-0.006054,1.45841,-1.95446,-0.00436,1.4226,-2.01111,0.192138,1.35887,-2.06308,0.206072,1.08647,-1.73678,0.080007,1.04543,-1.78152,0.110004,0.968125,-1.80349,0.215583,0.876808,-1.78282,0.19226,0.686004,-1.78658,0.173218,0.61369,-1.80344,0.083989,0.714866,-1.79643,0.066497,0.646778,-1.80841,0.051556,0.426118,-1.83971,-0.059948,0.364522,-1.91476,0.19752,0.384056,-1.8786,0.17064,0.335851,-1.80738,0.252168,1.08451,-2.1146,0.288552,1.00836,-2.09663,0.123858,1.02526,-2.08455,0.160377,0.953333,-2.06918,0.251391,0.850651,-2.06683,0.087856,0.793723,-2.05702,0.0935,0.907338,-2.07706,0.02279,0.904934,-2.07182,-0.209584,0.879831,-2.053,-0.265107,0.972447,-1.99884,-0.30143,0.69234,-2.01194,-0.338003,0.743562,-2.07561,0.090247,1.29627,-1.81671,0.106657,1.27398,-2.03016},
/*1909*/{0.221188,1.84012,-1.71837,0.298435,1.78586,-1.86858,0.135175,1.69467,-1.62038,0.074656,1.5897,-1.55299,0.223071,1.55714,-1.60995,0.308806,1.53161,-1.62301,0.248436,1.86558,-2.11812,0.307412,1.79176,-1.94496,0.104718,1.84828,-2.03993,0.045082,1.69422,-2.19595,0.055073,1.59401,-2.24429,0.200089,1.47245,-2.18078,0.239524,1.41806,-2.1875,0.16741,1.3861,-1.79956,-0.016052,1.43929,-1.89807,-0.007552,1.45913,-1.95405,-0.005315,1.42377,-2.01042,0.191992,1.36124,-2.06307,0.198305,1.08524,-1.73667,0.072856,1.04871,-1.78197,0.10036,0.968079,-1.80423,0.201536,0.871902,-1.78322,0.17658,0.68261,-1.78664,0.156665,0.611248,-1.80315,0.068059,0.712917,-1.79673,0.049946,0.644066,-1.80848,0.031484,0.426444,-1.83955,-0.080528,0.365035,-1.91377,0.177707,0.383967,-1.87853,0.150261,0.335735,-1.80685,0.260093,1.09219,-2.11447,0.299349,1.01748,-2.09653,0.133553,1.02771,-2.08566,0.173096,0.957479,-2.06984,0.266242,0.856041,-2.06714,0.104162,0.794423,-2.05732,0.105673,0.908014,-2.07828,0.035577,0.904813,-2.07225,-0.195798,0.872202,-2.05491,-0.257786,0.961174,-2.0013,-0.276712,0.679094,-2.00999,-0.315956,0.7275,-2.07716,0.089968,1.29778,-1.81657,0.106167,1.27583,-2.03007},
/*1910*/{0.222989,1.84284,-1.71928,0.297559,1.78846,-1.86995,0.139537,1.69783,-1.61966,0.084826,1.59068,-1.55063,0.232408,1.56125,-1.60993,0.318301,1.53754,-1.62492,0.247036,1.86776,-2.11847,0.30747,1.79318,-1.94602,0.103314,1.8506,-2.0392,0.038976,1.70116,-2.19367,0.046354,1.60111,-2.24405,0.190635,1.47704,-2.18289,0.229854,1.42242,-2.18929,0.166978,1.38725,-1.79889,-0.01689,1.44063,-1.89845,-0.007716,1.4608,-1.95463,-0.006065,1.42881,-2.01046,0.190288,1.3635,-2.06373,0.191183,1.08375,-1.73695,0.065557,1.04928,-1.78138,0.088989,0.969751,-1.8044,0.186488,0.868053,-1.78341,0.161218,0.680651,-1.78679,0.138585,0.60994,-1.8045,0.052491,0.711965,-1.79702,0.034651,0.644697,-1.80864,0.010982,0.427104,-1.84033,-0.101341,0.365931,-1.91342,0.15682,0.38433,-1.87909,0.129004,0.334829,-1.80675,0.267735,1.10019,-2.11399,0.308454,1.02696,-2.09649,0.142842,1.0316,-2.08642,0.184043,0.962406,-2.07139,0.280989,0.862654,-2.06738,0.119891,0.795847,-2.05718,0.118917,0.908928,-2.07861,0.048677,0.903563,-2.07333,-0.1847,0.861988,-2.05394,-0.24957,0.948752,-2.00431,-0.252608,0.665884,-2.01029,-0.294189,0.712525,-2.07844,0.088558,1.29899,-1.81764,0.104769,1.27857,-2.03129},
/*1911*/{0.225365,1.84593,-1.71996,0.299613,1.79025,-1.87067,0.144083,1.70071,-1.61901,0.092767,1.59176,-1.54866,0.240753,1.56571,-1.61029,0.327691,1.54494,-1.62727,0.244435,1.86957,-2.11949,0.306682,1.7951,-1.94735,0.102427,1.85291,-2.03878,0.032216,1.70791,-2.19218,0.037812,1.60878,-2.24356,0.182564,1.48242,-2.1842,0.220353,1.42772,-2.19044,0.166035,1.38893,-1.79876,-0.018649,1.44164,-1.89916,-0.008184,1.46294,-1.95388,-0.006636,1.42894,-2.01026,0.189859,1.3663,-2.06483,0.182381,1.08292,-1.73894,0.056056,1.05114,-1.78286,0.078787,0.970153,-1.80318,0.1703,0.864909,-1.7837,0.144398,0.679636,-1.78773,0.12184,0.608408,-1.80451,0.03691,0.711967,-1.79724,0.016157,0.643838,-1.80913,-0.008862,0.427684,-1.83941,-0.122609,0.368015,-1.91399,0.136701,0.384088,-1.87849,0.109418,0.335882,-1.80607,0.273613,1.10862,-2.11439,0.317663,1.03694,-2.09629,0.151561,1.03595,-2.0875,0.195409,0.968408,-2.07142,0.296264,0.869053,-2.06797,0.136922,0.798709,-2.05764,0.131113,0.910243,-2.07936,0.061391,0.903079,-2.07489,-0.168072,0.853166,-2.05735,-0.240194,0.934533,-2.00605,-0.228164,0.652509,-2.01057,-0.270625,0.695705,-2.07924,0.088384,1.30029,-1.81814,0.104777,1.28063,-2.03185},
/*1912*/{0.228121,1.84986,-1.72074,0.298305,1.79252,-1.87286,0.148402,1.70389,-1.6186,0.100389,1.59363,-1.54822,0.249125,1.57198,-1.61153,0.335083,1.55276,-1.63031,0.242358,1.87294,-2.11982,0.306107,1.79773,-1.94875,0.100848,1.85676,-2.03692,0.02558,1.71492,-2.19101,0.029769,1.61633,-2.24278,0.173578,1.48893,-2.1848,0.210821,1.43424,-2.19145,0.165755,1.38969,-1.79843,-0.018821,1.44316,-1.89864,-0.008678,1.46587,-1.95383,-0.007364,1.43018,-2.00994,0.189324,1.36919,-2.06523,0.177841,1.0839,-1.73912,0.046126,1.05369,-1.78433,0.067124,0.971916,-1.80433,0.152529,0.863371,-1.7846,0.128468,0.679091,-1.78865,0.105204,0.607797,-1.80523,0.020308,0.712665,-1.7979,-0.000954,0.644919,-1.80977,-0.028056,0.428809,-1.83942,-0.142048,0.367949,-1.91361,0.116217,0.383646,-1.87875,0.089527,0.335869,-1.80516,0.279277,1.11822,-2.11429,0.32517,1.04785,-2.09656,0.159404,1.04146,-2.08811,0.205392,0.97503,-2.07218,0.309304,0.877402,-2.06789,0.15318,0.800154,-2.05668,0.142483,0.912938,-2.07955,0.073029,0.902107,-2.07614,-0.153758,0.842282,-2.05747,-0.234044,0.920052,-2.00735,-0.202501,0.639077,-2.01148,-0.247017,0.67951,-2.08012,0.08806,1.3014,-1.8187,0.104313,1.28303,-2.03253},
/*1913*/{0.230724,1.85373,-1.72138,0.300076,1.79593,-1.87331,0.153511,1.70722,-1.61891,0.109208,1.59678,-1.54617,0.256486,1.57798,-1.61345,0.343015,1.561,-1.6331,0.239479,1.87642,-2.12074,0.305305,1.80032,-1.95019,0.098788,1.8593,-2.03614,0.019508,1.72237,-2.19019,0.021939,1.62404,-2.24226,0.165633,1.49623,-2.18506,0.202382,1.44177,-2.19214,0.165309,1.39158,-1.79918,-0.018194,1.44638,-1.89884,-0.008481,1.46731,-1.95303,-0.007808,1.43234,-2.00977,0.188448,1.37259,-2.06555,0.172434,1.08384,-1.73881,0.038908,1.05522,-1.7825,0.055866,0.974234,-1.80533,0.134252,0.86228,-1.78539,0.111409,0.67902,-1.78996,0.088086,0.60839,-1.80665,0.004307,0.713678,-1.79828,-0.017006,0.646464,-1.81072,-0.04994,0.43043,-1.83953,-0.16239,0.368774,-1.91374,0.096353,0.383285,-1.87804,0.069011,0.33534,-1.8049,0.284482,1.12829,-2.11416,0.332534,1.05858,-2.0964,0.167594,1.04728,-2.08833,0.2154,0.982716,-2.07237,0.322043,0.886995,-2.06806,0.169095,0.802864,-2.05766,0.153944,0.914059,-2.08152,0.08553,0.899626,-2.07783,-0.137719,0.830094,-2.05778,-0.225061,0.90327,-2.00882,-0.176461,0.625377,-2.01187,-0.223262,0.663151,-2.08121,0.088276,1.30343,-1.81921,0.10398,1.28576,-2.03314},
/*1914*/{0.233114,1.858,-1.72232,0.299233,1.79879,-1.87508,0.157964,1.71089,-1.61906,0.117003,1.59965,-1.54521,0.263728,1.58555,-1.61488,0.349483,1.57006,-1.63631,0.236319,1.88039,-2.12071,0.304136,1.80377,-1.95183,0.097162,1.86206,-2.03359,0.012812,1.72946,-2.18944,0.015329,1.63143,-2.24278,0.15726,1.50464,-2.18457,0.194152,1.44981,-2.19182,0.166163,1.39257,-1.79854,-0.017501,1.44892,-1.89822,-0.008287,1.47041,-1.95241,-0.007175,1.43502,-2.01001,0.188298,1.37655,-2.06557,0.158457,1.07983,-1.74228,0.030107,1.05925,-1.78235,0.043628,0.976842,-1.80711,0.117037,0.862948,-1.78758,0.095011,0.679122,-1.79182,0.069384,0.609118,-1.80891,-0.011531,0.715891,-1.79906,-0.034571,0.648615,-1.81063,-0.066955,0.429464,-1.83863,-0.182341,0.370413,-1.91301,0.076126,0.383218,-1.87802,0.049483,0.335722,-1.80415,0.289736,1.13673,-2.11322,0.33935,1.06938,-2.09626,0.174193,1.05358,-2.08833,0.224233,0.98949,-2.072,0.334968,0.898186,-2.06809,0.184748,0.805336,-2.05792,0.164677,0.916414,-2.08226,0.095617,0.899835,-2.07902,-0.126815,0.817853,-2.05913,-0.216737,0.886658,-2.00877,-0.150128,0.611809,-2.01366,-0.198407,0.646284,-2.08238,0.088649,1.30496,-1.81993,0.10431,1.28916,-2.03402},
/*1915*/{0.23612,1.86234,-1.7233,0.299794,1.8032,-1.87686,0.163153,1.71443,-1.61935,0.124074,1.60288,-1.54475,0.269212,1.59206,-1.61722,0.356137,1.57911,-1.64044,0.232047,1.88494,-2.12142,0.303908,1.80762,-1.95401,0.095688,1.86525,-2.03248,0.007591,1.7375,-2.18845,0.007491,1.6389,-2.2418,0.150324,1.51305,-2.18467,0.187381,1.45815,-2.19225,0.167995,1.39473,-1.79911,-0.01698,1.45143,-1.89749,-0.007925,1.47371,-1.95161,-0.007269,1.43906,-2.00975,0.188644,1.38101,-2.06596,0.149849,1.08083,-1.74537,0.021644,1.06288,-1.7833,0.031784,0.980623,-1.80632,0.100095,0.86377,-1.7897,0.077971,0.679903,-1.7933,0.052503,0.610321,-1.80899,-0.02859,0.717383,-1.80035,-0.051506,0.650362,-1.81063,-0.087391,0.431693,-1.83924,-0.202042,0.372223,-1.91238,0.055665,0.382922,-1.87834,0.028963,0.335905,-1.80557,0.294356,1.14569,-2.11378,0.345509,1.08006,-2.09656,0.180693,1.05936,-2.08782,0.232994,0.997738,-2.07197,0.345852,0.909652,-2.06827,0.200517,0.808743,-2.05824,0.1746,0.918014,-2.0841,0.106282,0.898214,-2.07956,-0.111232,0.806374,-2.06246,-0.206732,0.868018,-2.0094,-0.122996,0.598548,-2.01532,-0.173131,0.630582,-2.08401,0.090023,1.30723,-1.82092,0.104804,1.29332,-2.03519},
/*1916*/{0.238834,1.86707,-1.7247,0.300254,1.80718,-1.87916,0.171372,1.71859,-1.61853,0.130929,1.60714,-1.5447,0.275795,1.59953,-1.62008,0.362341,1.58873,-1.64424,0.228107,1.88996,-2.12177,0.303474,1.81134,-1.95569,0.093749,1.86896,-2.03021,0.001724,1.74499,-2.18749,0.001346,1.64691,-2.24137,0.142922,1.52192,-2.1835,0.179443,1.46712,-2.19207,0.167973,1.39613,-1.79866,-0.015722,1.45499,-1.89633,-0.007026,1.47694,-1.95061,-0.006312,1.44264,-2.00915,0.189275,1.38538,-2.06541,0.142881,1.08084,-1.74704,0.012898,1.06671,-1.78427,0.022723,0.98405,-1.80684,0.08524,0.866306,-1.7914,0.06058,0.681841,-1.79469,0.035286,0.613277,-1.81025,-0.045413,0.720435,-1.80116,-0.070105,0.653456,-1.81233,-0.106455,0.433887,-1.83912,-0.221626,0.375292,-1.91192,0.035839,0.383272,-1.87849,0.009476,0.336538,-1.80583,0.298043,1.15458,-2.11405,0.351606,1.09087,-2.09636,0.187696,1.0651,-2.08693,0.240663,1.00539,-2.07105,0.356824,0.922018,-2.06813,0.21504,0.812173,-2.05894,0.183055,0.91982,-2.0846,0.115881,0.897935,-2.08103,-0.093296,0.791476,-2.0597,-0.195906,0.84946,-2.01146,-0.093523,0.586323,-2.01753,-0.147346,0.613925,-2.0853,0.090219,1.30919,-1.82131,0.105316,1.29732,-2.03569},
/*1917*/{0.241162,1.87173,-1.72562,0.30046,1.81232,-1.88105,0.177504,1.72258,-1.61885,0.139194,1.61156,-1.54407,0.280832,1.60719,-1.62204,0.366384,1.59795,-1.64797,0.224621,1.89505,-2.1219,0.303121,1.81637,-1.95755,0.091791,1.8723,-2.02834,-0.004061,1.75277,-2.18655,-0.006186,1.6547,-2.24028,0.136402,1.53071,-2.18285,0.173013,1.47622,-2.1922,0.168943,1.39744,-1.7979,-0.015267,1.45825,-1.89576,-0.006254,1.48012,-1.94925,-0.005297,1.44604,-2.00892,0.189901,1.39011,-2.06495,0.136247,1.08097,-1.74898,0.003843,1.06908,-1.78406,0.01022,0.988329,-1.8074,0.071823,0.869628,-1.79456,0.042647,0.683436,-1.79554,0.016204,0.613841,-1.81264,-0.062751,0.722793,-1.80238,-0.086633,0.656106,-1.81259,-0.125569,0.435331,-1.83856,-0.240758,0.379194,-1.91152,0.015787,0.382525,-1.87856,-0.011292,0.336038,-1.80628,0.302001,1.16377,-2.11432,0.356588,1.09949,-2.09662,0.193412,1.07169,-2.08643,0.247699,1.01299,-2.07032,0.36656,0.93423,-2.06846,0.229845,0.816185,-2.05993,0.192006,0.92198,-2.08506,0.127062,0.894057,-2.08175,-0.081589,0.781381,-2.06161,-0.186041,0.82913,-2.01033,-0.064759,0.573835,-2.01967,-0.12079,0.597886,-2.08745,0.090801,1.31106,-1.8219,0.106199,1.30147,-2.03637},
/*1918*/{0.24353,1.87758,-1.72743,0.300528,1.81726,-1.88316,0.184397,1.7266,-1.61955,0.146317,1.61613,-1.54439,0.285979,1.61519,-1.62433,0.37136,1.60751,-1.65208,0.220196,1.90071,-2.12252,0.302577,1.82074,-1.96013,0.089734,1.8759,-2.02617,-0.008281,1.76101,-2.18605,-0.011582,1.66202,-2.23934,0.129705,1.54021,-2.18206,0.166847,1.48535,-2.19202,0.169828,1.39861,-1.79727,-0.013741,1.46148,-1.89544,-0.004726,1.48381,-1.94729,-0.005075,1.45113,-2.00829,0.190393,1.39541,-2.06478,0.130278,1.08384,-1.75246,-0.005346,1.07412,-1.78513,6.6e-005,0.993345,-1.80908,0.058965,0.873144,-1.79572,0.026806,0.687098,-1.79781,-0.000674,0.617834,-1.81262,-0.079457,0.726306,-1.8038,-0.104771,0.659143,-1.81411,-0.145375,0.437508,-1.8377,-0.260031,0.384438,-1.91105,-0.002285,0.382919,-1.87899,-0.031618,0.33588,-1.80712,0.305219,1.17241,-2.11388,0.36118,1.11052,-2.09628,0.198496,1.07824,-2.08615,0.254167,1.02041,-2.06942,0.375879,0.946713,-2.06802,0.243807,0.819846,-2.0613,0.198937,0.922305,-2.08595,0.13642,0.891428,-2.08158,-0.066092,0.766593,-2.06088,-0.173384,0.808904,-2.01011,-0.036638,0.561895,-2.02243,-0.092524,0.582887,-2.08841,0.091364,1.31285,-1.82305,0.106694,1.30647,-2.03764},
/*1919*/{0.246136,1.88396,-1.72891,0.301365,1.82178,-1.8851,0.189435,1.73162,-1.61992,0.151572,1.62053,-1.5442,0.290727,1.62288,-1.62652,0.375538,1.61733,-1.65644,0.215803,1.90633,-2.12248,0.302684,1.82625,-1.96189,0.087928,1.87943,-2.02362,-0.013524,1.76818,-2.18486,-0.018238,1.66978,-2.2384,0.123438,1.54949,-2.18105,0.160854,1.49465,-2.19134,0.171016,1.40043,-1.79671,-0.011572,1.46445,-1.89385,-0.00447,1.48765,-1.94621,-0.003515,1.45561,-2.00801,0.190768,1.40025,-2.06393,0.122317,1.08435,-1.75442,-0.010988,1.07986,-1.78732,-0.010698,0.999087,-1.8111,0.045499,0.876858,-1.79779,0.009094,0.691081,-1.79854,-0.01865,0.620881,-1.81418,-0.096262,0.730554,-1.80429,-0.122543,0.662586,-1.81524,-0.163594,0.441211,-1.83778,-0.27859,0.390364,-1.91079,-0.021723,0.382223,-1.87949,-0.050865,0.336765,-1.80662,0.307966,1.1807,-2.11448,0.364847,1.1208,-2.09622,0.203146,1.0855,-2.08547,0.259934,1.02827,-2.06923,0.384025,0.958258,-2.0679,0.255986,0.82458,-2.0633,0.207323,0.923888,-2.08645,0.145905,0.889133,-2.08214,-0.049741,0.752681,-2.05728,-0.159618,0.786789,-2.00951,-0.00731,0.550563,-2.02495,-0.066523,0.567804,-2.091,0.092321,1.31513,-1.82353,0.107571,1.31102,-2.03818},
/*1920*/{0.2468,1.88868,-1.73072,0.302162,1.82734,-1.88702,0.196046,1.73642,-1.62101,0.157255,1.62556,-1.54434,0.294358,1.63014,-1.62819,0.378876,1.62688,-1.66018,0.212829,1.91194,-2.1225,0.301886,1.83078,-1.96398,0.086352,1.88331,-2.02208,-0.017189,1.7754,-2.18417,-0.023698,1.67762,-2.23748,0.117907,1.55866,-2.17998,0.155323,1.50408,-2.19152,0.173313,1.40199,-1.79671,-0.010981,1.46866,-1.8925,-0.00318,1.49145,-1.94446,-0.00255,1.46059,-2.00768,0.192267,1.40587,-2.0637,0.116125,1.08563,-1.75796,-0.018166,1.08839,-1.78827,-0.020749,1.00512,-1.81069,0.032697,0.880258,-1.79949,-0.007359,0.69571,-1.79964,-0.03589,0.625921,-1.81449,-0.112923,0.735854,-1.80468,-0.138838,0.669341,-1.81512,-0.180502,0.446399,-1.83674,-0.297026,0.398113,-1.91025,-0.04118,0.380593,-1.87966,-0.072254,0.337412,-1.80794,0.311206,1.18906,-2.11376,0.369345,1.13065,-2.09567,0.207895,1.09202,-2.08565,0.265359,1.0367,-2.06878,0.390623,0.96959,-2.06748,0.269251,0.828228,-2.06304,0.21362,0.924267,-2.08679,0.154667,0.886234,-2.08209,-0.030567,0.739517,-2.05985,-0.145587,0.764926,-2.00779,0.02378,0.539781,-2.02783,-0.038058,0.554198,-2.09356,0.09372,1.31753,-1.8246,0.108666,1.31638,-2.03931},
/*1921*/{0.249309,1.89405,-1.73226,0.303336,1.83266,-1.88919,0.200808,1.74191,-1.62209,0.163445,1.63008,-1.54372,0.297555,1.63806,-1.63093,0.381377,1.63623,-1.66387,0.209075,1.9173,-2.12266,0.301151,1.83655,-1.9656,0.084638,1.88699,-2.0204,-0.022642,1.78301,-2.18383,-0.029171,1.68517,-2.23605,0.111839,1.56797,-2.17853,0.150098,1.51323,-2.19116,0.173911,1.40308,-1.79666,-0.009019,1.47263,-1.89247,-0.001596,1.49584,-1.94249,-0.000457,1.46624,-2.0068,0.192906,1.41109,-2.06288,0.109331,1.08632,-1.76043,-0.026156,1.09219,-1.78704,-0.030561,1.01156,-1.81247,0.018287,0.885367,-1.80062,-0.024112,0.700794,-1.79928,-0.052202,0.632758,-1.81378,-0.129516,0.741702,-1.80593,-0.154654,0.676136,-1.81571,-0.197183,0.44992,-1.83562,-0.314621,0.406468,-1.9106,-0.059404,0.379217,-1.88028,-0.092484,0.337657,-1.80826,0.314635,1.19762,-2.11328,0.372524,1.13881,-2.09449,0.211423,1.09924,-2.0854,0.268481,1.04114,-2.06906,0.396339,0.980648,-2.06769,0.280477,0.83202,-2.06445,0.21938,0.925187,-2.08697,0.162537,0.882779,-2.08238,-0.013025,0.726045,-2.06009,-0.129149,0.743829,-2.00664,0.054528,0.530181,-2.03079,-0.009278,0.541531,-2.09558,0.093871,1.31959,-1.82584,0.109242,1.32171,-2.04051},
/*1922*/{0.250926,1.9002,-1.73389,0.303682,1.83805,-1.89129,0.204748,1.74703,-1.62266,0.169606,1.63564,-1.54366,0.300378,1.64621,-1.63381,0.384004,1.64568,-1.66811,0.206053,1.92265,-2.12224,0.300625,1.84225,-1.96748,0.083388,1.89137,-2.01839,-0.026895,1.78946,-2.18183,-0.034048,1.69306,-2.23526,0.10663,1.57668,-2.17723,0.145307,1.52221,-2.19072,0.175625,1.40515,-1.797,-0.006805,1.47613,-1.89197,0.000151,1.50038,-1.94085,0.001039,1.47206,-2.00652,0.193588,1.41696,-2.06263,0.104263,1.09093,-1.76136,-0.030085,1.10179,-1.78746,-0.038187,1.01839,-1.80952,0.003856,0.891824,-1.79986,-0.040032,0.707541,-1.79994,-0.06783,0.638815,-1.81291,-0.144817,0.749169,-1.80688,-0.17163,0.683836,-1.81638,-0.215474,0.456175,-1.83653,-0.330808,0.415106,-1.91169,-0.077906,0.378715,-1.88066,-0.113031,0.338359,-1.80874,0.31747,1.20605,-2.11307,0.376693,1.14822,-2.09255,0.215083,1.10656,-2.08553,0.272644,1.05009,-2.06889,0.398894,0.991014,-2.06698,0.291891,0.8359,-2.06554,0.224918,0.925427,-2.08676,0.170731,0.87944,-2.0816,0.003398,0.711983,-2.06007,-0.113937,0.721838,-2.00568,0.085228,0.521481,-2.03482,0.02005,0.529992,-2.09858,0.095231,1.32221,-1.82733,0.110298,1.32745,-2.04198},
/*1923*/{0.252727,1.90624,-1.73515,0.304387,1.84356,-1.89315,0.209709,1.75269,-1.62408,0.173753,1.64175,-1.54433,0.302956,1.65392,-1.63627,0.385898,1.65425,-1.67233,0.203373,1.92808,-2.12219,0.300024,1.84759,-1.96942,0.081972,1.89581,-2.01614,-0.031443,1.79676,-2.18142,-0.039234,1.70078,-2.23363,0.101984,1.58553,-2.17637,0.140518,1.53081,-2.19065,0.177545,1.40665,-1.79808,-0.004715,1.48002,-1.89061,0.001931,1.50464,-1.93848,0.001495,1.4774,-2.00622,0.194578,1.4226,-2.0618,0.097663,1.09356,-1.76432,-0.034346,1.10914,-1.78702,-0.047676,1.02656,-1.8117,-0.011245,0.898118,-1.79918,-0.05611,0.713833,-1.79796,-0.084049,0.646275,-1.8119,-0.160526,0.758234,-1.80778,-0.186479,0.691705,-1.81601,-0.232174,0.461773,-1.83569,-0.347656,0.424994,-1.91163,-0.095859,0.378317,-1.88081,-0.133031,0.339007,-1.80948,0.319639,1.2134,-2.1128,0.379122,1.15654,-2.09178,0.218496,1.11353,-2.08631,0.276226,1.05752,-2.06829,0.400328,1.00086,-2.06635,0.302299,0.839311,-2.06668,0.229723,0.924703,-2.08688,0.178288,0.876258,-2.08141,0.021445,0.69909,-2.05998,-0.095961,0.696523,-2.00317,0.116004,0.513788,-2.03901,0.050389,0.517541,-2.10132,0.096619,1.32455,-1.8287,0.110962,1.33304,-2.04329},
/*1924*/{0.254428,1.91149,-1.73682,0.304315,1.8482,-1.89504,0.213096,1.75835,-1.62468,0.177831,1.64667,-1.54431,0.305256,1.66185,-1.6383,0.387548,1.66327,-1.67625,0.200717,1.9329,-2.1217,0.299633,1.85292,-1.97126,0.081393,1.89958,-2.015,-0.034462,1.8036,-2.18055,-0.044232,1.70788,-2.23196,0.097016,1.59352,-2.17494,0.136253,1.53914,-2.19021,0.179932,1.40786,-1.799,-0.002571,1.48424,-1.89,0.003327,1.509,-1.93722,0.003362,1.48376,-2.00622,0.195337,1.42834,-2.06198,0.093229,1.09629,-1.76628,-0.041829,1.1162,-1.78792,-0.054923,1.03482,-1.81055,-0.024673,0.905748,-1.79856,-0.071539,0.721517,-1.79641,-0.099664,0.652966,-1.80992,-0.174737,0.765668,-1.80873,-0.201931,0.699599,-1.81695,-0.247531,0.468874,-1.83536,-0.363217,0.435213,-1.91226,-0.114787,0.377143,-1.88065,-0.153837,0.339549,-1.80974,0.321857,1.22164,-2.11238,0.382287,1.16459,-2.09111,0.221209,1.12071,-2.08664,0.280128,1.06633,-2.06746,0.401101,1.0094,-2.06613,0.311606,0.841907,-2.0681,0.234366,0.923686,-2.08614,0.186199,0.872058,-2.08022,0.040535,0.685391,-2.05975,-0.077305,0.67724,-2.0014,0.146554,0.507496,-2.04349,0.080496,0.508228,-2.10477,0.09784,1.32696,-1.83088,0.111659,1.33898,-2.04533},
/*1925*/{0.254806,1.9174,-1.7385,0.305631,1.85381,-1.8969,0.216497,1.76419,-1.62545,0.182495,1.65186,-1.54415,0.307294,1.6694,-1.64139,0.388484,1.6712,-1.67906,0.198382,1.93796,-2.12121,0.298455,1.85852,-1.97287,0.08012,1.90405,-2.01404,-0.037124,1.80959,-2.17939,-0.048373,1.71567,-2.22994,0.09279,1.60023,-2.17378,0.132379,1.54638,-2.18973,0.181642,1.4097,-1.80071,-0.00031,1.48891,-1.88861,0.004904,1.51394,-1.93695,0.005366,1.49006,-2.00614,0.19618,1.43377,-2.06195,0.089059,1.10108,-1.76798,-0.045184,1.12483,-1.78743,-0.06187,1.043,-1.80904,-0.038233,0.913407,-1.79801,-0.085932,0.729718,-1.79486,-0.115143,0.661173,-1.80726,-0.188859,0.773314,-1.80964,-0.216152,0.707655,-1.81746,-0.264739,0.474635,-1.83494,-0.377789,0.446451,-1.91303,-0.134197,0.376611,-1.88127,-0.174358,0.339949,-1.81076,0.324065,1.22867,-2.1121,0.38363,1.17183,-2.08985,0.223521,1.12766,-2.08781,0.282231,1.07261,-2.06768,0.400958,1.01719,-2.06593,0.320749,0.844478,-2.06853,0.238487,0.921521,-2.0853,0.193099,0.866492,-2.079,0.055867,0.671304,-2.05942,-0.056122,0.656462,-2.00078,0.177153,0.502082,-2.04708,0.110496,0.499281,-2.10726,0.098735,1.32994,-1.83282,0.112082,1.34483,-2.04712},
/*1926*/{0.256038,1.92258,-1.73966,0.304823,1.85877,-1.89876,0.219834,1.76933,-1.6265,0.184656,1.65769,-1.5447,0.308338,1.67577,-1.6426,0.389429,1.67965,-1.68314,0.196273,1.94271,-2.12117,0.297715,1.86315,-1.9745,0.078852,1.90757,-2.01314,-0.04033,1.81608,-2.17829,-0.052802,1.72247,-2.2287,0.089113,1.60724,-2.17278,0.128616,1.55397,-2.1898,0.183719,1.4115,-1.80264,0.001452,1.49345,-1.88793,0.006472,1.51809,-1.93542,0.007255,1.49494,-2.00516,0.197024,1.43933,-2.06259,0.084293,1.10439,-1.769,-0.05065,1.13095,-1.78703,-0.068086,1.0511,-1.80891,-0.0508,0.921497,-1.79721,-0.099675,0.737382,-1.79343,-0.128966,0.66898,-1.80572,-0.201732,0.782072,-1.80999,-0.229495,0.716575,-1.81874,-0.277427,0.481008,-1.8322,-0.392085,0.45885,-1.91317,-0.152421,0.376608,-1.88145,-0.194771,0.340649,-1.81127,0.325598,1.23558,-2.11142,0.385634,1.17926,-2.08857,0.226487,1.13295,-2.08916,0.282942,1.07863,-2.0678,0.400194,1.02345,-2.06646,0.330426,0.846867,-2.06999,0.242557,0.917529,-2.08388,0.20169,0.861812,-2.07863,0.077612,0.658706,-2.05844,-0.034276,0.633431,-1.99784,0.208285,0.497159,-2.05027,0.140896,0.49112,-2.11013,0.100397,1.33259,-1.83472,0.112655,1.3504,-2.04886},
/*1927*/{0.257955,1.92718,-1.74099,0.304962,1.86398,-1.90063,0.222199,1.77448,-1.62686,0.188846,1.66219,-1.54415,0.310514,1.68255,-1.64517,0.390338,1.6884,-1.68693,0.194057,1.94706,-2.12143,0.297911,1.86835,-1.97626,0.07831,1.91213,-2.01141,-0.043617,1.82166,-2.17681,-0.057101,1.72919,-2.22605,0.085487,1.61445,-2.17229,0.125078,1.56074,-2.18955,0.186036,1.41363,-1.80427,0.004152,1.49745,-1.88781,0.007815,1.52208,-1.9346,0.009407,1.50119,-2.0053,0.198074,1.44472,-2.06291,0.080032,1.1072,-1.76841,-0.051709,1.14028,-1.78615,-0.074242,1.05991,-1.80906,-0.060207,0.930126,-1.79747,-0.111938,0.745844,-1.7915,-0.141053,0.677076,-1.80289,-0.21442,0.790497,-1.81137,-0.24228,0.72469,-1.81954,-0.293231,0.488521,-1.83178,-0.405082,0.472891,-1.91349,-0.170796,0.376858,-1.88034,-0.215517,0.34145,-1.81172,0.327072,1.2414,-2.11013,0.386703,1.1852,-2.08692,0.227003,1.13944,-2.09007,0.285682,1.08361,-2.06865,0.398121,1.02887,-2.06628,0.338318,0.848196,-2.07129,0.247173,0.914732,-2.08239,0.209057,0.854854,-2.07738,0.098212,0.646634,-2.05852,-0.012783,0.611935,-1.99546,0.237768,0.493855,-2.05356,0.170735,0.483469,-2.11244,0.10204,1.33546,-1.83691,0.113732,1.35612,-2.05083},
/*1928*/{0.258589,1.93229,-1.74282,0.30533,1.86873,-1.90221,0.224765,1.7801,-1.62756,0.192427,1.66752,-1.5442,0.311265,1.68895,-1.64724,0.391193,1.6953,-1.69084,0.192396,1.95074,-2.12098,0.297497,1.87309,-1.97765,0.077765,1.91541,-2.01102,-0.045317,1.82737,-2.17355,-0.061312,1.73614,-2.2246,0.081505,1.62068,-2.17163,0.121803,1.56725,-2.18964,0.187603,1.41594,-1.80606,0.00586,1.50178,-1.88738,0.009316,1.52683,-1.93388,0.011125,1.50697,-2.00492,0.197991,1.44992,-2.06346,0.075613,1.11081,-1.76918,-0.055624,1.14617,-1.78532,-0.079316,1.06802,-1.80823,-0.069294,0.938826,-1.79709,-0.123369,0.754805,-1.78879,-0.152428,0.686173,-1.79991,-0.225282,0.79899,-1.81135,-0.252733,0.733366,-1.81882,-0.304925,0.495827,-1.82939,-0.416068,0.486641,-1.91343,-0.190032,0.377105,-1.88033,-0.235863,0.343776,-1.81179,0.328883,1.24725,-2.10881,0.387222,1.19025,-2.08519,0.227727,1.14603,-2.09159,0.285339,1.09245,-2.07206,0.397166,1.03357,-2.06629,0.346873,0.849418,-2.07192,0.251559,0.91032,-2.08162,0.216248,0.84792,-2.07666,0.118098,0.633995,-2.0582,0.010342,0.591414,-1.99458,0.268487,0.491398,-2.05615,0.201136,0.477424,-2.11465,0.102889,1.33861,-1.83881,0.113666,1.36169,-2.05254},
/*1929*/{0.2598,1.93677,-1.74412,0.305522,1.87345,-1.90335,0.225807,1.78516,-1.62824,0.195128,1.6726,-1.54437,0.311928,1.695,-1.64901,0.391559,1.70202,-1.69313,0.191015,1.95439,-2.12088,0.297206,1.87791,-1.97844,0.078427,1.91773,-2.01009,-0.046302,1.8321,-2.17265,-0.064361,1.74227,-2.22257,0.07858,1.62665,-2.17109,0.118647,1.57328,-2.18971,0.190039,1.41806,-1.8084,0.007262,1.5064,-1.88722,0.010727,1.53104,-1.93335,0.012696,1.51149,-2.00394,0.198311,1.45435,-2.06394,0.073786,1.11551,-1.76818,-0.058229,1.15329,-1.78501,-0.083127,1.07667,-1.80782,-0.076949,0.946808,-1.79631,-0.133717,0.762914,-1.78699,-0.162628,0.695023,-1.79728,-0.235136,0.807484,-1.81221,-0.262831,0.743048,-1.8182,-0.316884,0.503288,-1.82648,-0.426861,0.502215,-1.91338,-0.206523,0.378412,-1.87853,-0.256971,0.345431,-1.81238,0.330072,1.25226,-2.10804,0.38766,1.19469,-2.08364,0.228103,1.15134,-2.0926,0.284937,1.09734,-2.07435,0.395864,1.03669,-2.06747,0.355011,0.849155,-2.07264,0.256186,0.906277,-2.08053,0.225329,0.841551,-2.07633,0.139033,0.621554,-2.05749,0.034964,0.570796,-1.99195,0.298113,0.489469,-2.05816,0.230332,0.471897,-2.11624,0.104261,1.34166,-1.84036,0.113679,1.36645,-2.05396},
/*1930*/{0.260152,1.94074,-1.74521,0.305449,1.87824,-1.90431,0.227078,1.78957,-1.62869,0.19662,1.67673,-1.54495,0.312069,1.70063,-1.65098,0.391426,1.70835,-1.69669,0.189565,1.95842,-2.12076,0.296895,1.88243,-1.97958,0.078731,1.92105,-2.00928,-0.049241,1.83868,-2.16928,-0.067991,1.7478,-2.22064,0.076389,1.63221,-2.17068,0.115253,1.57867,-2.18998,0.191258,1.42094,-1.80934,0.009467,1.51076,-1.8866,0.012055,1.53544,-1.93276,0.013919,1.51732,-2.00359,0.198059,1.4589,-2.06428,0.068849,1.1184,-1.76774,-0.061074,1.15968,-1.78358,-0.088175,1.08347,-1.8076,-0.083968,0.953807,-1.79549,-0.143039,0.771194,-1.78468,-0.172936,0.702336,-1.79601,-0.243506,0.816236,-1.81063,-0.270911,0.749659,-1.81739,-0.328068,0.511513,-1.82427,-0.435934,0.517996,-1.91328,-0.224279,0.380161,-1.87761,-0.278081,0.347646,-1.81374,0.330365,1.25657,-2.10668,0.387644,1.19809,-2.08218,0.22705,1.15641,-2.09416,0.284163,1.10061,-2.07612,0.394331,1.03864,-2.068,0.362448,0.849337,-2.07391,0.260574,0.900181,-2.07969,0.232777,0.834523,-2.07571,0.156489,0.608924,-2.05752,0.057824,0.55379,-1.9926,0.326352,0.48892,-2.05927,0.260103,0.467098,-2.1173,0.104914,1.34523,-1.84142,0.11342,1.37147,-2.05488},
/*1931*/{0.261597,1.94497,-1.74648,0.305452,1.88187,-1.90588,0.228174,1.79442,-1.62916,0.199498,1.68149,-1.54454,0.312742,1.7063,-1.65243,0.391469,1.71487,-1.69952,0.189083,1.96168,-2.12056,0.296535,1.88582,-1.98026,0.078439,1.9239,-2.00868,-0.050818,1.84424,-2.1672,-0.071593,1.75341,-2.21806,0.07428,1.6375,-2.17069,0.112632,1.58351,-2.19026,0.193421,1.42397,-1.81039,0.011198,1.51494,-1.8867,0.013398,1.53919,-1.93246,0.015418,1.52155,-2.00308,0.199069,1.4633,-2.0651,0.066252,1.12252,-1.76598,-0.062112,1.1651,-1.78616,-0.09118,1.08974,-1.80823,-0.087464,0.95946,-1.79577,-0.149287,0.778414,-1.78425,-0.179606,0.711242,-1.79282,-0.250161,0.823961,-1.81011,-0.278613,0.758868,-1.81635,-0.339353,0.519902,-1.82144,-0.444361,0.535557,-1.91093,-0.241352,0.382056,-1.87628,-0.299571,0.352531,-1.81338,0.330788,1.26021,-2.10526,0.387157,1.20072,-2.0811,0.226796,1.16047,-2.09581,0.282685,1.10398,-2.0783,0.393214,1.03921,-2.06925,0.36946,0.849218,-2.07585,0.264159,0.892782,-2.07856,0.241474,0.826876,-2.07439,0.176445,0.598427,-2.05902,0.083428,0.53543,-1.99176,0.353661,0.487895,-2.05918,0.29001,0.463145,-2.11767,0.106693,1.34866,-1.84241,0.114328,1.3759,-2.05578},
/*1932*/{0.261836,1.9482,-1.74732,0.306652,1.88617,-1.90645,0.229309,1.79856,-1.62981,0.20147,1.68486,-1.54415,0.313256,1.71089,-1.65486,0.391376,1.72012,-1.70206,0.188379,1.96478,-2.12112,0.296486,1.88941,-1.98129,0.078066,1.92654,-2.0075,-0.051929,1.84945,-2.16391,-0.074165,1.75841,-2.21575,0.072565,1.64221,-2.17041,0.109586,1.58817,-2.19094,0.194496,1.42717,-1.81145,0.012507,1.51948,-1.88576,0.015005,1.54373,-1.93216,0.015686,1.526,-2.00265,0.199582,1.46727,-2.06544,0.062345,1.12833,-1.76439,-0.063908,1.17096,-1.78702,-0.09381,1.09543,-1.80818,-0.090892,0.964772,-1.79525,-0.155348,0.784793,-1.78225,-0.185747,0.716728,-1.79193,-0.254772,0.832513,-1.8082,-0.284701,0.766476,-1.81448,-0.350082,0.529426,-1.81952,-0.452728,0.552663,-1.90823,-0.260186,0.385055,-1.87607,-0.320533,0.357856,-1.81508,0.330965,1.26235,-2.1033,0.386077,1.20229,-2.08032,0.225473,1.16386,-2.09672,0.281299,1.10633,-2.07957,0.392066,1.03907,-2.07004,0.375414,0.846367,-2.07588,0.269685,0.886077,-2.0785,0.249555,0.817929,-2.07345,0.201281,0.584998,-2.05543,0.108168,0.516924,-1.99134,0.381427,0.488827,-2.05893,0.318441,0.460172,-2.11757,0.107383,1.35242,-1.84287,0.114138,1.38024,-2.0562},
/*1933*/{0.263054,1.95218,-1.74839,0.305902,1.88903,-1.90733,0.229896,1.80269,-1.62986,0.202101,1.68844,-1.54399,0.313014,1.71538,-1.65627,0.390574,1.72488,-1.70525,0.187326,1.96754,-2.12103,0.296639,1.89293,-1.98235,0.078408,1.92884,-2.00795,-0.052964,1.85398,-2.16126,-0.076752,1.7633,-2.21389,0.069562,1.64553,-2.16997,0.10761,1.59269,-2.1915,0.195757,1.43016,-1.81173,0.013119,1.52313,-1.88596,0.015745,1.54825,-1.93166,0.017486,1.53068,-2.00215,0.199497,1.47048,-2.06587,0.060144,1.13145,-1.7623,-0.064772,1.17587,-1.78681,-0.094805,1.09956,-1.80946,-0.092596,0.969515,-1.7952,-0.159011,0.7907,-1.78266,-0.193125,0.723054,-1.79092,-0.258386,0.838861,-1.8059,-0.288757,0.774455,-1.80926,-0.359042,0.539836,-1.81821,-0.460102,0.569873,-1.90468,-0.278242,0.389933,-1.87713,-0.340338,0.364219,-1.81683,0.330448,1.26439,-2.10236,0.384663,1.20328,-2.07977,0.223655,1.16643,-2.09812,0.278391,1.10829,-2.081,0.389918,1.03808,-2.07225,0.381368,0.844453,-2.07706,0.273485,0.878549,-2.07763,0.256467,0.810417,-2.07324,0.218579,0.576202,-2.05645,0.131008,0.500734,-1.99114,0.407413,0.490025,-2.05772,0.346381,0.457479,-2.11605,0.107662,1.3559,-1.84323,0.113955,1.38414,-2.05651},
/*1934*/{0.263174,1.95491,-1.74961,0.30663,1.89372,-1.90836,0.230676,1.80634,-1.63089,0.203068,1.69211,-1.54405,0.31325,1.71952,-1.65762,0.389959,1.72934,-1.70737,0.187143,1.97069,-2.12149,0.296814,1.8961,-1.98323,0.07884,1.93127,-2.00728,-0.052836,1.85736,-2.15826,-0.079323,1.76759,-2.21144,0.067646,1.64935,-2.17031,0.105724,1.59612,-2.19223,0.195993,1.43371,-1.81208,0.014211,1.52696,-1.88551,0.016184,1.55271,-1.93152,0.017925,1.53489,-2.00153,0.200264,1.47322,-2.06591,0.058578,1.13809,-1.7611,-0.065565,1.18004,-1.78824,-0.095995,1.10371,-1.81017,-0.092966,0.97287,-1.79546,-0.162295,0.794861,-1.78203,-0.197645,0.727939,-1.79015,-0.260671,0.845825,-1.80396,-0.292771,0.782462,-1.80642,-0.36902,0.549526,-1.81561,-0.468366,0.587142,-1.89975,-0.296514,0.397024,-1.87839,-0.360088,0.372638,-1.81869,0.32944,1.26458,-2.10175,0.383067,1.20292,-2.07965,0.221218,1.16825,-2.09809,0.2759,1.10919,-2.08133,0.387466,1.03681,-2.07405,0.38793,0.842907,-2.07858,0.278426,0.872306,-2.07817,0.263639,0.80201,-2.07253,0.23831,0.5658,-2.05635,0.155469,0.485306,-1.99148,0.432589,0.491685,-2.05557,0.37433,0.455283,-2.11548,0.107694,1.35967,-1.84294,0.11375,1.38765,-2.05626},
/*1935*/{0.263567,1.95782,-1.75078,0.306865,1.896,-1.90982,0.230876,1.81009,-1.63104,0.203541,1.69472,-1.54359,0.312983,1.72298,-1.6594,0.388606,1.73298,-1.70951,0.186296,1.97294,-2.12146,0.297069,1.89918,-1.98393,0.079647,1.93404,-2.00716,-0.053493,1.86089,-2.15681,-0.081194,1.77216,-2.20968,0.066118,1.65261,-2.17099,0.103612,1.59938,-2.19313,0.19684,1.43733,-1.81225,0.014997,1.53015,-1.88514,0.016958,1.55605,-1.93134,0.018758,1.53836,-2.00151,0.20074,1.4757,-2.06602,0.058091,1.14016,-1.75825,-0.064912,1.18345,-1.78884,-0.094532,1.10494,-1.81143,-0.091189,0.975268,-1.79533,-0.165235,0.797963,-1.78202,-0.201677,0.733255,-1.7904,-0.261818,0.852213,-1.80119,-0.295995,0.788643,-1.804,-0.377779,0.559754,-1.81271,-0.476898,0.604487,-1.89493,-0.313505,0.405171,-1.88053,-0.377425,0.380659,-1.82268,0.32766,1.2645,-2.10179,0.381143,1.20124,-2.07974,0.218122,1.16902,-2.09891,0.271499,1.10909,-2.0832,0.384101,1.03465,-2.07588,0.39252,0.84004,-2.07983,0.282017,0.86431,-2.07923,0.270646,0.794164,-2.0724,0.258171,0.556634,-2.0566,0.178781,0.472334,-1.99241,0.456087,0.494201,-2.0537,0.399517,0.453612,-2.11252,0.108419,1.36313,-1.84251,0.114036,1.39049,-2.05593},
/*1936*/{0.263757,1.96076,-1.75173,0.306678,1.89912,-1.91021,0.231298,1.81352,-1.63153,0.203809,1.6979,-1.5442,0.312486,1.72582,-1.66108,0.387857,1.73614,-1.71158,0.187365,1.97548,-2.12185,0.297074,1.9016,-1.98506,0.07997,1.93634,-2.00702,-0.054326,1.86452,-2.15372,-0.08303,1.77579,-2.20748,0.064949,1.65595,-2.17114,0.10178,1.60235,-2.1943,0.196707,1.44092,-1.81211,0.015396,1.53348,-1.88552,0.01729,1.55962,-1.93135,0.0184,1.54189,-2.00133,0.201259,1.47838,-2.06617,0.057594,1.14393,-1.75712,-0.064809,1.18629,-1.78955,-0.094837,1.10813,-1.81218,-0.089481,0.976998,-1.79614,-0.165807,0.800788,-1.78238,-0.206532,0.735898,-1.79051,-0.261361,0.858518,-1.79789,-0.29715,0.796736,-1.80047,-0.386376,0.570044,-1.81073,-0.484229,0.621513,-1.88897,-0.331036,0.414409,-1.88371,-0.396331,0.390188,-1.82497,0.325122,1.2632,-2.10224,0.377555,1.19869,-2.08044,0.21511,1.16919,-2.09982,0.267758,1.1081,-2.08382,0.3803,1.03189,-2.07737,0.397691,0.837235,-2.08089,0.285297,0.855335,-2.07855,0.277677,0.786479,-2.0735,0.276875,0.548012,-2.05632,0.201961,0.460493,-1.99288,0.47815,0.495818,-2.05097,0.425898,0.451912,-2.11059,0.10833,1.36666,-1.84223,0.114005,1.39353,-2.05571},
/*1937*/{0.264541,1.96255,-1.75224,0.30673,1.90172,-1.91129,0.231182,1.81641,-1.632,0.204035,1.69968,-1.54341,0.312601,1.72773,-1.66171,0.387235,1.73798,-1.71404,0.187292,1.97733,-2.12282,0.297465,1.90303,-1.98567,0.081172,1.93832,-2.00722,-0.054111,1.86777,-2.15101,-0.084203,1.77894,-2.20601,0.063823,1.65906,-2.17192,0.100258,1.60519,-2.19511,0.197315,1.44449,-1.81163,0.016222,1.53635,-1.88509,0.017091,1.56288,-1.93169,0.01896,1.54452,-2.00115,0.201218,1.4801,-2.06586,0.059054,1.14679,-1.75686,-0.067484,1.18758,-1.79123,-0.093109,1.10887,-1.81179,-0.085069,0.978167,-1.79693,-0.165732,0.802732,-1.78359,-0.208625,0.74065,-1.79197,-0.259683,0.864232,-1.79517,-0.298878,0.804189,-1.7978,-0.395897,0.580509,-1.80968,-0.493713,0.637564,-1.88138,-0.348787,0.425234,-1.88823,-0.413064,0.402049,-1.82783,0.322364,1.26076,-2.10258,0.373885,1.19575,-2.08107,0.211198,1.1689,-2.10043,0.26293,1.10627,-2.08492,0.376482,1.02835,-2.07899,0.402032,0.834234,-2.08191,0.288594,0.847455,-2.0795,0.284176,0.777949,-2.07373,0.295824,0.53959,-2.05613,0.223524,0.449426,-1.99181,0.49844,0.497287,-2.04805,0.4489,0.449254,-2.10689,0.108717,1.37012,-1.84107,0.113982,1.39552,-2.05474},
/*1938*/{0.264624,1.96515,-1.753,0.307008,1.90371,-1.91194,0.231559,1.81852,-1.633,0.203258,1.70309,-1.54417,0.311734,1.72966,-1.66172,0.386447,1.73975,-1.71579,0.18713,1.97932,-2.12339,0.297781,1.90541,-1.98682,0.082167,1.94112,-2.00799,-0.054346,1.8705,-2.14837,-0.085144,1.78226,-2.20423,0.062902,1.66133,-2.17254,0.098475,1.60708,-2.19653,0.197865,1.44773,-1.81129,0.015646,1.53922,-1.88583,0.017099,1.56609,-1.93154,0.019348,1.5465,-2.00047,0.201997,1.48189,-2.06541,0.060946,1.14861,-1.75695,-0.065146,1.19106,-1.79205,-0.090975,1.10967,-1.81218,-0.080738,0.977607,-1.79719,-0.16614,0.805179,-1.78387,-0.211197,0.744241,-1.79311,-0.257784,0.870649,-1.79196,-0.299037,0.811627,-1.79528,-0.404903,0.592133,-1.80876,-0.504475,0.653656,-1.87383,-0.364898,0.438071,-1.89227,-0.426514,0.414467,-1.83066,0.319863,1.25754,-2.10296,0.369968,1.19165,-2.08197,0.206312,1.16744,-2.10092,0.257565,1.10474,-2.08559,0.372058,1.02474,-2.08017,0.404092,0.832608,-2.08316,0.291344,0.840717,-2.08388,0.290931,0.77043,-2.07486,0.312058,0.532025,-2.05577,0.245834,0.440161,-1.99103,0.517567,0.498724,-2.04567,0.472008,0.447215,-2.10378,0.108934,1.37325,-1.84015,0.114398,1.39756,-2.05394},
/*1939*/{0.264768,1.9669,-1.75396,0.306736,1.90567,-1.91308,0.231338,1.82088,-1.63318,0.203481,1.70516,-1.54306,0.310098,1.73147,-1.66245,0.384728,1.74095,-1.71699,0.188359,1.98084,-2.12453,0.298024,1.90622,-1.98723,0.082876,1.94242,-2.00808,-0.053894,1.87315,-2.14659,-0.086293,1.7844,-2.2026,0.06194,1.66235,-2.17329,0.097964,1.60844,-2.1972,0.197546,1.45104,-1.81104,0.016389,1.54137,-1.88577,0.017892,1.56846,-1.93189,0.018776,1.54869,-2.00039,0.201984,1.48318,-2.06448,0.064556,1.14964,-1.75799,-0.062766,1.18882,-1.79246,-0.087398,1.11028,-1.8125,-0.075349,0.976992,-1.79827,-0.166002,0.805821,-1.78594,-0.214451,0.747653,-1.79453,-0.25515,0.875443,-1.79038,-0.297918,0.819258,-1.79294,-0.412678,0.604135,-1.80786,-0.513596,0.669689,-1.86568,-0.381,0.451451,-1.89826,-0.439285,0.427106,-1.83366,0.317029,1.25411,-2.10447,0.365377,1.18817,-2.08333,0.202816,1.16507,-2.10126,0.251799,1.10263,-2.08657,0.367997,1.02085,-2.08184,0.407526,0.830969,-2.08419,0.294174,0.832666,-2.08565,0.296164,0.762759,-2.07876,0.330767,0.527339,-2.05659,0.265567,0.433922,-1.99107,0.536467,0.500802,-2.04286,0.492312,0.445966,-2.10039,0.108942,1.37615,-1.83901,0.114387,1.39904,-2.05295},
/*1940*/{0.265021,1.96804,-1.7548,0.307462,1.90726,-1.91426,0.230826,1.82298,-1.63422,0.202403,1.70652,-1.54363,0.309364,1.73202,-1.66392,0.383061,1.74138,-1.71919,0.188429,1.98187,-2.12514,0.298207,1.90777,-1.98861,0.0835,1.94459,-2.00882,-0.054134,1.87427,-2.14468,-0.086442,1.78638,-2.2012,0.062157,1.66411,-2.17415,0.097035,1.61019,-2.19849,0.19783,1.45325,-1.81054,0.016265,1.54295,-1.88547,0.018033,1.57056,-1.93173,0.019365,1.55002,-2.00061,0.202869,1.4852,-2.06336,0.068711,1.14981,-1.75981,-0.06008,1.18861,-1.79056,-0.083071,1.10769,-1.81199,-0.0696,0.976343,-1.79955,-0.166069,0.807801,-1.78694,-0.215881,0.751971,-1.79571,-0.251188,0.881036,-1.78818,-0.298438,0.826385,-1.79272,-0.418687,0.616226,-1.808,-0.521763,0.685255,-1.85713,-0.397438,0.464563,-1.90245,-0.45228,0.440244,-1.83545,0.31291,1.25011,-2.10499,0.361286,1.18349,-2.08475,0.197661,1.16284,-2.10195,0.24566,1.09916,-2.08753,0.362435,1.01588,-2.08275,0.41006,0.828539,-2.08374,0.29629,0.826686,-2.08838,0.302699,0.755946,-2.08061,0.347184,0.522002,-2.05592,0.284134,0.426559,-1.99,0.55272,0.502333,-2.04051,0.512827,0.44502,-2.09606,0.109351,1.37814,-1.83845,0.115478,1.40086,-2.05239},
/*1941*/{0.264924,1.96905,-1.75575,0.306384,1.90834,-1.91514,0.229802,1.82433,-1.63502,0.201164,1.70858,-1.54356,0.308177,1.73199,-1.66494,0.382006,1.74231,-1.72015,0.190039,1.98313,-2.12634,0.298812,1.90802,-1.98943,0.084355,1.94585,-2.00938,-0.052855,1.87605,-2.14327,-0.087438,1.78823,-2.19998,0.06208,1.66442,-2.17484,0.09617,1.61065,-2.19949,0.197274,1.45549,-1.80972,0.015765,1.54429,-1.88635,0.017829,1.57161,-1.9321,0.01958,1.55061,-2.00054,0.20473,1.48627,-2.06251,0.073496,1.14896,-1.76164,-0.055382,1.18659,-1.7902,-0.078782,1.1074,-1.81245,-0.064506,0.974689,-1.80093,-0.165862,0.80885,-1.78825,-0.217794,0.755857,-1.79727,-0.247426,0.886694,-1.78569,-0.295696,0.83429,-1.79013,-0.425699,0.628113,-1.80768,-0.529394,0.701492,-1.85042,-0.412162,0.479215,-1.90645,-0.464371,0.454487,-1.83719,0.309159,1.24583,-2.10615,0.357814,1.17787,-2.0859,0.192854,1.1603,-2.10255,0.241104,1.0963,-2.08774,0.357601,1.0116,-2.08417,0.413592,0.827524,-2.08322,0.299692,0.819925,-2.09086,0.3085,0.750957,-2.08302,0.361375,0.517938,-2.05652,0.300451,0.421768,-1.98953,0.569044,0.505152,-2.03694,0.530345,0.444732,-2.09345,0.109405,1.37986,-1.83768,0.116987,1.40179,-2.05166},
/*1942*/{0.264816,1.96983,-1.75664,0.30599,1.90877,-1.91571,0.228939,1.82549,-1.63592,0.200536,1.71012,-1.54389,0.307434,1.73193,-1.66622,0.38054,1.73985,-1.72142,0.191431,1.98364,-2.12746,0.298723,1.90806,-1.98995,0.085458,1.94717,-2.01118,-0.052404,1.87679,-2.14128,-0.087033,1.78946,-2.19921,0.061398,1.66512,-2.17544,0.096234,1.61072,-2.20058,0.196599,1.45723,-1.80813,0.015697,1.54482,-1.88644,0.017875,1.5726,-1.93242,0.019393,1.55011,-2.00053,0.20545,1.48701,-2.06112,0.07963,1.14796,-1.76384,-0.050855,1.18481,-1.7895,-0.074107,1.10506,-1.81144,-0.057824,0.973219,-1.80295,-0.165322,0.811003,-1.78959,-0.219807,0.760164,-1.79852,-0.243343,0.891756,-1.78391,-0.294825,0.841884,-1.7883,-0.434325,0.639479,-1.80696,-0.534756,0.718736,-1.84335,-0.42644,0.494439,-1.90903,-0.476013,0.469629,-1.83806,0.30519,1.2412,-2.10723,0.351995,1.17221,-2.08764,0.188322,1.15709,-2.10269,0.234559,1.09263,-2.08836,0.352617,1.00651,-2.08532,0.41499,0.825366,-2.08238,0.303086,0.814129,-2.0942,0.314177,0.745666,-2.08577,0.374373,0.513908,-2.05553,0.315091,0.41621,-1.98886,0.581085,0.507162,-2.03508,0.545354,0.445049,-2.09005,0.109391,1.38118,-1.8363,0.118092,1.40199,-2.05034},
/*1943*/{0.265105,1.97022,-1.75737,0.306557,1.90957,-1.91667,0.228101,1.82646,-1.63674,0.197175,1.71077,-1.54458,0.3054,1.73148,-1.66662,0.378656,1.73832,-1.72209,0.19208,1.98403,-2.12793,0.298525,1.90834,-1.99077,0.086509,1.94833,-2.01223,-0.052607,1.87791,-2.14055,-0.087186,1.7904,-2.19844,0.062097,1.66486,-2.17576,0.095779,1.61047,-2.20174,0.196848,1.4589,-1.80827,0.015369,1.54491,-1.88683,0.016678,1.57323,-1.93309,0.021438,1.54885,-2.00081,0.206313,1.48774,-2.05993,0.086187,1.14782,-1.7668,-0.046606,1.18131,-1.78826,-0.068208,1.10234,-1.81054,-0.051336,0.971186,-1.80378,-0.164483,0.812791,-1.79089,-0.222628,0.764847,-1.79969,-0.23931,0.896858,-1.78375,-0.292293,0.849772,-1.78799,-0.436873,0.65507,-1.80603,-0.538363,0.736467,-1.83751,-0.439583,0.510166,-1.91127,-0.48813,0.485648,-1.83895,0.301739,1.23636,-2.10816,0.34851,1.16662,-2.08897,0.183386,1.15403,-2.10299,0.22931,1.08846,-2.08831,0.348547,1.00174,-2.08601,0.418309,0.824029,-2.081,0.306971,0.808803,-2.09744,0.319759,0.740279,-2.0884,0.386285,0.509913,-2.05532,0.329442,0.411954,-1.98797,0.592535,0.508636,-2.0319,0.559698,0.445965,-2.08667,0.110252,1.38213,-1.83566,0.119868,1.40209,-2.04975},
/*1944*/{0.265026,1.9703,-1.75871,0.30554,1.90977,-1.91764,0.226198,1.82692,-1.63771,0.19607,1.71138,-1.54463,0.304196,1.73002,-1.66716,0.37747,1.73583,-1.72314,0.192509,1.98342,-2.12873,0.29841,1.90807,-1.99126,0.087102,1.94832,-2.0136,-0.050763,1.87725,-2.13843,-0.086472,1.7902,-2.19804,0.062707,1.66423,-2.17625,0.095806,1.60923,-2.20315,0.196459,1.45937,-1.80747,0.015297,1.54473,-1.88669,0.016609,1.57303,-1.93328,0.019181,1.54766,-2.00035,0.206692,1.48804,-2.05818,0.092211,1.14421,-1.77015,-0.039608,1.17943,-1.78749,-0.062098,1.09864,-1.81067,-0.044439,0.968412,-1.80532,-0.163684,0.815532,-1.79184,-0.223737,0.769708,-1.80006,-0.234469,0.902761,-1.7838,-0.29042,0.85733,-1.78727,-0.441902,0.669652,-1.80481,-0.539785,0.755769,-1.83384,-0.451872,0.526656,-1.91073,-0.499922,0.503075,-1.8377,0.298336,1.23138,-2.10902,0.344215,1.16068,-2.09055,0.178448,1.15178,-2.10185,0.223334,1.08474,-2.08893,0.343893,0.997015,-2.08648,0.420027,0.822116,-2.07833,0.309632,0.804021,-2.09957,0.324524,0.735509,-2.09055,0.395439,0.506425,-2.05479,0.340724,0.408313,-1.98892,0.60202,0.51166,-2.02977,0.571746,0.446918,-2.08441,0.110276,1.38239,-1.83458,0.120322,1.40174,-2.04871},
/*1945*/{0.264435,1.97036,-1.75918,0.305364,1.90918,-1.91839,0.223867,1.82761,-1.63857,0.192665,1.71265,-1.54604,0.301766,1.72851,-1.66762,0.375148,1.73291,-1.72362,0.193714,1.98302,-2.12971,0.29823,1.90777,-1.9918,0.0887,1.94888,-2.01473,-0.050025,1.87661,-2.13657,-0.085451,1.78996,-2.19789,0.062909,1.66274,-2.17731,0.096485,1.60826,-2.20419,0.196262,1.45978,-1.80679,0.014793,1.54427,-1.88715,0.016585,1.57177,-1.93373,0.02036,1.54581,-2.00159,0.208053,1.48828,-2.05695,0.097952,1.14271,-1.77232,-0.033925,1.17595,-1.7858,-0.056118,1.09515,-1.81024,-0.037539,0.965529,-1.80631,-0.162096,0.81887,-1.79229,-0.223419,0.775851,-1.80043,-0.229855,0.908354,-1.78371,-0.286864,0.865872,-1.7883,-0.446297,0.685127,-1.80353,-0.539504,0.775799,-1.83114,-0.463444,0.542111,-1.90977,-0.512823,0.520859,-1.8363,0.295561,1.22568,-2.11005,0.339945,1.15539,-2.09212,0.1737,1.14854,-2.10279,0.218329,1.08049,-2.08799,0.339634,0.992061,-2.087,0.421445,0.820347,-2.07609,0.312537,0.799295,-2.1011,0.328027,0.731673,-2.09213,0.403765,0.504654,-2.05513,0.349475,0.405774,-1.98879,0.61006,0.514227,-2.02691,0.58039,0.446556,-2.08212,0.110869,1.38221,-1.83411,0.122522,1.40111,-2.0482},
/*1946*/{0.263628,1.96953,-1.76055,0.304899,1.90901,-1.91853,0.221645,1.82755,-1.63948,0.189539,1.71247,-1.54665,0.300217,1.72721,-1.66845,0.373017,1.72977,-1.72395,0.194786,1.9826,-2.13042,0.298465,1.90646,-1.99194,0.088785,1.94846,-2.01572,-0.048907,1.87618,-2.13683,-0.084349,1.7893,-2.19862,0.063857,1.66071,-2.17799,0.096808,1.60594,-2.20574,0.195977,1.46035,-1.8055,0.015036,1.54275,-1.88757,0.015715,1.57002,-1.93422,0.021239,1.54503,-2.00282,0.20926,1.48808,-2.05557,0.104198,1.14062,-1.77483,-0.028623,1.17117,-1.78553,-0.048738,1.09026,-1.81104,-0.029621,0.962496,-1.80811,-0.160632,0.822143,-1.79236,-0.223826,0.781304,-1.79989,-0.224175,0.914268,-1.78434,-0.283857,0.874275,-1.78874,-0.449092,0.700925,-1.80276,-0.538332,0.795716,-1.83033,-0.473673,0.558525,-1.90643,-0.523374,0.540639,-1.83293,0.292728,1.22114,-2.1109,0.335597,1.15015,-2.09359,0.170051,1.14581,-2.10245,0.213549,1.07725,-2.08795,0.334746,0.987511,-2.0874,0.421759,0.818243,-2.07416,0.314075,0.795432,-2.10173,0.330368,0.727992,-2.09231,0.409736,0.502623,-2.05549,0.35719,0.401549,-1.98828,0.615012,0.515132,-2.02631,0.5881,0.448038,-2.08068,0.111394,1.3819,-1.83349,0.124685,1.40036,-2.04752},
/*1947*/{0.262883,1.96873,-1.76151,0.304582,1.90712,-1.91892,0.219759,1.82728,-1.64075,0.186291,1.71215,-1.548,0.297193,1.72429,-1.66908,0.370555,1.72598,-1.72457,0.195297,1.98135,-2.13096,0.297846,1.90544,-1.9924,0.088516,1.9475,-2.01773,-0.048154,1.87574,-2.13626,-0.083074,1.78765,-2.19888,0.064817,1.65849,-2.17865,0.097467,1.60364,-2.20728,0.196025,1.46011,-1.80542,0.014606,1.5413,-1.88818,0.016164,1.56861,-1.93414,0.021002,1.54273,-2.00294,0.209979,1.48754,-2.05446,0.111965,1.13819,-1.77654,-0.023497,1.16462,-1.78458,-0.04278,1.08514,-1.81078,-0.020113,0.958809,-1.80932,-0.157605,0.826171,-1.79256,-0.223101,0.78711,-1.79968,-0.218461,0.9206,-1.78665,-0.278637,0.882996,-1.78932,-0.451594,0.715408,-1.79947,-0.535251,0.815778,-1.83113,-0.482001,0.573935,-1.90207,-0.534537,0.560055,-1.8301,0.290158,1.21652,-2.11199,0.332929,1.14447,-2.09494,0.166903,1.14186,-2.102,0.2094,1.07326,-2.08737,0.330021,0.982596,-2.08794,0.420883,0.816701,-2.07284,0.313207,0.792014,-2.10148,0.332204,0.724739,-2.09197,0.415068,0.501202,-2.05504,0.363519,0.399144,-1.98963,0.619468,0.515972,-2.02468,0.596056,0.449223,-2.07922,0.11207,1.38106,-1.83302,0.125981,1.39916,-2.04704},
/*1948*/{0.262478,1.96766,-1.76203,0.304223,1.90642,-1.91893,0.2175,1.827,-1.64102,0.182361,1.71273,-1.54938,0.29462,1.72182,-1.66929,0.368457,1.72168,-1.72449,0.196027,1.98008,-2.13161,0.297641,1.90421,-1.99237,0.088943,1.94717,-2.01906,-0.046475,1.87382,-2.13487,-0.081213,1.78514,-2.19983,0.066176,1.65592,-2.18107,0.098223,1.6005,-2.20829,0.196079,1.45921,-1.80468,0.014109,1.53901,-1.8884,0.016414,1.56632,-1.93528,0.021591,1.54069,-2.00369,0.210708,1.48635,-2.05415,0.117075,1.13649,-1.77794,-0.018331,1.15954,-1.78408,-0.035669,1.08004,-1.81164,-0.011193,0.954606,-1.81104,-0.155274,0.829317,-1.79196,-0.220513,0.793966,-1.79904,-0.21156,0.926885,-1.78686,-0.273511,0.890589,-1.78992,-0.453939,0.732166,-1.79789,-0.53118,0.835852,-1.83333,-0.490034,0.590324,-1.89795,-0.543611,0.579961,-1.82564,0.288641,1.21146,-2.11334,0.3294,1.13925,-2.09618,0.164017,1.13975,-2.10197,0.205365,1.06913,-2.08711,0.32501,0.97825,-2.08783,0.419162,0.815038,-2.0723,0.311763,0.788739,-2.09976,0.33055,0.721604,-2.09026,0.417515,0.49876,-2.05455,0.367931,0.396317,-1.98958,0.62312,0.515313,-2.02304,0.599973,0.449883,-2.07921,0.11258,1.37962,-1.83289,0.127472,1.39744,-2.04687},
/*1949*/{0.260807,1.9658,-1.76266,0.301989,1.90391,-1.91855,0.215035,1.82603,-1.64178,0.178634,1.71169,-1.54986,0.291028,1.71807,-1.66947,0.365172,1.71677,-1.72394,0.196244,1.97829,-2.13208,0.297437,1.90204,-1.99256,0.08876,1.94563,-2.02099,-0.045098,1.87106,-2.13515,-0.079981,1.78257,-2.2016,0.066372,1.65299,-2.18183,0.100124,1.59694,-2.21035,0.196443,1.45857,-1.80469,0.014071,1.53698,-1.88894,0.016249,1.56396,-1.93521,0.022288,1.5386,-2.00482,0.211337,1.48414,-2.05416,0.123087,1.13346,-1.77919,-0.012887,1.1564,-1.78492,-0.028478,1.07497,-1.81107,-0.003464,0.950837,-1.81199,-0.150725,0.833898,-1.79194,-0.217927,0.799464,-1.79798,-0.2042,0.93231,-1.78857,-0.266942,0.898715,-1.79113,-0.454377,0.749137,-1.79646,-0.525019,0.855575,-1.83606,-0.496224,0.606363,-1.89267,-0.551344,0.601164,-1.81998,0.286922,1.20688,-2.11483,0.327663,1.13343,-2.09815,0.161403,1.13695,-2.10107,0.202319,1.0662,-2.08608,0.320837,0.974152,-2.08769,0.416416,0.813107,-2.07209,0.308878,0.785261,-2.09734,0.32864,0.718623,-2.0888,0.419574,0.497263,-2.05429,0.370096,0.392647,-1.9906,0.625578,0.515586,-2.02264,0.60042,0.449718,-2.07938,0.113246,1.37835,-1.83251,0.128395,1.39518,-2.04655},
/*1950*/{0.260036,1.96448,-1.76311,0.302105,1.90194,-1.91968,0.212159,1.82494,-1.64234,0.175841,1.71103,-1.55073,0.287993,1.71494,-1.66969,0.362674,1.71143,-1.72342,0.196185,1.9759,-2.13269,0.296657,1.9005,-1.99271,0.089668,1.94392,-2.0223,-0.04361,1.86766,-2.13611,-0.078119,1.77903,-2.20294,0.067125,1.64859,-2.18381,0.101224,1.59351,-2.21192,0.196357,1.45716,-1.80498,0.013997,1.53455,-1.88898,0.015819,1.56202,-1.9362,0.021549,1.53616,-2.00539,0.211037,1.4815,-2.05448,0.127891,1.13112,-1.77996,-0.006245,1.15153,-1.7844,-0.022156,1.06936,-1.813,0.004558,0.946735,-1.81286,-0.146172,0.837355,-1.7911,-0.21532,0.806378,-1.79651,-0.196289,0.938521,-1.79018,-0.261355,0.906852,-1.7932,-0.453438,0.765716,-1.79574,-0.517884,0.874394,-1.83921,-0.501422,0.621309,-1.88694,-0.55762,0.622343,-1.81555,0.285596,1.20246,-2.11586,0.324509,1.12961,-2.09956,0.159505,1.1343,-2.10068,0.199373,1.06316,-2.08582,0.316695,0.970616,-2.08749,0.413551,0.81074,-2.07226,0.305411,0.781781,-2.09607,0.326349,0.715248,-2.08668,0.419587,0.494836,-2.05348,0.370592,0.390015,-1.99033,0.625613,0.514445,-2.02207,0.60042,0.449718,-2.07938,0.113207,1.37669,-1.83234,0.1281,1.39255,-2.04647},
/*1951*/{0.258723,1.96209,-1.76401,0.301558,1.90004,-1.91956,0.208665,1.82372,-1.64275,0.169443,1.7097,-1.55178,0.284035,1.71014,-1.6697,0.359203,1.70549,-1.7232,0.197181,1.97392,-2.13334,0.295984,1.89792,-1.993,0.088215,1.94246,-2.02413,-0.042793,1.86475,-2.13742,-0.076185,1.7751,-2.20545,0.068875,1.64458,-2.18568,0.10256,1.58918,-2.2138,0.196457,1.45574,-1.80477,0.013746,1.53243,-1.88969,0.01593,1.55934,-1.93719,0.022238,1.53306,-2.006,0.211109,1.47936,-2.05514,0.135257,1.13022,-1.78102,-0.001134,1.14587,-1.78459,-0.014231,1.06486,-1.81321,0.01276,0.943113,-1.8134,-0.141315,0.840996,-1.79044,-0.211636,0.811984,-1.79598,-0.187142,0.944336,-1.79197,-0.252119,0.915126,-1.79163,-0.451026,0.781994,-1.79482,-0.509502,0.891784,-1.8435,-0.505291,0.637789,-1.88074,-0.561443,0.643975,-1.81005,0.28469,1.19822,-2.11743,0.322608,1.12442,-2.10051,0.15746,1.13175,-2.09979,0.196479,1.06131,-2.08594,0.31291,0.967037,-2.08759,0.409452,0.807805,-2.0724,0.301285,0.778493,-2.09454,0.323262,0.711727,-2.0858,0.416929,0.491314,-2.05211,0.370337,0.386617,-1.99,0.623672,0.51327,-2.02214,0.60041,0.448558,-2.07957,0.113702,1.37493,-1.83228,0.128822,1.38993,-2.04645},
/*1952*/{0.257755,1.96009,-1.76402,0.300467,1.89753,-1.92011,0.205214,1.82188,-1.6431,0.1652,1.70788,-1.55235,0.279981,1.70629,-1.66915,0.35585,1.69964,-1.72271,0.196962,1.97118,-2.1339,0.295565,1.89537,-1.99291,0.088016,1.93998,-2.02596,-0.043222,1.86105,-2.14003,-0.074754,1.77075,-2.20758,0.070667,1.64006,-2.18839,0.104588,1.58467,-2.21571,0.196407,1.45413,-1.8049,0.013858,1.52987,-1.8895,0.016332,1.55637,-1.93762,0.022931,1.53018,-2.0071,0.210626,1.47673,-2.05598,0.137451,1.12646,-1.78171,0.004462,1.14108,-1.78414,-0.007217,1.06027,-1.81345,0.020415,0.939749,-1.81326,-0.136257,0.844158,-1.79107,-0.20744,0.818063,-1.79589,-0.178586,0.947489,-1.79418,-0.24448,0.922334,-1.79286,-0.447307,0.796232,-1.7924,-0.500696,0.908583,-1.84687,-0.50733,0.65232,-1.87404,-0.563874,0.664161,-1.80431,0.283519,1.19445,-2.11838,0.321096,1.12027,-2.10194,0.15607,1.13009,-2.09905,0.193757,1.05885,-2.08552,0.310436,0.963427,-2.08755,0.404178,0.804533,-2.07298,0.296986,0.774876,-2.09365,0.318989,0.708336,-2.08457,0.41484,0.488385,-2.05024,0.367198,0.383205,-1.98896,0.619289,0.509803,-2.02336,0.595452,0.445632,-2.07925,0.114192,1.37285,-1.83222,0.129029,1.38703,-2.04648},
/*1953*/{0.256246,1.95723,-1.76422,0.299576,1.89469,-1.91973,0.201579,1.81979,-1.64318,0.158951,1.70604,-1.55398,0.27535,1.70108,-1.6693,0.352329,1.69267,-1.7214,0.196952,1.96836,-2.13467,0.294621,1.89278,-1.99319,0.086866,1.93775,-2.02678,-0.043329,1.85906,-2.14267,-0.073019,1.76576,-2.21033,0.072627,1.63503,-2.19098,0.10654,1.5791,-2.21774,0.196219,1.452,-1.80517,0.013753,1.52691,-1.89007,0.0165,1.55397,-1.93849,0.022488,1.52726,-2.00738,0.211555,1.47424,-2.05651,0.144638,1.12377,-1.78138,0.009442,1.13637,-1.78499,-0.001595,1.05468,-1.8128,0.028255,0.936834,-1.81362,-0.129812,0.847342,-1.79098,-0.202172,0.823757,-1.79489,-0.168503,0.952928,-1.79592,-0.235986,0.92883,-1.79464,-0.44221,0.812324,-1.7926,-0.490658,0.923395,-1.85226,-0.508178,0.666896,-1.86845,-0.564777,0.684987,-1.7993,0.282352,1.19114,-2.11988,0.319059,1.11728,-2.10314,0.154041,1.12885,-2.09855,0.190908,1.0574,-2.08541,0.308186,0.960172,-2.08706,0.400721,0.800031,-2.07315,0.292586,0.77121,-2.09285,0.314356,0.705029,-2.08319,0.409975,0.484893,-2.04997,0.363087,0.379728,-1.98573,0.615451,0.505182,-2.02273,0.590826,0.439793,-2.07864,0.114431,1.37044,-1.83255,0.129626,1.38445,-2.04679},
/*1954*/{0.254491,1.95444,-1.76438,0.299574,1.89201,-1.92003,0.198857,1.81687,-1.64343,0.155174,1.70384,-1.55425,0.271314,1.6964,-1.66951,0.347939,1.68524,-1.72016,0.196561,1.96495,-2.13496,0.294304,1.89003,-1.99329,0.086985,1.93459,-2.02875,-0.042888,1.85366,-2.14563,-0.071433,1.76002,-2.21331,0.074392,1.6293,-2.19372,0.109137,1.5735,-2.21969,0.196497,1.44997,-1.80555,0.014205,1.52267,-1.88986,0.016404,1.55074,-1.93893,0.022264,1.52356,-2.00754,0.211684,1.47159,-2.05752,0.150589,1.12126,-1.78039,0.012209,1.133,-1.78648,0.004738,1.04986,-1.81242,0.035262,0.933794,-1.81309,-0.124093,0.851053,-1.7891,-0.195555,0.829867,-1.79394,-0.158274,0.956857,-1.7963,-0.22668,0.93572,-1.79505,-0.437195,0.828172,-1.79286,-0.480483,0.938255,-1.85625,-0.506775,0.681279,-1.86189,-0.563525,0.703922,-1.79487,0.281005,1.1886,-2.12121,0.316736,1.11378,-2.10453,0.152385,1.12729,-2.09892,0.18916,1.05505,-2.08582,0.307558,0.957502,-2.08641,0.396362,0.796073,-2.07452,0.287356,0.767182,-2.09245,0.309594,0.700887,-2.08234,0.404352,0.480619,-2.04748,0.356042,0.376077,-1.98283,0.609224,0.499252,-2.0239,0.583869,0.434198,-2.07907,0.115678,1.36758,-1.83275,0.130269,1.38136,-2.04705},
/*1955*/{0.253125,1.95152,-1.76431,0.298814,1.88881,-1.91983,0.195284,1.81414,-1.6437,0.149273,1.70086,-1.55488,0.265938,1.69106,-1.66862,0.344098,1.67812,-1.71895,0.19594,1.96119,-2.13492,0.293855,1.88696,-1.99357,0.084802,1.93126,-2.03033,-0.042363,1.84735,-2.14826,-0.069663,1.75396,-2.21731,0.077383,1.62364,-2.19655,0.11142,1.56835,-2.22185,0.196163,1.44729,-1.80586,0.013495,1.51981,-1.8911,0.016114,1.5472,-1.93896,0.021389,1.51993,-2.00758,0.211272,1.46886,-2.05851,0.154822,1.11921,-1.78023,0.017433,1.1261,-1.78737,0.010948,1.04466,-1.81372,0.043943,0.930653,-1.81199,-0.117196,0.853899,-1.78915,-0.190687,0.834447,-1.79292,-0.147982,0.961577,-1.79838,-0.217359,0.941919,-1.79585,-0.430841,0.842823,-1.79124,-0.470224,0.951089,-1.86024,-0.504639,0.695229,-1.85713,-0.559981,0.722221,-1.78992,0.279748,1.18571,-2.12258,0.315468,1.11024,-2.1054,0.150829,1.1254,-2.0983,0.187317,1.05245,-2.08454,0.306655,0.955471,-2.08596,0.392322,0.791323,-2.07486,0.282962,0.763295,-2.09098,0.3041,0.697211,-2.08116,0.396718,0.475515,-2.04687,0.347057,0.372289,-1.98172,0.603044,0.492692,-2.02296,0.577079,0.42591,-2.0773,0.115679,1.36468,-1.83315,0.13002,1.37827,-2.04747},
/*1956*/{0.2514,1.94741,-1.76367,0.298452,1.88493,-1.91977,0.192043,1.81105,-1.64349,0.143708,1.69905,-1.55688,0.260853,1.6852,-1.66812,0.339386,1.66938,-1.71684,0.195172,1.95703,-2.13569,0.29285,1.88384,-1.99328,0.084584,1.92735,-2.03204,-0.042664,1.84087,-2.15134,-0.068038,1.74739,-2.22061,0.078365,1.61748,-2.19952,0.113856,1.56169,-2.22395,0.197722,1.44466,-1.80631,0.014177,1.5156,-1.89004,0.016432,1.54323,-1.9392,0.020979,1.51591,-2.00749,0.210552,1.46613,-2.0598,0.159533,1.11589,-1.77833,0.023568,1.12311,-1.78761,0.016285,1.04028,-1.81474,0.050373,0.927843,-1.81151,-0.110373,0.856235,-1.78875,-0.183628,0.839098,-1.79215,-0.137936,0.964511,-1.79976,-0.206865,0.94735,-1.79725,-0.423455,0.857142,-1.79135,-0.459849,0.962728,-1.86334,-0.500955,0.709112,-1.85148,-0.5552,0.739182,-1.78466,0.278888,1.18231,-2.12283,0.31407,1.10668,-2.10699,0.149468,1.12209,-2.09813,0.18609,1.05019,-2.08461,0.305461,0.953041,-2.08509,0.38799,0.785914,-2.07531,0.277736,0.759052,-2.09032,0.298921,0.69245,-2.08024,0.388119,0.469487,-2.04555,0.338849,0.369108,-1.97839,0.595581,0.483738,-2.02239,0.567622,0.417218,-2.07587,0.117703,1.36148,-1.83333,0.130289,1.37487,-2.04778},
/*1957*/{0.24961,1.94349,-1.76366,0.297691,1.88141,-1.91941,0.187516,1.80733,-1.64393,0.13717,1.69538,-1.5575,0.256203,1.67926,-1.66785,0.334652,1.66175,-1.71503,0.194502,1.9528,-2.13616,0.291791,1.87963,-1.99297,0.084121,1.92341,-2.03281,-0.042893,1.83378,-2.15572,-0.065685,1.74029,-2.22434,0.08148,1.61032,-2.20275,0.117238,1.55526,-2.226,0.198047,1.44177,-1.80646,0.014138,1.51119,-1.89032,0.015207,1.53924,-1.93954,0.020127,1.51138,-2.00712,0.20996,1.46364,-2.06093,0.161946,1.11416,-1.77765,0.026676,1.11847,-1.78954,0.021362,1.03619,-1.81568,0.057611,0.924808,-1.81032,-0.103253,0.858857,-1.78639,-0.177194,0.843785,-1.78989,-0.127514,0.96712,-1.80147,-0.19739,0.952188,-1.79886,-0.414185,0.86831,-1.793,-0.450387,0.974197,-1.86774,-0.495673,0.720564,-1.84785,-0.549433,0.754056,-1.78194,0.277446,1.17891,-2.12368,0.313,1.10321,-2.10791,0.148273,1.11999,-2.09849,0.185218,1.04754,-2.08468,0.303877,0.950468,-2.08466,0.383699,0.780558,-2.07549,0.273299,0.755145,-2.08974,0.293207,0.688025,-2.07898,0.379526,0.464413,-2.04481,0.327621,0.365135,-1.9763,0.586253,0.475343,-2.02302,0.556901,0.407909,-2.07476,0.118762,1.35803,-1.83375,0.130531,1.37157,-2.04824},
/*1958*/{0.247949,1.93926,-1.76288,0.296716,1.87704,-1.91904,0.183701,1.80348,-1.64383,0.130984,1.69246,-1.55845,0.250713,1.67277,-1.66681,0.32884,1.65286,-1.71306,0.19406,1.94799,-2.13691,0.291916,1.87579,-1.993,0.082494,1.91844,-2.03559,-0.041906,1.82589,-2.15937,-0.06356,1.73279,-2.22828,0.084015,1.60347,-2.20579,0.120969,1.54875,-2.22802,0.198177,1.43873,-1.80745,0.01358,1.50661,-1.8907,0.016065,1.53518,-1.93966,0.019392,1.50646,-2.0068,0.209732,1.46038,-2.06214,0.166366,1.11201,-1.77588,0.029906,1.11416,-1.7912,0.027353,1.03081,-1.81566,0.065967,0.921704,-1.80852,-0.095803,0.861013,-1.78581,-0.169386,0.848433,-1.78974,-0.115993,0.969757,-1.80306,-0.186672,0.956593,-1.80016,-0.406402,0.879847,-1.79206,-0.440842,0.984557,-1.87096,-0.489292,0.73192,-1.84296,-0.541357,0.768555,-1.77739,0.276121,1.17571,-2.12417,0.311266,1.10098,-2.1085,0.147254,1.11665,-2.09805,0.184251,1.04397,-2.08412,0.301963,0.947357,-2.08468,0.379256,0.773896,-2.07518,0.268521,0.751144,-2.08933,0.286769,0.683558,-2.07891,0.365769,0.456876,-2.04236,0.31485,0.361206,-1.97323,0.576458,0.465694,-2.02194,0.545084,0.397323,-2.0727,0.119813,1.35429,-1.83423,0.13076,1.36776,-2.04876},
/*1959*/{0.246732,1.93487,-1.76249,0.296679,1.8728,-1.91857,0.179163,1.79973,-1.64385,0.12499,1.6889,-1.55958,0.244623,1.66646,-1.66668,0.324062,1.64372,-1.71137,0.193806,1.94342,-2.1381,0.291331,1.8712,-1.99285,0.081837,1.91272,-2.03648,-0.04077,1.81458,-2.16203,-0.061245,1.72466,-2.23237,0.086888,1.59576,-2.20833,0.124627,1.54133,-2.22963,0.199189,1.43537,-1.8088,0.012876,1.50224,-1.89059,0.01447,1.52961,-1.9396,0.01789,1.50168,-2.00654,0.208718,1.45697,-2.064,0.169288,1.10865,-1.77314,0.032615,1.10741,-1.79171,0.032876,1.02517,-1.81677,0.073469,0.918785,-1.8067,-0.086937,0.863083,-1.78413,-0.161424,0.852106,-1.78894,-0.105643,0.971802,-1.80474,-0.175647,0.961148,-1.80205,-0.398316,0.890365,-1.79211,-0.431337,0.993721,-1.87409,-0.482023,0.742306,-1.83963,-0.532222,0.780823,-1.77452,0.274412,1.17281,-2.12493,0.310051,1.09756,-2.10883,0.14608,1.11277,-2.09719,0.182839,1.03984,-2.08339,0.299789,0.942425,-2.08453,0.374209,0.767906,-2.07493,0.262933,0.746915,-2.08845,0.279879,0.679291,-2.0785,0.356998,0.452308,-2.04278,0.300308,0.358796,-1.97334,0.565146,0.455193,-2.02111,0.533488,0.388331,-2.07102,0.121198,1.35034,-1.83493,0.130205,1.36373,-2.04956},
/*1960*/{0.244947,1.92996,-1.76191,0.296741,1.86748,-1.91813,0.174973,1.79551,-1.64418,0.11938,1.68681,-1.56095,0.239201,1.65937,-1.66542,0.318147,1.63464,-1.70853,0.193679,1.93813,-2.13928,0.290285,1.86711,-1.99322,0.080919,1.90722,-2.03923,-0.039783,1.80791,-2.16735,-0.058125,1.71653,-2.23658,0.090611,1.58822,-2.21154,0.128609,1.53377,-2.23143,0.19917,1.43222,-1.81036,0.01247,1.49677,-1.88984,0.015073,1.52504,-1.93908,0.016537,1.49589,-2.00514,0.20794,1.4539,-2.0656,0.172348,1.10597,-1.77054,0.036403,1.10379,-1.79476,0.03797,1.02078,-1.81749,0.08111,0.915505,-1.80621,-0.078471,0.865164,-1.78257,-0.153387,0.856304,-1.78703,-0.093751,0.973622,-1.8067,-0.164644,0.964881,-1.80332,-0.388223,0.900423,-1.79361,-0.421886,1.00212,-1.87675,-0.472921,0.752013,-1.83616,-0.523234,0.792057,-1.77121,0.273012,1.16921,-2.12571,0.309113,1.0941,-2.10979,0.144792,1.1085,-2.09675,0.181885,1.03632,-2.08321,0.297438,0.937293,-2.08466,0.368438,0.760967,-2.07444,0.257258,0.742787,-2.08873,0.273099,0.674685,-2.07791,0.345577,0.446878,-2.04206,0.289235,0.35251,-1.97138,0.553657,0.444566,-2.01965,0.519174,0.377226,-2.06961,0.122925,1.34614,-1.8354,0.130062,1.35979,-2.05009},
/*1961*/{0.242574,1.9248,-1.76163,0.295339,1.86218,-1.91719,0.170385,1.7914,-1.64457,0.111096,1.68346,-1.56178,0.232941,1.65213,-1.66502,0.312129,1.62481,-1.70663,0.194518,1.93289,-2.14014,0.290345,1.86238,-1.99225,0.077847,1.902,-2.03903,-0.03947,1.79898,-2.17179,-0.055339,1.70794,-2.24059,0.096688,1.58091,-2.21409,0.133725,1.52672,-2.23343,0.19954,1.42882,-1.81116,0.012056,1.49189,-1.88967,0.012659,1.51975,-1.93877,0.015718,1.49114,-2.00459,0.2075,1.45079,-2.06726,0.175758,1.10264,-1.7675,0.040667,1.09811,-1.79478,0.043842,1.01422,-1.81633,0.090197,0.913148,-1.80314,-0.069762,0.866037,-1.78126,-0.14377,0.860462,-1.78486,-0.081918,0.974874,-1.80809,-0.152727,0.967736,-1.80522,-0.377382,0.909771,-1.79408,-0.411592,1.00912,-1.87892,-0.463343,0.76077,-1.83283,-0.512485,0.801553,-1.76809,0.271372,1.16485,-2.12627,0.308612,1.08874,-2.1093,0.143176,1.1046,-2.09657,0.180536,1.03208,-2.08318,0.296043,0.931307,-2.0847,0.362535,0.754731,-2.0744,0.251204,0.738436,-2.08821,0.265048,0.669892,-2.07788,0.333928,0.4411,-2.04124,0.273211,0.351112,-1.96964,0.541081,0.432893,-2.01846,0.505475,0.366764,-2.06773,0.124138,1.34203,-1.83607,0.129991,1.35608,-2.05077},
/*1962*/{0.240369,1.91942,-1.76099,0.294314,1.85719,-1.91624,0.165846,1.78703,-1.64445,0.104261,1.68015,-1.56369,0.227015,1.64496,-1.66378,0.305981,1.61514,-1.70428,0.194011,1.92714,-2.14097,0.290095,1.8574,-1.99177,0.077991,1.89638,-2.04176,-0.037384,1.78926,-2.17637,-0.05202,1.69902,-2.24455,0.099962,1.57274,-2.21611,0.13842,1.51848,-2.23515,0.200457,1.42436,-1.81321,0.011698,1.48592,-1.88948,0.014194,1.51486,-1.93888,0.014088,1.48505,-2.00451,0.206287,1.44699,-2.06934,0.178261,1.09847,-1.76529,0.043181,1.09032,-1.79607,0.049242,1.00753,-1.81773,0.098568,0.910581,-1.8016,-0.05962,0.866799,-1.78019,-0.133647,0.862137,-1.78444,-0.069594,0.974877,-1.8094,-0.14111,0.970211,-1.80657,-0.368119,0.916321,-1.79436,-0.401402,1.01608,-1.88029,-0.452413,0.767626,-1.83039,-0.501091,0.810069,-1.76559,0.269956,1.16098,-2.12693,0.306436,1.08537,-2.10989,0.141439,1.09963,-2.09637,0.179283,1.02768,-2.08263,0.293984,0.925072,-2.08421,0.357177,0.747477,-2.07435,0.244436,0.733883,-2.08812,0.257687,0.666029,-2.07754,0.321277,0.436718,-2.04011,0.25542,0.35495,-1.96754,0.526918,0.420735,-2.01639,0.487919,0.356211,-2.06656,0.125845,1.337,-1.83747,0.129564,1.35151,-2.05219},
/*1963*/{0.238628,1.91419,-1.76014,0.294549,1.85199,-1.91566,0.16121,1.78243,-1.64468,0.096952,1.67673,-1.56526,0.220734,1.63774,-1.66312,0.299327,1.6052,-1.70172,0.194273,1.92153,-2.14159,0.28983,1.85211,-1.99175,0.077048,1.88898,-2.04261,-0.036599,1.77977,-2.18106,-0.048144,1.68957,-2.24863,0.104911,1.56406,-2.21889,0.143514,1.51054,-2.23715,0.200495,1.42029,-1.81443,0.012024,1.48004,-1.88923,0.011763,1.50872,-1.93885,0.012779,1.47957,-2.00364,0.205901,1.44354,-2.07109,0.18224,1.09552,-1.76347,0.048047,1.08549,-1.7971,0.055744,1.00149,-1.81831,0.10721,0.906991,-1.80036,-0.049193,0.867911,-1.77823,-0.125212,0.864137,-1.78256,-0.056903,0.975551,-1.8105,-0.128462,0.972371,-1.80753,-0.355885,0.923514,-1.79486,-0.39057,1.02161,-1.88238,-0.441664,0.773629,-1.82841,-0.489465,0.817216,-1.76403,0.267727,1.15548,-2.12761,0.304882,1.08062,-2.11005,0.140116,1.09534,-2.0972,0.177704,1.02329,-2.0832,0.290702,0.919336,-2.08424,0.349804,0.740631,-2.07386,0.237033,0.729177,-2.08796,0.247915,0.660284,-2.07739,0.307057,0.432301,-2.03937,0.235798,0.35559,-1.96839,0.511167,0.40613,-2.01574,0.46733,0.344037,-2.06443,0.127282,1.33211,-1.83847,0.129548,1.34731,-2.05316},
/*1964*/{0.236359,1.90878,-1.75942,0.293554,1.84626,-1.91439,0.157094,1.77763,-1.64515,0.090676,1.67465,-1.56609,0.213543,1.62998,-1.66166,0.292561,1.59577,-1.69935,0.194655,1.91609,-2.14251,0.290343,1.84689,-1.99086,0.076099,1.88325,-2.04473,-0.033158,1.77032,-2.18625,-0.043924,1.68029,-2.25287,0.110275,1.55614,-2.22048,0.149089,1.50235,-2.23893,0.200459,1.41607,-1.81603,0.011794,1.4743,-1.88854,0.012681,1.50275,-1.94008,0.012127,1.4742,-2.00224,0.204969,1.43944,-2.073,0.184349,1.0913,-1.76186,0.051305,1.07699,-1.79723,0.063307,0.994406,-1.81941,0.116739,0.90411,-1.79724,-0.038044,0.867789,-1.77737,-0.113721,0.865342,-1.78155,-0.043329,0.975289,-1.81089,-0.115147,0.974028,-1.8089,-0.343768,0.928474,-1.79527,-0.378995,1.02632,-1.88355,-0.428812,0.778669,-1.82584,-0.477828,0.823681,-1.76294,0.265511,1.15001,-2.12859,0.30259,1.07543,-2.11082,0.137908,1.08925,-2.09596,0.17572,1.01772,-2.08242,0.2872,0.914385,-2.08405,0.341882,0.733695,-2.07315,0.230362,0.724299,-2.08757,0.239776,0.655375,-2.07723,0.292803,0.426172,-2.03755,0.216451,0.357759,-1.9649,0.497953,0.390877,-2.00977,0.449658,0.338943,-2.06367,0.128628,1.32715,-1.83943,0.129323,1.34261,-2.05411},
/*1965*/{0.23459,1.90271,-1.7588,0.293413,1.84047,-1.91439,0.152357,1.77308,-1.64526,0.083167,1.67182,-1.5677,0.207642,1.62311,-1.66104,0.285002,1.58604,-1.69677,0.195638,1.91064,-2.14366,0.290178,1.84125,-1.99027,0.075607,1.87565,-2.04552,-0.032698,1.76087,-2.19153,-0.03873,1.67063,-2.25671,0.115557,1.54864,-2.22284,0.155094,1.49389,-2.24047,0.200888,1.41108,-1.81776,0.010337,1.46891,-1.88915,0.012485,1.49704,-1.9401,0.010111,1.46912,-2.00256,0.204185,1.43454,-2.07518,0.188045,1.08718,-1.75962,0.057027,1.07218,-1.7975,0.069194,0.987791,-1.81952,0.125235,0.90096,-1.79583,-0.026676,0.867287,-1.77531,-0.103863,0.866449,-1.78059,-0.030534,0.973872,-1.81182,-0.102383,0.973831,-1.80912,-0.33142,0.933002,-1.79394,-0.367148,1.03019,-1.88486,-0.415922,0.783252,-1.82368,-0.464408,0.828167,-1.76115,0.262375,1.14479,-2.13037,0.299976,1.06999,-2.11311,0.135073,1.0846,-2.09666,0.172276,1.01313,-2.08263,0.282005,0.909025,-2.0847,0.33546,0.726526,-2.07202,0.222904,0.718984,-2.08707,0.231126,0.650589,-2.0766,0.276522,0.423381,-2.03067,0.194307,0.354953,-1.96644,0.476878,0.384419,-2.00135,0.427618,0.341366,-2.06426,0.12891,1.32193,-1.84084,0.128167,1.33766,-2.0555},
/*1966*/{0.232184,1.89674,-1.75793,0.292514,1.8349,-1.91285,0.147391,1.76774,-1.64566,0.075192,1.66909,-1.56953,0.200262,1.61633,-1.65938,0.277455,1.57692,-1.69374,0.196709,1.90461,-2.14424,0.290334,1.83602,-1.98927,0.074565,1.86927,-2.04741,-0.029086,1.75134,-2.19712,-0.034102,1.6606,-2.26045,0.121868,1.5403,-2.22506,0.161084,1.48612,-2.2422,0.201022,1.40554,-1.81752,0.009505,1.46298,-1.8882,0.011597,1.49036,-1.94059,0.004838,1.46805,-2.00384,0.204001,1.43025,-2.07707,0.192636,1.08298,-1.75707,0.061288,1.06502,-1.79823,0.075841,0.981587,-1.81915,0.135907,0.89719,-1.79305,-0.015946,0.866208,-1.77577,-0.091175,0.866654,-1.77821,-0.017514,0.972935,-1.81219,-0.089324,0.973953,-1.80979,-0.317965,0.936226,-1.79564,-0.35526,1.03228,-1.88583,-0.402832,0.786354,-1.82265,-0.451027,0.832107,-1.75976,0.258706,1.13917,-2.1331,0.295099,1.06426,-2.11606,0.13101,1.08098,-2.09736,0.167848,1.0085,-2.08291,0.276547,0.903298,-2.08529,0.32814,0.718692,-2.06834,0.21588,0.714308,-2.08603,0.220605,0.645229,-2.07487,0.256538,0.42385,-2.02586,0.17076,0.354463,-1.96406,0.450675,0.385526,-2.00529,0.404142,0.341801,-2.06429,0.128013,1.31634,-1.84268,0.126493,1.334,-2.05719},
/*1967*/{0.230487,1.89141,-1.75716,0.292605,1.82899,-1.91127,0.14259,1.76274,-1.646,0.068486,1.66612,-1.57075,0.192961,1.60867,-1.65843,0.269269,1.56815,-1.69099,0.197517,1.89958,-2.14509,0.290124,1.83008,-1.98917,0.074469,1.86299,-2.04807,-0.026116,1.74172,-2.20396,-0.027373,1.6509,-2.26398,0.127017,1.53217,-2.22665,0.167586,1.47798,-2.24402,0.200463,1.40081,-1.81986,0.008292,1.4579,-1.8879,0.009608,1.4842,-1.94015,0.003913,1.46373,-2.00399,0.201893,1.42525,-2.0783,0.198425,1.07869,-1.75714,0.068134,1.05798,-1.79727,0.083135,0.974968,-1.81882,0.146936,0.893956,-1.79096,-0.003811,0.864782,-1.77486,-0.080084,0.86543,-1.77774,-0.00363,0.970943,-1.81133,-0.075235,0.973178,-1.80878,-0.304748,0.937905,-1.7954,-0.341973,1.03467,-1.88591,-0.389475,0.788226,-1.82095,-0.436137,0.834515,-1.75823,0.253707,1.13437,-2.13771,0.289818,1.059,-2.12044,0.126514,1.07921,-2.09719,0.162451,1.00583,-2.08153,0.269998,0.896624,-2.08601,0.321243,0.712168,-2.06386,0.210147,0.71125,-2.08453,0.212715,0.64231,-2.06942,0.229239,0.424403,-2.01989,0.148001,0.354854,-1.96408,0.429044,0.383466,-1.99798,0.380302,0.341801,-2.0636,0.127635,1.31121,-1.8438,0.124533,1.32918,-2.05826},
/*1968*/{0.228839,1.88599,-1.75621,0.29204,1.82252,-1.91076,0.138093,1.75889,-1.64677,0.060719,1.66393,-1.57275,0.18562,1.60245,-1.65718,0.261045,1.56061,-1.68804,0.198099,1.89411,-2.14707,0.291037,1.82443,-1.9878,0.074604,1.85974,-2.04844,-0.020351,1.73182,-2.20913,-0.021061,1.64077,-2.26746,0.134312,1.52389,-2.2284,0.174613,1.46966,-2.24498,0.200324,1.39491,-1.82052,0.006926,1.45255,-1.88727,0.006936,1.47923,-1.93996,0.002383,1.45958,-2.00436,0.199653,1.42058,-2.0786,0.202627,1.07522,-1.75603,0.072684,1.0494,-1.79666,0.092369,0.968545,-1.8183,0.158676,0.889978,-1.78855,0.008686,0.863491,-1.77188,-0.067358,0.865,-1.7773,0.010556,0.969536,-1.8108,-0.061129,0.971669,-1.80853,-0.28904,0.938795,-1.79515,-0.329262,1.03529,-1.88624,-0.374016,0.789089,-1.82029,-0.422586,0.835549,-1.75808,0.248846,1.13099,-2.14283,0.284393,1.05452,-2.12607,0.122713,1.07838,-2.09668,0.158441,1.00532,-2.08165,0.263713,0.891779,-2.08764,0.314134,0.708549,-2.05914,0.203435,0.7131,-2.08126,0.202135,0.645515,-2.06561,0.209577,0.426978,-2.01753,0.123836,0.355519,-1.96077,0.406521,0.381935,-2.00083,0.357276,0.342721,-2.06233,0.126372,1.30568,-1.84473,0.122376,1.32468,-2.05908},
/*1969*/{0.226696,1.88079,-1.75558,0.291691,1.8174,-1.90911,0.132733,1.75426,-1.64754,0.052495,1.66141,-1.57459,0.178126,1.59685,-1.65572,0.252592,1.55281,-1.68521,0.198971,1.8889,-2.14796,0.29223,1.81937,-1.98765,0.075576,1.85624,-2.04841,-0.015111,1.72437,-2.21739,-0.013359,1.63028,-2.27077,0.141857,1.5159,-2.23069,0.182268,1.46139,-2.24608,0.200177,1.39005,-1.82262,0.005351,1.44777,-1.8875,0.004641,1.47374,-1.93832,0.002739,1.45283,-2.00264,0.196819,1.41757,-2.07992,0.20891,1.07127,-1.75578,0.079727,1.04237,-1.79624,0.100697,0.962471,-1.81798,0.170703,0.885112,-1.78623,0.022119,0.860661,-1.7707,-0.05335,0.863396,-1.77611,0.02427,0.96694,-1.80993,-0.046933,0.969992,-1.80652,-0.275357,0.938881,-1.79571,-0.315876,1.03515,-1.88665,-0.358824,0.788545,-1.81929,-0.406983,0.834407,-1.75737,0.24597,1.12803,-2.14619,0.280682,1.05149,-2.1285,0.119584,1.07826,-2.0969,0.154731,1.00457,-2.08194,0.258743,0.890285,-2.08772,0.304919,0.707784,-2.05605,0.194896,0.718327,-2.0786,0.189138,0.650028,-2.06387,0.194323,0.428906,-2.01547,0.10122,0.357116,-1.95858,0.383905,0.382397,-1.99668,0.333194,0.341784,-2.0614,0.127093,1.30054,-1.84588,0.12096,1.32059,-2.06009},
/*1970*/{0.225254,1.87627,-1.75424,0.291668,1.81084,-1.90761,0.128202,1.75068,-1.6478,0.04536,1.65981,-1.57626,0.171086,1.59137,-1.65542,0.244512,1.5461,-1.68269,0.200349,1.88444,-2.1493,0.29219,1.81366,-1.98659,0.076293,1.85312,-2.04851,-0.00867,1.71443,-2.22437,-0.004305,1.62041,-2.27461,0.149789,1.50849,-2.23224,0.190794,1.45464,-2.24698,0.199115,1.38478,-1.82478,0.002013,1.44339,-1.88737,0.001717,1.46955,-1.93732,-0.000577,1.44944,-2.00292,0.194351,1.41417,-2.0811,0.217571,1.06938,-1.75588,0.088035,1.03779,-1.79522,0.111058,0.956028,-1.81628,0.183441,0.879976,-1.78453,0.03506,0.857167,-1.77055,-0.039563,0.86021,-1.77732,0.038509,0.964174,-1.808,-0.033228,0.966691,-1.80565,-0.261318,0.937347,-1.7951,-0.304045,1.03395,-1.88624,-0.342827,0.786268,-1.81847,-0.390748,0.832072,-1.75585,0.242577,1.12661,-2.14703,0.278422,1.05088,-2.12778,0.117125,1.07716,-2.09753,0.1526,1.00331,-2.08133,0.256573,0.890198,-2.08774,0.294894,0.707815,-2.05505,0.183814,0.723712,-2.07721,0.175164,0.655162,-2.06314,0.170534,0.430719,-2.01313,0.079033,0.357745,-1.95623,0.361939,0.380686,-1.99745,0.310953,0.342681,-2.05967,0.125039,1.29557,-1.8478,0.117619,1.31742,-2.06179},
/*1971*/{0.223862,1.87186,-1.75302,0.291773,1.80653,-1.90676,0.123673,1.74776,-1.64869,0.037383,1.65862,-1.5784,0.163331,1.58698,-1.6549,0.235455,1.54045,-1.67987,0.201157,1.87957,-2.15086,0.2921,1.8088,-1.98528,0.076679,1.85116,-2.04876,-0.000569,1.70514,-2.23078,0.004315,1.61067,-2.27713,0.158616,1.50149,-2.23346,0.19978,1.44864,-2.24682,0.197532,1.3805,-1.82748,0.000643,1.43956,-1.88734,0.000487,1.46719,-1.93772,-0.003214,1.44687,-2.00212,0.192162,1.41177,-2.08231,0.222844,1.06837,-1.75628,0.094237,1.03068,-1.79486,0.119404,0.952846,-1.81557,0.196356,0.877204,-1.78341,0.048753,0.854028,-1.77118,-0.025843,0.856233,-1.77824,0.052095,0.961404,-1.80599,-0.019524,0.964925,-1.80426,-0.246552,0.935291,-1.79419,-0.293054,1.03164,-1.88543,-0.326167,0.783179,-1.8187,-0.372789,0.827505,-1.75587,0.238431,1.12631,-2.14568,0.27533,1.05097,-2.12713,0.113623,1.07462,-2.09755,0.150222,1.00197,-2.08163,0.256692,0.89041,-2.08632,0.282864,0.707568,-2.05681,0.172177,0.727198,-2.07592,0.16178,0.65899,-2.06305,0.151739,0.430118,-2.01146,0.057887,0.357974,-1.95651,0.340368,0.380545,-1.9956,0.290543,0.342773,-2.05947,0.123451,1.29149,-1.84997,0.114741,1.31522,-2.06372},
/*1972*/{0.222519,1.86808,-1.75134,0.291199,1.80264,-1.90572,0.117911,1.7456,-1.64984,0.02915,1.65838,-1.58044,0.155508,1.58372,-1.65452,0.227556,1.53574,-1.67757,0.203705,1.87539,-2.15086,0.29255,1.80399,-1.98437,0.077131,1.84863,-2.04919,0.006694,1.69677,-2.2358,0.013759,1.6013,-2.27902,0.16686,1.49524,-2.2337,0.209175,1.44319,-2.24655,0.19487,1.37546,-1.82726,-0.002008,1.43634,-1.88602,-0.001448,1.46673,-1.93734,-0.005351,1.44509,-2.00102,0.189899,1.40971,-2.08342,0.229623,1.07088,-1.75715,0.102579,1.02725,-1.79187,0.129853,0.950284,-1.81366,0.20989,0.872702,-1.78295,0.062295,0.85145,-1.77182,-0.013708,0.854045,-1.77852,0.065506,0.960167,-1.80379,-0.005866,0.963122,-1.80354,-0.235479,0.934185,-1.79801,-0.282975,1.02796,-1.88416,-0.306778,0.778669,-1.81834,-0.355674,0.820617,-1.75461,0.235559,1.1263,-2.14507,0.272007,1.05034,-2.12793,0.110283,1.07266,-2.09738,0.146508,1.00094,-2.08169,0.257156,0.890401,-2.08478,0.270377,0.70553,-2.05934,0.159981,0.729315,-2.0765,0.148414,0.661033,-2.06263,0.132447,0.431381,-2.01199,0.035782,0.361087,-1.95615,0.318815,0.379774,-1.99635,0.267465,0.342059,-2.05931,0.119943,1.28748,-1.85119,0.111147,1.31366,-2.06465},
/*1973*/{0.221818,1.86446,-1.75016,0.290714,1.79876,-1.90409,0.112277,1.74437,-1.65039,0.021349,1.65903,-1.58348,0.147435,1.58176,-1.6542,0.217695,1.53071,-1.67562,0.20594,1.87206,-2.1506,0.292716,1.80095,-1.98322,0.077051,1.84684,-2.04928,0.013279,1.68829,-2.24015,0.023567,1.59306,-2.28085,0.177557,1.49018,-2.2334,0.220555,1.43988,-2.24528,0.193511,1.37119,-1.82899,-0.00309,1.4335,-1.88497,-0.003035,1.46557,-1.93709,-0.007045,1.44377,-1.99922,0.187365,1.40846,-2.08522,0.237486,1.07362,-1.75885,0.109807,1.02702,-1.79089,0.140992,0.949266,-1.81214,0.223603,0.872161,-1.78365,0.075221,0.848863,-1.77257,0.00055,0.852413,-1.78052,0.079328,0.958363,-1.80193,0.008614,0.96112,-1.80204,-0.221875,0.929266,-1.79799,-0.273715,1.02317,-1.88171,-0.289336,0.771983,-1.81986,-0.337518,0.812567,-1.75376,0.231076,1.12418,-2.14492,0.266856,1.04815,-2.1286,0.105184,1.07115,-2.09739,0.142592,0.996212,-2.0804,0.256025,0.891134,-2.08275,0.257232,0.703091,-2.06313,0.14639,0.728192,-2.07773,0.133863,0.660742,-2.06324,0.110268,0.431069,-2.01134,0.01352,0.359823,-1.95629,0.297001,0.378417,-1.99638,0.245376,0.341833,-2.05895,0.118203,1.28389,-1.85333,0.107819,1.31269,-2.06638},
/*1974*/{0.221105,1.86196,-1.7493,0.289363,1.79586,-1.90321,0.107606,1.74419,-1.65141,0.012969,1.66104,-1.58723,0.140201,1.58009,-1.65362,0.210117,1.52781,-1.67376,0.207039,1.86953,-2.15014,0.29234,1.79838,-1.98191,0.078065,1.84567,-2.0498,0.020429,1.68134,-2.24275,0.033398,1.58599,-2.28202,0.187534,1.48694,-2.23273,0.232225,1.43748,-2.24364,0.192547,1.36828,-1.83058,-0.005359,1.43236,-1.88355,-0.004443,1.46451,-1.93693,-0.008844,1.44269,-1.99696,0.185106,1.4078,-2.08681,0.24353,1.07854,-1.75899,0.121182,1.02737,-1.78806,0.152854,0.949772,-1.80865,0.237227,0.872551,-1.78382,0.088983,0.846569,-1.77307,0.014186,0.850417,-1.78095,0.091481,0.958319,-1.79997,0.020206,0.960045,-1.80139,-0.20705,0.92168,-1.79675,-0.265797,1.01703,-1.88113,-0.270372,0.764481,-1.82098,-0.319185,0.802566,-1.7534,0.225532,1.12164,-2.14564,0.261186,1.04539,-2.12856,0.100043,1.06813,-2.09633,0.135681,0.995061,-2.08065,0.249549,0.89082,-2.08242,0.242502,0.701005,-2.06555,0.133956,0.727606,-2.07923,0.118615,0.660658,-2.06422,0.093332,0.431896,-2.01206,-0.009506,0.361505,-1.95697,0.275087,0.37761,-1.99579,0.222851,0.341326,-2.05957,0.116671,1.2816,-1.8547,0.104634,1.31214,-2.06741},
/*1975*/{0.219961,1.85956,-1.7487,0.289657,1.79483,-1.90212,0.101996,1.74488,-1.65293,0.005294,1.66411,-1.59014,0.131587,1.57946,-1.65291,0.202059,1.52591,-1.67196,0.209495,1.8668,-2.1487,0.292372,1.79641,-1.98114,0.078232,1.84392,-2.05029,0.027964,1.67624,-2.24399,0.042073,1.58077,-2.28279,0.197581,1.4847,-2.23079,0.243846,1.43666,-2.24126,0.190012,1.36553,-1.83041,-0.006265,1.43098,-1.88243,-0.005577,1.46376,-1.93675,-0.010437,1.44199,-1.995,0.183613,1.40735,-2.08853,0.250361,1.0841,-1.76077,0.129133,1.02645,-1.78679,0.164205,0.950707,-1.80669,0.252446,0.87653,-1.78529,0.103682,0.846531,-1.77358,0.029251,0.847214,-1.78204,0.10336,0.957924,-1.79786,0.031993,0.958806,-1.8,-0.194111,0.915651,-1.7974,-0.258684,1.00968,-1.87874,-0.250832,0.756076,-1.82237,-0.299243,0.790688,-1.75425,0.220656,1.11869,-2.14681,0.254326,1.0415,-2.12916,0.093215,1.06693,-2.09636,0.129068,0.993373,-2.08043,0.23897,0.88618,-2.08435,0.2293,0.694892,-2.06655,0.120053,0.725637,-2.08096,0.10463,0.659038,-2.06472,0.069827,0.432248,-2.01361,-0.03025,0.361763,-1.95753,0.254027,0.376733,-1.99641,0.20077,0.341486,-2.06003,0.114625,1.27939,-1.85566,0.102132,1.31176,-2.06808},
/*1976*/{0.219018,1.85839,-1.74819,0.287869,1.79333,-1.90107,0.09661,1.74677,-1.65401,-0.001141,1.6674,-1.59404,0.123752,1.57951,-1.65316,0.192009,1.5248,-1.67106,0.211474,1.86557,-2.14809,0.292171,1.79464,-1.97927,0.078731,1.84307,-2.05107,0.034532,1.67157,-2.24461,0.050164,1.57629,-2.28306,0.208585,1.48385,-2.22855,0.255657,1.43729,-2.23852,0.188403,1.36363,-1.83068,-0.0073,1.43049,-1.88259,-0.007558,1.4634,-1.93632,-0.011669,1.44244,-1.99433,0.181728,1.40696,-2.08974,0.259072,1.09009,-1.76242,0.140086,1.02925,-1.78559,0.176309,0.953404,-1.80432,0.267251,0.879496,-1.78581,0.115943,0.846769,-1.77513,0.041287,0.845197,-1.78298,0.114742,0.958431,-1.79557,0.04278,0.956976,-1.79817,-0.179671,0.907164,-1.79726,-0.251458,1.00002,-1.87694,-0.230319,0.747775,-1.82513,-0.278155,0.778093,-1.75411,0.215105,1.11573,-2.14759,0.247465,1.03764,-2.13047,0.088375,1.06563,-2.09655,0.121064,0.990652,-2.08078,0.227846,0.88189,-2.08528,0.215465,0.690614,-2.0659,0.107818,0.723202,-2.08208,0.089215,0.657709,-2.06635,0.047458,0.432577,-2.0152,-0.051076,0.361332,-1.95821,0.231629,0.376563,-1.99755,0.17887,0.340811,-2.06073,0.112537,1.27808,-1.85673,0.099638,1.31177,-2.06892},
/*1977*/{0.218436,1.85779,-1.74751,0.287249,1.79208,-1.89964,0.091468,1.74854,-1.65512,-0.008879,1.6715,-1.59756,0.115865,1.58048,-1.65331,0.184599,1.52487,-1.66995,0.213696,1.8641,-2.14673,0.292312,1.79388,-1.97854,0.079608,1.8428,-2.05117,0.040703,1.66835,-2.24453,0.058696,1.57308,-2.28288,0.21874,1.48326,-2.22556,0.267652,1.43963,-2.23424,0.187053,1.36298,-1.82951,-0.009343,1.43103,-1.88215,-0.00849,1.46313,-1.93635,-0.01202,1.44179,-1.99412,0.180536,1.40644,-2.09097,0.265823,1.09606,-1.76243,0.148376,1.03107,-1.78492,0.187535,0.956964,-1.80367,0.28265,0.885706,-1.78651,0.129718,0.847679,-1.77576,0.054758,0.844545,-1.78432,0.125007,0.959039,-1.79481,0.053573,0.955931,-1.79659,-0.166603,0.901202,-1.79815,-0.244581,0.989877,-1.87574,-0.209777,0.737778,-1.827,-0.258037,0.765362,-1.75447,0.208508,1.11301,-2.14934,0.239956,1.03342,-2.13134,0.080653,1.06579,-2.0973,0.112809,0.991107,-2.08364,0.215707,0.878094,-2.08687,0.200013,0.685122,-2.06599,0.093446,0.721318,-2.08272,0.07383,0.655832,-2.06693,0.025794,0.432157,-2.0164,-0.073699,0.36347,-1.95888,0.210304,0.376672,-1.99857,0.15672,0.340433,-2.06231,0.110969,1.27782,-1.85633,0.098234,1.31115,-2.06859},
/*1978*/{0.216513,1.85804,-1.74697,0.286245,1.79101,-1.89908,0.086454,1.75096,-1.65628,-0.016142,1.67687,-1.60137,0.108393,1.5826,-1.65321,0.176146,1.52592,-1.66858,0.216096,1.86363,-2.14615,0.292036,1.79335,-1.97695,0.080774,1.843,-2.05196,0.047781,1.66586,-2.24378,0.067671,1.57055,-2.28295,0.229937,1.48622,-2.22214,0.280009,1.44314,-2.23001,0.185124,1.36322,-1.82832,-0.009388,1.43102,-1.8821,-0.008529,1.46304,-1.93677,-0.012636,1.44242,-1.99449,0.18024,1.40646,-2.09167,0.275737,1.10168,-1.76242,0.158116,1.03473,-1.78403,0.198569,0.961069,-1.80317,0.29604,0.892013,-1.78778,0.144465,0.848408,-1.77773,0.069295,0.843371,-1.78586,0.135338,0.96038,-1.79328,0.064197,0.954553,-1.79503,-0.154249,0.891238,-1.80016,-0.237963,0.977873,-1.87458,-0.188136,0.727342,-1.82853,-0.237316,0.752035,-1.75522,0.20251,1.10931,-2.14944,0.231038,1.02959,-2.1322,0.073017,1.06525,-2.09843,0.104679,0.990556,-2.08505,0.202946,0.874127,-2.0875,0.183662,0.682021,-2.06627,0.079713,0.718787,-2.08285,0.057476,0.654339,-2.06796,0.007126,0.433694,-2.01772,-0.095392,0.364032,-1.95907,0.188511,0.376002,-1.99875,0.135983,0.339838,-2.06245,0.109842,1.27795,-1.85618,0.097824,1.31119,-2.06849},
/*1979*/{0.214259,1.85883,-1.74632,0.2857,1.79069,-1.89707,0.08195,1.75422,-1.65816,-0.023056,1.6803,-1.60424,0.101041,1.58548,-1.65351,0.16849,1.52738,-1.66721,0.21906,1.86392,-2.14494,0.292249,1.79327,-1.97614,0.0811,1.84396,-2.05238,0.052749,1.66338,-2.24281,0.076014,1.56847,-2.28231,0.239999,1.4888,-2.21777,0.291772,1.4482,-2.22487,0.182984,1.36399,-1.82632,-0.010278,1.43133,-1.88302,-0.009615,1.46331,-1.93723,-0.013865,1.44298,-1.99522,0.179617,1.40627,-2.09232,0.282103,1.1088,-1.76265,0.166767,1.03783,-1.78325,0.209645,0.965025,-1.80266,0.309861,0.90016,-1.78931,0.158043,0.850623,-1.77856,0.083222,0.841909,-1.7888,0.144971,0.961439,-1.79253,0.074461,0.954119,-1.79435,-0.142179,0.880924,-1.80081,-0.230666,0.964875,-1.87453,-0.166575,0.717528,-1.82984,-0.215853,0.73824,-1.75616,0.19607,1.1066,-2.14935,0.222738,1.02674,-2.13304,0.064749,1.06649,-2.10009,0.093293,0.988434,-2.08529,0.189492,0.869728,-2.0875,0.168677,0.67738,-2.06509,0.064427,0.716737,-2.08333,0.041193,0.651989,-2.06831,-0.011339,0.434344,-2.01748,-0.120506,0.368109,-1.96249,0.167577,0.375264,-1.99926,0.11376,0.339658,-2.0637,0.108097,1.27862,-1.85555,0.097184,1.31103,-2.06805},
/*1980*/{0.212283,1.86053,-1.74526,0.284556,1.79217,-1.8961,0.076159,1.75776,-1.65898,-0.029621,1.68586,-1.60771,0.094519,1.58867,-1.65375,0.160175,1.53053,-1.66716,0.221286,1.86503,-2.14396,0.291227,1.79362,-1.97444,0.082529,1.84481,-2.05396,0.057196,1.66198,-2.24211,0.084818,1.56702,-2.28172,0.249856,1.49315,-2.21372,0.303169,1.45464,-2.21941,0.182238,1.36579,-1.8257,-0.010484,1.43234,-1.88426,-0.009928,1.46353,-1.9386,-0.013789,1.44296,-1.99572,0.180015,1.40624,-2.09282,0.288392,1.11718,-1.76315,0.175252,1.04259,-1.78342,0.220454,0.970887,-1.80274,0.321889,0.90779,-1.78955,0.171864,0.852355,-1.78026,0.096644,0.840622,-1.78699,0.15479,0.962694,-1.79072,0.082366,0.951296,-1.79391,-0.128192,0.870397,-1.80202,-0.222889,0.950057,-1.87338,-0.14468,0.706605,-1.83132,-0.194205,0.72462,-1.75652,0.18935,1.10424,-2.14975,0.213021,1.0228,-2.1332,0.056894,1.06693,-2.10171,0.082603,0.989376,-2.08754,0.174105,0.864711,-2.0883,0.152147,0.673462,-2.06385,0.048066,0.715086,-2.08378,0.023616,0.651273,-2.06832,-0.032471,0.435491,-2.01744,-0.135742,0.366187,-1.95948,0.145446,0.374919,-2.00026,0.091961,0.339802,-2.06331,0.107986,1.28001,-1.85494,0.097802,1.31083,-2.06771},
/*1981*/{0.209321,1.86269,-1.74497,0.284888,1.79298,-1.89461,0.071841,1.76178,-1.66045,-0.036285,1.69099,-1.61084,0.086723,1.59274,-1.655,0.152721,1.53358,-1.66687,0.223552,1.86643,-2.14245,0.29155,1.79495,-1.97263,0.083299,1.84575,-2.05444,0.061845,1.66013,-2.24045,0.093316,1.56697,-2.28128,0.259169,1.49854,-2.20897,0.314372,1.4621,-2.21368,0.181118,1.36801,-1.82507,-0.010678,1.43379,-1.88592,-0.010012,1.46418,-1.93942,-0.013879,1.44422,-1.99729,0.179325,1.40586,-2.09346,0.292648,1.12543,-1.76562,0.180162,1.04617,-1.78489,0.230042,0.976838,-1.80337,0.334488,0.916651,-1.79044,0.185801,0.854633,-1.78103,0.111331,0.838879,-1.78865,0.162764,0.964164,-1.79111,0.092356,0.950778,-1.79296,-0.116083,0.860431,-1.80259,-0.21528,0.934679,-1.87372,-0.122455,0.696146,-1.8322,-0.172408,0.710757,-1.75857,0.181605,1.10196,-2.14948,0.203975,1.01981,-2.13372,0.048222,1.07107,-2.10364,0.072444,0.99033,-2.08792,0.15918,0.861049,-2.08843,0.134901,0.671146,-2.06348,0.03201,0.713637,-2.08364,0.005721,0.649972,-2.06896,-0.056043,0.436251,-2.01891,-0.158575,0.367817,-1.95941,0.123728,0.375556,-2.00106,0.070388,0.341251,-2.06518,0.107133,1.28184,-1.85437,0.09755,1.31077,-2.06744},
/*1982*/{0.206452,1.86515,-1.74438,0.282687,1.79391,-1.89234,0.066383,1.76623,-1.66128,-0.043648,1.69653,-1.61388,0.081085,1.59792,-1.65667,0.145835,1.53831,-1.66749,0.225031,1.86866,-2.14102,0.291204,1.79601,-1.97112,0.084323,1.84658,-2.05513,0.066937,1.6589,-2.23915,0.102339,1.56739,-2.27979,0.268992,1.50531,-2.20395,0.325491,1.47049,-2.20798,0.179525,1.36983,-1.82341,-0.011046,1.43433,-1.8866,-0.010374,1.46538,-1.94024,-0.013319,1.44452,-1.99837,0.179139,1.4056,-2.09368,0.299753,1.13227,-1.76443,0.194806,1.05193,-1.78301,0.238433,0.981503,-1.80345,0.345556,0.924735,-1.79153,0.198655,0.856993,-1.7825,0.125295,0.839244,-1.79051,0.170933,0.965328,-1.79048,0.100266,0.948737,-1.79311,-0.102146,0.848239,-1.80491,-0.206123,0.918127,-1.87459,-0.100146,0.685206,-1.8336,-0.151102,0.696921,-1.75986,0.174494,1.09967,-2.14949,0.192985,1.01719,-2.13307,0.039964,1.07022,-2.10273,0.059833,0.993946,-2.0898,0.143501,0.85717,-2.08838,0.117358,0.671842,-2.06472,0.014726,0.714509,-2.08364,-0.010792,0.650681,-2.0687,-0.077533,0.43834,-2.01944,-0.180555,0.36825,-1.96258,0.102335,0.375413,-2.00068,0.050442,0.340548,-2.0636,0.106177,1.28326,-1.8533,0.097803,1.31058,-2.06663},
/*1983*/{0.203458,1.86777,-1.74414,0.280989,1.79721,-1.89044,0.061908,1.77025,-1.66295,-0.050443,1.70101,-1.61697,0.073822,1.60364,-1.65827,0.139306,1.5441,-1.66807,0.22669,1.87185,-2.13964,0.291117,1.79845,-1.96877,0.084501,1.84852,-2.05545,0.070571,1.65848,-2.23744,0.110127,1.56782,-2.27897,0.277971,1.5123,-2.19825,0.33609,1.48,-2.20169,0.178807,1.37258,-1.82361,-0.01156,1.43607,-1.88811,-0.009882,1.46656,-1.94222,-0.013224,1.44591,-2.00086,0.17878,1.4055,-2.09422,0.304235,1.14002,-1.76553,0.20101,1.05713,-1.78332,0.247819,0.987742,-1.80518,0.356951,0.934931,-1.7916,0.212272,0.859061,-1.78254,0.139478,0.838278,-1.7921,0.178731,0.965963,-1.79026,0.108965,0.945074,-1.7928,-0.089919,0.83846,-1.80419,-0.19644,0.901198,-1.87522,-0.077164,0.675031,-1.83398,-0.129417,0.683126,-1.76086,0.166238,1.09858,-2.14898,0.183721,1.01495,-2.13143,0.030825,1.07266,-2.10337,0.048804,0.99246,-2.08857,0.125603,0.856514,-2.08845,0.100017,0.66996,-2.06244,-0.002643,0.716782,-2.08348,-0.027745,0.652082,-2.06763,-0.097457,0.439255,-2.02019,-0.200075,0.369149,-1.96419,0.081081,0.375374,-2.00156,0.027314,0.340001,-2.06435,0.10554,1.28557,-1.85311,0.097936,1.31078,-2.06672},
/*1984*/{0.200501,1.87108,-1.74421,0.282112,1.8005,-1.88859,0.057301,1.77495,-1.66419,-0.056401,1.70742,-1.61952,0.067929,1.60959,-1.65969,0.132777,1.54947,-1.66895,0.227938,1.87499,-2.13863,0.291725,1.80108,-1.96756,0.085088,1.84945,-2.05651,0.075695,1.65883,-2.23489,0.118241,1.56923,-2.27746,0.287311,1.52123,-2.19386,0.345602,1.48987,-2.19506,0.178383,1.37561,-1.82314,-0.011489,1.43767,-1.88986,-0.009376,1.4683,-1.9435,-0.013186,1.44802,-2.00217,0.179694,1.40507,-2.09452,0.309554,1.1477,-1.76573,0.205806,1.06075,-1.78533,0.256859,0.995031,-1.80621,0.365754,0.943594,-1.79301,0.224103,0.86127,-1.78356,0.152913,0.837257,-1.79168,0.1859,0.966627,-1.79029,0.117604,0.942511,-1.79285,-0.075861,0.827828,-1.8047,-0.185887,0.883326,-1.87712,-0.053593,0.664016,-1.83506,-0.108205,0.668699,-1.76215,0.158896,1.09709,-2.1479,0.173048,1.01371,-2.13075,0.021647,1.07593,-2.10369,0.037868,0.995978,-2.08931,0.10851,0.857503,-2.08851,0.081226,0.670776,-2.06159,-0.019456,0.718715,-2.08214,-0.047099,0.654738,-2.06657,-0.116386,0.442136,-2.01632,-0.223067,0.372027,-1.96067,0.060291,0.375002,-2.00124,0.006113,0.340448,-2.06543,0.105069,1.2881,-1.85235,0.098444,1.31115,-2.06624},
/*1985*/{0.197527,1.87451,-1.74324,0.280504,1.80323,-1.88724,0.051969,1.7798,-1.66557,-0.06271,1.71323,-1.62311,0.060729,1.61543,-1.66215,0.12654,1.55552,-1.67008,0.229515,1.87897,-2.1373,0.290972,1.80409,-1.96545,0.08565,1.85163,-2.05705,0.080089,1.65967,-2.23276,0.125858,1.5711,-2.27653,0.294963,1.52864,-2.18807,0.355471,1.50061,-2.18851,0.179198,1.37887,-1.82355,-0.011148,1.43983,-1.89078,-0.00864,1.47029,-1.9448,-0.01194,1.44971,-2.00345,0.180119,1.40517,-2.09501,0.312309,1.15535,-1.76642,0.212722,1.0663,-1.78577,0.263749,1.00237,-1.8081,0.374255,0.953268,-1.7939,0.236724,0.863986,-1.78375,0.167095,0.836584,-1.79236,0.192578,0.967,-1.79038,0.12686,0.93977,-1.79278,-0.062302,0.813509,-1.80525,-0.174933,0.864535,-1.87877,-0.0316,0.653532,-1.83562,-0.085969,0.654488,-1.76318,0.151388,1.09671,-2.14621,0.162562,1.01252,-2.12852,0.01304,1.07973,-2.10429,0.026117,0.998468,-2.08964,0.092282,0.859585,-2.08804,0.063256,0.673152,-2.06164,-0.038,0.72156,-2.0814,-0.065059,0.658463,-2.06696,-0.135922,0.444096,-2.01976,-0.242635,0.375572,-1.96436,0.038994,0.375612,-2.00204,-0.015162,0.340067,-2.06481,0.105659,1.29095,-1.85177,0.099087,1.31175,-2.06589},
/*1986*/{0.194325,1.87817,-1.74322,0.280214,1.80535,-1.88509,0.047904,1.7851,-1.66731,-0.068525,1.71872,-1.62579,0.056263,1.62213,-1.66407,0.119737,1.56138,-1.67044,0.230124,1.88288,-2.13556,0.290589,1.80738,-1.96282,0.086952,1.85306,-2.0578,0.082999,1.66105,-2.23058,0.133707,1.57346,-2.27525,0.303422,1.53859,-2.18322,0.364695,1.51106,-2.18127,0.179098,1.38186,-1.82309,-0.011148,1.44256,-1.89325,-0.008555,1.47286,-1.94587,-0.010438,1.45258,-2.00575,0.18133,1.40571,-2.09509,0.316667,1.16298,-1.76649,0.217605,1.07184,-1.78737,0.27138,1.00941,-1.80931,0.382954,0.963725,-1.79398,0.248065,0.866406,-1.7838,0.180709,0.834894,-1.79276,0.199511,0.966958,-1.79095,0.134849,0.935711,-1.79296,-0.049029,0.800625,-1.80679,-0.162704,0.845385,-1.8807,-0.008303,0.642943,-1.83595,-0.063501,0.640594,-1.76474,0.143528,1.09671,-2.14484,0.152428,1.0126,-2.127,0.003532,1.08342,-2.10487,0.014402,1.00345,-2.09092,0.075476,0.861506,-2.08676,0.044769,0.675417,-2.06063,-0.05566,0.724233,-2.08097,-0.084671,0.661461,-2.0663,-0.155709,0.448031,-2.019,-0.26306,0.380934,-1.96404,0.016484,0.375365,-2.00167,-0.036427,0.340634,-2.06437,0.104941,1.29389,-1.85153,0.100012,1.31311,-2.06585},
/*1987*/{0.19141,1.88181,-1.74304,0.279321,1.80915,-1.88371,0.043026,1.79035,-1.66835,-0.073453,1.72513,-1.62911,0.051057,1.6283,-1.66625,0.115787,1.56819,-1.67188,0.231379,1.88741,-2.13478,0.290596,1.81122,-1.9617,0.086817,1.85556,-2.05842,0.087585,1.66272,-2.22836,0.141459,1.57604,-2.27407,0.310344,1.54658,-2.17765,0.372827,1.52191,-2.17447,0.179341,1.38581,-1.82406,-0.01096,1.44574,-1.89431,-0.007234,1.47457,-1.94745,-0.009559,1.45413,-2.00724,0.181384,1.4058,-2.09603,0.31938,1.17038,-1.76716,0.222475,1.07599,-1.78875,0.277727,1.01515,-1.81127,0.390273,0.973277,-1.79485,0.258861,0.868554,-1.78449,0.19266,0.833025,-1.79263,0.205595,0.966104,-1.79155,0.141364,0.931359,-1.79535,-0.034633,0.78825,-1.80696,-0.150858,0.82604,-1.88328,0.015828,0.632039,-1.83624,-0.040937,0.627314,-1.76506,0.135647,1.09619,-2.14385,0.142158,1.0122,-2.12473,-0.003133,1.0879,-2.10498,0.004223,1.00613,-2.09038,0.059919,0.86402,-2.08555,0.026224,0.677666,-2.0601,-0.074486,0.72793,-2.08038,-0.102684,0.665131,-2.06546,-0.176438,0.451689,-2.01938,-0.283065,0.385251,-1.9663,-0.004856,0.375068,-2.00167,-0.058786,0.340455,-2.06352,0.105431,1.29734,-1.85092,0.100284,1.31363,-2.06548},
/*1988*/{0.188033,1.88571,-1.74299,0.278102,1.81463,-1.88221,0.039401,1.79537,-1.66925,-0.079179,1.73155,-1.6317,0.046006,1.63571,-1.66815,0.109757,1.57492,-1.67357,0.231466,1.89201,-2.13376,0.290794,1.81483,-1.95964,0.087738,1.85802,-2.05842,0.09261,1.66465,-2.22649,0.149309,1.5795,-2.2729,0.316738,1.55587,-2.1724,0.379944,1.53403,-2.16748,0.181618,1.39008,-1.82481,-0.009157,1.44812,-1.89633,-0.005827,1.47756,-1.94912,-0.007597,1.45699,-2.00886,0.183503,1.40605,-2.09434,0.321942,1.17699,-1.76756,0.228618,1.08152,-1.79008,0.283765,1.02255,-1.81187,0.397641,0.983106,-1.79523,0.270016,0.870783,-1.7842,0.20553,0.832412,-1.79232,0.210516,0.966265,-1.79213,0.150318,0.928252,-1.79655,-0.019436,0.775487,-1.8081,-0.137355,0.806289,-1.8856,0.03897,0.622171,-1.83621,-0.017378,0.613882,-1.7661,0.127996,1.09729,-2.14184,0.131945,1.01269,-2.12284,-0.012015,1.09274,-2.10549,-0.006539,1.01113,-2.09064,0.045348,0.866503,-2.08328,0.00749,0.681899,-2.06004,-0.091887,0.732207,-2.07957,-0.120925,0.669226,-2.0651,-0.201241,0.455066,-2.01863,-0.306872,0.395795,-1.96332,-0.025733,0.375744,-2.00111,-0.08052,0.340624,-2.0635,0.106858,1.30116,-1.84996,0.102542,1.31477,-2.06472},
/*1989*/{0.185294,1.88962,-1.7425,0.277907,1.81727,-1.88026,0.035461,1.80085,-1.67059,-0.082664,1.73775,-1.63507,0.04077,1.64186,-1.67039,0.10579,1.58132,-1.67513,0.23269,1.89756,-2.13272,0.291648,1.81833,-1.95806,0.088467,1.86058,-2.05852,0.097474,1.66678,-2.2257,0.156628,1.58285,-2.27127,0.323167,1.56611,-2.16722,0.386681,1.54591,-2.16083,0.183052,1.39422,-1.82579,-0.007868,1.45168,-1.89728,-0.004587,1.48019,-1.95104,-0.00607,1.46012,-2.00936,0.185088,1.40637,-2.09599,0.325885,1.18453,-1.76744,0.233776,1.08697,-1.78985,0.289516,1.02891,-1.81347,0.403044,0.992767,-1.79573,0.279934,0.872713,-1.78356,0.218089,0.831003,-1.79284,0.215764,0.964879,-1.79314,0.156999,0.923677,-1.79899,-0.004397,0.761795,-1.8092,-0.122194,0.785663,-1.88771,0.064093,0.612796,-1.83559,0.006236,0.60075,-1.76719,0.121069,1.09834,-2.13934,0.121595,1.01361,-2.12053,-0.018788,1.09818,-2.10505,-0.017166,1.01624,-2.0901,0.031262,0.869971,-2.08131,-0.010514,0.686503,-2.05939,-0.10978,0.737579,-2.07858,-0.139194,0.675061,-2.06449,-0.217784,0.460503,-2.01976,-0.324679,0.397111,-1.96381,-0.047955,0.375557,-2.00112,-0.102719,0.34031,-2.06325,0.108043,1.30504,-1.84964,0.103302,1.31611,-2.06454},
/*1990*/{0.182029,1.89344,-1.74322,0.277447,1.8216,-1.87863,0.032191,1.80601,-1.67189,-0.088528,1.74385,-1.63817,0.036994,1.64859,-1.67266,0.100695,1.58789,-1.67582,0.233639,1.90251,-2.13114,0.291119,1.82308,-1.95607,0.08851,1.86362,-2.05908,0.102287,1.67095,-2.22474,0.163612,1.58709,-2.27049,0.328593,1.57621,-2.16153,0.392706,1.55806,-2.15403,0.183861,1.39838,-1.82754,-0.007385,1.4553,-1.8982,-0.002784,1.48323,-1.95233,-0.004115,1.4624,-2.01076,0.185321,1.40724,-2.09688,0.327898,1.19145,-1.76768,0.235052,1.09292,-1.79209,0.294154,1.03521,-1.81355,0.407706,1.00105,-1.79611,0.289236,0.874645,-1.78382,0.229288,0.829036,-1.79193,0.222496,0.963557,-1.79037,0.1632,0.917625,-1.80092,0.011435,0.747839,-1.80941,-0.107135,0.765828,-1.88897,0.088074,0.603909,-1.83542,0.03115,0.588881,-1.76689,0.114653,1.09973,-2.13751,0.112518,1.01572,-2.11814,-0.027524,1.10431,-2.10566,-0.027217,1.02219,-2.09027,0.015864,0.875253,-2.08041,-0.028045,0.691436,-2.05954,-0.127634,0.742574,-2.07758,-0.156819,0.680345,-2.06416,-0.235806,0.46649,-2.02026,-0.341987,0.407338,-1.96392,-0.067399,0.376919,-1.99965,-0.123848,0.34107,-2.06264,0.108896,1.30889,-1.8495,0.103701,1.31758,-2.0645},
/*1991*/{0.179461,1.89779,-1.74324,0.275999,1.82755,-1.87774,0.028124,1.81175,-1.67351,-0.092795,1.75031,-1.64091,0.032916,1.65482,-1.6747,0.096396,1.59433,-1.67741,0.234318,1.90799,-2.12979,0.291617,1.82752,-1.9549,0.089131,1.86728,-2.05972,0.107235,1.67381,-2.22481,0.171085,1.59141,-2.26922,0.334918,1.58696,-2.15638,0.397021,1.57069,-2.14731,0.186364,1.40212,-1.82918,-0.005434,1.45942,-1.89901,-0.000739,1.48645,-1.95384,-0.002098,1.46599,-2.01183,0.185767,1.40736,-2.0973,0.330388,1.19848,-1.76818,0.239984,1.09824,-1.79123,0.297848,1.04182,-1.81468,0.411573,1.01014,-1.79612,0.298608,0.875787,-1.78317,0.239966,0.827255,-1.79235,0.225657,0.960654,-1.79833,0.170049,0.914269,-1.80279,0.026931,0.734906,-1.80997,-0.091232,0.745747,-1.89082,0.112949,0.5951,-1.83539,0.055702,0.576307,-1.76697,0.107888,1.10106,-2.13585,0.101858,1.01731,-2.11664,-0.034044,1.1107,-2.1057,-0.037055,1.02875,-2.0906,0.000283,0.881304,-2.08034,-0.045586,0.697538,-2.06008,-0.144862,0.749801,-2.07772,-0.175263,0.687936,-2.06418,-0.257262,0.471182,-2.02069,-0.360528,0.415863,-1.96374,-0.090752,0.37578,-2.00099,-0.144609,0.341317,-2.06261,0.110159,1.3129,-1.84914,0.103912,1.31895,-2.0642},
/*1992*/{0.177698,1.90187,-1.74316,0.275899,1.83182,-1.87689,0.025316,1.81723,-1.67538,-0.097257,1.75625,-1.64352,0.028374,1.66097,-1.67669,0.092676,1.60059,-1.67885,0.234995,1.91329,-2.12809,0.291222,1.83174,-1.95303,0.089969,1.87056,-2.05985,0.1126,1.6777,-2.22521,0.178265,1.59642,-2.26835,0.338391,1.59635,-2.15137,0.401883,1.58137,-2.13961,0.187974,1.40631,-1.83037,-0.003803,1.46338,-1.90038,0.000321,1.48935,-1.9552,0.000109,1.46897,-2.01224,0.18732,1.40762,-2.09786,0.332122,1.20445,-1.76839,0.243214,1.10474,-1.79158,0.30199,1.04795,-1.81392,0.415076,1.01826,-1.79702,0.30771,0.877069,-1.78243,0.252063,0.825742,-1.79235,0.230916,0.958093,-1.80061,0.178443,0.908383,-1.80349,0.04473,0.721661,-1.81153,-0.0743,0.723847,-1.89174,0.138383,0.587547,-1.83541,0.081335,0.564768,-1.76721,0.101237,1.10282,-2.13423,0.092803,1.01965,-2.11413,-0.040309,1.1174,-2.10567,-0.046501,1.03528,-2.09076,-0.016381,0.887463,-2.0806,-0.062396,0.70271,-2.06072,-0.161051,0.757199,-2.07696,-0.191875,0.693923,-2.06386,-0.276674,0.477474,-2.01906,-0.378777,0.425743,-1.96283,-0.112594,0.375995,-1.99894,-0.167072,0.342124,-2.06213,0.111393,1.31703,-1.84847,0.104828,1.32031,-2.06358},
/*1993*/{0.1752,1.90553,-1.74355,0.274947,1.83474,-1.87479,0.022038,1.82226,-1.67714,-0.101862,1.76142,-1.64642,0.02491,1.66734,-1.67821,0.088491,1.60674,-1.68081,0.236573,1.91873,-2.12646,0.291464,1.83588,-1.95205,0.091119,1.87373,-2.06063,0.118645,1.68202,-2.22581,0.184814,1.60134,-2.26743,0.342713,1.60701,-2.1464,0.405736,1.59358,-2.13353,0.190466,1.41024,-1.83195,-0.002121,1.46748,-1.90088,0.002907,1.49304,-1.95619,0.002683,1.47198,-2.01303,0.188698,1.4078,-2.09822,0.334104,1.21052,-1.76851,0.244401,1.10769,-1.79154,0.304769,1.05448,-1.81358,0.41775,1.02483,-1.79718,0.316164,0.877171,-1.78297,0.262447,0.822867,-1.79231,0.234951,0.953785,-1.80194,0.185807,0.901748,-1.80617,0.063512,0.709171,-1.81268,-0.056718,0.702942,-1.89249,0.163229,0.579058,-1.83521,0.108364,0.554526,-1.76747,0.094484,1.10552,-2.13277,0.083234,1.02303,-2.11307,-0.046323,1.12417,-2.10607,-0.055396,1.04375,-2.09042,-0.031287,0.893463,-2.08132,-0.078741,0.709256,-2.06181,-0.177478,0.765692,-2.077,-0.208714,0.702709,-2.06431,-0.295679,0.483355,-2.02012,-0.395094,0.436101,-1.9626,-0.133934,0.376537,-1.99848,-0.189867,0.342102,-2.06126,0.113032,1.32116,-1.84782,0.105614,1.32176,-2.06293},
/*1994*/{0.173543,1.90911,-1.74362,0.268249,1.84226,-1.87607,0.019304,1.82704,-1.67841,-0.104341,1.76757,-1.64918,0.021421,1.67338,-1.68026,0.085157,1.61266,-1.68195,0.23834,1.92384,-2.1255,0.290427,1.84094,-1.95111,0.092371,1.87714,-2.06135,0.123254,1.68701,-2.227,0.191657,1.60599,-2.26659,0.346003,1.61691,-2.1413,0.409068,1.6054,-2.12817,0.191553,1.41419,-1.83301,0.000222,1.47184,-1.90037,0.004375,1.49684,-1.95812,0.004534,1.47549,-2.01354,0.189663,1.40814,-2.0984,0.336221,1.2175,-1.76907,0.248101,1.1167,-1.79071,0.307306,1.0604,-1.81417,0.419904,1.03105,-1.79795,0.324074,0.877246,-1.7831,0.274251,0.820465,-1.79206,0.240163,0.949901,-1.80417,0.193292,0.895346,-1.80811,0.082052,0.69574,-1.81311,-0.03834,0.682465,-1.89371,0.187986,0.571625,-1.83565,0.135623,0.544408,-1.768,0.088783,1.1079,-2.13152,0.07411,1.02606,-2.11173,-0.052319,1.13216,-2.10586,-0.063903,1.05135,-2.09043,-0.046983,0.900251,-2.08246,-0.094338,0.717323,-2.06339,-0.19389,0.7737,-2.07621,-0.225144,0.712776,-2.06414,-0.304456,0.492212,-2.02112,-0.412636,0.448187,-1.96136,-0.156898,0.376285,-1.99765,-0.210575,0.343272,-2.06073,0.113753,1.32544,-1.84695,0.105729,1.32342,-2.06203},
/*1995*/{0.171469,1.91266,-1.74419,0.267513,1.84664,-1.8751,0.016069,1.83239,-1.68009,-0.107714,1.77335,-1.65246,0.017889,1.67898,-1.68255,0.081282,1.61824,-1.68363,0.240187,1.92893,-2.1235,0.291205,1.84552,-1.94947,0.093725,1.88094,-2.06226,0.128284,1.69141,-2.22744,0.198444,1.61089,-2.26543,0.347423,1.62544,-2.13691,0.411096,1.61598,-2.12238,0.193666,1.41804,-1.8345,0.001547,1.4768,-1.90152,0.006913,1.49985,-1.95887,0.006686,1.47988,-2.01435,0.190318,1.40841,-2.09823,0.337478,1.22246,-1.7688,0.251457,1.12147,-1.79002,0.307524,1.06433,-1.81402,0.420189,1.03526,-1.79861,0.332078,0.876962,-1.78357,0.284646,0.817157,-1.79223,0.244387,0.94509,-1.80586,0.200072,0.888017,-1.80966,0.098478,0.681358,-1.81375,-0.019214,0.661695,-1.89403,0.213616,0.565058,-1.83569,0.162917,0.535953,-1.76716,0.08213,1.111,-2.13072,0.065399,1.02941,-2.11066,-0.056453,1.14032,-2.10565,-0.071874,1.06037,-2.09039,-0.061049,0.907839,-2.08293,-0.110262,0.726792,-2.06583,-0.208542,0.781794,-2.07609,-0.239971,0.721086,-2.06401,-0.320188,0.498874,-2.02238,-0.426706,0.460041,-1.95999,-0.178658,0.376727,-1.99815,-0.231319,0.343248,-2.05997,0.11458,1.32976,-1.84633,0.105806,1.32522,-2.06134},
/*1996*/{0.170165,1.91618,-1.74376,0.273923,1.84756,-1.87242,0.014289,1.83734,-1.68208,-0.109737,1.77881,-1.65532,0.015137,1.6839,-1.68423,0.077924,1.6231,-1.68466,0.240104,1.93408,-2.12212,0.291651,1.84897,-1.94819,0.094371,1.88427,-2.06295,0.134337,1.6965,-2.22926,0.205113,1.61597,-2.26454,0.349797,1.63543,-2.13207,0.413434,1.62674,-2.11756,0.195101,1.42187,-1.8358,0.003942,1.48181,-1.90182,0.008491,1.50498,-1.96085,0.010147,1.4839,-2.01417,0.191576,1.40905,-2.0988,0.337762,1.22707,-1.76915,0.250036,1.12616,-1.79021,0.308376,1.06988,-1.81399,0.419353,1.03924,-1.79996,0.339122,0.875901,-1.78331,0.297588,0.815109,-1.79237,0.247498,0.93968,-1.80752,0.208279,0.880321,-1.81066,0.119914,0.668607,-1.81478,0.000589,0.641019,-1.89426,0.239531,0.558739,-1.83647,0.190616,0.526871,-1.76751,0.077064,1.11345,-2.12963,0.057319,1.03295,-2.1097,-0.06184,1.14767,-2.10494,-0.079398,1.06793,-2.08968,-0.073533,0.916151,-2.08389,-0.12432,0.734721,-2.06789,-0.223248,0.790395,-2.07594,-0.254577,0.728125,-2.06244,-0.333495,0.507053,-2.02381,-0.440134,0.472558,-1.95844,-0.200347,0.377488,-1.99896,-0.256183,0.344056,-2.06044,0.115268,1.33433,-1.84581,0.105957,1.32755,-2.06074},
/*1997*/{0.168997,1.91919,-1.74449,0.267622,1.85453,-1.87282,0.01298,1.84142,-1.68341,-0.113817,1.78409,-1.65803,0.012773,1.68924,-1.68621,0.076165,1.62818,-1.68536,0.241741,1.93856,-2.12014,0.291007,1.85349,-1.94734,0.095019,1.88735,-2.06344,0.139245,1.70122,-2.23117,0.210539,1.62072,-2.26411,0.351231,1.6452,-2.12821,0.414809,1.63629,-2.1122,0.196517,1.42526,-1.83554,0.006537,1.48672,-1.90196,0.011157,1.50827,-1.96138,0.012893,1.48738,-2.01333,0.193436,1.40979,-2.09879,0.338943,1.23167,-1.76942,0.251556,1.13112,-1.78932,0.309083,1.07386,-1.81247,0.419023,1.04258,-1.80043,0.346675,0.874307,-1.78371,0.3071,0.810369,-1.79233,0.254291,0.932705,-1.80841,0.214949,0.871368,-1.81199,0.136935,0.655843,-1.8156,0.021005,0.620735,-1.89523,0.264612,0.553395,-1.83685,0.217441,0.518471,-1.7676,0.071787,1.11601,-2.12945,0.04939,1.03552,-2.1089,-0.06508,1.15512,-2.10489,-0.085699,1.07606,-2.08972,-0.085643,0.924721,-2.08479,-0.137144,0.743397,-2.06993,-0.235695,0.79943,-2.07623,-0.267414,0.736831,-2.06245,-0.346496,0.514252,-2.0253,-0.452836,0.487943,-1.95866,-0.222233,0.377857,-1.99946,-0.278823,0.345,-2.06012,0.116378,1.33829,-1.84454,0.106823,1.32954,-2.05939},
/*1998*/{0.16804,1.92193,-1.74461,0.266725,1.85804,-1.87211,0.010632,1.84581,-1.68529,-0.115741,1.78901,-1.66132,0.010197,1.69377,-1.68757,0.073592,1.63229,-1.68661,0.242844,1.94263,-2.11904,0.291476,1.8572,-1.94582,0.096554,1.89084,-2.06389,0.144826,1.70535,-2.233,0.215537,1.62499,-2.26386,0.351651,1.65304,-2.12441,0.415982,1.64629,-2.10718,0.198404,1.42901,-1.83747,0.008625,1.49161,-1.90172,0.01384,1.51312,-1.96256,0.01366,1.49099,-2.01472,0.194243,1.41078,-2.09883,0.339984,1.23484,-1.77082,0.251325,1.135,-1.78936,0.307898,1.0772,-1.81116,0.417821,1.04619,-1.80163,0.353778,0.872581,-1.78403,0.316961,0.806796,-1.79276,0.258126,0.926659,-1.80999,0.221182,0.863592,-1.81373,0.155835,0.640617,-1.81565,0.042946,0.601165,-1.89546,0.289693,0.548491,-1.83641,0.24417,0.510252,-1.76671,0.066459,1.11883,-2.12944,0.040467,1.04069,-2.10883,-0.069999,1.16201,-2.10476,-0.091392,1.08415,-2.09006,-0.096529,0.933052,-2.08526,-0.149318,0.752056,-2.07206,-0.248708,0.806963,-2.0758,-0.278502,0.745126,-2.06266,-0.358098,0.520988,-2.02772,-0.463609,0.502929,-1.95812,-0.244187,0.378349,-2.00067,-0.301201,0.346782,-2.05981,0.117346,1.34284,-1.84423,0.10657,1.33189,-2.05892},
/*1999*/{0.166963,1.92474,-1.7445,0.266492,1.86143,-1.87146,0.009686,1.84995,-1.6867,-0.118708,1.79319,-1.66447,0.007317,1.69734,-1.68962,0.070958,1.63657,-1.68735,0.244927,1.94701,-2.11782,0.29164,1.86055,-1.94491,0.097616,1.8934,-2.06444,0.149302,1.70993,-2.23521,0.220992,1.63013,-2.2636,0.351893,1.65907,-2.12079,0.415957,1.65522,-2.10248,0.19917,1.43281,-1.83812,0.011116,1.49605,-1.901,0.016352,1.51651,-1.96249,0.016401,1.49438,-2.0149,0.196125,1.41142,-2.09819,0.341486,1.23812,-1.77122,0.25111,1.13826,-1.78592,0.307265,1.08071,-1.8097,0.415274,1.04867,-1.80261,0.360569,0.870642,-1.78451,0.327163,0.802619,-1.79307,0.262344,0.918845,-1.81106,0.230419,0.854051,-1.81426,0.174792,0.628614,-1.81746,0.064924,0.581454,-1.89614,0.314204,0.543638,-1.8363,0.271326,0.502567,-1.76718,0.062087,1.12205,-2.12918,0.034434,1.04409,-2.10942,-0.072655,1.16861,-2.10502,-0.097251,1.09097,-2.08955,-0.106027,0.941043,-2.086,-0.16019,0.760733,-2.07467,-0.259547,0.815719,-2.07575,-0.289994,0.753128,-2.06302,-0.372847,0.528143,-2.03037,-0.472253,0.51925,-1.95763,-0.262923,0.37853,-2.00246,-0.323978,0.349174,-2.05942,0.118407,1.34686,-1.84293,0.107424,1.33393,-2.0575},
/*2000*/{0.167037,1.92773,-1.74462,0.267776,1.86485,-1.87062,0.008003,1.85364,-1.68839,-0.120525,1.79744,-1.66735,0.004841,1.7009,-1.69121,0.068452,1.63951,-1.68793,0.246066,1.95019,-2.11596,0.291649,1.86405,-1.94419,0.099055,1.89562,-2.06589,0.153966,1.71413,-2.23769,0.225623,1.63392,-2.26383,0.353328,1.66629,-2.11786,0.416342,1.66355,-2.09827,0.201031,1.43592,-1.83941,0.013624,1.50103,-1.9016,0.017815,1.52078,-1.96412,0.018515,1.49785,-2.01542,0.196988,1.41237,-2.09807,0.341617,1.24077,-1.77239,0.247836,1.14065,-1.78689,0.305234,1.08376,-1.80886,0.411936,1.04915,-1.80336,0.366988,0.867365,-1.78469,0.336612,0.797796,-1.79363,0.266813,0.910556,-1.81173,0.237081,0.844228,-1.81516,0.195089,0.6167,-1.81662,0.086785,0.563257,-1.89626,0.338275,0.539196,-1.83696,0.297937,0.496584,-1.76875,0.058078,1.1247,-2.12979,0.02813,1.04703,-2.10987,-0.074716,1.17453,-2.1043,-0.102165,1.09711,-2.08873,-0.11496,0.948973,-2.08647,-0.170306,0.769167,-2.07676,-0.269402,0.823692,-2.07649,-0.299369,0.761484,-2.06359,-0.384818,0.536149,-2.032,-0.480502,0.534866,-1.95813,-0.280002,0.378408,-2.00377,-0.345681,0.352174,-2.05865,0.119186,1.35108,-1.84259,0.107451,1.33617,-2.05699},
/*2001*/{0.166615,1.92947,-1.74429,0.267075,1.86773,-1.86998,0.00625,1.85702,-1.69019,-0.122645,1.80091,-1.6705,0.00393,1.70476,-1.69266,0.06671,1.6425,-1.68881,0.246723,1.95354,-2.11493,0.292136,1.86714,-1.9433,0.100094,1.89886,-2.06638,0.159285,1.71795,-2.23931,0.229465,1.63829,-2.26374,0.353943,1.67303,-2.11542,0.416349,1.67114,-2.09428,0.201935,1.43872,-1.83994,0.015989,1.50472,-1.90101,0.019348,1.52388,-1.96474,0.020291,1.50174,-2.01573,0.197898,1.41328,-2.09785,0.341259,1.24278,-1.77339,0.24604,1.14365,-1.78457,0.303866,1.08462,-1.80706,0.407952,1.04912,-1.80424,0.373674,0.863753,-1.78519,0.346879,0.792418,-1.79459,0.270207,0.902681,-1.81265,0.241961,0.834278,-1.81802,0.213761,0.603473,-1.81748,0.109314,0.544878,-1.89701,0.362302,0.534955,-1.83683,0.323539,0.489707,-1.76818,0.053154,1.12816,-2.13096,0.023313,1.05183,-2.11203,-0.078018,1.18019,-2.10323,-0.10528,1.1026,-2.08753,-0.122224,0.955686,-2.08709,-0.178372,0.776453,-2.07839,-0.276659,0.832102,-2.07588,-0.307244,0.769701,-2.06479,-0.392305,0.54533,-2.03432,-0.488296,0.550985,-1.95775,-0.299279,0.379371,-2.00623,-0.367444,0.357701,-2.05875,0.119721,1.35436,-1.84209,0.107539,1.33837,-2.05638},
/*2002*/{0.166356,1.93228,-1.74434,0.267807,1.87036,-1.86867,0.005741,1.86032,-1.69123,-0.124545,1.80459,-1.67236,0.00201,1.70792,-1.69381,0.064735,1.64514,-1.68948,0.247593,1.95625,-2.1135,0.292627,1.86975,-1.9421,0.101603,1.9008,-2.06651,0.164894,1.7217,-2.24126,0.233183,1.64239,-2.26383,0.353999,1.67981,-2.11376,0.416281,1.67763,-2.09163,0.201813,1.44136,-1.84158,0.018128,1.50895,-1.90037,0.021662,1.52804,-1.96473,0.023245,1.5046,-2.01529,0.198123,1.41423,-2.09755,0.340203,1.24436,-1.77528,0.244439,1.14673,-1.784,0.300357,1.08621,-1.80817,0.404122,1.04771,-1.80414,0.379367,0.860115,-1.78533,0.356724,0.788118,-1.79408,0.27466,0.894076,-1.81323,0.251535,0.825736,-1.81693,0.233663,0.591477,-1.8185,0.132242,0.527738,-1.8981,0.384907,0.531685,-1.83823,0.349021,0.484057,-1.7694,0.050028,1.1317,-2.13192,0.018407,1.05515,-2.1128,-0.080307,1.18425,-2.10135,-0.108998,1.10798,-2.08614,-0.128077,0.961733,-2.08719,-0.185797,0.783008,-2.08028,-0.283438,0.840059,-2.07692,-0.314535,0.776982,-2.06541,-0.404149,0.553762,-2.03591,-0.495988,0.566522,-1.95796,-0.316798,0.379178,-2.00735,-0.389758,0.364226,-2.05686,0.119929,1.35761,-1.84156,0.106991,1.34064,-2.05573},
/*2003*/{0.166154,1.9343,-1.74415,0.26846,1.8729,-1.86754,0.005431,1.86296,-1.69223,-0.126388,1.80685,-1.67486,0.000506,1.71009,-1.69511,0.063491,1.64747,-1.68932,0.24827,1.9587,-2.11249,0.293237,1.87204,-1.94144,0.102207,1.90348,-2.06671,0.168741,1.72548,-2.24294,0.23691,1.6453,-2.26408,0.353905,1.68361,-2.11173,0.414914,1.68302,-2.08814,0.202447,1.44417,-1.8422,0.018074,1.51297,-1.90016,0.022283,1.53127,-1.96531,0.023973,1.50841,-2.01522,0.198697,1.41623,-2.09725,0.340271,1.24482,-1.77682,0.245219,1.14963,-1.78364,0.298347,1.08744,-1.80573,0.400659,1.04553,-1.80437,0.384504,0.856061,-1.78541,0.365869,0.784453,-1.79452,0.277677,0.884014,-1.81528,0.259988,0.814905,-1.81681,0.252456,0.580484,-1.8189,0.155029,0.511489,-1.8994,0.406385,0.526936,-1.83755,0.373465,0.478753,-1.76966,0.047009,1.13465,-2.13299,0.015183,1.05784,-2.11459,-0.083028,1.18818,-2.09898,-0.111326,1.11154,-2.08497,-0.132641,0.966328,-2.08716,-0.192109,0.788256,-2.08165,-0.28837,0.846215,-2.07693,-0.321968,0.784199,-2.06657,-0.410124,0.563126,-2.03766,-0.501875,0.581882,-1.95819,-0.334776,0.37955,-2.00942,-0.409437,0.371499,-2.05544,0.119805,1.36098,-1.84135,0.106756,1.34349,-2.05547},
/*2004*/{0.166694,1.93632,-1.74428,0.269591,1.87478,-1.86758,0.004872,1.86555,-1.69294,-0.127783,1.8094,-1.67844,-0.000685,1.7123,-1.69581,0.062122,1.64926,-1.68963,0.249789,1.96116,-2.11153,0.293924,1.87453,-1.941,0.104259,1.90509,-2.06673,0.173757,1.72858,-2.24464,0.239771,1.64807,-2.2649,0.353975,1.68813,-2.11088,0.415162,1.68767,-2.08595,0.203077,1.44669,-1.84298,0.019516,1.51663,-1.90018,0.02391,1.53398,-1.96564,0.025353,1.5112,-2.01507,0.199004,1.41768,-2.09743,0.339029,1.24449,-1.7778,0.243978,1.15062,-1.78335,0.294643,1.08708,-1.80572,0.39674,1.04245,-1.80426,0.38832,0.85182,-1.78516,0.372769,0.777836,-1.79501,0.281192,0.87423,-1.81569,0.266819,0.803516,-1.81785,0.271172,0.568863,-1.81983,0.177607,0.496806,-1.90115,0.428279,0.524006,-1.84032,0.397339,0.472867,-1.77148,0.044542,1.13825,-2.13426,0.012554,1.06155,-2.11673,-0.084371,1.19198,-2.09829,-0.113066,1.11528,-2.08361,-0.133741,0.969826,-2.08709,-0.197438,0.79296,-2.08206,-0.293696,0.853275,-2.07788,-0.327069,0.791772,-2.06828,-0.419322,0.573674,-2.03912,-0.508823,0.598632,-1.95911,-0.353211,0.378443,-2.00899,-0.431198,0.380268,-2.05494,0.12037,1.36394,-1.84115,0.106675,1.34566,-2.05517},
/*2005*/{0.166718,1.93778,-1.74478,0.270728,1.8769,-1.8672,0.004134,1.86733,-1.69551,-0.127893,1.81172,-1.68044,-0.001673,1.71377,-1.69738,0.061234,1.6501,-1.68936,0.249961,1.9627,-2.11036,0.294157,1.87627,-1.94032,0.105217,1.90768,-2.06695,0.177355,1.73151,-2.24547,0.243232,1.65055,-2.26545,0.354044,1.69151,-2.10879,0.414023,1.69157,-2.08389,0.203435,1.44872,-1.84382,0.020886,1.51971,-1.89982,0.024389,1.53691,-1.96575,0.026143,1.51448,-2.01468,0.199454,1.41989,-2.09729,0.338975,1.2429,-1.77837,0.240047,1.15099,-1.7836,0.291085,1.08598,-1.8051,0.39303,1.03948,-1.80374,0.391568,0.84755,-1.78506,0.381151,0.774006,-1.795,0.283999,0.863622,-1.81561,0.273427,0.79295,-1.8185,0.289187,0.55951,-1.8215,0.199507,0.483268,-1.90304,0.448135,0.520763,-1.84064,0.419494,0.467664,-1.77251,0.042998,1.14124,-2.13577,0.011286,1.06434,-2.11831,-0.085228,1.19538,-2.09596,-0.113012,1.11851,-2.08256,-0.134004,0.972262,-2.08721,-0.201754,0.795974,-2.08303,-0.295741,0.859697,-2.07894,-0.3307,0.79861,-2.06983,-0.429442,0.583074,-2.03988,-0.515944,0.614184,-1.96137,-0.37196,0.37793,-2.00896,-0.450897,0.390031,-2.05435,0.120601,1.36638,-1.84131,0.106519,1.34839,-2.05533},
/*2006*/{0.167295,1.93955,-1.74444,0.270575,1.87826,-1.86698,0.004537,1.86902,-1.6966,-0.127956,1.81355,-1.68268,-0.002905,1.71498,-1.69839,0.061003,1.65084,-1.68959,0.251314,1.96466,-2.10968,0.295262,1.87846,-1.93993,0.106946,1.90954,-2.0672,0.178529,1.73428,-2.24608,0.244765,1.65293,-2.26595,0.353959,1.69382,-2.10836,0.413535,1.69415,-2.08193,0.203702,1.45069,-1.84432,0.021619,1.52166,-1.89928,0.024856,1.53977,-1.96578,0.026761,1.51751,-2.01431,0.199063,1.42185,-2.09734,0.338985,1.24057,-1.77904,0.235922,1.14786,-1.78252,0.286964,1.08442,-1.8046,0.388257,1.03549,-1.80311,0.394447,0.843055,-1.78527,0.388027,0.767744,-1.79443,0.285656,0.853328,-1.81663,0.279224,0.781568,-1.81952,0.306231,0.549459,-1.8223,0.221009,0.470403,-1.90533,0.467972,0.517111,-1.84142,0.440399,0.462773,-1.77577,0.042523,1.14407,-2.13678,0.010718,1.06696,-2.1204,-0.085225,1.19709,-2.09506,-0.11268,1.12012,-2.08064,-0.132763,0.973888,-2.0871,-0.205547,0.798645,-2.0829,-0.29681,0.864246,-2.07932,-0.334526,0.804646,-2.06995,-0.438733,0.59343,-2.04193,-0.522759,0.630407,-1.96314,-0.394952,0.379836,-2.00988,-0.471348,0.399991,-2.05252,0.120691,1.36846,-1.84147,0.106044,1.35082,-2.05548},
/*2007*/{0.16795,1.94105,-1.74449,0.27164,1.87946,-1.86639,0.003764,1.87044,-1.69818,-0.129266,1.81445,-1.68473,-0.00271,1.71608,-1.69924,0.059517,1.65124,-1.68909,0.252255,1.966,-2.10926,0.296285,1.87961,-1.9389,0.107741,1.91102,-2.06707,0.180616,1.73692,-2.24637,0.246701,1.6545,-2.26705,0.352566,1.69707,-2.10823,0.413148,1.69574,-2.08091,0.20425,1.45307,-1.84454,0.020912,1.52514,-1.90003,0.02437,1.54318,-1.96522,0.027189,1.52002,-2.01407,0.199676,1.42431,-2.09749,0.336351,1.23762,-1.77978,0.235996,1.14888,-1.78194,0.282205,1.08227,-1.80495,0.38324,1.03141,-1.80253,0.396861,0.838167,-1.78516,0.393996,0.762449,-1.79448,0.287529,0.843309,-1.81459,0.284016,0.772133,-1.82003,0.323773,0.538826,-1.82306,0.240763,0.458816,-1.90731,0.485827,0.51504,-1.84312,0.461441,0.458698,-1.77788,0.042314,1.14628,-2.13714,0.00946,1.06848,-2.12062,-0.084269,1.19879,-2.09343,-0.112482,1.12153,-2.08055,-0.129925,0.974617,-2.08687,-0.208806,0.800596,-2.08253,-0.297395,0.869806,-2.08123,-0.337346,0.811307,-2.07099,-0.450927,0.602681,-2.04343,-0.528481,0.64568,-1.96561,-0.4165,0.391252,-2.00712,-0.489876,0.412465,-2.05145,0.120599,1.37132,-1.84149,0.106019,1.35363,-2.0555},
/*2008*/{0.168463,1.9421,-1.74465,0.273196,1.88032,-1.86671,0.004572,1.87127,-1.69875,-0.130628,1.81508,-1.6867,-0.002943,1.71614,-1.69955,0.059291,1.65099,-1.68902,0.25408,1.96687,-2.1088,0.296899,1.88122,-1.93889,0.109347,1.91354,-2.06727,0.184108,1.73849,-2.24794,0.248662,1.65594,-2.26813,0.352541,1.69698,-2.10742,0.411974,1.69689,-2.07995,0.203665,1.45507,-1.84468,0.021535,1.52559,-1.90076,0.02484,1.54506,-1.96542,0.027402,1.52185,-2.0136,0.199955,1.42704,-2.09715,0.3334,1.23387,-1.78029,0.230023,1.14695,-1.78137,0.276478,1.07978,-1.8032,0.378,1.02599,-1.8016,0.399024,0.833047,-1.78478,0.399808,0.757264,-1.79566,0.289189,0.832957,-1.81365,0.289973,0.760776,-1.81928,0.339547,0.531494,-1.82506,0.260411,0.448506,-1.90991,0.503,0.513497,-1.84497,0.481398,0.454606,-1.7803,0.043619,1.14858,-2.13798,0.013188,1.07036,-2.12203,-0.08271,1.19919,-2.09206,-0.110333,1.12222,-2.07949,-0.126088,0.974426,-2.08665,-0.210244,0.801861,-2.08179,-0.297596,0.873941,-2.08246,-0.338926,0.817067,-2.07263,-0.460672,0.612783,-2.04434,-0.535922,0.660807,-1.9669,-0.436568,0.401189,-2.00497,-0.509818,0.424783,-2.05008,0.120823,1.37271,-1.84193,0.106824,1.35577,-2.05604},
/*2009*/{0.169688,1.94359,-1.7439,0.272837,1.8816,-1.86639,0.005533,1.87217,-1.69886,-0.129874,1.81576,-1.68867,-0.002752,1.71585,-1.7,0.059109,1.65005,-1.68822,0.255043,1.96739,-2.10881,0.297541,1.88176,-1.93864,0.109749,1.91489,-2.06691,0.185537,1.73991,-2.24855,0.249228,1.65674,-2.26913,0.352326,1.69749,-2.10757,0.41134,1.69637,-2.07913,0.204051,1.45589,-1.84466,0.02249,1.5286,-1.89844,0.024126,1.54787,-1.96477,0.027485,1.52432,-2.0127,0.200236,1.42923,-2.09732,0.328701,1.23024,-1.7815,0.22445,1.14429,-1.78123,0.269755,1.07588,-1.80292,0.372978,1.02042,-1.80185,0.400898,0.827915,-1.78557,0.405729,0.752713,-1.79773,0.290329,0.82286,-1.81225,0.294303,0.750935,-1.81796,0.35559,0.52384,-1.82674,0.279111,0.438194,-1.91213,0.518917,0.513407,-1.84743,0.499681,0.452472,-1.78389,0.046336,1.14929,-2.13804,0.016118,1.07106,-2.12295,-0.081137,1.19955,-2.09156,-0.107891,1.12188,-2.07891,-0.122403,0.973579,-2.08648,-0.211618,0.802489,-2.08177,-0.29603,0.878141,-2.08329,-0.339935,0.822487,-2.07346,-0.467651,0.624655,-2.04578,-0.543171,0.676207,-1.96885,-0.455563,0.411617,-2.00162,-0.526426,0.43839,-2.04863,0.120816,1.37429,-1.84183,0.10607,1.3584,-2.05597},
/*2010*/{0.170961,1.94382,-1.74383,0.279514,1.87801,-1.86418,0.005564,1.87251,-1.70001,-0.1295,1.81545,-1.68998,-0.002733,1.71512,-1.70065,0.059265,1.64937,-1.68778,0.256182,1.96762,-2.10833,0.298368,1.88136,-1.93814,0.110602,1.91684,-2.06716,0.187562,1.74103,-2.24923,0.249116,1.65699,-2.26934,0.35185,1.69671,-2.10736,0.410516,1.69554,-2.07807,0.204343,1.45732,-1.84556,0.022313,1.52954,-1.89805,0.024518,1.54969,-1.96396,0.027626,1.52592,-2.01292,0.200441,1.43159,-2.09748,0.325501,1.22453,-1.78097,0.22062,1.14122,-1.78054,0.263522,1.07277,-1.80304,0.366267,1.01446,-1.80103,0.402663,0.823328,-1.78627,0.40929,0.748036,-1.79781,0.292816,0.814001,-1.81028,0.299747,0.741912,-1.81744,0.368469,0.516983,-1.82819,0.295954,0.429351,-1.91382,0.533495,0.512829,-1.84985,0.516624,0.450546,-1.78734,0.048361,1.14992,-2.13839,0.019377,1.0711,-2.12346,-0.07927,1.1991,-2.09148,-0.104897,1.1213,-2.07862,-0.117789,0.971757,-2.08648,-0.212922,0.802881,-2.08109,-0.293734,0.882092,-2.08423,-0.339829,0.829085,-2.07469,-0.476521,0.636466,-2.04618,-0.549954,0.693586,-1.97211,-0.472539,0.424771,-1.9994,-0.542102,0.453929,-2.0484,0.121383,1.37539,-1.84246,0.106407,1.3605,-2.05666},
/*2011*/{0.171919,1.9444,-1.74349,0.28083,1.87836,-1.864,0.00625,1.87277,-1.70107,-0.128594,1.81482,-1.69175,-0.00215,1.71417,-1.70078,0.059319,1.64808,-1.68663,0.256568,1.96767,-2.10822,0.299148,1.88217,-1.93797,0.111798,1.91803,-2.06711,0.188315,1.74188,-2.25027,0.249611,1.65695,-2.27077,0.351835,1.69578,-2.10781,0.410392,1.69409,-2.07803,0.204437,1.45795,-1.84585,0.02238,1.5298,-1.89802,0.0239,1.55104,-1.96376,0.026926,1.52752,-2.01256,0.200755,1.4335,-2.09726,0.320374,1.21968,-1.7819,0.215507,1.13751,-1.77983,0.256298,1.06803,-1.80344,0.361189,1.00796,-1.80028,0.405459,0.818722,-1.78677,0.414525,0.743388,-1.79863,0.295047,0.804961,-1.80819,0.303484,0.733709,-1.81566,0.380968,0.510012,-1.82961,0.311169,0.421312,-1.91513,0.54618,0.514006,-1.85342,0.533128,0.449899,-1.79068,0.052446,1.14989,-2.13805,0.024303,1.07067,-2.12298,-0.076492,1.197,-2.09073,-0.10068,1.11867,-2.07846,-0.113249,0.969965,-2.08658,-0.213408,0.803467,-2.081,-0.291228,0.885634,-2.08518,-0.339806,0.834805,-2.07548,-0.485916,0.648403,-2.04534,-0.556197,0.709195,-1.97438,-0.488359,0.436984,-1.99558,-0.555845,0.467791,-2.04628,0.1214,1.37594,-1.84301,0.10654,1.36217,-2.05729},
/*2012*/{0.173042,1.94488,-1.74335,0.28033,1.87976,-1.86417,0.007919,1.8721,-1.70033,-0.127431,1.8141,-1.69252,-0.001195,1.71216,-1.7003,0.060357,1.64628,-1.6853,0.25773,1.96693,-2.10789,0.299147,1.88214,-1.93792,0.112033,1.91864,-2.06731,0.188689,1.74185,-2.25055,0.248723,1.65657,-2.27149,0.351377,1.69327,-2.10753,0.40919,1.69048,-2.07749,0.204854,1.45991,-1.84591,0.022334,1.52993,-1.89758,0.024214,1.55134,-1.9637,0.026903,1.52794,-2.01201,0.200982,1.43539,-2.09711,0.31683,1.21293,-1.7813,0.209908,1.13458,-1.77973,0.24855,1.06382,-1.80352,0.354919,1.00106,-1.80045,0.407128,0.814383,-1.78769,0.41703,0.739317,-1.80114,0.296621,0.796985,-1.80633,0.307974,0.726251,-1.81407,0.393792,0.506543,-1.83204,0.324328,0.414761,-1.91709,0.557154,0.514618,-1.85642,0.548183,0.449909,-1.79591,0.055722,1.1489,-2.13765,0.028662,1.06984,-2.12257,-0.072527,1.19526,-2.0907,-0.097167,1.11613,-2.079,-0.108319,0.967514,-2.08672,-0.214517,0.804046,-2.08027,-0.287772,0.889641,-2.08608,-0.338727,0.841047,-2.07665,-0.489835,0.661677,-2.04553,-0.562863,0.725683,-1.97756,-0.504283,0.450485,-1.99268,-0.566636,0.482791,-2.04363,0.122728,1.37707,-1.84284,0.107652,1.36321,-2.0571},
/*2013*/{0.174407,1.94473,-1.74316,0.28033,1.87976,-1.86417,0.008322,1.87163,-1.70139,-0.125267,1.81288,-1.69301,-3.5e-005,1.71151,-1.70011,0.061341,1.6437,-1.68455,0.259086,1.9662,-2.10784,0.299198,1.88194,-1.93797,0.112745,1.91948,-2.06724,0.188353,1.74197,-2.25063,0.246719,1.65528,-2.27203,0.350515,1.69021,-2.10689,0.408404,1.68694,-2.07765,0.204792,1.45998,-1.84589,0.022061,1.52961,-1.89702,0.024149,1.55139,-1.96324,0.026734,1.52787,-2.01134,0.201958,1.43616,-2.09711,0.311538,1.20703,-1.78111,0.201705,1.1307,-1.77922,0.239666,1.05878,-1.8037,0.347947,0.994307,-1.79993,0.408075,0.810545,-1.78947,0.421191,0.73657,-1.80253,0.297575,0.789817,-1.80604,0.310978,0.719242,-1.81349,0.401906,0.500308,-1.83234,0.336025,0.408178,-1.91763,0.567175,0.514974,-1.85997,0.560593,0.450074,-1.79917,0.060381,1.14761,-2.13659,0.033898,1.06809,-2.12152,-0.069792,1.1919,-2.09113,-0.092557,1.11331,-2.07881,-0.102745,0.964689,-2.08671,-0.214259,0.805037,-2.07976,-0.284623,0.89345,-2.08679,-0.336537,0.84708,-2.07792,-0.496984,0.674879,-2.04719,-0.568126,0.743286,-1.98013,-0.517733,0.466009,-1.98953,-0.580156,0.499083,-2.04344,0.123132,1.37682,-1.84293,0.108327,1.3637,-2.05725},
/*2014*/{0.176576,1.944,-1.74191,0.280563,1.87978,-1.86471,0.008877,1.8704,-1.70172,-0.124192,1.81096,-1.69386,0.001629,1.70909,-1.69981,0.061692,1.64109,-1.68275,0.259262,1.96527,-2.10772,0.29905,1.88144,-1.93811,0.113204,1.91983,-2.06673,0.187328,1.74124,-2.25059,0.244958,1.65419,-2.27225,0.350027,1.68675,-2.10711,0.407832,1.6821,-2.07729,0.205396,1.46084,-1.84674,0.020805,1.52946,-1.89696,0.023962,1.55147,-1.96296,0.026517,1.52759,-2.01133,0.203293,1.43728,-2.09702,0.307641,1.20202,-1.78177,0.19156,1.12451,-1.78098,0.23238,1.05447,-1.80387,0.34305,0.987214,-1.79928,0.407788,0.806824,-1.79118,0.423337,0.732697,-1.80419,0.29797,0.782882,-1.80499,0.312442,0.713052,-1.814,0.410479,0.49623,-1.83371,0.344286,0.403592,-1.91803,0.573991,0.513433,-1.86354,0.570215,0.448052,-1.80319,0.065239,1.14622,-2.13587,0.040059,1.06548,-2.12057,-0.06587,1.18828,-2.09143,-0.087541,1.10973,-2.07908,-0.0963,0.961757,-2.08658,-0.214242,0.806084,-2.07902,-0.280306,0.897141,-2.08802,-0.334233,0.8544,-2.0787,-0.502627,0.6885,-2.04722,-0.571999,0.760398,-1.9828,-0.530285,0.481162,-1.9864,-0.591208,0.515425,-2.0414,0.124115,1.37716,-1.84321,0.109562,1.3643,-2.05757},
/*2015*/{0.177509,1.94364,-1.74187,0.281549,1.87873,-1.86528,0.011031,1.86881,-1.70122,-0.122151,1.80891,-1.69403,0.002328,1.70608,-1.69846,0.062672,1.63817,-1.68077,0.259656,1.96372,-2.10759,0.298461,1.88075,-1.9383,0.113157,1.91988,-2.06659,0.18538,1.74055,-2.25039,0.241395,1.65255,-2.27204,0.348242,1.68326,-2.10736,0.406317,1.67683,-2.07719,0.205229,1.46104,-1.8468,0.021037,1.52797,-1.89663,0.023454,1.55082,-1.96246,0.026903,1.52688,-2.01092,0.203396,1.43791,-2.09678,0.303294,1.19448,-1.7812,0.184999,1.12095,-1.78189,0.225122,1.05024,-1.80401,0.335915,0.980064,-1.79829,0.406477,0.803543,-1.792,0.42447,0.730277,-1.80543,0.297604,0.776565,-1.80507,0.317166,0.709365,-1.81282,0.417434,0.492624,-1.8352,0.351425,0.399481,-1.91893,0.58029,0.513212,-1.86654,0.578284,0.446539,-1.80664,0.070688,1.14353,-2.13484,0.04612,1.06307,-2.11981,-0.060767,1.18363,-2.09163,-0.082444,1.10476,-2.07918,-0.089377,0.958376,-2.08653,-0.213058,0.807074,-2.07844,-0.274756,0.902146,-2.08857,-0.331338,0.860232,-2.07911,-0.50351,0.702425,-2.04689,-0.575341,0.777469,-1.98551,-0.541116,0.497569,-1.98342,-0.600278,0.532707,-2.03971,0.124871,1.3766,-1.84327,0.1104,1.36424,-2.05766},
/*2016*/{0.178641,1.94219,-1.74163,0.281718,1.87833,-1.86534,0.011646,1.86753,-1.70074,-0.118896,1.80597,-1.69377,0.004389,1.7028,-1.69728,0.063928,1.63463,-1.67832,0.260304,1.96215,-2.10776,0.298532,1.87982,-1.9382,0.113008,1.91957,-2.06617,0.181663,1.73959,-2.24887,0.239346,1.65082,-2.27226,0.347041,1.67886,-2.10778,0.404983,1.67062,-2.07765,0.204947,1.46068,-1.84786,0.019734,1.52562,-1.89672,0.022635,1.54915,-1.96218,0.026893,1.52527,-2.01069,0.203575,1.43799,-2.0967,0.297466,1.18882,-1.78088,0.180667,1.11955,-1.78223,0.218789,1.04584,-1.80497,0.328493,0.973233,-1.7991,0.403874,0.800307,-1.79342,0.421818,0.727193,-1.80582,0.295402,0.770662,-1.80642,0.313804,0.701945,-1.81485,0.422043,0.488903,-1.83663,0.357315,0.395241,-1.92114,0.584463,0.511957,-1.86969,0.584294,0.443544,-1.80992,0.076038,1.14044,-2.13353,0.053242,1.06003,-2.11857,-0.057251,1.17952,-2.09276,-0.076068,1.09953,-2.0798,-0.081773,0.954241,-2.08655,-0.211883,0.809059,-2.07829,-0.269798,0.905456,-2.08955,-0.327404,0.867529,-2.07992,-0.511476,0.718865,-2.04811,-0.576063,0.795523,-1.98684,-0.551132,0.515028,-1.98104,-0.607062,0.549971,-2.03774,0.125544,1.37529,-1.84379,0.111237,1.36352,-2.05822},
/*2017*/{0.17983,1.94045,-1.74164,0.280508,1.87629,-1.86559,0.013174,1.86446,-1.70025,-0.117078,1.80235,-1.69319,0.005161,1.69901,-1.69609,0.065596,1.62985,-1.67654,0.258946,1.9594,-2.10728,0.298347,1.87834,-1.93832,0.112963,1.91758,-2.06637,0.177617,1.73833,-2.24806,0.235471,1.64866,-2.27188,0.346131,1.67269,-2.10836,0.404051,1.66304,-2.07871,0.204749,1.46056,-1.8481,0.019272,1.52411,-1.89638,0.022135,1.54802,-1.96184,0.026302,1.52326,-2.01055,0.204197,1.43723,-2.09645,0.294384,1.18165,-1.77931,0.174976,1.11577,-1.7825,0.210775,1.04074,-1.80686,0.321212,0.966299,-1.79928,0.399823,0.797224,-1.79342,0.419022,0.724335,-1.80688,0.291977,0.765973,-1.80879,0.311149,0.697984,-1.81694,0.424682,0.484963,-1.83777,0.360596,0.391972,-1.92275,0.586942,0.509526,-1.87162,0.587505,0.44091,-1.81334,0.082329,1.13754,-2.13238,0.060813,1.05687,-2.11744,-0.052362,1.17377,-2.09351,-0.070187,1.09392,-2.07997,-0.074441,0.949466,-2.08784,-0.20969,0.810224,-2.07807,-0.263733,0.9093,-2.08981,-0.323526,0.873053,-2.07953,-0.513173,0.732385,-2.04847,-0.576085,0.813093,-1.98996,-0.559554,0.531997,-1.97884,-0.615439,0.568931,-2.0376,0.126181,1.37462,-1.84339,0.111909,1.36234,-2.0578},
/*2018*/{0.18152,1.93838,-1.74071,0.281618,1.87535,-1.86566,0.014142,1.8616,-1.69996,-0.115471,1.79837,-1.69269,0.006899,1.69529,-1.69362,0.067042,1.62635,-1.674,0.259106,1.95699,-2.10743,0.298635,1.87684,-1.93863,0.112649,1.91764,-2.06514,0.173794,1.73621,-2.24676,0.232315,1.64644,-2.27081,0.345189,1.66603,-2.1091,0.403681,1.65639,-2.08024,0.20322,1.45911,-1.84771,0.018994,1.52133,-1.89693,0.022513,1.54526,-1.96177,0.026372,1.52134,-2.01043,0.204896,1.4364,-2.09577,0.28983,1.1756,-1.77907,0.169289,1.10863,-1.78379,0.205125,1.03677,-1.80823,0.314144,0.959816,-1.80068,0.395547,0.792714,-1.79438,0.416152,0.720497,-1.80791,0.287517,0.761186,-1.81174,0.308486,0.692575,-1.81843,0.425191,0.482622,-1.83998,0.361737,0.387351,-1.92499,0.587059,0.508304,-1.87402,0.588644,0.438168,-1.81558,0.088282,1.13464,-2.13149,0.068319,1.05275,-2.11579,-0.047156,1.16767,-2.09383,-0.06391,1.08747,-2.0802,-0.065175,0.943863,-2.08586,-0.206884,0.811797,-2.07726,-0.25657,0.91355,-2.09009,-0.31798,0.879216,-2.07928,-0.512946,0.748469,-2.04928,-0.573368,0.83078,-1.99101,-0.567189,0.549127,-1.9772,-0.621088,0.587175,-2.03666,0.125873,1.37237,-1.84352,0.113014,1.36083,-2.05807},
/*2019*/{0.182125,1.93598,-1.74034,0.281912,1.87191,-1.86543,0.015474,1.85858,-1.69916,-0.113179,1.79383,-1.69071,0.009175,1.69007,-1.69123,0.069368,1.62196,-1.67164,0.258311,1.95422,-2.10741,0.297803,1.87485,-1.9386,0.112128,1.91539,-2.06419,0.169641,1.73419,-2.24594,0.227318,1.64351,-2.27032,0.343957,1.65924,-2.11022,0.402535,1.648,-2.08216,0.2053,1.4577,-1.84655,0.018652,1.51893,-1.89597,0.022205,1.54236,-1.96278,0.025527,1.51859,-2.01027,0.204799,1.43511,-2.09533,0.286349,1.16945,-1.77729,0.163988,1.10636,-1.78459,0.200046,1.03243,-1.80912,0.307302,0.954462,-1.80117,0.390075,0.788338,-1.79505,0.410166,0.716853,-1.80832,0.283276,0.755979,-1.81396,0.304055,0.68833,-1.82327,0.423492,0.478004,-1.84177,0.361503,0.383199,-1.92725,0.586583,0.505594,-1.87479,0.587677,0.43403,-1.8181,0.093959,1.13041,-2.13064,0.07547,1.04886,-2.11532,-0.042188,1.16186,-2.09517,-0.057305,1.08105,-2.08054,-0.056704,0.938961,-2.08574,-0.203554,0.813632,-2.07733,-0.248464,0.917427,-2.0898,-0.311385,0.885383,-2.07901,-0.511822,0.762192,-2.0507,-0.570907,0.848405,-1.99305,-0.574886,0.56705,-1.9754,-0.627913,0.606993,-2.03588,0.127398,1.37087,-1.84288,0.114068,1.35855,-2.05735},
/*2020*/{0.183263,1.93281,-1.74028,0.280955,1.87046,-1.86619,0.017145,1.85402,-1.69767,-0.110391,1.78854,-1.6889,0.011324,1.68544,-1.689,0.070934,1.61707,-1.66914,0.257861,1.95111,-2.10797,0.297471,1.87186,-1.93875,0.11221,1.91335,-2.0636,0.163386,1.73233,-2.24438,0.22353,1.64061,-2.26985,0.341961,1.65128,-2.11154,0.400747,1.63912,-2.08413,0.203854,1.45501,-1.8465,0.019001,1.5144,-1.89562,0.021134,1.53889,-1.96145,0.025386,1.51548,-2.01083,0.205282,1.43359,-2.09477,0.283267,1.16418,-1.77585,0.160677,1.10239,-1.78609,0.196153,1.02835,-1.81102,0.302103,0.949664,-1.80182,0.38489,0.783789,-1.79589,0.406509,0.71111,-1.80854,0.278481,0.750486,-1.81665,0.300993,0.681367,-1.8233,0.419928,0.473123,-1.84375,0.358959,0.379745,-1.92995,0.583218,0.500989,-1.87649,0.584512,0.429592,-1.81985,0.099714,1.1266,-2.12979,0.083654,1.04351,-2.11345,-0.037664,1.15491,-2.09532,-0.050235,1.07464,-2.08098,-0.048128,0.933361,-2.08603,-0.199453,0.814715,-2.07694,-0.240487,0.919961,-2.09004,-0.30485,0.890694,-2.07944,-0.509369,0.776443,-2.0512,-0.565187,0.866045,-1.9942,-0.580058,0.585035,-1.97481,-0.63208,0.625941,-2.03498,0.127416,1.36719,-1.84327,0.114983,1.35628,-2.05787},
/*2021*/{0.183543,1.92978,-1.73987,0.281129,1.86884,-1.86667,0.017813,1.84973,-1.69645,-0.108557,1.78266,-1.68653,0.013167,1.68036,-1.68599,0.074037,1.61193,-1.66625,0.256441,1.94758,-2.1082,0.29719,1.86982,-1.93892,0.110752,1.91069,-2.06332,0.158624,1.7292,-2.2429,0.217713,1.63742,-2.26891,0.341061,1.64405,-2.11298,0.400143,1.63018,-2.08713,0.203271,1.45236,-1.84587,0.018135,1.5126,-1.89581,0.021998,1.53665,-1.9625,0.025636,1.51144,-2.01015,0.20597,1.4317,-2.09372,0.27829,1.16016,-1.7749,0.158061,1.09922,-1.78736,0.192399,1.02485,-1.81295,0.298788,0.946649,-1.80286,0.379352,0.778777,-1.79629,0.401801,0.706538,-1.81069,0.273447,0.745164,-1.81964,0.296141,0.675893,-1.82678,0.415817,0.468876,-1.84679,0.355488,0.375035,-1.93326,0.579727,0.4957,-1.87783,0.581159,0.427201,-1.82189,0.106642,1.12252,-2.12945,0.090999,1.04049,-2.11261,-0.032321,1.14865,-2.09569,-0.043663,1.06826,-2.08098,-0.039454,0.927223,-2.08571,-0.194929,0.815864,-2.07668,-0.231136,0.922684,-2.09005,-0.296844,0.895804,-2.08059,-0.505899,0.790442,-2.05171,-0.557802,0.882094,-1.99537,-0.584702,0.602116,-1.97456,-0.63365,0.644988,-2.03396,0.127031,1.36486,-1.84272,0.115772,1.35367,-2.05738},
/*2022*/{0.18431,1.92541,-1.7391,0.281769,1.86445,-1.86678,0.019675,1.84462,-1.69482,-0.10699,1.77669,-1.68408,0.016198,1.67489,-1.68245,0.076933,1.60631,-1.6633,0.255396,1.94344,-2.1096,0.296939,1.86659,-1.93924,0.110014,1.90756,-2.06221,0.155547,1.7259,-2.24271,0.212355,1.63371,-2.26849,0.338586,1.6367,-2.11498,0.397172,1.62001,-2.08952,0.201965,1.44867,-1.84411,0.016749,1.50881,-1.89594,0.021463,1.53246,-1.96127,0.025167,1.50816,-2.01126,0.206995,1.42955,-2.09242,0.274689,1.15526,-1.77261,0.154787,1.09459,-1.78912,0.189179,1.02076,-1.81391,0.296972,0.944462,-1.80405,0.374847,0.772596,-1.7975,0.396064,0.70211,-1.81259,0.268379,0.739903,-1.8228,0.289783,0.672965,-1.82974,0.409413,0.463075,-1.84839,0.349309,0.371174,-1.93667,0.573677,0.489965,-1.87878,0.575789,0.421639,-1.82281,0.111985,1.11842,-2.12878,0.098936,1.036,-2.11166,-0.026382,1.14197,-2.0963,-0.036985,1.06079,-2.08062,-0.031457,0.921137,-2.08576,-0.189732,0.816498,-2.07607,-0.221547,0.925276,-2.0908,-0.2876,0.9006,-2.08019,-0.501075,0.804265,-2.05217,-0.548672,0.898611,-1.99603,-0.587835,0.619477,-1.97476,-0.636847,0.664828,-2.03448,0.125857,1.36085,-1.84256,0.116785,1.35093,-2.05738},
/*2023*/{0.185336,1.92186,-1.73881,0.274884,1.86396,-1.86939,0.02028,1.83972,-1.6934,-0.105667,1.76991,-1.68101,0.018351,1.66854,-1.67918,0.07965,1.60009,-1.65942,0.253887,1.93946,-2.10996,0.296198,1.86429,-1.94009,0.109335,1.90421,-2.06157,0.150108,1.72264,-2.24066,0.207392,1.62973,-2.26762,0.335709,1.62709,-2.11658,0.395302,1.60939,-2.09226,0.200361,1.44459,-1.84354,0.016877,1.50495,-1.89559,0.020457,1.52921,-1.96178,0.025456,1.50455,-2.01153,0.207038,1.42717,-2.09138,0.272348,1.15098,-1.77113,0.152004,1.09107,-1.79093,0.186954,1.01681,-1.81645,0.295404,0.942313,-1.80512,0.369058,0.767352,-1.7985,0.391867,0.695588,-1.81299,0.263619,0.735829,-1.82376,0.284631,0.667944,-1.83177,0.404705,0.45924,-1.8519,0.342037,0.366537,-1.94045,0.567196,0.483199,-1.87998,0.565323,0.412147,-1.82479,0.118023,1.11442,-2.12801,0.105976,1.03157,-2.11089,-0.021574,1.13503,-2.09668,-0.030822,1.05379,-2.08101,-0.02244,0.915456,-2.08555,-0.183217,0.816391,-2.0758,-0.211629,0.926158,-2.09148,-0.279536,0.904542,-2.08168,-0.495531,0.817634,-2.05292,-0.537391,0.913097,-1.99582,-0.5889,0.636034,-1.97549,-0.637354,0.684226,-2.03436,0.124691,1.35678,-1.8428,0.117038,1.34803,-2.05772},
/*2024*/{0.185956,1.91684,-1.73812,0.275072,1.86033,-1.86943,0.021876,1.83378,-1.69135,-0.103393,1.76334,-1.67733,0.020509,1.66177,-1.67572,0.082928,1.59523,-1.65688,0.252598,1.93484,-2.11071,0.295564,1.86123,-1.94032,0.108123,1.90001,-2.06017,0.143781,1.71919,-2.23947,0.201099,1.6254,-2.26705,0.332955,1.61822,-2.11835,0.392586,1.59854,-2.09492,0.199001,1.4406,-1.84247,0.0156,1.50099,-1.89597,0.02099,1.52566,-1.9596,0.025172,1.49979,-2.01159,0.207975,1.42467,-2.09046,0.27111,1.14579,-1.76962,0.147995,1.0881,-1.79356,0.182374,1.01303,-1.81867,0.29414,0.938518,-1.80522,0.364214,0.761258,-1.80001,0.386206,0.689487,-1.81559,0.257707,0.731067,-1.82643,0.279144,0.66199,-1.83425,0.395199,0.449384,-1.85239,0.33324,0.362126,-1.94532,0.558185,0.476389,-1.88176,0.555485,0.404304,-1.82539,0.124109,1.11053,-2.12734,0.11314,1.02752,-2.11022,-0.017025,1.12816,-2.09735,-0.024325,1.04727,-2.08138,-0.014629,0.909506,-2.08499,-0.177129,0.816515,-2.07522,-0.201741,0.926915,-2.09176,-0.268834,0.907264,-2.08162,-0.488503,0.830155,-2.05474,-0.5268,0.927476,-1.99654,-0.590223,0.652076,-1.97682,-0.632005,0.701005,-2.03472,0.124041,1.35249,-1.84254,0.117854,1.34489,-2.05755},
/*2025*/{0.186651,1.91241,-1.73781,0.281839,1.85352,-1.86792,0.023279,1.82707,-1.68885,-0.10055,1.75617,-1.67302,0.02401,1.65456,-1.67205,0.085879,1.58911,-1.6538,0.252241,1.93004,-2.11234,0.295486,1.8566,-1.94014,0.106935,1.89547,-2.0598,0.137745,1.71417,-2.238,0.195296,1.62039,-2.26657,0.328495,1.60791,-2.12028,0.389491,1.587,-2.09889,0.198755,1.43796,-1.84074,0.015783,1.49677,-1.89636,0.019728,1.52186,-1.96015,0.0241,1.49574,-2.01224,0.207394,1.42222,-2.08933,0.268475,1.14133,-1.76873,0.14615,1.08498,-1.79506,0.180618,1.01015,-1.81955,0.291852,0.935193,-1.80572,0.358463,0.756054,-1.80079,0.380163,0.683481,-1.81652,0.252264,0.726476,-1.82719,0.271302,0.657712,-1.83628,0.382954,0.446205,-1.85663,0.322621,0.357825,-1.949,0.548007,0.467695,-1.88278,0.545117,0.395718,-1.8269,0.129353,1.1068,-2.12633,0.120352,1.02349,-2.10955,-0.011061,1.12149,-2.09723,-0.017755,1.04034,-2.08185,-0.005588,0.903863,-2.08515,-0.170272,0.816422,-2.07491,-0.190284,0.927258,-2.09104,-0.258927,0.911351,-2.08324,-0.481343,0.842333,-2.05544,-0.514988,0.940155,-1.99741,-0.589102,0.667861,-1.97825,-0.632369,0.720418,-2.03669,0.123981,1.34953,-1.84192,0.118581,1.34144,-2.05693},
/*2026*/{0.18651,1.9068,-1.73688,0.280798,1.85094,-1.86838,0.024482,1.82069,-1.6868,-0.098882,1.74818,-1.66883,0.027183,1.64841,-1.66766,0.090471,1.58303,-1.65028,0.250177,1.92506,-2.1138,0.295718,1.8533,-1.94055,0.105483,1.89139,-2.05902,0.132718,1.70997,-2.23635,0.188509,1.61538,-2.26586,0.325596,1.59781,-2.1228,0.386209,1.57525,-2.10257,0.196976,1.43473,-1.83955,0.016007,1.49136,-1.89716,0.019689,1.51767,-1.95956,0.023527,1.49002,-2.01317,0.20799,1.4187,-2.08784,0.266122,1.13654,-1.76778,0.142849,1.08256,-1.79793,0.177037,1.00673,-1.82126,0.288428,0.92958,-1.80577,0.353339,0.749212,-1.80275,0.372099,0.67685,-1.818,0.24537,0.721932,-1.82858,0.265319,0.65306,-1.83764,0.372154,0.439895,-1.85923,0.310088,0.352787,-1.95277,0.537913,0.458454,-1.88449,0.532146,0.385766,-1.82917,0.135492,1.10293,-2.12651,0.128223,1.01855,-2.10978,-0.005641,1.1148,-2.09788,-0.010134,1.03312,-2.08218,0.003009,0.897979,-2.08481,-0.164185,0.816207,-2.07464,-0.180079,0.927739,-2.09121,-0.248094,0.914276,-2.08397,-0.471785,0.852619,-2.05584,-0.502096,0.952418,-1.99758,-0.585359,0.682263,-1.97981,-0.629224,0.737346,-2.03815,0.123653,1.34553,-1.84116,0.119937,1.33705,-2.0562},
/*2027*/{0.187128,1.90153,-1.73646,0.281198,1.84672,-1.86897,0.027067,1.81289,-1.6829,-0.096923,1.7398,-1.66427,0.030086,1.64152,-1.66313,0.09548,1.5767,-1.64686,0.248662,1.91943,-2.11477,0.29425,1.84868,-1.94087,0.104275,1.88592,-2.05818,0.126211,1.70491,-2.23495,0.182397,1.61028,-2.26559,0.321511,1.58789,-2.12538,0.382532,1.56273,-2.10653,0.195269,1.43068,-1.83814,0.014108,1.48748,-1.8972,0.019189,1.51355,-1.96021,0.023815,1.48501,-2.01288,0.207782,1.41527,-2.08698,0.263403,1.13215,-1.76735,0.140758,1.0789,-1.79938,0.175145,1.00303,-1.82173,0.284726,0.924395,-1.80588,0.347054,0.742659,-1.8038,0.364625,0.669767,-1.81984,0.239141,0.717866,-1.83013,0.257841,0.648885,-1.83933,0.359703,0.433928,-1.8619,0.295342,0.352065,-1.95537,0.526003,0.447889,-1.88546,0.518569,0.375982,-1.83139,0.140976,1.09831,-2.12695,0.13556,1.01468,-2.10983,-0.000291,1.10751,-2.09762,-0.002942,1.02644,-2.08199,0.012218,0.892547,-2.08542,-0.156196,0.815936,-2.07497,-0.168381,0.927817,-2.0936,-0.237695,0.916028,-2.08444,-0.46335,0.863259,-2.05635,-0.488054,0.962085,-1.99772,-0.581128,0.695857,-1.98309,-0.623769,0.752574,-2.03996,0.122228,1.34147,-1.8406,0.120154,1.33303,-2.05566},
/*2028*/{0.187503,1.89553,-1.73546,0.280271,1.84148,-1.869,0.028872,1.80516,-1.68109,-0.094456,1.73113,-1.65939,0.034279,1.63369,-1.65884,0.100171,1.56987,-1.64375,0.247234,1.91404,-2.11681,0.294856,1.84443,-1.94118,0.102996,1.88048,-2.0577,0.119885,1.70018,-2.23422,0.176051,1.60436,-2.26486,0.317982,1.5764,-2.12854,0.378143,1.54967,-2.11049,0.195427,1.4273,-1.83586,0.014238,1.48337,-1.89816,0.018481,1.509,-1.96008,0.022753,1.47927,-2.01315,0.208512,1.41163,-2.08588,0.26118,1.12757,-1.7667,0.138874,1.07613,-1.80108,0.171696,0.999393,-1.82421,0.280446,0.918561,-1.80662,0.34005,0.736208,-1.80527,0.354173,0.662854,-1.82057,0.23198,0.713072,-1.83175,0.248204,0.643995,-1.84132,0.345052,0.429793,-1.86331,0.276417,0.356597,-1.95554,0.512557,0.437974,-1.88898,0.500417,0.367069,-1.8336,0.146563,1.09451,-2.1278,0.14295,1.01064,-2.11038,0.004917,1.10049,-2.09727,0.004129,1.01973,-2.08189,0.022185,0.887305,-2.08551,-0.148045,0.815322,-2.07522,-0.157653,0.928025,-2.0923,-0.226518,0.918502,-2.08712,-0.454895,0.872988,-2.05624,-0.475775,0.973009,-1.99789,-0.574798,0.707932,-1.98512,-0.615886,0.765953,-2.04206,0.122512,1.33804,-1.83936,0.121487,1.32848,-2.05438},
/*2029*/{0.18768,1.88883,-1.73461,0.280901,1.83479,-1.86896,0.030561,1.79687,-1.67792,-0.09171,1.722,-1.6539,0.038725,1.62585,-1.65494,0.10507,1.56363,-1.63992,0.245361,1.90831,-2.11784,0.294479,1.83967,-1.94215,0.101631,1.87614,-2.05677,0.114141,1.69473,-2.23306,0.16984,1.59885,-2.2647,0.313515,1.56509,-2.13089,0.373781,1.53665,-2.11475,0.194818,1.42328,-1.8341,0.011968,1.47634,-1.89797,0.018182,1.50377,-1.95936,0.022745,1.47385,-2.0137,0.20804,1.40806,-2.08541,0.259116,1.12282,-1.76527,0.136826,1.07188,-1.80274,0.169516,0.995326,-1.82468,0.276179,0.912742,-1.80719,0.331765,0.728848,-1.80628,0.345517,0.655579,-1.82156,0.223407,0.709261,-1.83308,0.237716,0.639141,-1.84342,0.332743,0.426597,-1.865,0.257952,0.354057,-1.95889,0.49794,0.425136,-1.89275,0.482165,0.356316,-1.83505,0.151568,1.09057,-2.12839,0.14977,1.0057,-2.11089,0.010496,1.09423,-2.09707,0.010876,1.01272,-2.08134,0.031763,0.881537,-2.08638,-0.139728,0.814301,-2.07563,-0.1452,0.927432,-2.09311,-0.215208,0.919641,-2.08575,-0.44149,0.882192,-2.05829,-0.464257,0.981695,-1.99861,-0.566958,0.718708,-1.98785,-0.604064,0.776415,-2.05022,0.122456,1.33293,-1.83907,0.122573,1.32403,-2.05412},
/*2030*/{0.188757,1.88284,-1.73383,0.280481,1.83096,-1.8698,0.033277,1.78839,-1.67416,-0.088296,1.71216,-1.64882,0.043671,1.61787,-1.65114,0.110771,1.55672,-1.63655,0.243432,1.90264,-2.1193,0.294418,1.83474,-1.94284,0.100355,1.86956,-2.05536,0.108989,1.68911,-2.23224,0.16309,1.59329,-2.26425,0.309278,1.55438,-2.13426,0.367837,1.5223,-2.11939,0.194765,1.41758,-1.8319,0.011509,1.4705,-1.89835,0.017459,1.49888,-1.96003,0.021339,1.46824,-2.0141,0.207996,1.40419,-2.08401,0.257188,1.11724,-1.76448,0.135029,1.06753,-1.80241,0.167089,0.990476,-1.82565,0.272445,0.907133,-1.80735,0.324501,0.722809,-1.8073,0.336909,0.648178,-1.82377,0.215298,0.70444,-1.83405,0.229685,0.635459,-1.84452,0.316044,0.42067,-1.86712,0.238526,0.357611,-1.96004,0.482921,0.411505,-1.89666,0.462933,0.345233,-1.8376,0.157595,1.08635,-2.12874,0.157144,1.0016,-2.1119,0.016202,1.0877,-2.09663,0.018268,1.00649,-2.08126,0.041481,0.875526,-2.08694,-0.130907,0.813396,-2.07679,-0.13295,0.92587,-2.0938,-0.203132,0.9211,-2.08661,-0.430351,0.889639,-2.05828,-0.451008,0.988698,-1.99819,-0.559123,0.72765,-1.99199,-0.596971,0.789586,-2.05225,0.12171,1.3275,-1.83885,0.123186,1.31929,-2.05392},
/*2031*/{0.189896,1.87645,-1.73307,0.281132,1.82348,-1.86913,0.036395,1.77899,-1.67096,-0.083986,1.70276,-1.643,0.049837,1.60989,-1.64628,0.117056,1.55062,-1.63395,0.241772,1.89717,-2.12091,0.29382,1.82959,-1.94332,0.098605,1.86429,-2.05475,0.10394,1.68246,-2.23092,0.156626,1.5874,-2.2636,0.3037,1.54197,-2.1374,0.36303,1.50846,-2.12396,0.195103,1.41433,-1.82993,0.00965,1.46513,-1.89958,0.016088,1.49273,-1.95922,0.020526,1.46321,-2.01506,0.207682,1.40039,-2.08381,0.255576,1.11317,-1.76387,0.130633,1.06226,-1.8037,0.165109,0.985768,-1.82577,0.268023,0.901535,-1.80779,0.316255,0.716103,-1.80874,0.327842,0.643206,-1.82518,0.20768,0.701285,-1.83377,0.219743,0.62989,-1.84529,0.299928,0.41765,-1.87076,0.217365,0.355836,-1.9599,0.467422,0.401308,-1.90053,0.444573,0.339912,-1.83874,0.162304,1.08196,-2.12933,0.163813,0.997679,-2.11307,0.021927,1.08087,-2.09653,0.025391,0.999555,-2.08145,0.051841,0.870015,-2.08805,-0.121447,0.813121,-2.0782,-0.12029,0.925436,-2.09468,-0.191209,0.922472,-2.08719,-0.418607,0.895816,-2.05792,-0.438761,0.995299,-1.99891,-0.550387,0.736307,-1.99585,-0.587789,0.799366,-2.05286,0.122002,1.32348,-1.83825,0.124231,1.3147,-2.05329},
/*2032*/{0.190255,1.87,-1.73219,0.281677,1.81948,-1.87037,0.03969,1.76974,-1.66744,-0.078741,1.69325,-1.63718,0.054936,1.60135,-1.64151,0.122703,1.54363,-1.63219,0.239107,1.89154,-2.1219,0.294554,1.82408,-1.9439,0.097179,1.85908,-2.05417,0.098648,1.67649,-2.23034,0.149364,1.58201,-2.26383,0.298584,1.5292,-2.14079,0.356397,1.49419,-2.12875,0.19404,1.40978,-1.82796,0.007822,1.45991,-1.89997,0.014362,1.48629,-1.95892,0.018859,1.45682,-2.01563,0.207548,1.39617,-2.08251,0.25209,1.10795,-1.76216,0.129691,1.05794,-1.80252,0.163292,0.981614,-1.82614,0.262833,0.895164,-1.80691,0.30957,0.710454,-1.81098,0.319358,0.63849,-1.82699,0.199195,0.698311,-1.83532,0.208618,0.628181,-1.84715,0.282928,0.417223,-1.87341,0.195583,0.357044,-1.95841,0.448696,0.394608,-1.90551,0.422337,0.339534,-1.84027,0.167642,1.07822,-2.12979,0.169263,0.993853,-2.11416,0.027359,1.07399,-2.09604,0.031829,0.992705,-2.08141,0.061973,0.864788,-2.08998,-0.111318,0.812149,-2.0798,-0.108195,0.924809,-2.09471,-0.178526,0.923303,-2.08748,-0.405715,0.902602,-2.05948,-0.425763,1.00229,-1.99971,-0.538592,0.742498,-1.99903,-0.577399,0.809703,-2.05763,0.121172,1.31865,-1.8373,0.124784,1.30949,-2.05231},
/*2033*/{0.191586,1.86378,-1.73115,0.281501,1.81182,-1.86972,0.04258,1.75998,-1.66373,-0.073335,1.6831,-1.63129,0.060907,1.59392,-1.63789,0.130323,1.53759,-1.62855,0.238202,1.88656,-2.1235,0.294703,1.81861,-1.94511,0.095724,1.85366,-2.05165,0.092832,1.671,-2.23001,0.141937,1.57611,-2.26371,0.293236,1.51665,-2.14415,0.349761,1.48041,-2.13371,0.191962,1.40438,-1.82573,0.005379,1.45417,-1.90044,0.012353,1.48054,-1.95889,0.017097,1.45062,-2.01583,0.207163,1.39042,-2.08087,0.248638,1.10188,-1.76125,0.127205,1.05333,-1.80157,0.160886,0.978247,-1.82558,0.256567,0.889409,-1.80711,0.30232,0.706377,-1.81244,0.310262,0.63309,-1.83024,0.192414,0.698929,-1.83446,0.199902,0.628802,-1.84712,0.266898,0.417788,-1.87608,0.173939,0.356685,-1.95998,0.428041,0.393359,-1.90936,0.400839,0.339885,-1.83983,0.171129,1.07429,-2.13157,0.176082,0.990223,-2.11541,0.030828,1.0667,-2.09598,0.03926,0.985174,-2.08115,0.072417,0.858951,-2.09184,-0.100767,0.810934,-2.08118,-0.09431,0.926285,-2.09648,-0.165516,0.923404,-2.08728,-0.389178,0.90485,-2.05843,-0.41431,1.00775,-2.00006,-0.526385,0.746952,-2.00244,-0.559461,0.808475,-2.0585,0.118771,1.31328,-1.83607,0.124225,1.30358,-2.05101},
/*2034*/{0.193145,1.85825,-1.73046,0.28285,1.80599,-1.87031,0.047133,1.74953,-1.66031,-0.06805,1.67181,-1.62488,0.06794,1.58576,-1.63402,0.138774,1.53206,-1.62535,0.235784,1.88147,-2.12516,0.295315,1.81232,-1.94617,0.094317,1.84928,-2.05035,0.086394,1.66662,-2.22999,0.135235,1.57092,-2.26339,0.286837,1.50468,-2.14849,0.344008,1.46651,-2.13825,0.189626,1.39994,-1.82476,0.001707,1.44937,-1.90135,0.010011,1.4745,-1.95967,0.014595,1.44572,-2.01655,0.206732,1.38638,-2.08054,0.245071,1.10026,-1.75883,0.122609,1.05128,-1.80182,0.157367,0.977163,-1.82644,0.2512,0.883612,-1.80837,0.297256,0.705446,-1.81369,0.296391,0.631161,-1.83476,0.186165,0.702446,-1.83371,0.190285,0.630753,-1.84735,0.244049,0.420032,-1.87896,0.151657,0.357881,-1.96129,0.405506,0.392228,-1.91117,0.377292,0.339789,-1.84198,0.176163,1.07036,-2.13209,0.18337,0.986736,-2.11651,0.036543,1.06,-2.09542,0.045651,0.978641,-2.08095,0.082877,0.852453,-2.093,-0.089124,0.810042,-2.08277,-0.081911,0.923695,-2.09724,-0.151949,0.922998,-2.08769,-0.374917,0.909363,-2.05857,-0.401999,1.01121,-1.99938,-0.513485,0.751482,-2.00684,-0.546063,0.813672,-2.06391,0.116462,1.30858,-1.83614,0.123606,1.29908,-2.05104},
/*2035*/{0.194742,1.853,-1.72923,0.283028,1.80109,-1.87143,0.052205,1.73991,-1.65613,-0.061583,1.66136,-1.61898,0.07589,1.57822,-1.63032,0.146318,1.52546,-1.62303,0.233345,1.87705,-2.1264,0.29562,1.80721,-1.94786,0.092965,1.84611,-2.0477,0.082828,1.6604,-2.2288,0.127762,1.5655,-2.26271,0.280948,1.49273,-2.15337,0.335644,1.45306,-2.14388,0.187142,1.39551,-1.82291,-0.001973,1.44508,-1.90186,0.007,1.46899,-1.96127,0.011356,1.44025,-2.0173,0.204463,1.38185,-2.0803,0.241476,1.09992,-1.75428,0.120816,1.05164,-1.80136,0.155647,0.976935,-1.82602,0.246782,0.880711,-1.80783,0.292599,0.705617,-1.81386,0.285206,0.62973,-1.83562,0.181112,0.707031,-1.83237,0.181557,0.636742,-1.84657,0.224961,0.420867,-1.87935,0.130083,0.358046,-1.96335,0.383999,0.391663,-1.91203,0.354997,0.339353,-1.84227,0.18019,1.06788,-2.13288,0.19023,0.983878,-2.11775,0.04148,1.05264,-2.09519,0.052384,0.971881,-2.08131,0.092834,0.846416,-2.09242,-0.076605,0.808323,-2.08312,-0.067853,0.921571,-2.09708,-0.138534,0.922731,-2.08729,-0.366598,0.915554,-2.06238,-0.388937,1.01421,-1.99963,-0.49959,0.753167,-2.01134,-0.530772,0.816325,-2.06785,0.113409,1.30431,-1.83566,0.121692,1.29404,-2.0505},
/*2036*/{0.195576,1.84874,-1.72856,0.284297,1.79704,-1.87209,0.056411,1.73031,-1.65279,-0.053649,1.65125,-1.61323,0.083967,1.57082,-1.62642,0.155611,1.51985,-1.61972,0.2317,1.87392,-2.12786,0.296614,1.80184,-1.94894,0.091628,1.84322,-2.04437,0.079229,1.65757,-2.22882,0.120455,1.56055,-2.26167,0.274606,1.48141,-2.15697,0.326854,1.44098,-2.14997,0.183915,1.39221,-1.82158,-0.005289,1.44143,-1.9033,0.003357,1.46436,-1.96167,0.008794,1.4352,-2.01869,0.204262,1.37733,-2.07844,0.239703,1.09786,-1.75097,0.118968,1.05302,-1.80317,0.153484,0.976826,-1.82599,0.248046,0.884346,-1.8054,0.287432,0.705388,-1.81456,0.282941,0.630647,-1.83252,0.175406,0.711483,-1.8311,0.171979,0.640906,-1.84567,0.205464,0.424813,-1.88141,0.107409,0.359654,-1.96346,0.362779,0.388697,-1.91162,0.332599,0.338892,-1.84297,0.184773,1.06458,-2.13222,0.196116,0.982385,-2.11854,0.04559,1.04638,-2.09506,0.060321,0.966282,-2.08122,0.103208,0.841875,-2.09304,-0.064074,0.806662,-2.08357,-0.053865,0.919316,-2.09781,-0.12317,0.92139,-2.08834,-0.351362,0.917744,-2.06362,-0.375474,1.01488,-1.99982,-0.484215,0.753536,-2.01496,-0.515367,0.817179,-2.07184,0.110054,1.30098,-1.83459,0.120775,1.28944,-2.04924},
/*2037*/{0.197038,1.84481,-1.72756,0.284618,1.79274,-1.874,0.062685,1.72128,-1.65003,-0.046116,1.64076,-1.60684,0.093166,1.56489,-1.6242,0.165552,1.51513,-1.61718,0.230692,1.87108,-2.12874,0.296896,1.7979,-1.95119,0.090922,1.84116,-2.04297,0.076368,1.6542,-2.22743,0.113721,1.55757,-2.26017,0.267488,1.4716,-2.16103,0.318425,1.42957,-2.15508,0.180829,1.38948,-1.82021,-0.008403,1.43827,-1.90489,0.001475,1.46033,-1.96251,0.004929,1.42919,-2.01913,0.202414,1.37328,-2.07675,0.235991,1.09842,-1.75091,0.117429,1.05093,-1.80254,0.152009,0.9757,-1.825,0.250751,0.888171,-1.80237,0.279741,0.70403,-1.81419,0.271238,0.63046,-1.83304,0.166871,0.715374,-1.82922,0.160739,0.644032,-1.84262,0.185821,0.424354,-1.88191,0.086295,0.361347,-1.96305,0.341312,0.387919,-1.91087,0.311812,0.337757,-1.8418,0.188894,1.06503,-2.13274,0.203245,0.98259,-2.11927,0.050689,1.04081,-2.09469,0.067798,0.961461,-2.08122,0.114816,0.839073,-2.09335,-0.049741,0.806038,-2.08453,-0.03972,0.917322,-2.09871,-0.109566,0.921091,-2.08971,-0.337493,0.918306,-2.06441,-0.363711,1.01556,-2.00139,-0.468948,0.751942,-2.01874,-0.499557,0.816588,-2.07569,0.107032,1.29834,-1.83315,0.119179,1.28471,-2.04761},
/*2038*/{0.197934,1.84115,-1.72704,0.284685,1.78943,-1.875,0.068893,1.71369,-1.64789,-0.036187,1.63198,-1.60185,0.102649,1.55853,-1.62113,0.176021,1.51146,-1.61411,0.229368,1.8684,-2.12884,0.297023,1.7939,-1.95333,0.090253,1.84046,-2.04066,0.071796,1.65316,-2.22545,0.107818,1.55584,-2.25778,0.258461,1.46287,-2.1638,0.309252,1.41871,-2.16009,0.17853,1.38799,-1.81806,-0.010134,1.43606,-1.9074,-0.000151,1.45981,-1.96319,0.002411,1.42589,-2.02159,0.200911,1.37065,-2.07591,0.232648,1.09884,-1.75022,0.115095,1.04839,-1.80107,0.152385,0.974682,-1.82548,0.257351,0.891456,-1.80052,0.269344,0.703126,-1.81303,0.260842,0.631868,-1.83362,0.1578,0.717402,-1.8269,0.1502,0.647053,-1.83979,0.16653,0.423636,-1.87963,0.065272,0.36212,-1.96314,0.320633,0.387524,-1.91197,0.290832,0.337532,-1.84111,0.193803,1.06512,-2.13313,0.210422,0.98375,-2.11965,0.056142,1.03732,-2.096,0.076409,0.958603,-2.08128,0.127834,0.837187,-2.09327,-0.035902,0.804327,-2.08392,-0.02514,0.914788,-2.0996,-0.094554,0.919079,-2.08884,-0.325582,0.917675,-2.06436,-0.35087,1.01474,-2.00159,-0.452446,0.750701,-2.02303,-0.482071,0.81338,-2.08017,0.103922,1.29709,-1.83263,0.117883,1.28204,-2.04689},
/*2039*/{0.199202,1.83832,-1.7267,0.284915,1.78496,-1.87632,0.074164,1.70775,-1.64572,-0.026656,1.62401,-1.59647,0.112877,1.55411,-1.61894,0.188071,1.50836,-1.61204,0.228787,1.86599,-2.12901,0.297158,1.79076,-1.95443,0.090513,1.83979,-2.04017,0.066895,1.65228,-2.2227,0.100634,1.55589,-2.25575,0.249343,1.45647,-2.1657,0.299102,1.40965,-2.16576,0.175997,1.38723,-1.81623,-0.012902,1.43586,-1.90841,-0.001409,1.45935,-1.96447,-0.000133,1.4229,-2.02283,0.200291,1.36807,-2.07519,0.229796,1.09838,-1.74916,0.111405,1.04487,-1.80076,0.148268,0.971774,-1.82241,0.26153,0.893418,-1.80244,0.259198,0.701734,-1.81089,0.249348,0.630185,-1.83076,0.147305,0.718734,-1.82591,0.137964,0.648552,-1.83923,0.147624,0.425854,-1.88001,0.043615,0.363045,-1.96259,0.299193,0.386335,-1.90976,0.270634,0.337224,-1.83999,0.199006,1.06633,-2.13316,0.218573,0.985147,-2.11942,0.061543,1.03439,-2.09685,0.083518,0.955949,-2.0822,0.141687,0.836318,-2.09277,-0.021314,0.802057,-2.0834,-0.010268,0.913858,-2.09993,-0.079866,0.918027,-2.09103,-0.308291,0.914955,-2.06527,-0.338686,1.01179,-2.00209,-0.434967,0.746369,-2.02598,-0.464389,0.808669,-2.08413,0.100722,1.29685,-1.83145,0.116309,1.27967,-2.04543},
/*2040*/{0.200256,1.83635,-1.7276,0.284067,1.78366,-1.87763,0.079674,1.70353,-1.6442,-0.017482,1.61773,-1.59209,0.123809,1.55059,-1.61703,0.199284,1.50635,-1.61075,0.228821,1.86389,-2.12926,0.297035,1.78814,-1.95496,0.09053,1.8394,-2.04027,0.06219,1.65304,-2.21981,0.092928,1.55679,-2.25457,0.240572,1.45237,-2.16771,0.288821,1.40236,-2.17098,0.173351,1.38616,-1.81489,-0.013357,1.43515,-1.90851,-0.003159,1.45899,-1.96471,-0.001463,1.42192,-2.02321,0.196852,1.3658,-2.07566,0.229145,1.09828,-1.74829,0.106723,1.04544,-1.80117,0.143718,0.970445,-1.82071,0.261604,0.892158,-1.8027,0.245686,0.698875,-1.8096,0.233443,0.625928,-1.82865,0.135232,0.719043,-1.82472,0.123922,0.649061,-1.83782,0.12782,0.424095,-1.87862,0.022698,0.363046,-1.96173,0.27855,0.385911,-1.91099,0.247809,0.336863,-1.8405,0.205855,1.06807,-2.13295,0.226951,0.987437,-2.11912,0.069804,1.03139,-2.0976,0.092972,0.953474,-2.08401,0.157046,0.837734,-2.09276,-0.005919,0.800742,-2.08302,0.004336,0.912496,-2.10098,-0.064674,0.915397,-2.09041,-0.292612,0.913175,-2.06823,-0.329187,1.00832,-2.00493,-0.416186,0.741328,-2.02889,-0.446471,0.802736,-2.08749,0.097918,1.29607,-1.83095,0.113307,1.2779,-2.04487},
/*2041*/{0.2011,1.83517,-1.72783,0.284131,1.78029,-1.87861,0.08529,1.70065,-1.64285,-0.008006,1.61179,-1.58821,0.135902,1.54773,-1.61512,0.211678,1.50612,-1.60862,0.229212,1.86209,-2.12995,0.296478,1.78665,-1.95613,0.089869,1.83896,-2.04047,0.056463,1.65512,-2.21694,0.085639,1.55837,-2.25318,0.231188,1.44867,-2.17076,0.277748,1.39646,-2.17646,0.171807,1.38535,-1.81296,-0.015086,1.43549,-1.90942,-0.004893,1.45844,-1.96478,-0.002843,1.42122,-2.02309,0.195183,1.36438,-2.07568,0.219087,1.09318,-1.74928,0.099173,1.04374,-1.80162,0.137965,0.967742,-1.82166,0.253097,0.886792,-1.80162,0.232008,0.69502,-1.80846,0.216899,0.622367,-1.82705,0.122234,0.718778,-1.824,0.109036,0.64855,-1.83708,0.106682,0.424831,-1.87722,0.00075,0.363965,-1.9604,0.257197,0.385543,-1.90965,0.226031,0.335951,-1.83915,0.212888,1.06974,-2.13324,0.236821,0.990226,-2.11887,0.076748,1.02932,-2.09918,0.103997,0.952238,-2.08495,0.174324,0.83969,-2.09222,0.009269,0.79891,-2.08225,0.019894,0.910174,-2.10113,-0.050162,0.912868,-2.09141,-0.278732,0.909322,-2.06865,-0.319086,1.00421,-2.00622,-0.396327,0.734097,-2.03105,-0.428612,0.793336,-2.09032,0.095498,1.29577,-1.83026,0.111376,1.2768,-2.04407},
/*2042*/{0.201926,1.83393,-1.72904,0.284204,1.77907,-1.87871,0.090132,1.69901,-1.64146,0.002602,1.60772,-1.58439,0.14721,1.54689,-1.61287,0.224444,1.50672,-1.60831,0.22849,1.86084,-2.12988,0.29443,1.78544,-1.95716,0.089532,1.83798,-2.0409,0.051158,1.65739,-2.21338,0.077507,1.5606,-2.2525,0.222134,1.44603,-2.17466,0.267122,1.39282,-2.18175,0.168932,1.38467,-1.81261,-0.016363,1.43456,-1.90914,-0.006543,1.4577,-1.96515,-0.003678,1.42197,-2.02309,0.194337,1.36371,-2.07584,0.213101,1.09056,-1.74945,0.09589,1.04271,-1.79933,0.130491,0.965559,-1.82214,0.241713,0.882558,-1.8005,0.218267,0.691646,-1.80647,0.201436,0.619852,-1.82625,0.108885,0.718024,-1.82227,0.09264,0.648262,-1.83738,0.085673,0.424882,-1.87644,-0.020035,0.364653,-1.95902,0.235963,0.384935,-1.90842,0.204873,0.335802,-1.83837,0.22141,1.0723,-2.13239,0.24738,0.993536,-2.11847,0.086125,1.02824,-2.1007,0.114159,0.951172,-2.08588,0.188909,0.841929,-2.09287,0.024591,0.79728,-2.08165,0.03457,0.909074,-2.10102,-0.034086,0.911561,-2.09193,-0.264666,0.905428,-2.07004,-0.309151,0.999187,-2.00904,-0.375721,0.725299,-2.03457,-0.408545,0.783867,-2.09377,0.093216,1.29483,-1.83053,0.110015,1.27657,-2.04433},
/*2043*/{0.203508,1.83344,-1.72926,0.282596,1.77905,-1.87996,0.09413,1.69777,-1.6402,0.010268,1.60362,-1.58094,0.158613,1.54682,-1.61181,0.236945,1.50834,-1.60791,0.228193,1.85995,-2.13052,0.293655,1.78433,-1.95723,0.089176,1.83805,-2.04204,0.044273,1.66246,-2.20979,0.068079,1.56388,-2.25161,0.211926,1.4438,-2.17866,0.255534,1.39002,-2.18657,0.167452,1.38429,-1.81106,-0.017332,1.43445,-1.9092,-0.007014,1.45766,-1.96464,-0.005508,1.42249,-2.02332,0.192611,1.36373,-2.07666,0.20891,1.08848,-1.74855,0.088073,1.04185,-1.79955,0.122371,0.963923,-1.82137,0.228005,0.877723,-1.79933,0.202993,0.687984,-1.80613,0.184478,0.616272,-1.82514,0.094885,0.7175,-1.82213,0.077671,0.648095,-1.83708,0.06465,0.425116,-1.87531,-0.041309,0.365651,-1.95836,0.214014,0.384898,-1.90731,0.183936,0.335043,-1.837,0.228916,1.0768,-2.1337,0.258444,0.99773,-2.11818,0.095576,1.0291,-2.10241,0.126257,0.951619,-2.08719,0.205454,0.844742,-2.09257,0.040071,0.796208,-2.08068,0.049945,0.90833,-2.10083,-0.020561,0.910028,-2.09311,-0.251139,0.898974,-2.07016,-0.30001,0.992281,-2.00991,-0.354309,0.716392,-2.03631,-0.388193,0.772171,-2.09714,0.091633,1.29448,-1.83061,0.108398,1.27666,-2.04445},
/*2044*/{0.205167,1.83369,-1.72938,0.282706,1.77853,-1.88022,0.098352,1.69781,-1.63909,0.021642,1.60075,-1.57721,0.169746,1.54717,-1.60974,0.250595,1.51162,-1.60755,0.227708,1.85966,-2.13035,0.292852,1.78383,-1.9578,0.089079,1.8382,-2.04249,0.039226,1.66755,-2.2065,0.059243,1.56843,-2.25155,0.202547,1.44404,-2.1834,0.244419,1.38935,-2.19111,0.164981,1.384,-1.81032,-0.019397,1.43425,-1.90948,-0.008554,1.45721,-1.9652,-0.00624,1.4224,-2.02203,0.191319,1.36396,-2.07694,0.203186,1.08184,-1.74872,0.083005,1.03884,-1.79851,0.111002,0.963515,-1.82107,0.215185,0.873847,-1.79836,0.187256,0.684464,-1.8064,0.167378,0.612498,-1.8253,0.080508,0.715985,-1.8228,0.061316,0.647615,-1.83749,0.043831,0.425579,-1.87445,-0.062574,0.366043,-1.95788,0.193279,0.384043,-1.90763,0.163429,0.334897,-1.83702,0.237576,1.08151,-2.13337,0.268934,1.00299,-2.11759,0.105859,1.02852,-2.10417,0.13913,0.952006,-2.08785,0.221526,0.847157,-2.09083,0.056535,0.795135,-2.07977,0.063763,0.907432,-2.10076,-0.006841,0.908868,-2.09406,-0.236596,0.893469,-2.07122,-0.291016,0.983981,-2.01267,-0.332901,0.705554,-2.0384,-0.367471,0.760415,-2.10072,0.089687,1.29408,-1.83058,0.10718,1.27672,-2.0444},
/*2045*/{0.205531,1.83412,-1.72999,0.282047,1.77801,-1.88074,0.102546,1.69767,-1.63746,0.029915,1.59828,-1.57365,0.1813,1.54879,-1.60861,0.262945,1.51588,-1.60861,0.226672,1.85949,-2.13012,0.292718,1.78367,-1.95778,0.088954,1.8394,-2.04246,0.034008,1.67376,-2.20307,0.049503,1.57392,-2.2515,0.193671,1.44561,-2.18698,0.233388,1.39092,-2.19483,0.164024,1.38452,-1.81018,-0.01994,1.43371,-1.90927,-0.01042,1.45687,-1.96493,-0.0078,1.42342,-2.02133,0.189517,1.36579,-2.07727,0.19627,1.07854,-1.74925,0.074165,1.03944,-1.79894,0.100852,0.962589,-1.82165,0.200586,0.869598,-1.79812,0.172511,0.680552,-1.80658,0.151412,0.609565,-1.82551,0.06575,0.714226,-1.82287,0.045436,0.645567,-1.83787,0.024207,0.425176,-1.87372,-0.082931,0.366493,-1.95715,0.172905,0.384129,-1.90543,0.142707,0.334786,-1.83571,0.246137,1.08663,-2.13308,0.280189,1.00953,-2.11732,0.115255,1.02948,-2.1056,0.151592,0.954105,-2.08957,0.2378,0.851787,-2.09099,0.072685,0.795086,-2.07936,0.076697,0.9073,-2.10082,0.006868,0.906721,-2.09443,-0.222905,0.885938,-2.07186,-0.281473,0.974464,-2.01468,-0.308431,0.693617,-2.03926,-0.344666,0.747528,-2.10335,0.089352,1.29411,-1.83104,0.106401,1.2779,-2.04499},
/*2046*/{0.206699,1.83492,-1.73026,0.28112,1.77808,-1.88075,0.106073,1.69791,-1.6366,0.040072,1.59572,-1.57051,0.191904,1.55108,-1.60843,0.275836,1.52052,-1.61032,0.225531,1.86019,-2.13029,0.292156,1.78391,-1.95808,0.087807,1.84103,-2.04199,0.027211,1.68029,-2.1999,0.040754,1.58009,-2.25133,0.184122,1.4493,-2.19096,0.222616,1.39347,-2.19866,0.16326,1.38483,-1.80999,-0.021185,1.43455,-1.90952,-0.011236,1.45835,-1.96439,-0.008972,1.42363,-2.0198,0.189267,1.3677,-2.077,0.185682,1.07722,-1.74946,0.062654,1.04091,-1.80143,0.091831,0.96111,-1.82176,0.187225,0.864989,-1.79821,0.155658,0.676805,-1.80651,0.13514,0.608018,-1.82598,0.05055,0.711666,-1.82301,0.030168,0.644558,-1.83834,0.00394,0.425312,-1.8741,-0.103491,0.366864,-1.95713,0.15256,0.383944,-1.90667,0.121705,0.334634,-1.83554,0.254017,1.09322,-2.13292,0.290137,1.01687,-2.11701,0.125332,1.03133,-2.1066,0.162772,0.959748,-2.09183,0.251813,0.855582,-2.09091,0.088844,0.795244,-2.07924,0.091044,0.908212,-2.10148,0.021139,0.905265,-2.09506,-0.209463,0.878363,-2.07203,-0.274873,0.96462,-2.01556,-0.285286,0.682562,-2.04155,-0.322642,0.733977,-2.10621,0.088741,1.29462,-1.83105,0.105926,1.27932,-2.04506},
/*2047*/{0.208334,1.83637,-1.73023,0.282567,1.77943,-1.88256,0.111132,1.69875,-1.63582,0.049886,1.59365,-1.56734,0.202479,1.55438,-1.60831,0.287209,1.52636,-1.61175,0.224242,1.86077,-2.13025,0.290867,1.78397,-1.95917,0.086684,1.84198,-2.04154,0.021065,1.68721,-2.1985,0.031438,1.58696,-2.25119,0.17364,1.45247,-2.19367,0.211351,1.39741,-2.20205,0.161479,1.38501,-1.80903,-0.022217,1.43479,-1.90965,-0.011254,1.45863,-1.9644,-0.010205,1.42484,-2.01979,0.188402,1.37027,-2.07698,0.17845,1.07541,-1.75003,0.056091,1.04319,-1.80123,0.079655,0.962624,-1.82248,0.171957,0.860579,-1.79941,0.139831,0.67418,-1.80717,0.116773,0.604393,-1.82651,0.034337,0.710679,-1.82396,0.014107,0.642589,-1.83977,-0.015316,0.427059,-1.87385,-0.123847,0.367415,-1.95716,0.132061,0.383796,-1.90624,0.10128,0.33512,-1.83588,0.261266,1.09928,-2.13226,0.300496,1.02499,-2.11668,0.135174,1.03329,-2.10667,0.174625,0.962967,-2.09242,0.266544,0.860311,-2.09113,0.105089,0.796085,-2.07971,0.103868,0.908421,-2.10133,0.034015,0.904026,-2.09547,-0.194887,0.869949,-2.07287,-0.267329,0.95251,-2.01877,-0.260388,0.670164,-2.04247,-0.299642,0.719842,-2.10889,0.087662,1.29461,-1.83172,0.10576,1.28108,-2.04577},
/*2048*/{0.21028,1.83888,-1.73124,0.282384,1.78049,-1.8827,0.116235,1.6994,-1.63504,0.059421,1.59281,-1.56499,0.212685,1.55875,-1.60861,0.29861,1.53326,-1.61415,0.223164,1.8627,-2.13055,0.290197,1.78457,-1.95988,0.086109,1.84431,-2.04076,0.014369,1.69338,-2.19589,0.023344,1.59401,-2.25149,0.164659,1.45873,-2.19597,0.201301,1.40258,-2.20442,0.160723,1.38559,-1.80921,-0.022296,1.43651,-1.90957,-0.011445,1.45888,-1.96385,-0.011369,1.42585,-2.01995,0.187607,1.37263,-2.07699,0.171769,1.07412,-1.75036,0.045098,1.04344,-1.80243,0.069132,0.963015,-1.82244,0.156568,0.856174,-1.79959,0.123699,0.672211,-1.80866,0.100562,0.60237,-1.8278,0.017782,0.709636,-1.82441,-0.004021,0.64277,-1.83767,-0.036927,0.428011,-1.87556,-0.144089,0.368371,-1.95764,0.1114,0.383145,-1.90661,0.080332,0.334783,-1.83538,0.268081,1.10635,-2.13203,0.309117,1.03356,-2.11632,0.14375,1.03708,-2.10781,0.186162,0.967566,-2.09272,0.280714,0.865583,-2.09097,0.1214,0.797699,-2.07961,0.116673,0.91021,-2.1019,0.045902,0.903263,-2.09584,-0.181247,0.860361,-2.07421,-0.259448,0.938785,-2.01908,-0.236703,0.657917,-2.04457,-0.276198,0.70535,-2.11151,0.087394,1.29532,-1.8322,0.105378,1.28274,-2.04631},
/*2049*/{0.212488,1.84085,-1.73175,0.28268,1.78157,-1.88373,0.121311,1.70038,-1.63453,0.068235,1.59259,-1.56263,0.222186,1.56281,-1.60918,0.308912,1.5405,-1.61714,0.220575,1.86451,-2.13094,0.289736,1.78675,-1.96078,0.084651,1.84543,-2.03992,0.007766,1.69992,-2.19401,0.014593,1.60117,-2.25148,0.155474,1.46514,-2.19765,0.190595,1.40849,-2.20651,0.160646,1.38562,-1.80921,-0.022596,1.4371,-1.90958,-0.012091,1.46032,-1.9637,-0.011769,1.42701,-2.01982,0.187016,1.37411,-2.07718,0.163322,1.07213,-1.75155,0.037453,1.04516,-1.80173,0.057737,0.963805,-1.82433,0.140133,0.853729,-1.80103,0.107674,0.671994,-1.80958,0.083729,0.602521,-1.82913,0.002309,0.710177,-1.82613,-0.020526,0.642459,-1.83901,-0.055083,0.428279,-1.8746,-0.164309,0.369287,-1.95717,0.09086,0.383112,-1.90605,0.060286,0.334979,-1.8361,0.27391,1.11482,-2.13174,0.318139,1.04277,-2.11591,0.152364,1.04046,-2.10755,0.196336,0.972977,-2.0929,0.293742,0.871676,-2.09075,0.136692,0.798693,-2.07935,0.128559,0.911377,-2.10223,0.05895,0.901804,-2.09612,-0.163448,0.84748,-2.07124,-0.250902,0.92436,-2.02042,-0.211086,0.645684,-2.04667,-0.252513,0.690711,-2.11382,0.086972,1.29562,-1.83281,0.104827,1.2841,-2.04699},
/*2050*/{0.214785,1.84309,-1.73269,0.28222,1.78389,-1.885,0.127981,1.70193,-1.6337,0.079553,1.59316,-1.56083,0.23236,1.56799,-1.6111,0.319194,1.54879,-1.62086,0.218323,1.86726,-2.13116,0.288693,1.78912,-1.96185,0.083536,1.84797,-2.03848,0.002628,1.7077,-2.19244,0.006631,1.60913,-2.25181,0.146555,1.47213,-2.19896,0.181056,1.41555,-2.20785,0.160602,1.38638,-1.81023,-0.022596,1.43903,-1.90936,-0.012757,1.46231,-1.96326,-0.011289,1.42879,-2.0204,0.187372,1.37683,-2.07698,0.155991,1.07238,-1.75234,0.027233,1.04719,-1.80269,0.046943,0.964673,-1.8225,0.122972,0.853354,-1.80235,0.091384,0.671033,-1.81109,0.064916,0.601141,-1.82958,-0.013246,0.711311,-1.82679,-0.038121,0.644243,-1.84152,-0.075339,0.42843,-1.87366,-0.184832,0.370142,-1.95717,0.070854,0.383491,-1.90669,0.039643,0.335449,-1.83625,0.279671,1.12245,-2.13181,0.325576,1.05188,-2.11554,0.159904,1.04465,-2.10739,0.206351,0.978679,-2.09237,0.308374,0.879549,-2.09102,0.153087,0.80059,-2.07972,0.140262,0.913168,-2.10099,0.070892,0.900623,-2.09732,-0.154749,0.839827,-2.07569,-0.241807,0.908422,-2.02036,-0.185726,0.632846,-2.04916,-0.228627,0.67626,-2.11584,0.086948,1.29668,-1.83372,0.105001,1.28655,-2.04796},
/*2051*/{0.217626,1.84658,-1.73313,0.282853,1.78652,-1.88601,0.134357,1.70338,-1.63258,0.087763,1.59382,-1.55876,0.241661,1.57423,-1.61265,0.329133,1.55738,-1.62392,0.214893,1.87006,-2.13123,0.288326,1.79166,-1.96309,0.082315,1.84951,-2.03693,-0.002495,1.71361,-2.19047,-0.002138,1.6165,-2.25184,0.137577,1.47971,-2.19981,0.171921,1.42329,-2.20885,0.160233,1.38618,-1.80915,-0.022127,1.44116,-1.90931,-0.01304,1.46421,-1.96315,-0.011653,1.43078,-2.02034,0.187176,1.37945,-2.07674,0.145448,1.07075,-1.75504,0.018567,1.04986,-1.8022,0.035477,0.966664,-1.82241,0.106234,0.853232,-1.80448,0.074351,0.670879,-1.81213,0.047736,0.602011,-1.83022,-0.028968,0.713069,-1.82649,-0.054868,0.647001,-1.84046,-0.095532,0.428779,-1.87422,-0.204897,0.372002,-1.95698,0.051178,0.383166,-1.9067,0.019246,0.335721,-1.83652,0.285015,1.13005,-2.13022,0.332047,1.0613,-2.11535,0.167653,1.04899,-2.10774,0.215436,0.98398,-2.092,0.319849,0.888865,-2.09077,0.168687,0.803212,-2.08059,0.151227,0.913598,-2.10122,0.082352,0.899173,-2.09684,-0.137893,0.826741,-2.07326,-0.233013,0.89124,-2.02139,-0.159172,0.620239,-2.05019,-0.203739,0.661146,-2.1181,0.086094,1.29731,-1.83432,0.104669,1.28884,-2.04858},
/*2052*/{0.220286,1.85,-1.73375,0.282398,1.78978,-1.88716,0.141512,1.7054,-1.63206,0.09676,1.59616,-1.5585,0.249725,1.58023,-1.61487,0.337297,1.56636,-1.62794,0.212377,1.87369,-2.13188,0.287888,1.79414,-1.96438,0.080802,1.85204,-2.03573,-0.008469,1.72086,-2.18917,-0.008596,1.62452,-2.25155,0.130145,1.48794,-2.20036,0.163171,1.43145,-2.21003,0.160653,1.3872,-1.80962,-0.021333,1.44469,-1.90876,-0.010779,1.46815,-1.96281,-0.010769,1.43234,-2.02012,0.187453,1.38192,-2.07627,0.137962,1.0706,-1.75671,0.009996,1.0485,-1.79999,0.024149,0.969597,-1.82296,0.089634,0.854,-1.80579,0.057362,0.671169,-1.81367,0.029879,0.603134,-1.83186,-0.045727,0.714155,-1.82862,-0.071798,0.649833,-1.84064,-0.116644,0.429725,-1.87325,-0.225325,0.374194,-1.95647,0.030632,0.382729,-1.90724,-0.001716,0.335479,-1.83621,0.289743,1.13813,-2.13085,0.338884,1.07054,-2.11475,0.174559,1.05301,-2.10622,0.224121,0.98964,-2.09114,0.3334,0.899368,-2.09067,0.183769,0.804941,-2.08053,0.16208,0.914866,-2.1009,0.093133,0.897534,-2.09728,-0.121501,0.813936,-2.07285,-0.22369,0.873993,-2.02145,-0.131395,0.608248,-2.05335,-0.179615,0.64681,-2.12076,0.086107,1.29929,-1.83443,0.104553,1.29125,-2.04872},
/*2053*/{0.222771,1.85363,-1.73488,0.28287,1.79235,-1.88885,0.149393,1.70761,-1.63125,0.106919,1.59839,-1.55712,0.258165,1.58728,-1.61745,0.345934,1.57567,-1.63218,0.208526,1.87738,-2.13221,0.287696,1.79756,-1.96594,0.079549,1.85384,-2.03371,-0.014759,1.72824,-2.18863,-0.016213,1.63241,-2.25154,0.121752,1.49656,-2.20029,0.155108,1.43988,-2.2111,0.161303,1.38779,-1.80885,-0.019977,1.44543,-1.90738,-0.011517,1.46851,-1.96129,-0.010364,1.43506,-2.02022,0.187574,1.38507,-2.07547,0.132231,1.07013,-1.75757,0.001154,1.05468,-1.80204,0.012758,0.972544,-1.82348,0.074668,0.856264,-1.80823,0.040011,0.672831,-1.81475,0.011232,0.604917,-1.83369,-0.063159,0.716173,-1.8296,-0.088734,0.650719,-1.8416,-0.13586,0.43191,-1.87326,-0.24478,0.376956,-1.95585,0.009968,0.382216,-1.90723,-0.022346,0.335126,-1.83608,0.294337,1.14593,-2.13029,0.345694,1.08013,-2.11442,0.181214,1.05845,-2.10673,0.232838,0.995958,-2.09078,0.344536,0.909963,-2.08983,0.198895,0.808366,-2.08107,0.170397,0.917255,-2.10158,0.103334,0.895844,-2.09766,-0.108255,0.802984,-2.07512,-0.212563,0.855281,-2.02,-0.10362,0.596369,-2.05641,-0.154185,0.6319,-2.12228,0.087038,1.29974,-1.83478,0.105458,1.29387,-2.04914},
/*2054*/{0.224774,1.85838,-1.73611,0.281957,1.79634,-1.88879,0.157392,1.71061,-1.63102,0.116986,1.60055,-1.55566,0.265079,1.59407,-1.61991,0.353293,1.58526,-1.63664,0.205993,1.88184,-2.13199,0.287302,1.80122,-1.9672,0.078512,1.85634,-2.03289,-0.020496,1.73636,-2.18803,-0.023179,1.64067,-2.25089,0.113979,1.50516,-2.20047,0.147815,1.44916,-2.21193,0.161328,1.38802,-1.80818,-0.020754,1.44736,-1.90803,-0.010764,1.47066,-1.96055,-0.010146,1.43872,-2.01998,0.188141,1.38784,-2.07455,0.126496,1.07053,-1.75982,-0.006107,1.05997,-1.80313,0.002088,0.977186,-1.82376,0.061716,0.858417,-1.81064,0.02299,0.674662,-1.81575,-0.005294,0.607263,-1.83381,-0.080176,0.718789,-1.83099,-0.105973,0.653577,-1.84172,-0.154303,0.434141,-1.87356,-0.264411,0.38066,-1.95535,-0.009943,0.381635,-1.90717,-0.042301,0.335319,-1.83635,0.29864,1.15357,-2.13036,0.351672,1.08897,-2.11332,0.187547,1.06433,-2.1061,0.240247,1.00307,-2.0902,0.354821,0.921871,-2.08903,0.213002,0.81136,-2.08176,0.179396,0.919106,-2.10197,0.114371,0.893963,-2.09761,-0.096749,0.790873,-2.07629,-0.200793,0.834932,-2.02028,-0.076136,0.583613,-2.0573,-0.127869,0.616621,-2.12405,0.086113,1.30056,-1.83556,0.10561,1.29683,-2.04988},
/*2055*/{0.227415,1.86229,-1.7374,0.284937,1.80087,-1.89126,0.163915,1.71354,-1.63139,0.124023,1.60272,-1.55508,0.27257,1.60049,-1.62227,0.359891,1.59443,-1.6414,0.202908,1.88642,-2.13193,0.287347,1.80466,-1.9686,0.076998,1.85931,-2.02948,-0.024711,1.74403,-2.18685,-0.029766,1.64875,-2.25021,0.107674,1.51483,-2.20021,0.141216,1.45808,-2.21213,0.162047,1.38916,-1.80673,-0.01923,1.44963,-1.90663,-0.009741,1.47356,-1.95919,-0.010396,1.44143,-2.02021,0.188877,1.39173,-2.0733,0.118495,1.07094,-1.76213,-0.013816,1.06411,-1.80219,-0.009059,0.98082,-1.82563,0.048546,0.861641,-1.81205,0.005984,0.677546,-1.81694,-0.022066,0.609181,-1.83411,-0.096103,0.721475,-1.83169,-0.124893,0.65782,-1.84528,-0.174776,0.438549,-1.87393,-0.283889,0.386362,-1.95479,-0.028351,0.38135,-1.90689,-0.062471,0.335714,-1.83719,0.302889,1.16126,-2.12971,0.35693,1.09784,-2.11292,0.193766,1.06963,-2.10515,0.247368,1.00961,-2.08973,0.365715,0.93255,-2.08845,0.227399,0.81419,-2.08204,0.1875,0.919874,-2.10166,0.123097,0.89142,-2.09737,-0.077624,0.776026,-2.07391,-0.188615,0.813916,-2.02029,-0.050644,0.575021,-2.06116,-0.103379,0.602776,-2.12569,0.086716,1.30219,-1.8355,0.106522,1.3002,-2.04982},
/*2056*/{0.229484,1.86713,-1.73835,0.285665,1.80401,-1.89295,0.171191,1.71685,-1.63144,0.133214,1.60613,-1.55432,0.279031,1.60842,-1.62449,0.365926,1.60448,-1.64623,0.199235,1.89089,-2.132,0.286966,1.8095,-1.97005,0.075758,1.86122,-2.02767,-0.030511,1.75167,-2.18704,-0.036176,1.65699,-2.24959,0.100663,1.5239,-2.20008,0.13383,1.46727,-2.21278,0.162696,1.38961,-1.80602,-0.017945,1.45181,-1.90659,-0.008893,1.47644,-1.95759,-0.007887,1.44554,-2.01942,0.189467,1.39509,-2.07191,0.110809,1.07144,-1.76447,-0.020908,1.06913,-1.80331,-0.018382,0.98617,-1.82596,0.035728,0.864637,-1.81363,-0.009981,0.680582,-1.818,-0.040429,0.612326,-1.83517,-0.112901,0.725428,-1.83277,-0.141292,0.66082,-1.84443,-0.19199,0.440753,-1.87158,-0.302275,0.39225,-1.95413,-0.047945,0.380859,-1.90692,-0.083168,0.336385,-1.83729,0.306307,1.16913,-2.12958,0.361466,1.10796,-2.11348,0.198755,1.07553,-2.10466,0.254272,1.01726,-2.08909,0.374379,0.94383,-2.08784,0.24136,0.817234,-2.08248,0.195751,0.920437,-2.1007,0.133112,0.888388,-2.09614,-0.067168,0.764586,-2.07511,-0.175731,0.793087,-2.01999,-0.019878,0.562617,-2.06185,-0.076152,0.58844,-2.12707,0.086792,1.30326,-1.83604,0.107406,1.30373,-2.05029},
/*2057*/{0.231452,1.87193,-1.73996,0.285576,1.80806,-1.89459,0.177332,1.72057,-1.63188,0.14107,1.61011,-1.55393,0.284856,1.61599,-1.62788,0.371194,1.61379,-1.65163,0.196749,1.89547,-2.13127,0.286847,1.81322,-1.97185,0.0745,1.86451,-2.02707,-0.033226,1.75908,-2.18589,-0.042102,1.66496,-2.24849,0.093772,1.53197,-2.19894,0.127795,1.47685,-2.21304,0.163264,1.39034,-1.80518,-0.016455,1.45591,-1.90674,-0.00812,1.47975,-1.95675,-0.006418,1.44985,-2.01936,0.190289,1.39954,-2.07047,0.107585,1.07444,-1.76596,-0.028251,1.07423,-1.80335,-0.02826,0.990676,-1.82727,0.023597,0.86871,-1.81535,-0.027155,0.684476,-1.81855,-0.057427,0.617051,-1.83503,-0.129707,0.730355,-1.83336,-0.157822,0.665515,-1.84535,-0.210149,0.445205,-1.87032,-0.32069,0.39881,-1.95315,-0.06752,0.379175,-1.90693,-0.102882,0.336656,-1.83781,0.309712,1.17736,-2.12938,0.365883,1.11649,-2.11217,0.203788,1.08113,-2.10408,0.259982,1.02371,-2.08794,0.382619,0.954434,-2.08726,0.254351,0.820963,-2.08295,0.2033,0.921123,-2.10016,0.142387,0.885781,-2.0955,-0.049501,0.751361,-2.07432,-0.161063,0.771999,-2.01853,0.009449,0.552855,-2.06421,-0.04867,0.575916,-2.12836,0.086555,1.30519,-1.83681,0.108237,1.30802,-2.05093},
/*2058*/{0.233546,1.87742,-1.74106,0.284942,1.81245,-1.89604,0.184305,1.72487,-1.63241,0.149013,1.61405,-1.55338,0.290207,1.62398,-1.63103,0.375427,1.62351,-1.65557,0.193809,1.8999,-2.13084,0.285964,1.81663,-1.97302,0.073695,1.86824,-2.02461,-0.038394,1.76694,-2.18479,-0.047742,1.67317,-2.24716,0.088414,1.54118,-2.19773,0.122032,1.48602,-2.21304,0.163531,1.39128,-1.80466,-0.013925,1.45793,-1.90549,-0.006067,1.48259,-1.95497,-0.00479,1.45453,-2.01959,0.191109,1.40333,-2.06905,0.099216,1.07469,-1.76979,-0.035208,1.07909,-1.80291,-0.03785,0.997282,-1.82747,0.009359,0.872396,-1.81652,-0.043879,0.689088,-1.81891,-0.073658,0.6223,-1.83597,-0.145593,0.735628,-1.83413,-0.17328,0.6719,-1.84586,-0.226973,0.449768,-1.87039,-0.338666,0.407048,-1.95259,-0.086181,0.378126,-1.90719,-0.123531,0.337052,-1.83738,0.312809,1.18476,-2.12871,0.370609,1.12516,-2.11067,0.208621,1.08759,-2.10421,0.265898,1.03069,-2.08772,0.389236,0.964598,-2.08637,0.266103,0.823688,-2.08343,0.209618,0.921221,-2.09966,0.151057,0.882403,-2.09462,-0.02996,0.73647,-2.07342,-0.14527,0.750571,-2.0176,0.039705,0.541928,-2.06533,-0.020877,0.562419,-2.13043,0.087049,1.30648,-1.83746,0.109374,1.31193,-2.05146},
/*2059*/{0.235367,1.88273,-1.74299,0.287663,1.81753,-1.89788,0.189402,1.72983,-1.6332,0.155712,1.61821,-1.5534,0.294611,1.63108,-1.63389,0.379905,1.63322,-1.66093,0.191733,1.90407,-2.13037,0.286024,1.82233,-1.97497,0.073874,1.87228,-2.02343,-0.041468,1.7744,-2.18459,-0.053227,1.68127,-2.2461,0.082209,1.55033,-2.19762,0.116508,1.49514,-2.21311,0.166394,1.39276,-1.80399,-0.013148,1.46167,-1.90537,-0.005176,1.48635,-1.95345,-0.003178,1.45921,-2.01928,0.19221,1.4079,-2.06779,0.09317,1.07641,-1.77277,-0.04009,1.0846,-1.80308,-0.044799,1.00228,-1.8252,-0.004514,0.87706,-1.81752,-0.058744,0.694584,-1.8192,-0.091466,0.627538,-1.83582,-0.160439,0.742167,-1.83416,-0.189941,0.677531,-1.84558,-0.244345,0.455644,-1.86921,-0.356085,0.415559,-1.95203,-0.105819,0.377047,-1.90789,-0.143478,0.337114,-1.83799,0.315899,1.19243,-2.12793,0.373648,1.13413,-2.11032,0.213129,1.09412,-2.10457,0.271269,1.03758,-2.08717,0.395137,0.974756,-2.08536,0.278299,0.827123,-2.08333,0.215923,0.921245,-2.09915,0.159974,0.87895,-2.09376,-0.012007,0.722113,-2.07264,-0.129228,0.728444,-2.01658,0.069396,0.532706,-2.06744,0.00701,0.550463,-2.13179,0.088222,1.30896,-1.83801,0.110633,1.31652,-2.05194},
/*2060*/{0.237308,1.88794,-1.74466,0.287899,1.82159,-1.89921,0.193948,1.73451,-1.63394,0.162555,1.62302,-1.55366,0.299197,1.63865,-1.63626,0.384048,1.64238,-1.666,0.189915,1.90836,-2.13024,0.286484,1.82671,-1.97621,0.072781,1.87584,-2.02213,-0.044768,1.78131,-2.18413,-0.057824,1.6893,-2.2447,0.077588,1.55943,-2.19657,0.111407,1.50367,-2.21266,0.166645,1.3935,-1.80408,-0.011506,1.46542,-1.90397,-0.004784,1.48995,-1.95179,-0.001648,1.46439,-2.01919,0.193365,1.41248,-2.06699,0.088974,1.07754,-1.7749,-0.045628,1.09088,-1.80348,-0.052414,1.00927,-1.82642,-0.018578,0.883034,-1.81797,-0.074226,0.701092,-1.8188,-0.104641,0.63336,-1.83398,-0.175961,0.750075,-1.83549,-0.204928,0.684779,-1.84448,-0.261781,0.461009,-1.86868,-0.372816,0.425249,-1.95064,-0.124064,0.377029,-1.90661,-0.164251,0.337512,-1.83834,0.318774,1.20009,-2.12758,0.377064,1.14198,-2.10922,0.216673,1.10114,-2.10452,0.275293,1.04497,-2.08662,0.398326,0.98382,-2.08458,0.289413,0.829794,-2.08374,0.222426,0.920988,-2.09837,0.168747,0.874283,-2.09274,0.006574,0.708835,-2.07135,-0.111907,0.70805,-2.01634,0.099035,0.524539,-2.06922,0.036408,0.539657,-2.1335,0.088183,1.31072,-1.83922,0.111119,1.3214,-2.05297},
/*2061*/{0.238488,1.89329,-1.74671,0.288413,1.82609,-1.90064,0.199082,1.73958,-1.63426,0.168966,1.62738,-1.55357,0.302295,1.64639,-1.63962,0.386119,1.65114,-1.66995,0.188684,1.91201,-2.13022,0.286002,1.83077,-1.97753,0.072843,1.87948,-2.02075,-0.047488,1.78827,-2.18368,-0.06283,1.69716,-2.24239,0.07182,1.56757,-2.1955,0.106716,1.51204,-2.21301,0.168567,1.39469,-1.80439,-0.010359,1.46895,-1.90297,-0.002285,1.49389,-1.95118,-0.000501,1.4694,-2.01927,0.19407,1.41699,-2.06618,0.083765,1.08124,-1.77618,-0.048957,1.09852,-1.80346,-0.061313,1.01667,-1.82676,-0.031861,0.888857,-1.81579,-0.088665,0.7078,-1.81843,-0.120242,0.641243,-1.83382,-0.188929,0.755989,-1.83565,-0.219366,0.691705,-1.84515,-0.2773,0.46682,-1.86748,-0.389108,0.435192,-1.94982,-0.143849,0.375911,-1.907,-0.184505,0.338039,-1.83803,0.321998,1.20773,-2.12703,0.380851,1.15008,-2.10687,0.219864,1.1081,-2.10441,0.278402,1.05156,-2.08553,0.400907,0.992082,-2.08416,0.30036,0.832299,-2.0842,0.227436,0.918648,-2.09702,0.176064,0.869487,-2.09179,0.020459,0.69397,-2.07107,-0.093011,0.685217,-2.01465,0.128289,0.518174,-2.07224,0.065504,0.528961,-2.13497,0.08898,1.31295,-1.84044,0.111886,1.32606,-2.05405},
/*2062*/{0.240078,1.89842,-1.7478,0.288897,1.83052,-1.9026,0.202816,1.74427,-1.63495,0.174035,1.63131,-1.55353,0.305437,1.6533,-1.64212,0.388636,1.65972,-1.67471,0.188116,1.91586,-2.12999,0.286173,1.8354,-1.97884,0.072618,1.88274,-2.02009,-0.04975,1.79533,-2.18355,-0.067484,1.70448,-2.24079,0.068433,1.57531,-2.19388,0.102242,1.51974,-2.21292,0.170423,1.39574,-1.80555,-0.007182,1.47262,-1.90324,-0.000477,1.49811,-1.94962,0.001824,1.47399,-2.01893,0.195254,1.42192,-2.06572,0.078889,1.08344,-1.77707,-0.0543,1.1054,-1.8041,-0.068094,1.0237,-1.82659,-0.045671,0.896261,-1.81728,-0.102236,0.714591,-1.81756,-0.134653,0.647855,-1.83231,-0.202387,0.764363,-1.83579,-0.233263,0.700127,-1.84592,-0.291772,0.473427,-1.86529,-0.404719,0.446572,-1.94879,-0.16218,0.375758,-1.9065,-0.206346,0.337406,-1.83879,0.324071,1.2151,-2.12655,0.383314,1.15759,-2.10574,0.222946,1.11454,-2.10435,0.280358,1.05801,-2.08504,0.401893,0.999954,-2.08368,0.311036,0.835144,-2.0847,0.232594,0.915944,-2.09508,0.184605,0.864138,-2.09027,0.043149,0.680278,-2.06988,-0.073688,0.661838,-2.01215,0.158791,0.512065,-2.07382,0.093089,0.518469,-2.13603,0.090447,1.31502,-1.84221,0.113207,1.33104,-2.05564},
/*2063*/{0.241926,1.90343,-1.74889,0.289688,1.83495,-1.90406,0.206344,1.74945,-1.63534,0.179387,1.63642,-1.55373,0.308582,1.66006,-1.64438,0.391274,1.66774,-1.67885,0.186325,1.919,-2.12988,0.285949,1.8399,-1.9799,0.07198,1.88598,-2.01942,-0.051901,1.80134,-2.18171,-0.071277,1.71205,-2.23865,0.064474,1.58314,-2.19357,0.09795,1.52724,-2.2128,0.172281,1.39641,-1.80635,-0.005543,1.47656,-1.90198,0.001629,1.50164,-1.94816,0.003034,1.47932,-2.01883,0.195922,1.42681,-2.06562,0.073469,1.08713,-1.77928,-0.059185,1.11161,-1.80186,-0.075175,1.03198,-1.82786,-0.056801,0.904223,-1.81767,-0.114936,0.721913,-1.81665,-0.148213,0.655246,-1.83092,-0.214988,0.771534,-1.8358,-0.245258,0.708057,-1.8456,-0.307665,0.479687,-1.86409,-0.419133,0.457966,-1.94798,-0.181914,0.375565,-1.90688,-0.226337,0.338906,-1.83912,0.326065,1.22177,-2.12545,0.385529,1.165,-2.10438,0.225601,1.12069,-2.10452,0.283877,1.06468,-2.08441,0.402169,1.00721,-2.0832,0.32082,0.836823,-2.08518,0.237338,0.913207,-2.09399,0.193455,0.858751,-2.08942,0.06,0.667926,-2.07001,-0.051918,0.63878,-2.0089,0.189257,0.507002,-2.07521,0.122543,0.509586,-2.1366,0.091392,1.31694,-1.84399,0.113643,1.33613,-2.05721},
/*2064*/{0.243123,1.90794,-1.75057,0.291009,1.83906,-1.90607,0.209079,1.75414,-1.63562,0.183339,1.64046,-1.55401,0.310674,1.66629,-1.64761,0.393858,1.67624,-1.68077,0.186063,1.9223,-2.12963,0.286654,1.84365,-1.98106,0.071731,1.88956,-2.01937,-0.054921,1.80757,-2.18067,-0.074824,1.71906,-2.23645,0.060148,1.58941,-2.19282,0.094969,1.53375,-2.21248,0.173988,1.39789,-1.80738,-0.004345,1.48022,-1.90166,0.002436,1.50569,-1.94664,0.00483,1.48475,-2.01783,0.195067,1.43222,-2.06589,0.070483,1.08976,-1.78008,-0.062876,1.11918,-1.80363,-0.081372,1.03983,-1.82672,-0.06654,0.910908,-1.81748,-0.126843,0.729084,-1.81508,-0.159909,0.662911,-1.82977,-0.226159,0.780163,-1.83467,-0.257142,0.715924,-1.84439,-0.320595,0.486467,-1.8613,-0.432305,0.470561,-1.94483,-0.199883,0.375532,-1.90728,-0.24677,0.340446,-1.83922,0.327313,1.22815,-2.12501,0.386878,1.17201,-2.10305,0.228042,1.12532,-2.10531,0.28623,1.07229,-2.08371,0.401514,1.01378,-2.08198,0.33083,0.837997,-2.08529,0.242475,0.909718,-2.09328,0.200748,0.851992,-2.08786,0.077918,0.653591,-2.0706,-0.030322,0.617697,-2.00811,0.219196,0.502365,-2.07593,0.152648,0.500934,-2.13646,0.092251,1.31934,-1.84586,0.113533,1.34161,-2.05888},
/*2065*/{0.244141,1.91207,-1.7518,0.291424,1.8435,-1.90704,0.212422,1.7588,-1.63635,0.18907,1.64498,-1.55448,0.31295,1.67223,-1.65049,0.394641,1.68331,-1.68572,0.185766,1.9252,-2.12996,0.287033,1.84792,-1.98235,0.071751,1.89308,-2.01829,-0.055599,1.81372,-2.18001,-0.07866,1.72545,-2.23393,0.05734,1.59627,-2.19229,0.091403,1.53984,-2.2129,0.176606,1.39938,-1.8087,-0.00145,1.48443,-1.90143,0.003271,1.50975,-1.94659,0.006413,1.4896,-2.01768,0.195325,1.43663,-2.06652,0.066815,1.09338,-1.78082,-0.064233,1.1278,-1.80276,-0.08611,1.0463,-1.82618,-0.074718,0.918157,-1.81746,-0.137355,0.736531,-1.81446,-0.170516,0.669913,-1.82759,-0.236054,0.787442,-1.8345,-0.267958,0.723782,-1.84409,-0.331742,0.49406,-1.85872,-0.443958,0.483836,-1.94398,-0.219204,0.375766,-1.90705,-0.26731,0.341611,-1.83897,0.328625,1.23347,-2.12361,0.388422,1.17702,-2.10146,0.228721,1.13233,-2.10537,0.287535,1.07819,-2.08462,0.400964,1.01937,-2.08189,0.339008,0.838413,-2.08533,0.247446,0.905248,-2.09145,0.209835,0.846166,-2.08707,0.102802,0.639624,-2.06696,-0.0083,0.596041,-2.00581,0.248699,0.498587,-2.07612,0.181784,0.492923,-2.13665,0.0937,1.32209,-1.84758,0.11383,1.34624,-2.06051},
/*2066*/{0.246585,1.91652,-1.75307,0.291852,1.8471,-1.90857,0.215555,1.76315,-1.63699,0.192935,1.64866,-1.55437,0.314502,1.67775,-1.65284,0.395134,1.69015,-1.68986,0.185345,1.92792,-2.13054,0.286884,1.85155,-1.98269,0.073917,1.89472,-2.01842,-0.056,1.81909,-2.17748,-0.081558,1.7319,-2.23193,0.054437,1.60197,-2.19139,0.087592,1.54587,-2.21299,0.177825,1.40073,-1.80951,4.6e-005,1.48763,-1.90019,0.004973,1.51407,-1.94492,0.008183,1.49428,-2.01714,0.195371,1.44134,-2.06664,0.064009,1.09659,-1.7811,-0.06787,1.1341,-1.80401,-0.091504,1.05464,-1.827,-0.081246,0.925088,-1.81741,-0.146389,0.744243,-1.81295,-0.181067,0.677081,-1.82628,-0.245359,0.795261,-1.834,-0.277719,0.731123,-1.84262,-0.346684,0.500125,-1.85755,-0.455374,0.498161,-1.94152,-0.237229,0.376817,-1.90649,-0.28713,0.34341,-1.83929,0.330375,1.23917,-2.12232,0.389097,1.18216,-2.09969,0.228983,1.13703,-2.10612,0.287948,1.08245,-2.085,0.399776,1.0235,-2.08154,0.348157,0.838503,-2.08547,0.252773,0.90058,-2.09034,0.218555,0.838633,-2.08633,0.118045,0.627284,-2.06872,0.015715,0.574286,-2.00358,0.278412,0.495952,-2.07627,0.211091,0.485605,-2.13567,0.094482,1.32432,-1.84904,0.113985,1.35118,-2.0617},
/*2067*/{0.247627,1.9201,-1.75434,0.293657,1.85219,-1.91066,0.217125,1.76725,-1.63691,0.197741,1.65164,-1.55417,0.315906,1.68301,-1.65519,0.396749,1.69622,-1.69474,0.185009,1.93065,-2.13038,0.286981,1.85528,-1.98388,0.074805,1.89707,-2.01829,-0.056831,1.82415,-2.17565,-0.084379,1.73791,-2.22951,0.052744,1.60732,-2.19046,0.085407,1.55129,-2.21305,0.180054,1.40232,-1.81061,0.001227,1.49144,-1.89973,0.006288,1.51755,-1.94275,0.009886,1.49956,-2.01625,0.1966,1.44654,-2.06706,0.059982,1.09927,-1.7813,-0.069792,1.14113,-1.80405,-0.094546,1.06087,-1.82591,-0.087179,0.931433,-1.81703,-0.154956,0.751651,-1.81173,-0.190048,0.68448,-1.82437,-0.253296,0.802976,-1.83317,-0.284953,0.738562,-1.84029,-0.357525,0.507748,-1.85538,-0.465134,0.513155,-1.93982,-0.25531,0.37773,-1.90541,-0.306363,0.346878,-1.83871,0.330469,1.24376,-2.12172,0.38899,1.18652,-2.09793,0.228749,1.14236,-2.10681,0.285973,1.08779,-2.08834,0.398262,1.02663,-2.08133,0.355877,0.838507,-2.08566,0.257788,0.894792,-2.08909,0.22706,0.831303,-2.08515,0.139744,0.613104,-2.0653,0.038992,0.555755,-2.00286,0.306756,0.493535,-2.07472,0.240374,0.478899,-2.13448,0.096048,1.32671,-1.85084,0.114859,1.35668,-2.06315},
/*2068*/{0.248632,1.92405,-1.75531,0.293372,1.85506,-1.91061,0.219406,1.77123,-1.63709,0.200621,1.65509,-1.554,0.317876,1.68826,-1.65785,0.397347,1.70203,-1.69856,0.184943,1.93302,-2.13044,0.287591,1.8578,-1.98411,0.075532,1.89965,-2.01788,-0.05747,1.82959,-2.17324,-0.087193,1.74333,-2.22687,0.050263,1.61275,-2.1901,0.082912,1.55602,-2.213,0.180927,1.40466,-1.81166,0.002612,1.49497,-1.8982,0.007746,1.52155,-1.94164,0.011123,1.50419,-2.01489,0.195881,1.45017,-2.06727,0.057851,1.1031,-1.78035,-0.071596,1.14748,-1.80384,-0.097809,1.0673,-1.82696,-0.092234,0.936887,-1.81685,-0.161527,0.758034,-1.81093,-0.196794,0.692047,-1.82178,-0.259819,0.810106,-1.83217,-0.291808,0.74644,-1.83832,-0.366176,0.516316,-1.85165,-0.473787,0.528098,-1.93716,-0.271885,0.378574,-1.90523,-0.326609,0.350202,-1.83896,0.330235,1.24831,-2.12022,0.388776,1.18959,-2.09622,0.228353,1.14672,-2.10762,0.286019,1.09158,-2.08948,0.396531,1.02797,-2.08176,0.363993,0.838342,-2.08534,0.263391,0.889149,-2.08818,0.235096,0.824229,-2.08497,0.159713,0.600456,-2.06432,0.063665,0.537256,-2.00176,0.334701,0.492449,-2.07318,0.270086,0.473124,-2.13298,0.096515,1.32957,-1.85139,0.114051,1.36083,-2.06361},
/*2069*/{0.250866,1.92745,-1.75618,0.294237,1.85873,-1.91201,0.22134,1.77468,-1.63765,0.202332,1.65816,-1.55415,0.319024,1.69164,-1.65945,0.397363,1.7073,-1.70213,0.184892,1.93541,-2.13056,0.28789,1.86167,-1.9853,0.075882,1.90266,-2.01815,-0.057329,1.83454,-2.17152,-0.088728,1.74835,-2.22474,0.048983,1.61662,-2.18976,0.081058,1.56035,-2.21301,0.182983,1.40664,-1.81197,0.004516,1.49855,-1.8973,0.008071,1.52513,-1.94126,0.012861,1.50856,-2.01417,0.196522,1.45415,-2.06707,0.054914,1.10656,-1.77908,-0.074399,1.15272,-1.80725,-0.100719,1.0744,-1.82809,-0.09655,0.942206,-1.8166,-0.167728,0.764307,-1.80919,-0.203804,0.698301,-1.82071,-0.265807,0.8171,-1.83041,-0.298285,0.753782,-1.83529,-0.374361,0.524533,-1.84952,-0.481028,0.545435,-1.93448,-0.288738,0.380603,-1.90412,-0.345485,0.354041,-1.83856,0.330162,1.25079,-2.11817,0.387374,1.19194,-2.09518,0.2273,1.15021,-2.10834,0.284124,1.09366,-2.09074,0.39461,1.0289,-2.0821,0.370708,0.8375,-2.08676,0.267434,0.882642,-2.0882,0.243888,0.815781,-2.08246,0.180743,0.589307,-2.06511,0.086109,0.520431,-2.00319,0.361413,0.491286,-2.07,0.298096,0.466735,-2.13038,0.09773,1.33237,-1.85205,0.114706,1.36503,-2.06411},
/*2070*/{0.2517,1.93025,-1.75723,0.29655,1.8623,-1.91255,0.222913,1.77806,-1.63819,0.205645,1.66049,-1.55325,0.319273,1.69585,-1.66118,0.397434,1.71092,-1.705,0.184618,1.93788,-2.13059,0.288186,1.86431,-1.98575,0.076467,1.90478,-2.01764,-0.057095,1.83937,-2.16864,-0.089998,1.75325,-2.22229,0.048034,1.62036,-2.18934,0.079085,1.5635,-2.21319,0.184042,1.40947,-1.81317,0.005935,1.50216,-1.89624,0.009616,1.52884,-1.93945,0.013641,1.5127,-2.0129,0.196452,1.45764,-2.06744,0.052004,1.11094,-1.77857,-0.073601,1.15699,-1.80587,-0.103593,1.07923,-1.82777,-0.098524,0.946903,-1.81659,-0.172815,0.770043,-1.80843,-0.208878,0.704828,-1.81889,-0.269648,0.82457,-1.82856,-0.303753,0.760869,-1.83399,-0.38367,0.532642,-1.847,-0.487123,0.561214,-1.93053,-0.307093,0.382464,-1.90376,-0.366115,0.35991,-1.83933,0.330244,1.2531,-2.11668,0.386569,1.19288,-2.09402,0.225963,1.15317,-2.10918,0.282038,1.0964,-2.0917,0.393275,1.02921,-2.08312,0.378315,0.836305,-2.08708,0.272696,0.875729,-2.08792,0.251922,0.806948,-2.08163,0.202653,0.577213,-2.06238,0.111912,0.502868,-2.00138,0.388103,0.490386,-2.0665,0.32656,0.46181,-2.1271,0.098654,1.33539,-1.85237,0.114198,1.369,-2.0644},
/*2071*/{0.253633,1.93267,-1.75751,0.29648,1.86588,-1.91363,0.224664,1.78099,-1.63844,0.206945,1.66288,-1.55375,0.321293,1.69942,-1.66319,0.398107,1.71479,-1.7083,0.185865,1.94019,-2.131,0.289471,1.86737,-1.98626,0.07723,1.90724,-2.01721,-0.057075,1.84264,-2.16686,-0.091197,1.75742,-2.21977,0.046357,1.62344,-2.18865,0.078008,1.56676,-2.21282,0.185687,1.41182,-1.81334,0.007533,1.50515,-1.89633,0.010346,1.53247,-1.93879,0.013545,1.51688,-2.01171,0.19636,1.46087,-2.06712,0.050112,1.11384,-1.77783,-0.072518,1.16098,-1.80451,-0.104584,1.08451,-1.82926,-0.099989,0.951478,-1.81784,-0.176601,0.775706,-1.8078,-0.214799,0.709977,-1.81829,-0.272822,0.830643,-1.8263,-0.307815,0.768603,-1.83298,-0.392333,0.540604,-1.84403,-0.492102,0.578067,-1.92663,-0.324262,0.385354,-1.90461,-0.3851,0.366186,-1.83983,0.329034,1.2548,-2.11564,0.384455,1.19372,-2.09336,0.224049,1.15547,-2.10943,0.27928,1.09776,-2.0927,0.390642,1.02784,-2.08409,0.384686,0.833862,-2.08748,0.277986,0.869042,-2.08771,0.258529,0.801843,-2.08144,0.223574,0.566937,-2.06236,0.136798,0.488657,-2.0022,0.412715,0.490453,-2.06284,0.355434,0.457658,-2.12376,0.09941,1.33829,-1.85259,0.114051,1.3726,-2.06457},
/*2072*/{0.254666,1.93507,-1.75848,0.297977,1.86879,-1.91462,0.226366,1.78418,-1.63877,0.209206,1.66618,-1.55376,0.321496,1.70152,-1.66491,0.397848,1.71785,-1.71154,0.186469,1.94215,-2.13122,0.290174,1.86938,-1.98751,0.078661,1.90847,-2.01737,-0.055934,1.84653,-2.16437,-0.092168,1.76061,-2.21795,0.046227,1.62625,-2.18831,0.077227,1.56939,-2.21265,0.186532,1.41461,-1.81339,0.008241,1.50832,-1.89439,0.010952,1.53586,-1.93806,0.013907,1.52,-2.01077,0.196265,1.46447,-2.06699,0.049262,1.11843,-1.77736,-0.0766,1.16437,-1.80589,-0.105405,1.08789,-1.82981,-0.100435,0.95552,-1.81822,-0.179584,0.78044,-1.80743,-0.217304,0.716514,-1.8175,-0.275453,0.836949,-1.82529,-0.310745,0.775656,-1.83063,-0.398129,0.549891,-1.84066,-0.496053,0.595935,-1.92163,-0.342012,0.39063,-1.904,-0.403904,0.372725,-1.84051,0.327691,1.25442,-2.1147,0.382373,1.19299,-2.09313,0.221047,1.15692,-2.10934,0.275978,1.0977,-2.09328,0.389058,1.02674,-2.08543,0.390198,0.831861,-2.08769,0.28121,0.861673,-2.08833,0.26564,0.795747,-2.08171,0.244243,0.557133,-2.06175,0.15965,0.472917,-2.0015,0.437508,0.491021,-2.05802,0.381796,0.453506,-2.12008,0.100227,1.34125,-1.8523,0.113928,1.37609,-2.06426},
/*2073*/{0.256254,1.93724,-1.75905,0.298545,1.87211,-1.91509,0.228694,1.78648,-1.63955,0.21065,1.66792,-1.55373,0.322167,1.70384,-1.66501,0.398512,1.71948,-1.71375,0.186816,1.94394,-2.13156,0.2906,1.87143,-1.98774,0.078877,1.91199,-2.01663,-0.057278,1.85335,-2.16364,-0.091908,1.76326,-2.21616,0.045617,1.62867,-2.18822,0.076749,1.57194,-2.21224,0.187621,1.41724,-1.81352,0.008768,1.51135,-1.89467,0.010694,1.53865,-1.93792,0.015983,1.52234,-2.00902,0.196436,1.46743,-2.06689,0.049922,1.12114,-1.77654,-0.076505,1.16694,-1.80665,-0.104699,1.09029,-1.82969,-0.099904,0.958583,-1.81919,-0.181416,0.784442,-1.80741,-0.221472,0.72098,-1.81594,-0.275861,0.842922,-1.82382,-0.312393,0.781838,-1.82701,-0.403856,0.557846,-1.83734,-0.500054,0.612797,-1.91467,-0.359362,0.397233,-1.90616,-0.420287,0.381588,-1.84277,0.325487,1.25387,-2.11432,0.380291,1.19076,-2.09246,0.21769,1.15739,-2.10964,0.271819,1.09729,-2.09336,0.386094,1.02448,-2.08637,0.396361,0.828606,-2.08728,0.284863,0.853795,-2.08967,0.27378,0.784773,-2.08335,0.261591,0.54677,-2.06215,0.182321,0.460756,-2.00159,0.460524,0.492165,-2.05375,0.408672,0.45023,-2.11509,0.101148,1.34393,-1.85214,0.114518,1.37896,-2.06408},
/*2074*/{0.257183,1.93913,-1.75937,0.298472,1.87397,-1.91603,0.22963,1.78853,-1.64014,0.211214,1.67018,-1.55326,0.321648,1.70465,-1.66702,0.397158,1.7207,-1.71647,0.187588,1.94563,-2.13162,0.291471,1.87307,-1.98845,0.079793,1.91368,-2.01663,-0.056727,1.85649,-2.1618,-0.091987,1.7656,-2.21466,0.045536,1.62977,-2.18753,0.077174,1.57321,-2.21203,0.188131,1.42004,-1.81372,0.009135,1.51402,-1.89305,0.011751,1.54134,-1.93674,0.01643,1.52522,-2.00761,0.197179,1.47006,-2.06664,0.049926,1.12292,-1.77623,-0.071417,1.16973,-1.80681,-0.102806,1.09275,-1.83129,-0.09886,0.960188,-1.8197,-0.1828,0.788087,-1.80737,-0.224018,0.725683,-1.81542,-0.276346,0.848989,-1.82201,-0.31508,0.788589,-1.82576,-0.408286,0.568774,-1.83521,-0.503584,0.62924,-1.90677,-0.375674,0.406092,-1.90875,-0.438171,0.390173,-1.84485,0.322791,1.25206,-2.11407,0.376972,1.18803,-2.09269,0.214065,1.15712,-2.10977,0.267317,1.09706,-2.09436,0.382861,1.02181,-2.08821,0.401482,0.826519,-2.08753,0.288017,0.845467,-2.09135,0.280903,0.776921,-2.08389,0.281031,0.538543,-2.06173,0.204703,0.449221,-2.00155,0.481783,0.492628,-2.04869,0.432845,0.447087,-2.11051,0.101921,1.3465,-1.85158,0.114661,1.38186,-2.06351},
/*2075*/{0.258825,1.94066,-1.75973,0.298358,1.87598,-1.91608,0.230475,1.79018,-1.64061,0.211887,1.67245,-1.55448,0.321642,1.70589,-1.66836,0.397327,1.72117,-1.71824,0.188852,1.94722,-2.13195,0.292045,1.8744,-1.98948,0.08074,1.91547,-2.01812,-0.056587,1.85744,-2.15918,-0.091471,1.76668,-2.21331,0.045659,1.6307,-2.18711,0.077191,1.57382,-2.21169,0.189359,1.42275,-1.81329,0.010322,1.51665,-1.89275,0.011731,1.5441,-1.93645,0.016698,1.52738,-2.00784,0.197352,1.4721,-2.06658,0.053099,1.12497,-1.77648,-0.073622,1.16989,-1.80848,-0.101476,1.09304,-1.83175,-0.095477,0.961523,-1.81934,-0.183025,0.791104,-1.80734,-0.226766,0.72941,-1.81535,-0.274606,0.854781,-1.82038,-0.315708,0.795455,-1.82302,-0.415501,0.576926,-1.83364,-0.506906,0.645685,-1.89795,-0.394114,0.414078,-1.91296,-0.455093,0.400913,-1.84758,0.32032,1.24911,-2.11425,0.372857,1.18475,-2.09298,0.210109,1.15616,-2.11002,0.262103,1.09508,-2.09467,0.378746,1.01799,-2.08869,0.40474,0.823744,-2.08775,0.291585,0.837321,-2.09314,0.287733,0.767778,-2.08648,0.298796,0.530433,-2.06153,0.225848,0.437451,-2.00087,0.501213,0.493799,-2.04484,0.45624,0.444185,-2.10508,0.102784,1.34932,-1.85089,0.114901,1.38387,-2.06299},
/*2076*/{0.259729,1.94221,-1.76039,0.299067,1.87789,-1.91772,0.231487,1.79163,-1.64094,0.21205,1.67338,-1.55406,0.321552,1.70667,-1.67053,0.396852,1.7218,-1.72088,0.189287,1.94866,-2.13306,0.293134,1.87509,-1.98971,0.081563,1.91617,-2.01775,-0.056057,1.85889,-2.15771,-0.091538,1.76763,-2.21239,0.047998,1.63115,-2.18622,0.07804,1.57471,-2.21106,0.18999,1.42566,-1.81271,0.010247,1.51844,-1.892,0.010639,1.54686,-1.93591,0.017072,1.52896,-2.00649,0.197417,1.47352,-2.06635,0.054854,1.12715,-1.77749,-0.06763,1.17083,-1.80668,-0.098744,1.09304,-1.83136,-0.091731,0.961879,-1.82023,-0.182583,0.792643,-1.80723,-0.229341,0.732649,-1.81532,-0.272064,0.85959,-1.8184,-0.314535,0.801904,-1.82053,-0.420318,0.585638,-1.83083,-0.51163,0.660935,-1.89058,-0.410057,0.426049,-1.917,-0.468709,0.412634,-1.84943,0.316757,1.24593,-2.11422,0.368603,1.18072,-2.09331,0.205352,1.15452,-2.11054,0.25606,1.09254,-2.09457,0.375363,1.01417,-2.08931,0.408169,0.82202,-2.08781,0.293966,0.829204,-2.09492,0.293615,0.759387,-2.08753,0.316471,0.523294,-2.06041,0.246464,0.43081,-2.00122,0.520063,0.493633,-2.0405,0.478034,0.442738,-2.10119,0.103275,1.35187,-1.84958,0.114754,1.38546,-2.06187},
/*2077*/{0.26025,1.94253,-1.76107,0.299828,1.87971,-1.91829,0.23233,1.7928,-1.64149,0.213014,1.67463,-1.55427,0.32097,1.70623,-1.67124,0.396265,1.72077,-1.72258,0.19032,1.94965,-2.13362,0.293934,1.87625,-1.99018,0.082673,1.91944,-2.01772,-0.055005,1.85943,-2.1564,-0.09021,1.76812,-2.21105,0.04857,1.6308,-2.1858,0.079752,1.57438,-2.21069,0.18983,1.42814,-1.81252,0.01073,1.52037,-1.89111,0.010923,1.54874,-1.93559,0.01627,1.53064,-2.00594,0.197675,1.47506,-2.06563,0.058022,1.12783,-1.77835,-0.068644,1.16974,-1.80734,-0.094963,1.0928,-1.83168,-0.086601,0.961177,-1.8207,-0.181348,0.79364,-1.80764,-0.22996,0.734835,-1.81586,-0.268215,0.863567,-1.81615,-0.313636,0.807813,-1.82003,-0.426266,0.598053,-1.83038,-0.517038,0.675888,-1.88198,-0.424292,0.439003,-1.92115,-0.480841,0.424854,-1.85139,0.313604,1.24241,-2.11462,0.364338,1.1764,-2.09422,0.199993,1.15278,-2.11098,0.250162,1.09008,-2.09525,0.37035,1.00952,-2.09016,0.411218,0.819728,-2.08736,0.297723,0.822816,-2.09754,0.300432,0.752976,-2.08956,0.33483,0.517631,-2.05964,0.26546,0.421189,-1.99957,0.536933,0.495573,-2.0373,0.497991,0.440805,-2.09686,0.103478,1.35405,-1.84864,0.114692,1.38704,-2.06104},
/*2078*/{0.261274,1.94299,-1.76165,0.300335,1.87986,-1.91907,0.23243,1.79343,-1.64213,0.211987,1.67495,-1.55403,0.320589,1.7056,-1.67249,0.394618,1.71815,-1.72444,0.191374,1.95091,-2.13396,0.294695,1.87693,-1.99076,0.084094,1.921,-2.01783,-0.051986,1.85504,-2.15353,-0.089249,1.76757,-2.21031,0.049991,1.63002,-2.18513,0.081496,1.57402,-2.21009,0.190654,1.4299,-1.812,0.011139,1.52166,-1.89091,0.011006,1.55021,-1.93463,0.016871,1.53129,-2.00526,0.198179,1.47544,-2.06537,0.062826,1.12677,-1.77861,-0.064569,1.16867,-1.8077,-0.090597,1.09132,-1.83073,-0.080655,0.959759,-1.82062,-0.179543,0.794267,-1.80841,-0.230391,0.737841,-1.81745,-0.263933,0.867726,-1.81411,-0.310748,0.813457,-1.81666,-0.430884,0.607635,-1.82872,-0.522485,0.690887,-1.87447,-0.438459,0.452697,-1.92489,-0.491665,0.437722,-1.85325,0.309888,1.23791,-2.11551,0.359533,1.1713,-2.09468,0.195435,1.1502,-2.11064,0.244089,1.08681,-2.09516,0.365041,1.00457,-2.09091,0.413546,0.817509,-2.08608,0.30059,0.815062,-2.1,0.305988,0.745547,-2.09085,0.347386,0.511791,-2.05902,0.283317,0.415478,-1.99984,0.553075,0.497762,-2.03337,0.516584,0.439983,-2.09354,0.104164,1.3556,-1.84748,0.114947,1.3876,-2.06005},
/*2079*/{0.262527,1.94335,-1.76182,0.30132,1.88134,-1.92042,0.232154,1.79393,-1.64297,0.21143,1.67628,-1.55524,0.319274,1.70412,-1.67334,0.393481,1.71612,-1.72588,0.19265,1.95149,-2.13488,0.295078,1.87727,-1.99092,0.084573,1.92148,-2.01847,-0.050601,1.85375,-2.15036,-0.088113,1.76665,-2.20975,0.052496,1.62877,-2.18445,0.083289,1.57262,-2.20964,0.19121,1.43219,-1.81146,0.01179,1.52245,-1.89009,0.011128,1.55164,-1.93468,0.016722,1.53202,-2.00429,0.198794,1.47612,-2.06478,0.069297,1.12572,-1.78002,-0.060109,1.16639,-1.80671,-0.084844,1.08838,-1.83077,-0.073939,0.957821,-1.8214,-0.177971,0.794639,-1.80929,-0.231114,0.740371,-1.8184,-0.259585,0.871858,-1.81173,-0.309148,0.820406,-1.81435,-0.437846,0.61906,-1.82912,-0.527482,0.705584,-1.86704,-0.450117,0.467296,-1.92779,-0.499816,0.451572,-1.85485,0.306114,1.23285,-2.11584,0.354644,1.16523,-2.09505,0.190235,1.14684,-2.11061,0.238276,1.08309,-2.09536,0.359578,0.999585,-2.09119,0.41659,0.815543,-2.08401,0.304436,0.808364,-2.10256,0.311992,0.739483,-2.09312,0.360454,0.506937,-2.05928,0.298247,0.407892,-1.99744,0.565595,0.49902,-2.03173,0.532768,0.439656,-2.0903,0.105069,1.35732,-1.84618,0.115463,1.38826,-2.05892},
/*2080*/{0.263028,1.94295,-1.76238,0.300551,1.88167,-1.9209,0.231771,1.79397,-1.6436,0.209738,1.67589,-1.55545,0.318606,1.70197,-1.67488,0.391877,1.7131,-1.72727,0.193485,1.9519,-2.13538,0.294909,1.87701,-1.99169,0.085563,1.92278,-2.01875,-0.050189,1.85261,-2.15019,-0.086266,1.76454,-2.20963,0.053607,1.62701,-2.18397,0.08576,1.571,-2.20909,0.191369,1.43303,-1.81106,0.011635,1.52275,-1.88955,0.01146,1.55237,-1.9349,0.016676,1.53195,-2.00429,0.199312,1.47667,-2.06434,0.074931,1.12504,-1.7816,-0.052777,1.16527,-1.80477,-0.079313,1.08547,-1.83011,-0.066553,0.954723,-1.82243,-0.175975,0.794533,-1.81058,-0.230966,0.743753,-1.82018,-0.25409,0.875726,-1.8102,-0.304307,0.825759,-1.8121,-0.441978,0.630292,-1.8283,-0.53262,0.720289,-1.86103,-0.461152,0.482626,-1.93036,-0.509303,0.465249,-1.85617,0.302294,1.22752,-2.11616,0.350028,1.15961,-2.09598,0.184794,1.14374,-2.11113,0.232254,1.07885,-2.09538,0.354665,0.994665,-2.09172,0.418306,0.813574,-2.08168,0.308275,0.802659,-2.10517,0.316633,0.733519,-2.09518,0.372865,0.503226,-2.05862,0.311887,0.402946,-1.99632,0.576805,0.500606,-2.02933,0.546059,0.439689,-2.08711,0.105412,1.35799,-1.84568,0.11602,1.3886,-2.05846},
/*2081*/{0.26383,1.9426,-1.76318,0.300196,1.88159,-1.92099,0.230438,1.79397,-1.64418,0.20862,1.67596,-1.55539,0.316856,1.70021,-1.675,0.390795,1.70922,-1.72868,0.194045,1.95223,-2.13562,0.29502,1.87719,-1.992,0.08615,1.92372,-2.02049,-0.048742,1.85083,-2.15013,-0.084407,1.76252,-2.20932,0.056951,1.62546,-2.18356,0.08793,1.56885,-2.2087,0.191575,1.43461,-1.81007,0.011613,1.5219,-1.89038,0.011491,1.55247,-1.93478,0.016881,1.53067,-2.00365,0.20039,1.47584,-2.06393,0.081151,1.12276,-1.7841,-0.049172,1.16179,-1.80309,-0.072988,1.08189,-1.82827,-0.059338,0.951276,-1.82259,-0.173605,0.794837,-1.81222,-0.233019,0.746815,-1.82123,-0.247948,0.879756,-1.80679,-0.301654,0.832555,-1.81015,-0.448297,0.642898,-1.82773,-0.536095,0.735713,-1.85645,-0.471134,0.498085,-1.93171,-0.519018,0.480094,-1.85634,0.298582,1.22253,-2.11608,0.345238,1.15371,-2.09649,0.179925,1.14013,-2.11085,0.225967,1.07544,-2.09473,0.347971,0.989315,-2.09166,0.419886,0.811722,-2.07971,0.31061,0.797203,-2.10589,0.321767,0.728022,-2.09605,0.38208,0.498308,-2.05818,0.324015,0.398849,-1.9974,0.586717,0.502873,-2.02815,0.55794,0.438384,-2.08471,0.106285,1.35858,-1.84424,0.11722,1.38759,-2.05723},
/*2082*/{0.264217,1.94169,-1.7639,0.300227,1.88157,-1.9212,0.229429,1.79402,-1.64459,0.206027,1.67594,-1.55655,0.316039,1.69746,-1.67637,0.390004,1.70513,-1.72959,0.19543,1.95185,-2.13651,0.295181,1.87697,-1.9921,0.086768,1.92382,-2.02183,-0.047749,1.84891,-2.14864,-0.082382,1.75964,-2.20928,0.058554,1.62236,-2.18291,0.090834,1.56571,-2.20825,0.192266,1.43531,-1.8095,0.011802,1.52246,-1.88955,0.011876,1.55244,-1.9345,0.016338,1.52957,-2.00395,0.201084,1.47579,-2.06333,0.088329,1.12104,-1.7858,-0.043677,1.15702,-1.80245,-0.06593,1.07773,-1.82815,-0.050606,0.947134,-1.82322,-0.171841,0.795685,-1.81286,-0.231735,0.751036,-1.8215,-0.242098,0.883827,-1.80458,-0.297452,0.83973,-1.80861,-0.452073,0.657202,-1.82587,-0.538153,0.751798,-1.85307,-0.48007,0.512719,-1.93169,-0.526801,0.496575,-1.85605,0.294903,1.21763,-2.11649,0.340717,1.14704,-2.0972,0.17447,1.1374,-2.10894,0.220832,1.06947,-2.09401,0.343155,0.984588,-2.0915,0.420448,0.809805,-2.07719,0.311813,0.792808,-2.10629,0.325277,0.724556,-2.09694,0.389814,0.494894,-2.05835,0.33455,0.394258,-1.99634,0.595097,0.503839,-2.02681,0.567567,0.438531,-2.08351,0.107111,1.35916,-1.84313,0.117827,1.38713,-2.05627},
/*2083*/{0.264286,1.94082,-1.76449,0.299615,1.88034,-1.92181,0.228193,1.79331,-1.64537,0.20385,1.67513,-1.55664,0.313976,1.69432,-1.67694,0.388717,1.70023,-1.73043,0.195838,1.95141,-2.13692,0.295157,1.87667,-1.99208,0.087389,1.92396,-2.02223,-0.045772,1.84564,-2.14842,-0.079136,1.75645,-2.20989,0.060648,1.61916,-2.18266,0.093755,1.56324,-2.20847,0.192822,1.43551,-1.80904,0.011283,1.52124,-1.88983,0.011555,1.55114,-1.93434,0.016829,1.52769,-2.00415,0.201421,1.47498,-2.06276,0.094708,1.11839,-1.78881,-0.038336,1.15168,-1.80036,-0.058264,1.07322,-1.82742,-0.041244,0.942861,-1.8248,-0.168688,0.797537,-1.81324,-0.231953,0.754709,-1.82214,-0.235262,0.888177,-1.80327,-0.292272,0.845735,-1.80766,-0.45429,0.671444,-1.82393,-0.538376,0.769224,-1.852,-0.486902,0.529006,-1.92908,-0.535386,0.512441,-1.85448,0.291493,1.21165,-2.11679,0.336071,1.14145,-2.09794,0.170141,1.13431,-2.10847,0.214713,1.06616,-2.09323,0.336786,0.979599,-2.09107,0.419604,0.80781,-2.07541,0.312156,0.788649,-2.10584,0.326598,0.720396,-2.09597,0.395742,0.492246,-2.0586,0.341911,0.390246,-1.99449,0.600507,0.503747,-2.02639,0.574667,0.438516,-2.08285,0.107975,1.35869,-1.84236,0.118868,1.38585,-2.05559},
/*2084*/{0.263245,1.93893,-1.76564,0.299173,1.88018,-1.92217,0.226464,1.79234,-1.64594,0.202177,1.67404,-1.55702,0.311896,1.69075,-1.67737,0.385828,1.69499,-1.73083,0.196423,1.9506,-2.13711,0.294955,1.87635,-1.99225,0.087532,1.92329,-2.02421,-0.044099,1.84247,-2.1476,-0.076496,1.75275,-2.21065,0.064228,1.61598,-2.18287,0.096659,1.55952,-2.20798,0.19332,1.43547,-1.80925,0.011752,1.5203,-1.8892,0.012403,1.54933,-1.9348,0.017101,1.52647,-2.00375,0.203293,1.47335,-2.06268,0.103473,1.11637,-1.79047,-0.032352,1.14618,-1.7997,-0.052534,1.06758,-1.82674,-0.031496,0.938153,-1.82618,-0.166589,0.799392,-1.81334,-0.2298,0.759413,-1.82213,-0.228365,0.892893,-1.80447,-0.286931,0.852907,-1.80659,-0.457711,0.685461,-1.82204,-0.537021,0.786754,-1.85237,-0.49477,0.543513,-1.92607,-0.543828,0.530813,-1.8521,0.288737,1.20677,-2.11743,0.331713,1.13668,-2.09941,0.166589,1.13127,-2.10822,0.209612,1.06283,-2.09319,0.331445,0.974874,-2.09058,0.417863,0.805581,-2.07528,0.310393,0.78478,-2.10431,0.32631,0.717269,-2.09454,0.398932,0.489083,-2.05716,0.347829,0.385378,-1.99435,0.605539,0.504086,-2.02665,0.579384,0.438412,-2.08337,0.10909,1.35803,-1.84165,0.120056,1.38432,-2.05499},
/*2085*/{0.263213,1.93838,-1.76631,0.298544,1.87933,-1.9229,0.224082,1.79127,-1.6463,0.199324,1.67275,-1.55779,0.309458,1.6865,-1.67822,0.384675,1.68889,-1.73138,0.196945,1.94954,-2.13782,0.294509,1.8756,-1.99257,0.088263,1.92235,-2.02567,-0.043485,1.83893,-2.14799,-0.074044,1.74829,-2.21162,0.06609,1.61217,-2.18302,0.099988,1.55545,-2.20808,0.193735,1.43486,-1.80952,0.011578,1.51848,-1.8892,0.013112,1.54868,-1.93486,0.018071,1.52394,-2.00424,0.203549,1.47188,-2.06281,0.108386,1.11342,-1.79162,-0.023897,1.14131,-1.79625,-0.043999,1.06158,-1.82503,-0.022525,0.934072,-1.82677,-0.162177,0.80182,-1.81363,-0.228182,0.764304,-1.82128,-0.221427,0.897138,-1.80242,-0.282815,0.859693,-1.80647,-0.459549,0.700593,-1.81933,-0.533956,0.804902,-1.8538,-0.499938,0.558061,-1.92221,-0.55051,0.548973,-1.84769,0.286196,1.20192,-2.11837,0.327931,1.12994,-2.10066,0.162926,1.12755,-2.10691,0.20522,1.05905,-2.09157,0.326098,0.970762,-2.0909,0.414846,0.803401,-2.07518,0.306861,0.780706,-2.10188,0.32317,0.713123,-2.09257,0.403437,0.48783,-2.05686,0.352418,0.382377,-1.99348,0.607767,0.502971,-2.0266,0.58235,0.437716,-2.08372,0.109844,1.35699,-1.84138,0.120739,1.38261,-2.0548},
/*2086*/{0.262796,1.93678,-1.76682,0.297653,1.87792,-1.92266,0.222249,1.79036,-1.64713,0.195982,1.67134,-1.55868,0.306657,1.68238,-1.67818,0.382405,1.68247,-1.73184,0.197076,1.94771,-2.13856,0.294008,1.8744,-1.99272,0.088714,1.92154,-2.02638,-0.041454,1.83512,-2.14911,-0.070935,1.74365,-2.21307,0.069436,1.60759,-2.18334,0.103326,1.55114,-2.20804,0.195323,1.43365,-1.80937,0.011603,1.517,-1.88965,0.012841,1.5459,-1.93526,0.017518,1.52192,-2.00463,0.203927,1.46923,-2.06257,0.115494,1.11185,-1.79356,-0.019204,1.1358,-1.79732,-0.037639,1.05634,-1.82469,-0.013533,0.92945,-1.82747,-0.158622,0.80472,-1.81326,-0.22536,0.769843,-1.82024,-0.21375,0.902466,-1.8021,-0.275473,0.867637,-1.80474,-0.460021,0.71663,-1.81804,-0.529752,0.822337,-1.85534,-0.50418,0.573651,-1.91733,-0.55727,0.56783,-1.84457,0.28376,1.19672,-2.11917,0.326223,1.1243,-2.101,0.160133,1.12503,-2.107,0.202195,1.05576,-2.09107,0.321269,0.966369,-2.09055,0.41088,0.800615,-2.0755,0.302271,0.776059,-2.09979,0.320881,0.708984,-2.09035,0.404165,0.484771,-2.05555,0.353451,0.380483,-1.99384,0.609546,0.502124,-2.02633,0.582395,0.437336,-2.08407,0.110707,1.35567,-1.84067,0.121139,1.37995,-2.05428},
/*2087*/{0.261197,1.93448,-1.76733,0.297587,1.87581,-1.92286,0.219909,1.78902,-1.64736,0.192176,1.66977,-1.55952,0.304237,1.6777,-1.67848,0.379365,1.67556,-1.73166,0.19738,1.9463,-2.13881,0.294377,1.87336,-1.99278,0.087996,1.9199,-2.02855,-0.040517,1.83067,-2.14988,-0.068653,1.73826,-2.21476,0.072839,1.60249,-2.18383,0.106946,1.54653,-2.2083,0.195764,1.4328,-1.80937,0.012203,1.51481,-1.8888,0.01261,1.54389,-1.93503,0.017835,1.51876,-2.00497,0.203811,1.46639,-2.06308,0.122619,1.10808,-1.79373,-0.013068,1.13014,-1.79553,-0.029082,1.05072,-1.82356,-0.005242,0.925527,-1.82813,-0.153495,0.807859,-1.81141,-0.221923,0.775511,-1.81914,-0.205534,0.907653,-1.80234,-0.26798,0.875198,-1.80612,-0.459141,0.731606,-1.81523,-0.523695,0.839248,-1.85845,-0.507627,0.58759,-1.9114,-0.563736,0.586417,-1.8394,0.283223,1.19206,-2.12019,0.322463,1.12,-2.10213,0.157449,1.12243,-2.1063,0.198357,1.05242,-2.0897,0.316283,0.962261,-2.09049,0.406447,0.796965,-2.07659,0.29778,0.771441,-2.0979,0.317117,0.705063,-2.08835,0.403626,0.482401,-2.05447,0.354067,0.376671,-1.9908,0.609001,0.499673,-2.02789,0.582842,0.435546,-2.08417,0.111646,1.35425,-1.83967,0.121171,1.37697,-2.05349},
/*2088*/{0.260304,1.93219,-1.7672,0.297699,1.87475,-1.92322,0.21702,1.78746,-1.6473,0.187436,1.6677,-1.5611,0.301039,1.67276,-1.67893,0.377445,1.66846,-1.73135,0.197806,1.94424,-2.1393,0.293221,1.87132,-1.99333,0.088211,1.91915,-2.02935,-0.039461,1.82504,-2.1504,-0.065147,1.7326,-2.21691,0.075909,1.59744,-2.18545,0.110481,1.5411,-2.20897,0.196198,1.43093,-1.80959,0.013249,1.51157,-1.88903,0.013774,1.54119,-1.9356,0.018056,1.51654,-2.00526,0.203696,1.46312,-2.06355,0.12848,1.105,-1.7942,-0.007539,1.12466,-1.79519,-0.022606,1.04555,-1.82372,0.003161,0.921826,-1.82846,-0.148961,0.811029,-1.81033,-0.219026,0.780856,-1.81709,-0.197127,0.912381,-1.80301,-0.261136,0.882337,-1.80451,-0.457304,0.74689,-1.8131,-0.516871,0.856144,-1.86168,-0.509652,0.60172,-1.90593,-0.566023,0.606171,-1.83549,0.28156,1.18804,-2.12127,0.321445,1.11403,-2.1027,0.155298,1.1199,-2.10566,0.195728,1.0502,-2.09005,0.31347,0.957988,-2.0903,0.401819,0.793571,-2.07797,0.292408,0.767386,-2.09705,0.312407,0.70085,-2.08716,0.400476,0.478748,-2.05318,0.353203,0.373592,-1.98759,0.606539,0.497444,-2.0265,0.58041,0.432238,-2.08421,0.112315,1.35194,-1.83956,0.12138,1.37388,-2.05349},
/*2089*/{0.258569,1.93046,-1.7676,0.297014,1.87301,-1.92323,0.214122,1.78555,-1.64771,0.183872,1.66635,-1.56217,0.297655,1.66739,-1.67893,0.374016,1.66056,-1.73048,0.197153,1.94157,-2.13963,0.2935,1.86949,-1.99321,0.088033,1.91632,-2.03186,-0.037706,1.81894,-2.1524,-0.062481,1.72609,-2.21859,0.078994,1.59201,-2.18619,0.114172,1.5357,-2.2095,0.197474,1.42969,-1.80982,0.013172,1.50881,-1.89001,0.01429,1.53817,-1.93586,0.018376,1.51319,-2.00556,0.203975,1.45998,-2.064,0.136379,1.10349,-1.79426,-0.00198,1.11969,-1.79476,-0.015836,1.03957,-1.82396,0.011133,0.917873,-1.82815,-0.14346,0.814577,-1.80911,-0.213877,0.786373,-1.81494,-0.188204,0.917889,-1.80355,-0.253622,0.89005,-1.80522,-0.454979,0.761727,-1.81067,-0.509078,0.87188,-1.86519,-0.510892,0.615722,-1.90034,-0.567473,0.624949,-1.83086,0.281044,1.18371,-2.12255,0.319805,1.11045,-2.10413,0.153623,1.11807,-2.10618,0.192863,1.04714,-2.08959,0.310546,0.954248,-2.08977,0.39686,0.789059,-2.07784,0.288202,0.763079,-2.09523,0.30873,0.696711,-2.08547,0.39509,0.473696,-2.05087,0.348957,0.369909,-1.98773,0.60196,0.492257,-2.02713,0.575425,0.427296,-2.08385,0.11363,1.35006,-1.83908,0.122162,1.37054,-2.05317},
/*2090*/{0.256998,1.92829,-1.7674,0.296123,1.86965,-1.92308,0.210757,1.78295,-1.64795,0.179398,1.66392,-1.56334,0.294056,1.66171,-1.6787,0.371083,1.65258,-1.7295,0.19741,1.93898,-2.1403,0.292776,1.86742,-1.99331,0.087508,1.91392,-2.0327,-0.036138,1.81388,-2.15391,-0.059123,1.71992,-2.22086,0.083057,1.58625,-2.18791,0.118358,1.52983,-2.20982,0.198421,1.42732,-1.81052,0.01386,1.50595,-1.8896,0.014128,1.53514,-1.93556,0.018757,1.51002,-2.00574,0.204406,1.45746,-2.0645,0.141519,1.10033,-1.79309,0.004071,1.113,-1.79415,-0.008558,1.03438,-1.82397,0.019847,0.914188,-1.82803,-0.137944,0.817474,-1.80771,-0.207668,0.792174,-1.81418,-0.178517,0.922224,-1.80472,-0.244969,0.896477,-1.80561,-0.449792,0.776356,-1.81179,-0.500415,0.886481,-1.86839,-0.510939,0.629678,-1.89408,-0.568777,0.643173,-1.82584,0.28017,1.17994,-2.12321,0.316718,1.10638,-2.1055,0.152304,1.11588,-2.10501,0.190268,1.04439,-2.08918,0.308658,0.951033,-2.08959,0.392489,0.784854,-2.07849,0.283632,0.758969,-2.09405,0.303422,0.692189,-2.08404,0.39086,0.470147,-2.04976,0.342785,0.366677,-1.98259,0.597955,0.486344,-2.02658,0.569616,0.420999,-2.08248,0.114873,1.34739,-1.83923,0.122674,1.36782,-2.05335},
/*2091*/{0.25564,1.92559,-1.76732,0.295879,1.86707,-1.92314,0.2079,1.78064,-1.64812,0.174592,1.66179,-1.56519,0.290801,1.65602,-1.67835,0.368397,1.64469,-1.72791,0.19773,1.93531,-2.14119,0.292299,1.86473,-1.99331,0.086892,1.91063,-2.03438,-0.035225,1.80714,-2.15589,-0.056463,1.71267,-2.22297,0.08643,1.58049,-2.1896,0.122468,1.52404,-2.21029,0.199115,1.42492,-1.81084,0.013593,1.50308,-1.88929,0.014443,1.53167,-1.93545,0.018129,1.50623,-2.00548,0.204257,1.45453,-2.06555,0.146131,1.09688,-1.79283,0.008627,1.10803,-1.79367,-0.001519,1.02764,-1.82256,0.028564,0.910542,-1.82678,-0.130916,0.820923,-1.80622,-0.203236,0.797037,-1.8129,-0.169173,0.926637,-1.80624,-0.236081,0.903147,-1.80658,-0.443348,0.790446,-1.81067,-0.491379,0.899752,-1.87125,-0.507495,0.643245,-1.88818,-0.566304,0.660269,-1.821,0.27869,1.17596,-2.12378,0.31525,1.10182,-2.10592,0.150218,1.11333,-2.10408,0.188038,1.0419,-2.08907,0.307702,0.947402,-2.08913,0.388777,0.78018,-2.07872,0.278882,0.755146,-2.09323,0.298356,0.687525,-2.08295,0.384818,0.463737,-2.04771,0.336007,0.363638,-1.9793,0.591422,0.478794,-2.02746,0.563243,0.412709,-2.08008,0.115841,1.34468,-1.83909,0.122591,1.36453,-2.05331},
/*2092*/{0.253511,1.92254,-1.76706,0.29565,1.86446,-1.92286,0.203954,1.77766,-1.64787,0.169203,1.65997,-1.56623,0.286883,1.64945,-1.67791,0.364214,1.63542,-1.7265,0.197368,1.93167,-2.14114,0.291879,1.86188,-1.99368,0.08597,1.90736,-2.03561,-0.034069,1.79928,-2.15879,-0.052998,1.70503,-2.22597,0.090892,1.57359,-2.19086,0.127189,1.51787,-2.21069,0.199999,1.42204,-1.81071,0.014304,1.49871,-1.88954,0.013583,1.52859,-1.93532,0.017446,1.50217,-2.00561,0.203827,1.45152,-2.0664,0.151869,1.09336,-1.79244,0.014988,1.10207,-1.79322,0.005731,1.02288,-1.82233,0.036599,0.907495,-1.82579,-0.124564,0.823514,-1.80449,-0.196857,0.8031,-1.8096,-0.159046,0.930605,-1.8071,-0.227105,0.908791,-1.808,-0.439292,0.80496,-1.81062,-0.481714,0.912838,-1.87378,-0.505471,0.655819,-1.8829,-0.563886,0.677191,-1.81633,0.277582,1.17277,-2.12447,0.312973,1.09856,-2.10679,0.148667,1.11069,-2.10415,0.185725,1.03891,-2.08947,0.306162,0.944138,-2.08849,0.384019,0.774203,-2.07868,0.274164,0.750791,-2.09256,0.293034,0.683484,-2.08203,0.376192,0.458028,-2.04671,0.325469,0.359508,-1.97883,0.584928,0.470101,-2.02474,0.554753,0.402487,-2.07744,0.116904,1.34145,-1.83924,0.122725,1.3611,-2.05349},
/*2093*/{0.251139,1.91949,-1.76706,0.29552,1.86187,-1.92264,0.200274,1.77485,-1.64797,0.163028,1.65747,-1.56815,0.281269,1.64303,-1.67761,0.359792,1.62626,-1.72529,0.196548,1.92795,-2.1417,0.292034,1.85914,-1.99362,0.084924,1.9014,-2.0383,-0.031984,1.79292,-2.16248,-0.050499,1.69719,-2.22873,0.095553,1.56701,-2.19314,0.132765,1.51083,-2.21093,0.200857,1.419,-1.81115,0.015182,1.495,-1.8885,0.015058,1.5235,-1.93502,0.016878,1.49824,-2.00565,0.203658,1.44854,-2.06714,0.156285,1.0906,-1.79217,0.020258,1.09727,-1.79318,0.012439,1.01694,-1.82115,0.044126,0.903564,-1.82418,-0.117807,0.825782,-1.80388,-0.190752,0.807969,-1.80681,-0.148747,0.934691,-1.80915,-0.217592,0.914748,-1.80838,-0.43131,0.817341,-1.80941,-0.472115,0.924452,-1.8763,-0.501718,0.66813,-1.87722,-0.559113,0.692922,-1.81135,0.276424,1.16924,-2.12531,0.311622,1.09455,-2.10767,0.147114,1.10714,-2.10311,0.183552,1.03577,-2.08944,0.304328,0.939979,-2.08805,0.379751,0.769022,-2.07842,0.26938,0.746218,-2.09215,0.287539,0.678968,-2.0811,0.368022,0.453284,-2.04574,0.31617,0.354927,-1.97481,0.575218,0.46047,-2.02438,0.545288,0.393277,-2.07477,0.11862,1.33786,-1.83933,0.123195,1.35748,-2.05362},
/*2094*/{0.249927,1.91637,-1.7663,0.295243,1.85744,-1.92219,0.1965,1.77135,-1.64756,0.157851,1.65448,-1.56819,0.276643,1.63632,-1.67689,0.355563,1.61698,-1.72333,0.19634,1.92382,-2.14225,0.291503,1.85601,-1.99378,0.082786,1.89905,-2.03782,-0.031425,1.78451,-2.16581,-0.046884,1.68875,-2.23116,0.099264,1.5597,-2.19459,0.137502,1.50483,-2.21101,0.201295,1.41615,-1.81225,0.014821,1.49044,-1.88826,0.01466,1.51952,-1.93531,0.017377,1.49345,-2.00442,0.203335,1.4455,-2.06826,0.161091,1.08898,-1.79103,0.025716,1.09354,-1.79371,0.019125,1.01134,-1.82127,0.052353,0.89989,-1.82236,-0.109858,0.828893,-1.80127,-0.184227,0.812412,-1.80618,-0.137613,0.937767,-1.80986,-0.207184,0.919724,-1.80915,-0.422723,0.827426,-1.80779,-0.462526,0.935094,-1.8786,-0.49633,0.67936,-1.87273,-0.551581,0.706741,-1.80692,0.274239,1.16549,-2.12578,0.31119,1.0893,-2.10741,0.146046,1.10448,-2.10261,0.182839,1.03221,-2.08904,0.301771,0.936408,-2.08787,0.374922,0.762852,-2.07789,0.264424,0.741956,-2.09169,0.281247,0.674215,-2.08077,0.357934,0.447276,-2.04448,0.303761,0.35082,-1.97396,0.565117,0.450392,-2.02217,0.534705,0.38349,-2.07151,0.12001,1.33421,-1.83968,0.123519,1.35388,-2.05398},
/*2095*/{0.247704,1.91287,-1.76574,0.294058,1.85436,-1.92216,0.19261,1.76788,-1.64752,0.150478,1.65221,-1.57007,0.271899,1.62913,-1.67615,0.349557,1.60746,-1.72106,0.195451,1.91867,-2.14296,0.291468,1.85212,-1.99337,0.08168,1.89399,-2.03914,-0.030571,1.77623,-2.16962,-0.043348,1.68009,-2.23384,0.104817,1.55409,-2.19618,0.143098,1.49817,-2.21122,0.202458,1.41297,-1.81284,0.015204,1.48564,-1.88849,0.014438,1.51487,-1.93497,0.017077,1.48883,-2.00383,0.203619,1.44182,-2.06977,0.16568,1.08566,-1.78923,0.029098,1.0866,-1.79431,0.025097,1.00637,-1.82198,0.06045,0.896576,-1.82042,-0.102507,0.831383,-1.79818,-0.175607,0.81624,-1.80277,-0.126703,0.93971,-1.81202,-0.195874,0.924195,-1.811,-0.414575,0.839335,-1.80804,-0.45207,0.945271,-1.87999,-0.49013,0.689573,-1.86869,-0.544819,0.719613,-1.80281,0.273566,1.16186,-2.12698,0.310048,1.08652,-2.10903,0.144803,1.10078,-2.10243,0.181268,1.02838,-2.08913,0.299493,0.932378,-2.08796,0.370017,0.756872,-2.07743,0.259164,0.737958,-2.09184,0.274629,0.669857,-2.08082,0.347877,0.441712,-2.04269,0.292397,0.350833,-1.96794,0.554553,0.439985,-2.01967,0.522803,0.372293,-2.06816,0.121786,1.33033,-1.84,0.124035,1.34984,-2.05434},
/*2096*/{0.245704,1.9083,-1.76493,0.294917,1.84982,-1.92138,0.188282,1.76404,-1.64767,0.144987,1.64873,-1.56986,0.266526,1.62258,-1.67582,0.344424,1.59782,-1.71871,0.195098,1.91402,-2.14357,0.290997,1.84852,-1.99354,0.081958,1.88915,-2.04213,-0.028639,1.76739,-2.17225,-0.040365,1.67085,-2.23699,0.10927,1.54687,-2.19715,0.148768,1.49168,-2.2113,0.203442,1.40948,-1.81426,0.015007,1.48158,-1.88799,0.015378,1.51016,-1.93469,0.01589,1.48407,-2.00332,0.20291,1.43869,-2.07056,0.169327,1.08263,-1.78747,0.033374,1.08177,-1.79549,0.031081,1.00035,-1.82214,0.068334,0.89287,-1.81923,-0.094023,0.833415,-1.79693,-0.167835,0.820205,-1.80224,-0.115356,0.942263,-1.81341,-0.186329,0.928359,-1.8128,-0.405863,0.850978,-1.80709,-0.441573,0.954002,-1.88193,-0.482833,0.698841,-1.86486,-0.536433,0.731595,-1.79876,0.272451,1.15757,-2.12803,0.309038,1.08318,-2.10986,0.143384,1.09654,-2.10239,0.180439,1.02468,-2.08907,0.296877,0.926824,-2.08826,0.364931,0.750068,-2.07694,0.253196,0.733254,-2.09135,0.267668,0.665104,-2.0805,0.337797,0.437015,-2.04186,0.273614,0.35313,-1.97011,0.542447,0.429005,-2.01675,0.507802,0.361444,-2.06507,0.123255,1.32641,-1.8405,0.123849,1.34606,-2.05484},
/*2097*/{0.243953,1.90405,-1.76429,0.294547,1.84588,-1.92108,0.184952,1.75986,-1.64763,0.139985,1.64583,-1.5703,0.260397,1.6149,-1.67481,0.337708,1.58863,-1.71703,0.194612,1.90889,-2.1445,0.290357,1.84373,-1.99357,0.080294,1.88422,-2.04323,-0.02766,1.75849,-2.17641,-0.036326,1.66162,-2.23974,0.114446,1.53937,-2.19823,0.154235,1.4844,-2.21142,0.205332,1.4061,-1.8156,0.015436,1.47619,-1.88723,0.015099,1.5046,-1.93416,0.015044,1.47869,-2.0023,0.202551,1.43562,-2.07219,0.174257,1.07743,-1.7837,0.038478,1.07794,-1.79639,0.036433,0.995347,-1.82302,0.07683,0.889604,-1.81641,-0.084766,0.835516,-1.7954,-0.158958,0.822987,-1.79958,-0.1034,0.943843,-1.81504,-0.174733,0.93149,-1.81376,-0.393841,0.858323,-1.80677,-0.43162,0.962025,-1.88288,-0.474507,0.707938,-1.86094,-0.527895,0.742035,-1.79401,0.270507,1.15332,-2.12867,0.307201,1.07854,-2.11086,0.142575,1.09166,-2.10214,0.179867,1.01965,-2.08811,0.294836,0.921137,-2.08777,0.359705,0.743,-2.0764,0.247347,0.728753,-2.09153,0.259807,0.659761,-2.08003,0.322923,0.431851,-2.04103,0.25328,0.355486,-1.96889,0.528195,0.414495,-2.01305,0.488035,0.349939,-2.06233,0.126065,1.32211,-1.84117,0.124332,1.34208,-2.05547},
/*2098*/{0.241501,1.89937,-1.76381,0.295021,1.84068,-1.92114,0.180599,1.75526,-1.64759,0.132124,1.64204,-1.57039,0.254541,1.60718,-1.67409,0.33243,1.57888,-1.7148,0.195275,1.90362,-2.1454,0.290517,1.83959,-1.9938,0.07933,1.87726,-2.04493,-0.027019,1.7487,-2.18071,-0.03214,1.65181,-2.24242,0.120382,1.53185,-2.19891,0.16112,1.47791,-2.21175,0.205235,1.40196,-1.81678,0.016343,1.47089,-1.88689,0.01457,1.50034,-1.93432,0.014022,1.47338,-2.00187,0.202206,1.4315,-2.07357,0.178402,1.07415,-1.78159,0.041477,1.07094,-1.79785,0.043232,0.988873,-1.82208,0.085701,0.885498,-1.81418,-0.07462,0.835592,-1.79258,-0.150371,0.825665,-1.79706,-0.091162,0.944981,-1.81587,-0.162658,0.934289,-1.815,-0.384475,0.865976,-1.80588,-0.420592,0.969156,-1.88371,-0.465024,0.715691,-1.85679,-0.51726,0.750667,-1.79074,0.269026,1.14908,-2.12955,0.306288,1.0744,-2.11174,0.141211,1.08711,-2.10284,0.179314,1.01533,-2.08801,0.291498,0.914703,-2.08789,0.352455,0.73557,-2.07539,0.24099,0.723663,-2.09123,0.251932,0.654729,-2.07964,0.311019,0.428432,-2.03905,0.23398,0.356477,-1.96908,0.515069,0.397149,-2.00986,0.470046,0.338665,-2.06108,0.126926,1.31756,-1.84184,0.123937,1.33764,-2.05612},
/*2099*/{0.240463,1.89472,-1.7627,0.294644,1.83601,-1.91959,0.176736,1.75062,-1.64734,0.126266,1.6385,-1.57127,0.248291,1.60008,-1.67318,0.325479,1.56952,-1.71243,0.194218,1.89816,-2.14636,0.290309,1.83483,-1.99349,0.077889,1.87122,-2.04586,-0.023181,1.73892,-2.18484,-0.0283,1.64204,-2.24563,0.125611,1.52493,-2.19945,0.167117,1.4707,-2.21168,0.206308,1.39767,-1.81843,0.016056,1.46562,-1.8864,0.014697,1.49458,-1.93501,0.014271,1.46813,-2.00164,0.20204,1.42739,-2.07551,0.182223,1.07107,-1.77937,0.047554,1.06667,-1.79867,0.049674,0.983352,-1.82223,0.095281,0.881682,-1.81081,-0.064682,0.836572,-1.79089,-0.13994,0.828692,-1.79517,-0.079439,0.945057,-1.81788,-0.150681,0.936226,-1.81576,-0.371436,0.873179,-1.80519,-0.409645,0.975563,-1.88471,-0.455163,0.72234,-1.85336,-0.50728,0.759702,-1.78876,0.267202,1.14499,-2.13121,0.305057,1.07001,-2.11344,0.139887,1.08196,-2.10254,0.178124,1.01062,-2.088,0.288779,0.90879,-2.08802,0.346909,0.728335,-2.07408,0.234697,0.718684,-2.09072,0.243387,0.648742,-2.07867,0.295038,0.42361,-2.0332,0.212881,0.354955,-1.96744,0.497301,0.387545,-1.99783,0.448818,0.341485,-2.0598,0.128581,1.31271,-1.84297,0.124188,1.33307,-2.05719},
/*2100*/{0.238958,1.88986,-1.76197,0.29412,1.82995,-1.9185,0.172962,1.74611,-1.6471,0.119802,1.6356,-1.57197,0.241562,1.59345,-1.67195,0.318343,1.56083,-1.71049,0.194764,1.89258,-2.14723,0.290764,1.83008,-1.99313,0.0769,1.86439,-2.04789,-0.023112,1.72962,-2.18934,-0.023524,1.63216,-2.24847,0.131742,1.51771,-2.20044,0.174234,1.46386,-2.212,0.207051,1.39344,-1.81986,0.015449,1.45988,-1.88574,0.014064,1.48902,-1.93562,0.012775,1.46344,-2.00098,0.201018,1.4228,-2.0777,0.18616,1.06802,-1.77554,0.050466,1.05894,-1.79974,0.055879,0.976671,-1.8218,0.103659,0.879161,-1.80851,-0.053741,0.836612,-1.78856,-0.12907,0.829963,-1.79345,-0.065839,0.944588,-1.81895,-0.13733,0.93719,-1.81644,-0.360754,0.878335,-1.80459,-0.39794,0.980457,-1.88478,-0.443973,0.727902,-1.84981,-0.495333,0.765655,-1.78442,0.264717,1.14071,-2.13339,0.302622,1.06548,-2.116,0.137646,1.07829,-2.10231,0.17599,1.00717,-2.08862,0.286681,0.903221,-2.08934,0.340009,0.721043,-2.07049,0.227607,0.714348,-2.08982,0.235502,0.645491,-2.07796,0.275195,0.423078,-2.02802,0.190135,0.354742,-1.96669,0.472175,0.386522,-1.99907,0.425753,0.341452,-2.06067,0.129579,1.30791,-1.84394,0.123245,1.32834,-2.05811},
/*2101*/{0.237697,1.88417,-1.76079,0.295083,1.82525,-1.91815,0.168404,1.74137,-1.64786,0.111999,1.63145,-1.5724,0.23509,1.58639,-1.67007,0.310859,1.55221,-1.70761,0.194846,1.88738,-2.148,0.291749,1.82472,-1.99263,0.075339,1.85844,-2.04897,-0.0202,1.71881,-2.19363,-0.018306,1.622,-2.25098,0.138194,1.50994,-2.2006,0.181347,1.45747,-2.21221,0.20727,1.3888,-1.82185,0.014897,1.45425,-1.8853,0.012692,1.48296,-1.93497,0.010169,1.45919,-2.00054,0.199916,1.41849,-2.07911,0.189155,1.06339,-1.77469,0.055817,1.05485,-1.80038,0.063312,0.970764,-1.82274,0.11311,0.875338,-1.80638,-0.043118,0.836874,-1.78585,-0.117812,0.831476,-1.79172,-0.052542,0.94458,-1.81909,-0.124592,0.938955,-1.81689,-0.347418,0.881157,-1.80313,-0.385932,0.984998,-1.88548,-0.4318,0.732752,-1.84708,-0.482408,0.771802,-1.78075,0.261135,1.13698,-2.13699,0.298822,1.06241,-2.12025,0.134568,1.07541,-2.10251,0.172697,1.00433,-2.08775,0.281318,0.897373,-2.08989,0.333105,0.714623,-2.06565,0.222644,0.711551,-2.08882,0.225003,0.642589,-2.07434,0.252772,0.424634,-2.02312,0.165439,0.354711,-1.96254,0.446386,0.387319,-1.99621,0.400831,0.341881,-2.0596,0.13007,1.30276,-1.8452,0.121821,1.32399,-2.05923},
/*2102*/{0.236161,1.87879,-1.7602,0.295279,1.82012,-1.91677,0.165477,1.73674,-1.648,0.105076,1.62893,-1.57349,0.228262,1.5801,-1.66883,0.303427,1.54409,-1.70514,0.195692,1.88198,-2.14925,0.29132,1.81973,-1.99277,0.074854,1.85128,-2.05066,-0.017263,1.70875,-2.19875,-0.013361,1.61172,-2.25324,0.145263,1.50298,-2.20157,0.188664,1.45061,-2.21214,0.207555,1.38397,-1.82296,0.013843,1.44944,-1.88559,0.010932,1.47733,-1.93483,0.007675,1.4549,-2.00028,0.197592,1.41458,-2.08043,0.193056,1.06082,-1.77251,0.060555,1.0476,-1.80038,0.069434,0.963915,-1.82316,0.122433,0.872376,-1.8031,-0.031943,0.836024,-1.78551,-0.106239,0.831466,-1.7895,-0.039151,0.943253,-1.81962,-0.110439,0.939384,-1.81718,-0.339761,0.889489,-1.80536,-0.373834,0.987795,-1.8861,-0.420314,0.736232,-1.8442,-0.46868,0.776434,-1.77819,0.257547,1.13389,-2.14202,0.295306,1.05901,-2.12498,0.130744,1.07463,-2.1023,0.168978,1.00333,-2.08745,0.27487,0.892144,-2.09051,0.327692,0.710793,-2.06096,0.217012,0.713265,-2.08525,0.216095,0.645194,-2.06931,0.227161,0.426222,-2.0187,0.144007,0.356191,-1.9643,0.424593,0.383019,-1.99405,0.378163,0.341966,-2.05804,0.129892,1.29792,-1.84641,0.119926,1.31978,-2.0603},
/*2103*/{0.235403,1.8738,-1.75875,0.296617,1.81428,-1.91527,0.16149,1.73197,-1.64816,0.098071,1.62602,-1.57378,0.220737,1.57386,-1.66693,0.295697,1.5367,-1.70261,0.19639,1.87716,-2.15105,0.293236,1.81527,-1.99218,0.074949,1.84801,-2.0501,-0.012961,1.6982,-2.20343,-0.006789,1.60155,-2.25587,0.152075,1.49611,-2.20197,0.195565,1.44428,-2.21247,0.206933,1.3791,-1.82523,0.01202,1.44445,-1.88429,0.00913,1.47159,-1.93352,0.004825,1.45016,-1.99993,0.195108,1.41219,-2.08121,0.19872,1.05675,-1.76977,0.06572,1.04101,-1.80056,0.076113,0.957869,-1.82351,0.131812,0.868957,-1.8012,-0.019128,0.834744,-1.78349,-0.094597,0.830925,-1.78907,-0.025844,0.942011,-1.81896,-0.098184,0.938642,-1.81763,-0.326191,0.891539,-1.80428,-0.36186,0.990183,-1.88606,-0.406433,0.738506,-1.84147,-0.45505,0.779403,-1.77621,0.253813,1.13098,-2.14664,0.291509,1.05619,-2.12879,0.128631,1.07412,-2.10099,0.166346,1.00231,-2.08624,0.269839,0.890318,-2.09054,0.319248,0.709611,-2.05741,0.209078,0.718378,-2.08168,0.20503,0.650097,-2.06634,0.208809,0.428491,-2.01643,0.120086,0.355553,-1.96046,0.402589,0.382605,-1.99262,0.355508,0.34253,-2.05701,0.129825,1.29275,-1.84813,0.117888,1.3166,-2.06171},
/*2104*/{0.234488,1.86823,-1.75785,0.297568,1.80878,-1.91503,0.157697,1.72752,-1.64856,0.091605,1.62372,-1.57493,0.213603,1.56836,-1.66622,0.28764,1.52976,-1.69982,0.196713,1.8722,-2.15206,0.293519,1.80965,-1.99197,0.075394,1.84528,-2.04831,-0.008218,1.6885,-2.21075,0.000451,1.5911,-2.25762,0.159864,1.48968,-2.20275,0.203988,1.43874,-2.21251,0.20637,1.37489,-1.82731,0.009701,1.4397,-1.88482,0.007328,1.46665,-1.93247,0.001883,1.4472,-2.00034,0.192669,1.41013,-2.08238,0.203402,1.05458,-1.76861,0.071564,1.03431,-1.80147,0.082933,0.951506,-1.82429,0.143477,0.86582,-1.79801,-0.006292,0.833365,-1.78312,-0.082679,0.83087,-1.7863,-0.011891,0.940191,-1.817,-0.083268,0.937831,-1.81475,-0.314485,0.895955,-1.803,-0.349069,0.991357,-1.88581,-0.392003,0.740812,-1.83906,-0.441538,0.781597,-1.77457,0.25066,1.1285,-2.1497,0.289098,1.05409,-2.13031,0.126184,1.07273,-2.10052,0.164627,1.00162,-2.08507,0.267964,0.890295,-2.0905,0.310184,0.708743,-2.05633,0.199515,0.723304,-2.07989,0.191467,0.65451,-2.06486,0.192292,0.430216,-2.01316,0.097727,0.358103,-1.95915,0.380942,0.381598,-1.99034,0.332251,0.342619,-2.05627,0.129148,1.28822,-1.85047,0.115832,1.31422,-2.06371}
};


static int getNumFrames() {return NFrames;}
static int getNumObservations() {return NObservations;}
static Real getFrameTime(int i) {return frameTimes[i];}
static const char* const* getObservationOrder() {return observationOrder;}
static ArrayViewConst_<Vec3> getFrame(int i) {
    const Vec3* o = (const Vec3*)observations;
    return ArrayViewConst_<Vec3>(o+i*getNumObservations(), o+(i+1)*getNumObservations());
}

